(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 14.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[    632323,      11884]
NotebookOptionsPosition[    627217,      11793]
NotebookOutlinePosition[    627614,      11809]
CellTagsIndexPosition[    627571,      11806]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Multipole moments", "Chapter",
 CellChangeTimes->{{3.920655244157207*^9, 
  3.920655246636298*^9}},ExpressionUUID->"0f5958a7-fc2d-421d-b6e9-\
4f7fb65b1ae8"],

Cell[CellGroupData[{

Cell["Dipole-dipole orientation average", "Section",
 CellChangeTimes->{{3.920042660745262*^9, 3.920042663001129*^9}, {
  3.920045933834403*^9, 
  3.920045939309576*^9}},ExpressionUUID->"10e6cfc1-eb30-44e5-9003-\
313493f96754"],

Cell["Dipole-dipole energy", "Text",
 CellChangeTimes->{{3.920044619977764*^9, 
  3.9200446254635553`*^9}},ExpressionUUID->"7fd73f06-c299-411e-8ae9-\
a8e15f288fd1"],

Cell[BoxData[
 RowBox[{
  RowBox[{"u\[Mu]\[Mu]", "[", 
   RowBox[{"r_List", ",", "\[Mu]1_List", ",", "\[Mu]2_List"}], "]"}], ":=", 
  RowBox[{"With", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"rhat", "=", 
      FractionBox["r", 
       RowBox[{"Norm", "[", "r", "]"}]]}], "}"}], ",", "\[IndentingNewLine]", 
    
    RowBox[{
     FractionBox[
      RowBox[{"-", "1"}], 
      SuperscriptBox[
       RowBox[{"Norm", "[", "r", "]"}], "3"]], 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"3", 
        RowBox[{"(", 
         RowBox[{"\[Mu]1", ".", "rhat"}], ")"}], 
        RowBox[{"(", 
         RowBox[{"\[Mu]2", ".", "rhat"}], ")"}]}], "-", 
       RowBox[{"\[Mu]1", ".", "\[Mu]2"}]}], ")"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.9200426967371483`*^9, 3.92004294182725*^9}, {
  3.920044396887742*^9, 3.9200443977841883`*^9}, {3.9200445278866*^9, 
  3.920044550714963*^9}, {3.920046211523576*^9, 3.920046218493442*^9}},
 CellLabel->
  "In[1675]:=",ExpressionUUID->"a1e08532-6166-4bf6-9a0e-8cb7528a07d9"],

Cell["\<\
Dipole energy for one dipole of magnitude \[Mu]1 at origin, pointing in +x \
direction, second dipole of magnitude \[LineSeparator]\[Mu]2 a distance r \
along the x-axis, with orientation theta with respect to x axis\
\>", "Text",
 CellChangeTimes->{{3.92004463177074*^9, 3.920044681941495*^9}, {
   3.9200447712442102`*^9, 3.920044786515231*^9}, 
   3.9200461909120407`*^9},ExpressionUUID->"3202917e-ea26-48c6-9349-\
b99149d0f2fe"],

Cell[BoxData[
 RowBox[{
  RowBox[{"u12", "[", 
   RowBox[{"r_", ",", "theta_", ",", "\[Mu]1_", ",", "\[Mu]2_"}], "]"}], ":=", 
  RowBox[{"u\[Mu]\[Mu]", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"r", ",", "0", ",", "0"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"\[Mu]1", ",", "0", ",", "0"}], "}"}], ",", 
    RowBox[{"\[Mu]2", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Cos", "[", "theta", "]"}], ",", 
       RowBox[{"Sin", "[", "theta", "]"}], ",", "0"}], "}"}]}]}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.9200447024239063`*^9, 3.920044765382059*^9}, {
  3.92004479988783*^9, 3.920044825938983*^9}},
 CellLabel->
  "In[1654]:=",ExpressionUUID->"3d240324-f64a-4630-8ff5-b60b6a769a2c"],

Cell[BoxData[
 RowBox[{
  RowBox[{"$Assumptions", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"kT", ">", "0"}], ",", 
     RowBox[{"r", ">", "0"}], ",", 
     RowBox[{"\[Mu]1", ">", "0"}], ",", 
     RowBox[{"\[Mu]2", ">", "0"}]}], "}"}]}], ";"}]], "Input",
 CellChangeTimes->{3.920045993943575*^9},
 CellLabel->
  "In[1667]:=",ExpressionUUID->"20bf5969-7ee5-405e-8d1d-ee394b11e73d"],

Cell["Unweighted average", "Text",
 CellChangeTimes->{{3.920044885131956*^9, 
  3.9200448888677387`*^9}},ExpressionUUID->"5da7ad11-60be-4c88-9274-\
f41c0a3f168d"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Integrate", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"u\[Mu]\[Mu]", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"x", ",", "0", ",", "0"}], "}"}], ",", 
      RowBox[{"\[Mu]1", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Cos", "[", "theta", "]"}], ",", 
         RowBox[{"Sin", "[", "theta", "]"}], ",", "0"}], "}"}]}], ",", 
      RowBox[{"\[Mu]2", 
       RowBox[{"{", 
        RowBox[{"1", ",", "0", ",", "0"}], "}"}]}]}], "]"}], 
    RowBox[{"Sin", "[", "theta", "]"}]}], ",", 
   RowBox[{"{", 
    RowBox[{"theta", ",", "0", ",", "Pi"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.9200429544658527`*^9, 3.9200430278018217`*^9}, {
  3.9200430603417177`*^9, 3.9200430683552027`*^9}, {3.92004375710509*^9, 
  3.9200437679687157`*^9}},
 CellLabel->
  "In[1668]:=",ExpressionUUID->"f86575bd-dcf8-450c-9868-888bcca57b74"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{{3.9200430150456467`*^9, 3.920043028480184*^9}, 
   3.920043069971986*^9, 3.920043802189399*^9, 3.920044407984825*^9, 
   3.920044553331334*^9, 3.920046001477543*^9},
 CellLabel->
  "Out[1668]=",ExpressionUUID->"9e645bf0-9c2a-4616-802a-95af5838dbfb"]
}, Open  ]],

Cell["Boltzmann-weighted average", "Text",
 CellChangeTimes->{{3.920044893592846*^9, 
  3.9200448987810087`*^9}},ExpressionUUID->"d8925abf-bec7-49c6-86a4-\
d3d783ef5323"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"boltzAvg", "=", 
   FractionBox[
    RowBox[{"Integrate", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"u12", "[", 
        RowBox[{"r", ",", "theta", ",", "\[Mu]1", ",", "\[Mu]2"}], "]"}], 
       RowBox[{"Exp", "[", 
        FractionBox[
         RowBox[{"-", 
          RowBox[{"u12", "[", 
           RowBox[{"r", ",", "theta", ",", "\[Mu]1", ",", "\[Mu]2"}], "]"}]}],
          "kT"], "]"}], 
       RowBox[{"Sin", "[", "theta", "]"}]}], ",", 
      RowBox[{"{", 
       RowBox[{"theta", ",", "0", ",", "Pi"}], "}"}]}], "]"}], 
    RowBox[{"Integrate", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"Exp", "[", 
        FractionBox[
         RowBox[{"-", 
          RowBox[{"u12", "[", 
           RowBox[{"r", ",", "theta", ",", "\[Mu]1", ",", "\[Mu]2"}], "]"}]}],
          "kT"], "]"}], 
       RowBox[{"Sin", "[", "theta", "]"}]}], ",", 
      RowBox[{"{", 
       RowBox[{"theta", ",", "0", ",", "Pi"}], "}"}]}], "]"}]]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Series", "[", 
  RowBox[{"boltzAvg", ",", 
   RowBox[{"{", 
    RowBox[{"r", ",", "Infinity", ",", "8"}], "}"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.920043078782837*^9, 3.920043117406069*^9}, {
   3.920043233163576*^9, 3.920043252037424*^9}, {3.920043301892688*^9, 
   3.920043314019911*^9}, {3.9200433597438297`*^9, 3.920043361841877*^9}, {
   3.920043392024332*^9, 3.92004346397059*^9}, 3.920043539085701*^9, {
   3.9200438115483837`*^9, 3.920043904362062*^9}, {3.92004483795537*^9, 
   3.92004487722504*^9}, {3.92004492058502*^9, 3.920044930390388*^9}, {
   3.920044963131899*^9, 3.920045095274897*^9}, {3.9200451334038982`*^9, 
   3.9200451358228827`*^9}, {3.9200459599011374`*^9, 3.920046006721386*^9}, {
   3.920046052144684*^9, 3.920046073743762*^9}},
 CellLabel->
  "In[1673]:=",ExpressionUUID->"071cf76b-b020-4cb7-a040-d0be07e6df10"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   RowBox[{"-", 
    FractionBox[
     RowBox[{"4", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["\[Mu]1", "2"], " ", 
        SuperscriptBox["\[Mu]2", "2"]}], ")"}]}], 
     RowBox[{"3", " ", "kT", " ", 
      SuperscriptBox["r", "6"]}]]}], "+", 
   InterpretationBox[
    SuperscriptBox[
     RowBox[{"O", "[", 
      FractionBox["1", "r"], "]"}], "9"],
    SeriesData[$CellContext`r, 
     DirectedInfinity[1], {}, 6, 9, 1],
    Editable->False]}],
  SeriesData[$CellContext`r, 
   DirectedInfinity[1], {
   Rational[-4, 
      3] $CellContext`kT^(-1) $CellContext`\[Mu]1^2 $CellContext`\[Mu]2^2}, 6,
    9, 1],
  Editable->False]], "Output",
 CellChangeTimes->{
  3.920043109028357*^9, {3.920043251496374*^9, 3.920043271615686*^9}, 
   3.920043326736063*^9, 3.9200433723955717`*^9, 3.9200435274666862`*^9, 
   3.920043579061412*^9, {3.920043829568417*^9, 3.920043848233683*^9}, {
   3.920043881927679*^9, 3.9200439093565407`*^9}, 3.920044421163375*^9, 
   3.920044559264161*^9, 3.920045108644103*^9, 3.920045140632679*^9, 
   3.920045971893784*^9, 3.920046004204101*^9, 3.920046076057693*^9},
 CellLabel->
  "Out[1674]=",ExpressionUUID->"c62aa57f-885c-482b-be2f-c6b5a8eb23f2"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Vector electric fields", "Section",
 CellChangeTimes->{{3.9203800282557297`*^9, 
  3.9203800384553967`*^9}},ExpressionUUID->"aa8d7999-7444-4782-ac2f-\
eee1a0b736e8"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"qPhi", "[", 
   RowBox[{"x_", ",", "y_"}], "]"}], ":=", 
  FractionBox["1", 
   RowBox[{"Sqrt", "[", 
    RowBox[{
     SuperscriptBox["x", "2"], "+", 
     SuperscriptBox["y", "2"]}], "]"}]]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"qfield", "[", 
   RowBox[{"x_", ",", "y_"}], "]"}], ":=", 
  RowBox[{"qfield", "[", 
   RowBox[{"x", ",", "y", ",", "0", ",", "1"}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"qfield", "[", 
   RowBox[{"x_", ",", "y_", ",", "x0_", ",", "sign_"}], "]"}], ":=", 
  RowBox[{"With", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"r", "=", 
      RowBox[{"Sqrt", "[", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"x", "-", "x0"}], ")"}], "2"], "+", 
        SuperscriptBox["y", "2"]}], "]"}]}], "}"}], ",", 
    RowBox[{"sign", 
     FractionBox[
      RowBox[{"{", 
       RowBox[{
        RowBox[{"x", "-", "x0"}], ",", "y"}], "}"}], 
      SuperscriptBox["r", "3"]]}]}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Mu]field", "[", 
   RowBox[{"x_", ",", "y_"}], "]"}], ":=", 
  RowBox[{"With", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"r", "=", 
       RowBox[{"Sqrt", "[", 
        RowBox[{
         SuperscriptBox["x", "2"], "+", 
         SuperscriptBox["y", "2"]}], "]"}]}], ",", 
      RowBox[{"rhat", "=", 
       FractionBox[
        RowBox[{"{", 
         RowBox[{"x", ",", "y"}], "}"}], 
        RowBox[{"Sqrt", "[", 
         RowBox[{
          SuperscriptBox["x", "2"], "+", 
          SuperscriptBox["y", "2"]}], "]"}]]}], ",", 
      RowBox[{"mu", "=", 
       RowBox[{"{", 
        RowBox[{"1", ",", "0"}], "}"}]}]}], "}"}], ",", 
    FractionBox[
     RowBox[{
      RowBox[{"3", 
       RowBox[{"(", 
        RowBox[{"mu", ".", "rhat"}], ")"}], "rhat"}], "-", "mu"}], 
     SuperscriptBox["r", "3"]]}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Qfield", "[", 
   RowBox[{"x_", ",", "y_"}], "]"}], ":=", 
  RowBox[{"With", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"r", "=", 
       RowBox[{"Sqrt", "[", 
        RowBox[{
         SuperscriptBox["x", "2"], "+", 
         SuperscriptBox["y", "2"]}], "]"}]}], ",", 
      RowBox[{"rhat", "=", 
       FractionBox[
        RowBox[{"{", 
         RowBox[{"x", ",", "y"}], "}"}], 
        RowBox[{"Sqrt", "[", 
         RowBox[{
          SuperscriptBox["x", "2"], "+", 
          SuperscriptBox["y", "2"]}], "]"}]]}], ",", 
      RowBox[{"that", "=", 
       FractionBox[
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "y"}], ",", "x"}], "}"}], 
        RowBox[{"Sqrt", "[", 
         RowBox[{
          SuperscriptBox["x", "2"], "+", 
          SuperscriptBox["y", "2"]}], "]"}]]}], ",", 
      RowBox[{"s", "=", 
       RowBox[{"{", 
        RowBox[{"1", ",", "0"}], "}"}]}]}], "}"}], ",", 
    RowBox[{
     FractionBox["3", 
      SuperscriptBox["r", "4"]], 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"3", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"s", ".", "rhat"}], ")"}], "2"]}], "-", "1"}], ")"}], 
        "rhat"}], "-", 
       RowBox[{"2", 
        RowBox[{"(", 
         RowBox[{"s", ".", "rhat"}], ")"}], 
        RowBox[{"(", 
         RowBox[{"s", ".", "that"}], ")"}], "that"}]}], ")"}]}]}], 
   "]"}]}]}], "Input",
 CellChangeTimes->{{3.920380050389554*^9, 3.9203800578978786`*^9}, {
  3.920380092077559*^9, 3.920380143642786*^9}, {3.920384130403224*^9, 
  3.920384286944353*^9}, {3.920385496832758*^9, 3.920385673029744*^9}, {
  3.920971575012385*^9, 3.920971617620344*^9}, {3.921006472282048*^9, 
  3.921006493805522*^9}},
 CellLabel->
  "In[2940]:=",ExpressionUUID->"07a2df1f-6ee9-43ad-a9b0-99e569867408"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"plot1", "=", 
   RowBox[{"VectorPlot", "[", 
    RowBox[{
     RowBox[{"qfield", "[", 
      RowBox[{"x", ",", "y", ",", ".5", ",", 
       RowBox[{"+", "1"}]}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", 
       RowBox[{"-", "3"}], ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", 
       RowBox[{"-", "3"}], ",", "3"}], "}"}], ",", 
     RowBox[{"VectorScaling", "->", "Automatic"}], ",", 
     RowBox[{"VectorSizes", "->", "1.5"}], ",", 
     RowBox[{"LabelStyle", "->", 
      RowBox[{"Opacity", "[", "0", "]"}]}], ",", 
     RowBox[{"VectorStyle", "->", "Red"}], ",", 
     RowBox[{"VectorColorFunction", "->", "None"}], ",", 
     RowBox[{"Prolog", "->", 
      RowBox[{"{", 
       RowBox[{"Red", ",", 
        RowBox[{"Disk", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0.5", ",", "0"}], "}"}], ",", ".2"}], "]"}]}], "}"}]}]}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"plot2", "=", 
   RowBox[{"VectorPlot", "[", 
    RowBox[{
     RowBox[{"qfield", "[", 
      RowBox[{"x", ",", "y", ",", "0", ",", 
       RowBox[{"-", "1"}]}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", 
       RowBox[{"-", "3"}], ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", 
       RowBox[{"-", "3"}], ",", "3"}], "}"}], ",", 
     RowBox[{"VectorScaling", "->", "Automatic"}], ",", 
     RowBox[{"VectorSizes", "->", "1.5"}], ",", 
     RowBox[{"LabelStyle", "->", 
      RowBox[{"Opacity", "[", "0", "]"}]}], ",", 
     RowBox[{"VectorStyle", "->", "Blue"}], ",", 
     RowBox[{"VectorColorFunction", "->", "None"}], ",", 
     RowBox[{"Epilog", "->", 
      RowBox[{"{", 
       RowBox[{"Blue", ",", 
        RowBox[{"Disk", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "0"}], "}"}], ",", ".2"}], "]"}]}], "}"}]}]}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"plotsum", "=", 
   RowBox[{"VectorPlot", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"qfield", "[", 
       RowBox[{"x", ",", "y", ",", "0.5", ",", "1"}], "]"}], "+", 
      RowBox[{"qfield", "[", 
       RowBox[{"x", ",", "y", ",", "0", ",", 
        RowBox[{"-", "1"}]}], "]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", 
       RowBox[{"-", "3"}], ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", 
       RowBox[{"-", "3"}], ",", "3"}], "}"}], ",", 
     RowBox[{"VectorScaling", "->", "Automatic"}], ",", 
     RowBox[{"VectorSizes", "->", "1.5"}], ",", 
     RowBox[{"LabelStyle", "->", 
      RowBox[{"Opacity", "[", "0", "]"}]}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"plotOverlay", "=", 
   RowBox[{"Show", "[", 
    RowBox[{"plot1", ",", "plot2", ",", 
     RowBox[{"Epilog", "->", 
      RowBox[{"{", 
       RowBox[{"Blue", ",", 
        RowBox[{"Disk", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "0.5"}], ",", "0"}], "}"}], ",", ".2"}], "]"}]}], 
       "}"}]}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"GraphicsRow", "[", 
  RowBox[{"{", 
   RowBox[{"plot1", ",", "plot2", ",", "plotOverlay", ",", "plotsum"}], "}"}],
   "]"}], "\[IndentingNewLine]"}], "Input",
 CellChangeTimes->{{3.920380147646849*^9, 3.9203801660358887`*^9}, {
  3.92038342769892*^9, 3.920383429047058*^9}, {3.920383593304151*^9, 
  3.920383641065705*^9}, {3.920383689487624*^9, 3.920383694412805*^9}, {
  3.920383806580357*^9, 3.920383828695483*^9}, {3.92097170827493*^9, 
  3.920971714451085*^9}, {3.920972050937051*^9, 3.920972082300343*^9}, {
  3.920972115635664*^9, 3.920972227238924*^9}, {3.920972342040743*^9, 
  3.9209723837615957`*^9}, {3.920972555440214*^9, 3.920972630955882*^9}, {
  3.92097266334824*^9, 3.9209727439959917`*^9}, {3.920972785842059*^9, 
  3.920972803643167*^9}, {3.920972868398546*^9, 3.920972884151588*^9}, {
  3.920993985641535*^9, 3.920993989560535*^9}, {3.9210060978848133`*^9, 
  3.9210061111521263`*^9}, {3.921006163860224*^9, 3.921006166183724*^9}, {
  3.921006878285554*^9, 3.921006907196287*^9}},
 CellLabel->
  "In[2946]:=",ExpressionUUID->"4f25bcd4-25ed-49b8-963b-31bb69967540"],

Cell[BoxData[
 GraphicsBox[{{}, {InsetBox[
     GraphicsBox[{{}, 
       {RGBColor[1, 0, 0], 
        {Arrowheads[{{0.02343750000000001, 1.}}], 
         ArrowBox[{{-2.7070547088739305`, -2.829794450139847}, \
{-2.9179452911260695`, -3.015877025405114}}]}, 
        {Arrowheads[{{0.023876743512748183`, 1.}}], 
         ArrowBox[{{-2.3359463912995198`, -2.8217890937522165`}, \
{-2.5390536087004802`, -3.0238823817927445`}}]}, 
        {Arrowheads[{{0.024345060541474145`, 1.}}], 
         ArrowBox[{{-1.9662052226612605`, -2.813000102039208}, \
{-2.1587947773387395`, -3.032671373505753}}]}, 
        {Arrowheads[{{0.024834181220247744`, 1.}}], 
         ArrowBox[{{-1.598217852164272, -2.803541085228777}, \
{-1.776782147835728, -3.042130390316184}}]}, 
        {Arrowheads[{{0.02532911879301356, 1.}}], 
         ArrowBox[{{-1.2324075841332183`, -2.793678785816638}, \
{-1.3925924158667817`, -3.051992689728323}}]}, 
        {Arrowheads[{{0.025806336132554855`, 1.}}], 
         ArrowBox[{{-0.8691654162470059, -2.7838925979331357`}, \
{-1.005834583752994, -3.0617788776118253`}}]}, 
        {Arrowheads[{{0.026233280311868713`, 1.}}], 
         ArrowBox[{{-0.508725367452308, -2.7749068739645018`}, \
{-0.616274632547692, -3.0707646015804593`}}]}, 
        {Arrowheads[{{0.026570986300117966`, 1.}}], 
         ArrowBox[{{-0.150996567103944, -2.7676451367252484`}, \
{-0.224003432896056, -3.0780263388197127`}}]}, 
        {Arrowheads[{{0.026781009540386546`, 1.}}], 
         ArrowBox[{{0.20458266552630905`, -2.7630602968230087`}, {
          0.17041733447369095`, -3.0826111787219523`}}]}, 
        {Arrowheads[{{0.026835663497094042`, 1.}}], 
         ArrowBox[{{0.5590577696534635, -2.761858555780451}, {
          0.5659422303465365, -3.08381291976451}}]}, 
        {Arrowheads[{{0.026727237900439158`, 1.}}], 
         ArrowBox[{{0.9137607239768434, -2.7642391564025894`}, {
          0.9612392760231566, -3.0814323191423716`}}]}, 
        {Arrowheads[{{0.026470821879959444`, 1.}}], 
         ArrowBox[{{1.2699622626519018`, -2.769813191403249}, {
          1.3550377373480982`, -3.075858284141712}}]}, 
        {Arrowheads[{{0.026098881599004795`, 1.}}], 
         ArrowBox[{{1.6285577056842186`, -2.7777589846840853`}, {
          1.7464422943157814`, -3.0679124908608757`}}]}, 
        {Arrowheads[{{0.025651067989640636`, 1.}}], 
         ArrowBox[{{1.9899413735770328`, -2.787106492081133}, {
          2.135058626422967, -3.058564983463828}}]}, 
        {Arrowheads[{{0.025164755772881964`, 1.}}], 
         ArrowBox[{{2.354076520034966, -2.796986381069952}, {
          2.520923479965034, -3.048685094475009}}]}, 
        {Arrowheads[{{0.024669593461185278`, 1.}}], 
         ArrowBox[{{2.720659531402359, -2.806755909106121}, {
          2.904340468597641, -3.03891556643884}}]}, 
        {Arrowheads[{{0.02401619735703311, 1.}}], 
         ArrowBox[{{-2.5141953441486162`, -2.505954950401421}, \
{-2.7358046558513838`, -2.690197472305211}}]}, 
        {Arrowheads[{{0.024552573484838417`, 1.}}], 
         ArrowBox[{{-2.142916338164377, -2.4969083879206853`}, \
{-2.357083661835623, -2.6992440347859468`}}]}, 
        {Arrowheads[{{0.02513300744592264, 1.}}], 
         ArrowBox[{{-1.7732550839975794`, -2.4867747183461453`}, \
{-1.9767449160024206`, -2.7093777043604867`}}]}, 
        {Arrowheads[{{0.02574715915044841, 1.}}], 
         ArrowBox[{{-1.4057662809463338`, -2.475663019462975}, \
{-1.5942337190536662`, -2.720489403243657}}]}, 
        {Arrowheads[{{0.02637367257076846, 1.}}], 
         ArrowBox[{{-1.0410872456091025`, -2.4639151461150854`}, \
{-1.2089127543908975`, -2.7322372765915466`}}]}, 
        {Arrowheads[{{0.026976320987290584`, 1.}}], 
         ArrowBox[{{-0.6798256893925128, -2.452221645723371}, \
{-0.8201743106074872, -2.743930776983261}}]}, 
        {Arrowheads[{{0.027502818281410435`, 1.}}], 
         ArrowBox[{{-0.32233113596814345`, -2.441690242530266}, \
{-0.42766886403185655`, -2.754462180176366}}]}, 
        {Arrowheads[{{0.027890418831252452`, 1.}}], 
         ArrowBox[{{
          0.03162476236668289, -2.4337491257641553`}, {-0.03162476236668289, \
-2.7624032969424768`}}]}, 
        {Arrowheads[{{0.028081077871624362`, 1.}}], 
         ArrowBox[{{0.38309694288951257`, -2.4297844137058835`}, {
          0.36690305711048743`, -2.7663680090007485`}}]}, 
        {Arrowheads[{{0.028042160264011667`, 1.}}], 
         ArrowBox[{{0.7338842890828473, -2.4305968307017105`}, {
          0.7661157109171527, -2.7655555920049215`}}]}, 
        {Arrowheads[{{0.02778055675657137, 1.}}], 
         ArrowBox[{{1.086014411001902, -2.4360161611748268`}, {
          1.163985588998098, -2.7601362615318052`}}]}, 
        {Arrowheads[{{0.027339563950025878`, 1.}}], 
         ArrowBox[{{1.4410760323137033`, -2.444987252628997}, {
          1.5589239676862967`, -2.751165170077635}}]}, 
        {Arrowheads[{{0.026781009540386577`, 1.}}], 
         ArrowBox[{{1.7998362716842402`, -2.4560535971760076`}, {
          1.9501637283157598`, -2.7400988255306244`}}]}, 
        {Arrowheads[{{0.026165358653906446`, 1.}}], 
         ArrowBox[{{2.1622946358098885`, -2.4678675140330832`}, {
          2.3377053641901115`, -2.728284908673549}}]}, 
        {Arrowheads[{{0.02553974055427605, 1.}}], 
         ArrowBox[{{2.5279827365104217`, -2.4794605669472594`}, {
          2.7220172634895783`, -2.7166918557593727`}}]}, 
        {Arrowheads[{{0.024099676679852577`, 1.}}], 
         ArrowBox[{{-2.6932775122697366`, -2.191496165514811}, \
{-2.9317224877302634`, -2.355137204353492}}]}, 
        {Arrowheads[{{0.024696324146672343`, 1.}}], 
         ArrowBox[{{-2.3203152554561415`, -2.182627992171156}, \
{-2.5546847445438585`, -2.364005377697147}}]}, 
        {Arrowheads[{{0.025363167830929234`, 1.}}], 
         ArrowBox[{{-1.9486616379243484`, -2.172325212585994}, \
{-2.1763383620756516`, -2.374308157282309}}]}, 
        {Arrowheads[{{0.02609888159900482, 1.}}], 
         ArrowBox[{{-1.5789220894182976`, -2.160479210309844}, \
{-1.7960779105817024`, -2.386154159558459}}]}, 
        {Arrowheads[{{0.026891224166846084`, 1.}}], 
         ArrowBox[{{-1.2119154695014873`, -2.1471591724218553`}, \
{-1.4130845304985127`, -2.3994741974464477`}}]}, 
        {Arrowheads[{{0.027709101799197045`, 1.}}], 
         ArrowBox[{{-0.8486451693622332, -2.132798306481398}, \
{-1.0263548306377668`, -2.4138350633869052`}}]}, 
        {Arrowheads[{{0.028493852410030388`, 1.}}], 
         ArrowBox[{{-0.49011162567715383`, -2.1184350857403773`}, \
{-0.6348883743228462, -2.4281982841279257`}}]}, 
        {Arrowheads[{{0.029156041542347046`, 1.}}], 
         ArrowBox[{{-0.1368605594264499, -2.105870161048213}, \
{-0.2381394405735501, -2.44076320882009}}]}, 
        {Arrowheads[{{0.029588854747557736`, 1.}}], 
         ArrowBox[{{0.21167711434640898`, -2.0974375251349437`}, {
          0.16332288565359102`, -2.4491958447333593`}}]}, 
        {Arrowheads[{{0.02970434883878871, 1.}}], 
         ArrowBox[{{0.5576019039831361, -2.095157910541416}, {
          0.5673980960168639, -2.451475459326887}}]}, 
        {Arrowheads[{{0.029476404523663385`, 1.}}], 
         ArrowBox[{{0.9040768988940203, -2.0996451571479464`}, {
          0.9709231011059797, -2.4469882127203566`}}]}, 
        {Arrowheads[{{0.028955473828209646`, 1.}}], 
         ArrowBox[{{1.2540289534384033`, -2.1097188932614874`}, {
          1.3709710465615967`, -2.4369144766068156`}}]}, 
        {Arrowheads[{{0.02824088617779116, 1.}}], 
         ArrowBox[{{1.6090465352435386`, -2.12312757300004}, {
          1.7659534647564614`, -2.423505796868263}}]}, 
        {Arrowheads[{{0.027436611884558218`, 1.}}], 
         ArrowBox[{{1.969254633000853, -2.1376518858352913`}, {
          2.155745366999147, -2.4089814840330117`}}]}, 
        {Arrowheads[{{0.026622248488570765`, 1.}}], 
         ArrowBox[{{2.33388810251067, -2.1517462821882525`}, {
          2.54111189748933, -2.3948870876800505`}}]}, 
        {Arrowheads[{{0.025846445228098796`, 1.}}], 
         ArrowBox[{{2.701909895653085, -2.1646004343826055`}, {
          2.923090104346915, -2.3820329354856975`}}]}, 
        {Arrowheads[{{0.024764359284653037`, 1.}}], 
         ArrowBox[{{-2.498916431311434, -1.8699392256064362`}, \
{-2.751083568688566, -2.027175091423538}}]}, 
        {Arrowheads[{{0.025503553404489374`, 1.}}], 
         ArrowBox[{{-2.125144574057701, -1.8600888188788764`}, \
{-2.374855425942299, -2.0370254981510976`}}]}, 
        {Arrowheads[{{0.02634983874958137, 1.}}], 
         ArrowBox[{{-1.7527737904101248`, -1.8482772613973006`}, \
{-1.9972262095898752`, -2.0488370556326734`}}]}, 
        {Arrowheads[{{0.027307799567962556`, 1.}}], 
         ArrowBox[{{-1.3826433600151284`, -1.8342190980440929`}, \
{-1.6173566399848716`, -2.062895218985881}}]}, 
        {Arrowheads[{{0.028365296955365868`, 1.}}], 
         ArrowBox[{{-1.0159982854616088`, -1.817851883958563}, \
{-1.2340017145383912`, -2.079262433071411}}]}, 
        {Arrowheads[{{0.029476404523663385`, 1.}}], 
         ArrowBox[{{-0.6545054254114866, -1.799695848983954}, \
{-0.8454945745885134, -2.09741846804602}}]}, 
        {Arrowheads[{{0.030539854751886045`, 1.}}], 
         ArrowBox[{{-0.2999371876573572, -1.7813980952823885`}, \
{-0.4500628123426428, -2.1157162217475856`}}]}, 
        {Arrowheads[{{0.03138964772031195, 1.}}], 
         ArrowBox[{{
          0.04681098734119277, -1.7661293895533157`}, {-0.04681098734119277, \
-2.1309849274766584`}}]}, 
        {Arrowheads[{{0.03183175949218799, 1.}}], 
         ArrowBox[{{0.3872269175044623, -1.7579583774758496`}, {
          0.3627730824955377, -2.1391559395541244`}}]}, 
        {Arrowheads[{{0.03174012468722872, 1.}}], 
         ArrowBox[{{0.7257650907438781, -1.7596647348470769`}, {
          0.7742349092561219, -2.137449582182897}}]}, 
        {Arrowheads[{{0.031142385894604194`, 1.}}], 
         ArrowBox[{{1.0679302802898984`, -1.7706313811140877`}, {
          1.1820697197101016`, -2.1264829359158863`}}]}, 
        {Arrowheads[{{0.030199703088278764`, 1.}}], 
         ArrowBox[{{1.417267771494251, -1.7873486824202125`}, {
          1.582732228505749, -2.1097656346097615`}}]}, 
        {Arrowheads[{{0.029104971031446446`, 1.}}], 
         ArrowBox[{{1.7743160106418632`, -1.8058746070883367`}, {
          1.9756839893581368`, -2.0912397099416373`}}]}, 
        {Arrowheads[{{0.02800364226870596, 1.}}], 
         ArrowBox[{{2.137730562406663, -1.8235494920550162`}, {
          2.362269437593337, -2.073564824974958}}]}, 
        {Arrowheads[{{0.026976320987290567`, 1.}}], 
         ArrowBox[{{2.5057036719672716`, -1.8391662342925286`}, {
          2.7442963280327284`, -2.0579480827374454`}}]}, 
        {Arrowheads[{{0.024750611776070422`, 1.}}], 
         ArrowBox[{{-2.679155844589049, -1.5584319192474845`}, \
{-2.945844155410951, -1.6891633449441605`}}]}, 
        {Arrowheads[{{0.025539740554276085`, 1.}}], 
         ArrowBox[{{-2.3033879004702884`, -1.549662854342037}, \
{-2.5716120995297116`, -1.697932409849608}}]}, 
        {Arrowheads[{{0.02647082187995947, 1.}}], 
         ArrowBox[{{-1.9283425206713822`, -1.5387851063351383`}, \
{-2.1966574793286178`, -1.7088101578565067`}}]}, 
        {Arrowheads[{{0.027570275186807085`, 1.}}], 
         ArrowBox[{{-1.5546738467851116`, -1.5251997838349163`}, \
{-1.8203261532148884`, -1.7223954803567287`}}]}, 
        {Arrowheads[{{0.028858781263565586`, 1.}}], 
         ArrowBox[{{-1.1835332860967842`, -1.5082578557343211`}, \
{-1.4414667139032158`, -1.7393374084573239`}}]}, 
        {Arrowheads[{{0.0303327098213714, 1.}}], 
         ArrowBox[{{-0.8168639653401129, -1.4875273660602368`}, \
{-1.0581360346598871`, -1.7600678981314082`}}]}, 
        {Arrowheads[{{0.0319251000393457, 1.}}], 
         ArrowBox[{{-0.4576196998318448, -1.4635111539155408`}, \
{-0.6673803001681552, -1.7840841102761043`}}]}, 
        {Arrowheads[{{0.03344601714271432, 1.}}], 
         ArrowBox[{{-0.10925946531497259`, -1.4390022939787919`}, \
{-0.2657405346850274, -1.8085929702128531`}}]}, 
        {Arrowheads[{{0.034551558739378326`, 1.}}], 
         ArrowBox[{{0.22667778507172948`, -1.4202238892790757`}, {
          0.14832221492827052`, -1.8273713749125693`}}]}, 
        {Arrowheads[{{0.03486412887679517, 1.}}], 
         ArrowBox[{{0.5544544317976626, -1.4147676385626893`}, {
          0.5705455682023374, -1.8328276256289557`}}]}, 
        {Arrowheads[{{0.03425466251412329, 1.}}], 
         ArrowBox[{{0.8840312907303178, -1.4253465155167828`}, {
          0.9909687092696822, -1.8222487486748622`}}]}, 
        {Arrowheads[{{0.03296541092513824, 1.}}], 
         ArrowBox[{{1.2239921332957446`, -1.446912875940472}, {
          1.4010078667042554`, -1.800682388251173}}]}, 
        {Arrowheads[{{0.03138964772031193, 1.}}], 
         ArrowBox[{{1.5763239050646671`, -1.47177449129443}, {
          1.7986760949353329`, -1.775820772897215}}]}, 
        {Arrowheads[{{0.029823026644856327`, 1.}}], 
         ArrowBox[{{1.9384287095105095`, -1.494858964762762}, {
          2.1865712904894905`, -1.752736299428883}}]}, 
        {Arrowheads[{{0.02840767700424747, 1.}}], 
         ArrowBox[{{2.306865762121309, -1.5143145011858556`}, {
          2.568134237878691, -1.7332807630057894`}}]}, 
        {Arrowheads[{{0.02718355173745576, 1.}}], 
         ArrowBox[{{2.679019222185699, -1.5300697311465596`}, {
          2.945980777814301, -1.7175255330450854`}}]}, 
        {Arrowheads[{{0.025467811485932624`, 1.}}], 
         ArrowBox[{{-2.4838987379360953`, -1.2403834124990323`}, \
{-2.7661012620639047`, -1.3576927988542837`}}]}, 
        {Arrowheads[{{0.02644625785840735, 1.}}], 
         ArrowBox[{{-2.106524645672029, -1.2312635774957508`}, \
{-2.393475354327971, -1.3668126338575652`}}]}, 
        {Arrowheads[{{0.027639022469113986`, 1.}}], 
         ArrowBox[{{-1.7295073316615452`, -1.21945893924793}, \
{-2.0204926683384548`, -1.378617272105386}}]}, 
        {Arrowheads[{{0.029104971031446433`, 1.}}], 
         ArrowBox[{{-1.3535505609336194`, -1.203916404725558}, \
{-1.6464494390663806`, -1.394159806627758}}]}, 
        {Arrowheads[{{0.03090727481441062, 1.}}], 
         ArrowBox[{{-0.9801510231498896, -1.1832446653710769`}, \
{-1.2698489768501104`, -1.4148315459822391`}}]}, 
        {Arrowheads[{{0.03308165355997636, 1.}}], 
         ArrowBox[{{-0.6123720020911955, -1.1560108947234384`}, \
{-0.8876279979088045, -1.4420653166298776`}}]}, 
        {Arrowheads[{{0.03554219832343682, 1.}}], 
         ArrowBox[{{-0.25586379822625543`, -1.1221667161113125`}, \
{-0.49413620177374457`, -1.4759094952420035`}}]}, 
        {Arrowheads[{{0.037890608915675694`, 1.}}], 
         ArrowBox[{{
          0.0816642510993401, -1.0868681575774786`}, {-0.0816642510993401, \
-1.5112080537758374`}}]}, 
        {Arrowheads[{{0.03929580154364731, 1.}}], 
         ArrowBox[{{0.3975831309704036, -1.0643473242683306`}, {
          0.3524168690295964, -1.5337288870849854`}}]}, 
        {Arrowheads[{{0.038992318678128884`, 1.}}], 
         ArrowBox[{{0.7057868664582395, -1.0692999247081874`}, {
          0.7942131335417605, -1.5287762866451287`}}]}, 
        {Arrowheads[{{0.0371641229902051, 1.}}], 
         ArrowBox[{{1.0283238553397178`, -1.0981005123588732`}, {
          1.2216761446602822`, -1.4999756989944428`}}]}, 
        {Arrowheads[{{0.03470579931652076, 1.}}], 
         ArrowBox[{{1.3729779653275271`, -1.134031642376534}, {
          1.6270220346724729`, -1.464044568976782}}]}, 
        {Arrowheads[{{0.032316627985300786`, 1.}}], 
         ArrowBox[{{1.73405416941395, -1.1658788294820939`}, {
          2.01594583058605, -1.4321973818712221`}}]}, 
        {Arrowheads[{{0.030265714237414837`, 1.}}], 
         ArrowBox[{{2.1041879480992423`, -1.1908007275703798`}, {
          2.3958120519007577`, -1.4072754837829362`}}]}, 
        {Arrowheads[{{0.02858197410631264, 1.}}], 
         ArrowBox[{{2.478682207663397, -1.209592276131373}, {
          2.771317792336603, -1.388483935221943}}]}, 
        {Arrowheads[{{0.025295472175760766`, 1.}}], 
         ArrowBox[{{-2.6668945449723047`, -0.9314528356026939}, \
{-2.9581054550276953`, -1.0171043229122931`}}]}, 
        {Arrowheads[{{0.026279390079816486`, 1.}}], 
         ArrowBox[{{-2.2878405458727253`, -0.9246411323333836}, \
{-2.5871594541272747`, -1.0239160261816034`}}]}, 
        {Arrowheads[{{0.02750281828141042, 1.}}], 
         ArrowBox[{{-1.9082554696209915`, -0.9156338409488498}, \
{-2.2167445303790085`, -1.0329233175661372`}}]}, 
        {Arrowheads[{{0.029054528012464553`, 1.}}], 
         ArrowBox[{{-1.5282534282255003`, -0.9033526255660256}, \
{-1.8467465717744997`, -1.0452045329489614`}}]}, 
        {Arrowheads[{{0.031062715342689718`, 1.}}], 
         ArrowBox[{{-1.1483374747685975`, -0.8860358030645152}, \
{-1.4766625252314025`, -1.0625213554504718`}}]}, 
        {Arrowheads[{{0.033702960300813926`, 1.}}], 
         ArrowBox[{{-0.7701065404674516, -0.8608261535668027}, \
{-1.1048934595325484`, -1.0877310049481843`}}]}, 
        {Arrowheads[{{0.0371641229902051, 1.}}], 
         ArrowBox[{{-0.3981505540775203, -0.8235753842691549}, \
{-0.7268494459224797, -1.1249817742458321`}}]}, 
        {Arrowheads[{{0.041421423078516845`, 1.}}], 
         ArrowBox[{{-0.044209215895446685`, -0.7712165551730186}, \
{-0.3307907841045533, -1.1773406033419684`}}]}, 
        {Arrowheads[{{0.045496252804832375`, 1.}}], 
         ArrowBox[{{0.27087377888190545`, -0.7143448613810415}, {
          0.10412622111809455`, -1.2342122971339455`}}]}, 
        {Arrowheads[{{0.04687500000000002, 1.}}], 
         ArrowBox[{{0.5444948137594364, -0.693605502941929}, {
          0.5805051862405636, -1.254951655573058}}]}, 
        {Arrowheads[{{0.044291190519396034`, 1.}}], 
         ArrowBox[{{0.8286382732694775, -0.731851954218566}, {
          1.0463617267305225`, -1.216705204296421}}]}, 
        {Arrowheads[{{0.03994207492635575, 1.}}], 
         ArrowBox[{{1.1590112261632761`, -0.7902283337121174}, {
          1.4659887738367239`, -1.1583288248028696`}}]}, 
        {Arrowheads[{{0.03591115851478668, 1.}}], 
         ArrowBox[{{1.5209227078595202`, -0.8376110529221781}, {
          1.8540772921404798`, -1.110946105592809}}]}, 
        {Arrowheads[{{0.03274019958493003, 1.}}], 
         ArrowBox[{{1.8958087823595706`, -0.8703402223311454}, {
          2.2291912176404294`, -1.0782169361838416`}}]}, 
        {Arrowheads[{{0.03033270982137139, 1.}}], 
         ArrowBox[{{2.2749036054584133`, -0.8925164196361421}, {
          2.6000963945415867`, -1.0560407388788449`}}]}, 
        {Arrowheads[{{0.028493852410030395`, 1.}}], 
         ArrowBox[{{2.6549488323561583`, -0.9079007510315904}, {
          2.9700511676438417`, -1.0406564074833966`}}]}, 
        {Arrowheads[{{0.025991160704169004`, 1.}}], 
         ArrowBox[{{-2.4723161382835745`, -0.6177843081196887}, \
{-2.7776838617164255`, -0.6812537975569694}}]}, 
        {Arrowheads[{{0.027183551737455753`, 1.}}], 
         ArrowBox[{{-2.091266102058669, -0.6120278924586238}, \
{-2.408733897941331, -0.6870102132180342}}]}, 
        {Arrowheads[{{0.028717969755743426`, 1.}}], 
         ArrowBox[{{-1.7087955213670711`, -0.6040651684007929}, \
{-2.041204478632929, -0.6949729372758651}}]}, 
        {Arrowheads[{{0.030756804204593088`, 1.}}], 
         ArrowBox[{{-1.3244829854223292`, -0.5925182303055792}, \
{-1.6755170145776708`, -0.7065198753710789}}]}, 
        {Arrowheads[{{0.03357301388447952, 1.}}], 
         ArrowBox[{{-0.9379503512150427, -0.5747545539382997}, \
{-1.3120496487849573`, -0.7242835517383583}}]}, 
        {Arrowheads[{{0.037639882113991795`, 1.}}], 
         ArrowBox[{{-0.5496000335549653, -0.5453881757229596}, \
{-0.9503999664450347, -0.7536499299536984}}]}, 
        {Arrowheads[{{0.04374290949045362, 1.}}], 
         ArrowBox[{{-0.16425845466989444`, -0.4930840255051908}, \
{-0.5857415453301056, -0.8059540801714672}}]}, 
        {Arrowheads[{{0.046875, 1.}}], 
         ArrowBox[{{
          0.17156089162418026`, -0.4266549171746554}, {-0.17156089162418026`, \
-0.8723831885020026}}]}, 
        {Arrowheads[{{0.046875, 1.}}], 
         ArrowBox[{{0.42815125401692256`, -0.37333703550840114`}, {
          0.32184874598307744`, -0.9257010701682569}}]}, 
        {Arrowheads[{{0.046875, 1.}}], 
         ArrowBox[{{0.6489720176099392, -0.3870406551096901}, {
          0.8510279823900608, -0.9119974505669679}}]}, 
        {Arrowheads[{{0.04687499999999999, 1.}}], 
         ArrowBox[{{0.929988212264568, -0.44685685817876564`}, {
          1.320011787735432, -0.8521812474978924}}]}, 
        {Arrowheads[{{0.04142142307851684, 1.}}], 
         ArrowBox[{{1.2915770413024679`, -0.5141443701153459}, {
          1.7084229586975321`, -0.7848937355613121}}]}, 
        {Arrowheads[{{0.03610399673243863, 1.}}], 
         ArrowBox[{{1.6791298034838684`, -0.5569943804598452}, {
          2.0708701965161316`, -0.7420437252168128}}]}, 
        {Arrowheads[{{0.03252413975826109, 1.}}], 
         ArrowBox[{{2.0670498907668606`, -0.5816164347435989}, {
          2.4329501092331394`, -0.7174216709330591}}]}, 
        {Arrowheads[{{0.030007341479058734`, 1.}}], 
         ArrowBox[{{2.4528194261310725`, -0.5968910230705616}, {
          2.7971805738689275`, -0.7021470826060964}}]}, 
        {Arrowheads[{{0.025613488107262886`, 1.}}], 
         ArrowBox[{{-2.6595523767816114`, -0.30976444787325036`}, \
{-2.9654476232183886`, -0.33975460496507864`}}]}, 
        {Arrowheads[{{0.02672723790043917, 1.}}], 
         ArrowBox[{{-2.2781077181302343`, -0.30713768404473213`}, \
{-2.5968922818697657`, -0.3423813687935969}}]}, 
        {Arrowheads[{{0.02816013992614846, 1.}}], 
         ArrowBox[{{-1.8948799436238226`, -0.30351612734518163`}, \
{-2.2301200563761774`, -0.3460029254931474}}]}, 
        {Arrowheads[{{0.030070539397068302`, 1.}}], 
         ArrowBox[{{-1.5090328251745309`, -0.29826402233793675`}, \
{-1.8659671748254691`, -0.35125503050039225`}}]}, 
        {Arrowheads[{{0.032740199584930026`, 1.}}], 
         ArrowBox[{{-1.1191381875371023`, -0.2901134074437151}, \
{-1.5058618124628977`, -0.3594056453946139}}]}, 
        {Arrowheads[{{0.03671951085472884, 1.}}], 
         ArrowBox[{{-0.7225989299893127, -0.2762091474809784}, \
{-1.1524010700106873`, -0.3733099053573506}}]}, 
        {Arrowheads[{{0.0432261639737414, 1.}}], 
         ArrowBox[{{-0.3144705061394658, -0.24894781727645188`}, \
{-0.8105294938605342, -0.4005712355618771}}]}, 
        {Arrowheads[{{0.046875, 1.}}], 
         ArrowBox[{{
          0.06680468348797458, -0.20463171758173881`}, {-0.4418046834879746, \
-0.4448873352565902}}]}, 
        {Arrowheads[{{0.04687499999999999, 1.}}], 
         ArrowBox[{{
          0.3825117877354321, -0.12209733175960114`}, {-0.007511787735432096, \
-0.5274217210787279}}]}, 
        {Arrowheads[{{0.046875, 1.}}], 
         ArrowBox[{{0.5093487459830774, -0.04857750908923664}, {
          0.6156512540169226, -0.6009415437490924}}]}, 
        {Arrowheads[{{0.046875, 1.}}], 
         ArrowBox[{{0.7116688869711658, -0.15712339997811986`}, {
          1.1633311130288342`, -0.49239565286020914`}}]}, 
        {Arrowheads[{{0.04687499999999999, 1.}}], 
         ArrowBox[{{1.0513392857142858`, -0.22037253578443305`}, {
          1.5736607142857142`, -0.42914651705389595`}}]}, 
        {Arrowheads[{{0.040647420527110824`, 1.}}], 
         ArrowBox[{{1.4522541454377795`, -0.2604240886762606}, {
          1.9227458545622205`, -0.3890949641620684}}]}, 
        {Arrowheads[{{0.03519380242396191, 1.}}], 
         ArrowBox[{{1.8557556485746525`, -0.28178851991757525`}, {
          2.2692443514253475`, -0.36773053292075375`}}]}, 
        {Arrowheads[{{0.031740124687228734`, 1.}}], 
         ArrowBox[{{2.249679453265055, -0.29327745580784614`}, {
          2.625320546734945, -0.35624159703048286`}}]}, 
        {Arrowheads[{{0.029366866771308786`, 1.}}], 
         ArrowBox[{{2.638011070482787, -0.3002549028016955}, {
          2.986988929517213, -0.3492641500366335}}]}, 
        {Arrowheads[{{0.026187836128434006`, 1.}}], 
         ArrowBox[{{-2.467872983229396, 0.}, {-2.782127016770604, 0.}}]}, 
        {Arrowheads[{{0.027469561193532794`, 1.}}], 
         ArrowBox[{{-2.0851826328388032`, 0.}, {-2.4148173671611968`, 
          0.}}]}, 
        {Arrowheads[{{0.02915604154234706, 1.}}], 
         ArrowBox[{{-1.7000637507459175`, 0.}, {-2.0499362492540825`, 
          0.}}]}, 
        {Arrowheads[{{0.031474952021966596`, 1.}}], 
         ArrowBox[{{-1.3111502878682004`, 0.}, {-1.6888497121317996`, 
          0.}}]}, 
        {Arrowheads[{{0.034864128876795165`, 1.}}], 
         ArrowBox[{{-0.915815226739229, 0.}, {-1.334184773260771, 0.}}]}, 
        {Arrowheads[{{0.04028681184452091, 1.}}], 
         ArrowBox[{{-0.5082791289328745, 0.}, {-0.9917208710671255, 0.}}]}, 
        {Arrowheads[{{0.046875, 1.}}], 
         ArrowBox[{{-0.09375, 0.}, {-0.65625, 0.}}]}, 
        {Arrowheads[{{0.046875, 1.}}], 
         ArrowBox[{{0.28125, 0.}, {-0.28125, 0.}}]}, 
        {Arrowheads[{{0.046875, 1.}}], 
         ArrowBox[{{0.65625, 0.}, {0.09375, 0.}}]}, 
        {Arrowheads[{{0.046875, 1.}}], 
         ArrowBox[{{0.46875, 0.}, {1.03125, 0.}}]}, 
        {Arrowheads[{{0.046875, 1.}}], 
         ArrowBox[{{0.84375, 0.}, {1.40625, 0.}}]}, 
        {Arrowheads[{{0.046161385059557136`, 1.}}], 
         ArrowBox[{{1.2230316896426572`, 0.}, {1.7769683103573428`, 0.}}]}, 
        {Arrowheads[{{0.038150603402689574`, 1.}}], 
         ArrowBox[{{1.6460963795838626`, 0.}, {2.1039036204161374`, 0.}}]}, 
        {Arrowheads[{{0.03357301388447953, 1.}}], 
         ArrowBox[{{2.0485619166931226`, 0.}, {2.4514380833068774`, 0.}}]}, 
        {Arrowheads[{{0.030611044196225956`, 1.}}], 
         ArrowBox[{{2.4413337348226443`, 0.}, {2.8086662651773557`, 0.}}]}, 
        {Arrowheads[{{0.025613488107262886`, 1.}}], 
         ArrowBox[{{-2.6595523767816114`, 
          0.30976444787325036`}, {-2.9654476232183886`, 
          0.33975460496507864`}}]}, 
        {Arrowheads[{{0.02672723790043917, 1.}}], 
         ArrowBox[{{-2.2781077181302343`, 
          0.30713768404473213`}, {-2.5968922818697657`, 
          0.3423813687935969}}]}, 
        {Arrowheads[{{0.02816013992614846, 1.}}], 
         ArrowBox[{{-1.8948799436238226`, 
          0.30351612734518163`}, {-2.2301200563761774`, 
          0.3460029254931474}}]}, 
        {Arrowheads[{{0.030070539397068302`, 1.}}], 
         ArrowBox[{{-1.5090328251745309`, 
          0.29826402233793675`}, {-1.8659671748254691`, 
          0.35125503050039225`}}]}, 
        {Arrowheads[{{0.032740199584930026`, 1.}}], 
         ArrowBox[{{-1.1191381875371023`, 
          0.2901134074437151}, {-1.5058618124628977`, 
          0.3594056453946139}}]}, 
        {Arrowheads[{{0.03671951085472884, 1.}}], 
         ArrowBox[{{-0.7225989299893127, 
          0.2762091474809784}, {-1.1524010700106873`, 
          0.3733099053573506}}]}, 
        {Arrowheads[{{0.0432261639737414, 1.}}], 
         ArrowBox[{{-0.3144705061394658, 
          0.24894781727645188`}, {-0.8105294938605342, 0.4005712355618771}}]}, 
        {Arrowheads[{{0.046875, 1.}}], 
         ArrowBox[{{0.06680468348797458, 
          0.20463171758173881`}, {-0.4418046834879746, 0.4448873352565902}}]}, 
        {Arrowheads[{{0.04687499999999999, 1.}}], 
         ArrowBox[{{0.3825117877354321, 
          0.12209733175960114`}, {-0.007511787735432096, 
          0.5274217210787279}}]}, 
        {Arrowheads[{{0.046875, 1.}}], 
         ArrowBox[{{0.5093487459830774, 0.04857750908923664}, {
          0.6156512540169226, 0.6009415437490924}}]}, 
        {Arrowheads[{{0.046875, 1.}}], 
         ArrowBox[{{0.7116688869711658, 0.15712339997811986`}, {
          1.1633311130288342`, 0.49239565286020914`}}]}, 
        {Arrowheads[{{0.04687499999999999, 1.}}], 
         ArrowBox[{{1.0513392857142858`, 0.22037253578443305`}, {
          1.5736607142857142`, 0.42914651705389595`}}]}, 
        {Arrowheads[{{0.040647420527110824`, 1.}}], 
         ArrowBox[{{1.4522541454377795`, 0.2604240886762606}, {
          1.9227458545622205`, 0.3890949641620684}}]}, 
        {Arrowheads[{{0.03519380242396191, 1.}}], 
         ArrowBox[{{1.8557556485746525`, 0.28178851991757525`}, {
          2.2692443514253475`, 0.36773053292075375`}}]}, 
        {Arrowheads[{{0.031740124687228734`, 1.}}], 
         ArrowBox[{{2.249679453265055, 0.29327745580784614`}, {
          2.625320546734945, 0.35624159703048286`}}]}, 
        {Arrowheads[{{0.029366866771308786`, 1.}}], 
         ArrowBox[{{2.638011070482787, 0.3002549028016955}, {
          2.986988929517213, 0.3492641500366335}}]}, 
        {Arrowheads[{{0.025991160704169004`, 1.}}], 
         ArrowBox[{{-2.4723161382835745`, 
          0.6177843081196887}, {-2.7776838617164255`, 
          0.6812537975569694}}]}, 
        {Arrowheads[{{0.027183551737455753`, 1.}}], 
         ArrowBox[{{-2.091266102058669, 
          0.6120278924586238}, {-2.408733897941331, 0.6870102132180342}}]}, 
        {Arrowheads[{{0.028717969755743426`, 1.}}], 
         ArrowBox[{{-1.7087955213670711`, 
          0.6040651684007929}, {-2.041204478632929, 0.6949729372758651}}]}, 
        {Arrowheads[{{0.030756804204593088`, 1.}}], 
         ArrowBox[{{-1.3244829854223292`, 
          0.5925182303055792}, {-1.6755170145776708`, 
          0.7065198753710789}}]}, 
        {Arrowheads[{{0.03357301388447952, 1.}}], 
         ArrowBox[{{-0.9379503512150427, 
          0.5747545539382997}, {-1.3120496487849573`, 
          0.7242835517383583}}]}, 
        {Arrowheads[{{0.037639882113991795`, 1.}}], 
         ArrowBox[{{-0.5496000335549653, 
          0.5453881757229596}, {-0.9503999664450347, 0.7536499299536984}}]}, 
        {Arrowheads[{{0.04374290949045362, 1.}}], 
         ArrowBox[{{-0.16425845466989444`, 
          0.4930840255051908}, {-0.5857415453301056, 0.8059540801714672}}]}, 
        {Arrowheads[{{0.046875, 1.}}], 
         ArrowBox[{{0.17156089162418026`, 
          0.4266549171746554}, {-0.17156089162418026`, 0.8723831885020026}}]}, 
        {Arrowheads[{{0.046875, 1.}}], 
         ArrowBox[{{0.42815125401692256`, 0.37333703550840114`}, {
          0.32184874598307744`, 0.9257010701682569}}]}, 
        {Arrowheads[{{0.046875, 1.}}], 
         ArrowBox[{{0.6489720176099392, 0.3870406551096901}, {
          0.8510279823900608, 0.9119974505669679}}]}, 
        {Arrowheads[{{0.04687499999999999, 1.}}], 
         ArrowBox[{{0.929988212264568, 0.44685685817876564`}, {
          1.320011787735432, 0.8521812474978924}}]}, 
        {Arrowheads[{{0.04142142307851684, 1.}}], 
         ArrowBox[{{1.2915770413024679`, 0.5141443701153459}, {
          1.7084229586975321`, 0.7848937355613121}}]}, 
        {Arrowheads[{{0.03610399673243863, 1.}}], 
         ArrowBox[{{1.6791298034838684`, 0.5569943804598452}, {
          2.0708701965161316`, 0.7420437252168128}}]}, 
        {Arrowheads[{{0.03252413975826109, 1.}}], 
         ArrowBox[{{2.0670498907668606`, 0.5816164347435989}, {
          2.4329501092331394`, 0.7174216709330591}}]}, 
        {Arrowheads[{{0.030007341479058734`, 1.}}], 
         ArrowBox[{{2.4528194261310725`, 0.5968910230705616}, {
          2.7971805738689275`, 0.7021470826060964}}]}, 
        {Arrowheads[{{0.025295472175760766`, 1.}}], 
         ArrowBox[{{-2.6668945449723047`, 
          0.9314528356026939}, {-2.9581054550276953`, 1.0171043229122931`}}]}, 
        {Arrowheads[{{0.026279390079816486`, 1.}}], 
         ArrowBox[{{-2.2878405458727253`, 
          0.9246411323333836}, {-2.5871594541272747`, 1.0239160261816034`}}]}, 
        {Arrowheads[{{0.02750281828141042, 1.}}], 
         ArrowBox[{{-1.9082554696209915`, 
          0.9156338409488498}, {-2.2167445303790085`, 1.0329233175661372`}}]}, 
        {Arrowheads[{{0.029054528012464553`, 1.}}], 
         ArrowBox[{{-1.5282534282255003`, 
          0.9033526255660256}, {-1.8467465717744997`, 1.0452045329489614`}}]}, 
        {Arrowheads[{{0.031062715342689718`, 1.}}], 
         ArrowBox[{{-1.1483374747685975`, 
          0.8860358030645152}, {-1.4766625252314025`, 1.0625213554504718`}}]}, 
        {Arrowheads[{{0.033702960300813926`, 1.}}], 
         ArrowBox[{{-0.7701065404674516, 
          0.8608261535668027}, {-1.1048934595325484`, 1.0877310049481843`}}]}, 
        {Arrowheads[{{0.0371641229902051, 1.}}], 
         ArrowBox[{{-0.3981505540775203, 
          0.8235753842691549}, {-0.7268494459224797, 
          1.1249817742458321`}}]}, 
        {Arrowheads[{{0.041421423078516845`, 1.}}], 
         ArrowBox[{{-0.044209215895446685`, 
          0.7712165551730186}, {-0.3307907841045533, 
          1.1773406033419684`}}]}, 
        {Arrowheads[{{0.045496252804832375`, 1.}}], 
         ArrowBox[{{0.27087377888190545`, 0.7143448613810415}, {
          0.10412622111809455`, 1.2342122971339455`}}]}, 
        {Arrowheads[{{0.04687500000000002, 1.}}], 
         ArrowBox[{{0.5444948137594364, 0.693605502941929}, {
          0.5805051862405636, 1.254951655573058}}]}, 
        {Arrowheads[{{0.044291190519396034`, 1.}}], 
         ArrowBox[{{0.8286382732694775, 0.731851954218566}, {
          1.0463617267305225`, 1.216705204296421}}]}, 
        {Arrowheads[{{0.03994207492635575, 1.}}], 
         ArrowBox[{{1.1590112261632761`, 0.7902283337121174}, {
          1.4659887738367239`, 1.1583288248028696`}}]}, 
        {Arrowheads[{{0.03591115851478668, 1.}}], 
         ArrowBox[{{1.5209227078595202`, 0.8376110529221781}, {
          1.8540772921404798`, 1.110946105592809}}]}, 
        {Arrowheads[{{0.03274019958493003, 1.}}], 
         ArrowBox[{{1.8958087823595706`, 0.8703402223311454}, {
          2.2291912176404294`, 1.0782169361838416`}}]}, 
        {Arrowheads[{{0.03033270982137139, 1.}}], 
         ArrowBox[{{2.2749036054584133`, 0.8925164196361421}, {
          2.6000963945415867`, 1.0560407388788449`}}]}, 
        {Arrowheads[{{0.028493852410030395`, 1.}}], 
         ArrowBox[{{2.6549488323561583`, 0.9079007510315904}, {
          2.9700511676438417`, 1.0406564074833966`}}]}, 
        {Arrowheads[{{0.025467811485932624`, 1.}}], 
         ArrowBox[{{-2.4838987379360953`, 
          1.2403834124990323`}, {-2.7661012620639047`, 
          1.3576927988542837`}}]}, 
        {Arrowheads[{{0.02644625785840735, 1.}}], 
         ArrowBox[{{-2.106524645672029, 
          1.2312635774957508`}, {-2.393475354327971, 
          1.3668126338575652`}}]}, 
        {Arrowheads[{{0.027639022469113986`, 1.}}], 
         ArrowBox[{{-1.7295073316615452`, 
          1.21945893924793}, {-2.0204926683384548`, 1.378617272105386}}]}, 
        {Arrowheads[{{0.029104971031446433`, 1.}}], 
         ArrowBox[{{-1.3535505609336194`, 
          1.203916404725558}, {-1.6464494390663806`, 1.394159806627758}}]}, 
        {Arrowheads[{{0.03090727481441062, 1.}}], 
         ArrowBox[{{-0.9801510231498896, 
          1.1832446653710769`}, {-1.2698489768501104`, 
          1.4148315459822391`}}]}, 
        {Arrowheads[{{0.03308165355997636, 1.}}], 
         ArrowBox[{{-0.6123720020911955, 
          1.1560108947234384`}, {-0.8876279979088045, 1.4420653166298776`}}]}, 
        {Arrowheads[{{0.03554219832343682, 1.}}], 
         ArrowBox[{{-0.25586379822625543`, 
          1.1221667161113125`}, {-0.49413620177374457`, 
          1.4759094952420035`}}]}, 
        {Arrowheads[{{0.037890608915675694`, 1.}}], 
         ArrowBox[{{0.0816642510993401, 
          1.0868681575774786`}, {-0.0816642510993401, 1.5112080537758374`}}]}, 
        {Arrowheads[{{0.03929580154364731, 1.}}], 
         ArrowBox[{{0.3975831309704036, 1.0643473242683306`}, {
          0.3524168690295964, 1.5337288870849854`}}]}, 
        {Arrowheads[{{0.038992318678128884`, 1.}}], 
         ArrowBox[{{0.7057868664582395, 1.0692999247081874`}, {
          0.7942131335417605, 1.5287762866451287`}}]}, 
        {Arrowheads[{{0.0371641229902051, 1.}}], 
         ArrowBox[{{1.0283238553397178`, 1.0981005123588732`}, {
          1.2216761446602822`, 1.4999756989944428`}}]}, 
        {Arrowheads[{{0.03470579931652076, 1.}}], 
         ArrowBox[{{1.3729779653275271`, 1.134031642376534}, {
          1.6270220346724729`, 1.464044568976782}}]}, 
        {Arrowheads[{{0.032316627985300786`, 1.}}], 
         ArrowBox[{{1.73405416941395, 1.1658788294820939`}, {2.01594583058605,
           1.4321973818712221`}}]}, 
        {Arrowheads[{{0.030265714237414837`, 1.}}], 
         ArrowBox[{{2.1041879480992423`, 1.1908007275703798`}, {
          2.3958120519007577`, 1.4072754837829362`}}]}, 
        {Arrowheads[{{0.02858197410631264, 1.}}], 
         ArrowBox[{{2.478682207663397, 1.209592276131373}, {2.771317792336603,
           1.388483935221943}}]}, 
        {Arrowheads[{{0.024750611776070422`, 1.}}], 
         ArrowBox[{{-2.679155844589049, 
          1.5584319192474845`}, {-2.945844155410951, 
          1.6891633449441605`}}]}, 
        {Arrowheads[{{0.025539740554276085`, 1.}}], 
         ArrowBox[{{-2.3033879004702884`, 
          1.549662854342037}, {-2.5716120995297116`, 1.697932409849608}}]}, 
        {Arrowheads[{{0.02647082187995947, 1.}}], 
         ArrowBox[{{-1.9283425206713822`, 
          1.5387851063351383`}, {-2.1966574793286178`, 
          1.7088101578565067`}}]}, 
        {Arrowheads[{{0.027570275186807085`, 1.}}], 
         ArrowBox[{{-1.5546738467851116`, 
          1.5251997838349163`}, {-1.8203261532148884`, 
          1.7223954803567287`}}]}, 
        {Arrowheads[{{0.028858781263565586`, 1.}}], 
         ArrowBox[{{-1.1835332860967842`, 
          1.5082578557343211`}, {-1.4414667139032158`, 
          1.7393374084573239`}}]}, 
        {Arrowheads[{{0.0303327098213714, 1.}}], 
         ArrowBox[{{-0.8168639653401129, 
          1.4875273660602368`}, {-1.0581360346598871`, 
          1.7600678981314082`}}]}, 
        {Arrowheads[{{0.0319251000393457, 1.}}], 
         ArrowBox[{{-0.4576196998318448, 
          1.4635111539155408`}, {-0.6673803001681552, 1.7840841102761043`}}]}, 
        {Arrowheads[{{0.03344601714271432, 1.}}], 
         ArrowBox[{{-0.10925946531497259`, 
          1.4390022939787919`}, {-0.2657405346850274, 1.8085929702128531`}}]}, 
        {Arrowheads[{{0.034551558739378326`, 1.}}], 
         ArrowBox[{{0.22667778507172948`, 1.4202238892790757`}, {
          0.14832221492827052`, 1.8273713749125693`}}]}, 
        {Arrowheads[{{0.03486412887679517, 1.}}], 
         ArrowBox[{{0.5544544317976626, 1.4147676385626893`}, {
          0.5705455682023374, 1.8328276256289557`}}]}, 
        {Arrowheads[{{0.03425466251412329, 1.}}], 
         ArrowBox[{{0.8840312907303178, 1.4253465155167828`}, {
          0.9909687092696822, 1.8222487486748622`}}]}, 
        {Arrowheads[{{0.03296541092513824, 1.}}], 
         ArrowBox[{{1.2239921332957446`, 1.446912875940472}, {
          1.4010078667042554`, 1.800682388251173}}]}, 
        {Arrowheads[{{0.03138964772031193, 1.}}], 
         ArrowBox[{{1.5763239050646671`, 1.47177449129443}, {
          1.7986760949353329`, 1.775820772897215}}]}, 
        {Arrowheads[{{0.029823026644856327`, 1.}}], 
         ArrowBox[{{1.9384287095105095`, 1.494858964762762}, {
          2.1865712904894905`, 1.752736299428883}}]}, 
        {Arrowheads[{{0.02840767700424747, 1.}}], 
         ArrowBox[{{2.306865762121309, 1.5143145011858556`}, {
          2.568134237878691, 1.7332807630057894`}}]}, 
        {Arrowheads[{{0.02718355173745576, 1.}}], 
         ArrowBox[{{2.679019222185699, 1.5300697311465596`}, {
          2.945980777814301, 1.7175255330450854`}}]}, 
        {Arrowheads[{{0.024764359284653037`, 1.}}], 
         ArrowBox[{{-2.498916431311434, 
          1.8699392256064362`}, {-2.751083568688566, 2.027175091423538}}]}, 
        {Arrowheads[{{0.025503553404489374`, 1.}}], 
         ArrowBox[{{-2.125144574057701, 
          1.8600888188788764`}, {-2.374855425942299, 
          2.0370254981510976`}}]}, 
        {Arrowheads[{{0.02634983874958137, 1.}}], 
         ArrowBox[{{-1.7527737904101248`, 
          1.8482772613973006`}, {-1.9972262095898752`, 
          2.0488370556326734`}}]}, 
        {Arrowheads[{{0.027307799567962556`, 1.}}], 
         ArrowBox[{{-1.3826433600151284`, 
          1.8342190980440929`}, {-1.6173566399848716`, 
          2.062895218985881}}]}, 
        {Arrowheads[{{0.028365296955365868`, 1.}}], 
         ArrowBox[{{-1.0159982854616088`, 
          1.817851883958563}, {-1.2340017145383912`, 2.079262433071411}}]}, 
        {Arrowheads[{{0.029476404523663385`, 1.}}], 
         ArrowBox[{{-0.6545054254114866, 
          1.799695848983954}, {-0.8454945745885134, 2.09741846804602}}]}, 
        {Arrowheads[{{0.030539854751886045`, 1.}}], 
         ArrowBox[{{-0.2999371876573572, 
          1.7813980952823885`}, {-0.4500628123426428, 2.1157162217475856`}}]}, 
        {Arrowheads[{{0.03138964772031195, 1.}}], 
         ArrowBox[{{0.04681098734119277, 
          1.7661293895533157`}, {-0.04681098734119277, 
          2.1309849274766584`}}]}, 
        {Arrowheads[{{0.03183175949218799, 1.}}], 
         ArrowBox[{{0.3872269175044623, 1.7579583774758496`}, {
          0.3627730824955377, 2.1391559395541244`}}]}, 
        {Arrowheads[{{0.03174012468722872, 1.}}], 
         ArrowBox[{{0.7257650907438781, 1.7596647348470769`}, {
          0.7742349092561219, 2.137449582182897}}]}, 
        {Arrowheads[{{0.031142385894604194`, 1.}}], 
         ArrowBox[{{1.0679302802898984`, 1.7706313811140877`}, {
          1.1820697197101016`, 2.1264829359158863`}}]}, 
        {Arrowheads[{{0.030199703088278764`, 1.}}], 
         ArrowBox[{{1.417267771494251, 1.7873486824202125`}, {
          1.582732228505749, 2.1097656346097615`}}]}, 
        {Arrowheads[{{0.029104971031446446`, 1.}}], 
         ArrowBox[{{1.7743160106418632`, 1.8058746070883367`}, {
          1.9756839893581368`, 2.0912397099416373`}}]}, 
        {Arrowheads[{{0.02800364226870596, 1.}}], 
         ArrowBox[{{2.137730562406663, 1.8235494920550162`}, {
          2.362269437593337, 2.073564824974958}}]}, 
        {Arrowheads[{{0.026976320987290567`, 1.}}], 
         ArrowBox[{{2.5057036719672716`, 1.8391662342925286`}, {
          2.7442963280327284`, 2.0579480827374454`}}]}, 
        {Arrowheads[{{0.024099676679852577`, 1.}}], 
         ArrowBox[{{-2.6932775122697366`, 
          2.191496165514811}, {-2.9317224877302634`, 2.355137204353492}}]}, 
        {Arrowheads[{{0.024696324146672343`, 1.}}], 
         ArrowBox[{{-2.3203152554561415`, 
          2.182627992171156}, {-2.5546847445438585`, 2.364005377697147}}]}, 
        {Arrowheads[{{0.025363167830929234`, 1.}}], 
         ArrowBox[{{-1.9486616379243484`, 
          2.172325212585994}, {-2.1763383620756516`, 2.374308157282309}}]}, 
        {Arrowheads[{{0.02609888159900482, 1.}}], 
         ArrowBox[{{-1.5789220894182976`, 
          2.160479210309844}, {-1.7960779105817024`, 2.386154159558459}}]}, 
        {Arrowheads[{{0.026891224166846084`, 1.}}], 
         ArrowBox[{{-1.2119154695014873`, 
          2.1471591724218553`}, {-1.4130845304985127`, 
          2.3994741974464477`}}]}, 
        {Arrowheads[{{0.027709101799197045`, 1.}}], 
         ArrowBox[{{-0.8486451693622332, 
          2.132798306481398}, {-1.0263548306377668`, 
          2.4138350633869052`}}]}, 
        {Arrowheads[{{0.028493852410030388`, 1.}}], 
         ArrowBox[{{-0.49011162567715383`, 
          2.1184350857403773`}, {-0.6348883743228462, 2.4281982841279257`}}]}, 
        {Arrowheads[{{0.029156041542347046`, 1.}}], 
         ArrowBox[{{-0.1368605594264499, 
          2.105870161048213}, {-0.2381394405735501, 2.44076320882009}}]}, 
        {Arrowheads[{{0.029588854747557736`, 1.}}], 
         ArrowBox[{{0.21167711434640898`, 2.0974375251349437`}, {
          0.16332288565359102`, 2.4491958447333593`}}]}, 
        {Arrowheads[{{0.02970434883878871, 1.}}], 
         ArrowBox[{{0.5576019039831361, 2.095157910541416}, {
          0.5673980960168639, 2.451475459326887}}]}, 
        {Arrowheads[{{0.029476404523663385`, 1.}}], 
         ArrowBox[{{0.9040768988940203, 2.0996451571479464`}, {
          0.9709231011059797, 2.4469882127203566`}}]}, 
        {Arrowheads[{{0.028955473828209646`, 1.}}], 
         ArrowBox[{{1.2540289534384033`, 2.1097188932614874`}, {
          1.3709710465615967`, 2.4369144766068156`}}]}, 
        {Arrowheads[{{0.02824088617779116, 1.}}], 
         ArrowBox[{{1.6090465352435386`, 2.12312757300004}, {
          1.7659534647564614`, 2.423505796868263}}]}, 
        {Arrowheads[{{0.027436611884558218`, 1.}}], 
         ArrowBox[{{1.969254633000853, 2.1376518858352913`}, {
          2.155745366999147, 2.4089814840330117`}}]}, 
        {Arrowheads[{{0.026622248488570765`, 1.}}], 
         ArrowBox[{{2.33388810251067, 2.1517462821882525`}, {2.54111189748933,
           2.3948870876800505`}}]}, 
        {Arrowheads[{{0.025846445228098796`, 1.}}], 
         ArrowBox[{{2.701909895653085, 2.1646004343826055`}, {
          2.923090104346915, 2.3820329354856975`}}]}, 
        {Arrowheads[{{0.02401619735703311, 1.}}], 
         ArrowBox[{{-2.5141953441486162`, 
          2.505954950401421}, {-2.7358046558513838`, 2.690197472305211}}]}, 
        {Arrowheads[{{0.024552573484838417`, 1.}}], 
         ArrowBox[{{-2.142916338164377, 
          2.4969083879206853`}, {-2.357083661835623, 
          2.6992440347859468`}}]}, 
        {Arrowheads[{{0.02513300744592264, 1.}}], 
         ArrowBox[{{-1.7732550839975794`, 
          2.4867747183461453`}, {-1.9767449160024206`, 
          2.7093777043604867`}}]}, 
        {Arrowheads[{{0.02574715915044841, 1.}}], 
         ArrowBox[{{-1.4057662809463338`, 
          2.475663019462975}, {-1.5942337190536662`, 2.720489403243657}}]}, 
        {Arrowheads[{{0.02637367257076846, 1.}}], 
         ArrowBox[{{-1.0410872456091025`, 
          2.4639151461150854`}, {-1.2089127543908975`, 
          2.7322372765915466`}}]}, 
        {Arrowheads[{{0.026976320987290584`, 1.}}], 
         ArrowBox[{{-0.6798256893925128, 
          2.452221645723371}, {-0.8201743106074872, 2.743930776983261}}]}, 
        {Arrowheads[{{0.027502818281410435`, 1.}}], 
         ArrowBox[{{-0.32233113596814345`, 
          2.441690242530266}, {-0.42766886403185655`, 2.754462180176366}}]}, 
        {Arrowheads[{{0.027890418831252452`, 1.}}], 
         ArrowBox[{{0.03162476236668289, 
          2.4337491257641553`}, {-0.03162476236668289, 
          2.7624032969424768`}}]}, 
        {Arrowheads[{{0.028081077871624362`, 1.}}], 
         ArrowBox[{{0.38309694288951257`, 2.4297844137058835`}, {
          0.36690305711048743`, 2.7663680090007485`}}]}, 
        {Arrowheads[{{0.028042160264011667`, 1.}}], 
         ArrowBox[{{0.7338842890828473, 2.4305968307017105`}, {
          0.7661157109171527, 2.7655555920049215`}}]}, 
        {Arrowheads[{{0.02778055675657137, 1.}}], 
         ArrowBox[{{1.086014411001902, 2.4360161611748268`}, {
          1.163985588998098, 2.7601362615318052`}}]}, 
        {Arrowheads[{{0.027339563950025878`, 1.}}], 
         ArrowBox[{{1.4410760323137033`, 2.444987252628997}, {
          1.5589239676862967`, 2.751165170077635}}]}, 
        {Arrowheads[{{0.026781009540386577`, 1.}}], 
         ArrowBox[{{1.7998362716842402`, 2.4560535971760076`}, {
          1.9501637283157598`, 2.7400988255306244`}}]}, 
        {Arrowheads[{{0.026165358653906446`, 1.}}], 
         ArrowBox[{{2.1622946358098885`, 2.4678675140330832`}, {
          2.3377053641901115`, 2.728284908673549}}]}, 
        {Arrowheads[{{0.02553974055427605, 1.}}], 
         ArrowBox[{{2.5279827365104217`, 2.4794605669472594`}, {
          2.7220172634895783`, 2.7166918557593727`}}]}, 
        {Arrowheads[{{0.02343750000000001, 1.}}], 
         ArrowBox[{{-2.7070547088739305`, 
          2.829794450139847}, {-2.9179452911260695`, 3.015877025405114}}]}, 
        {Arrowheads[{{0.023876743512748183`, 1.}}], 
         ArrowBox[{{-2.3359463912995198`, 
          2.8217890937522165`}, {-2.5390536087004802`, 
          3.0238823817927445`}}]}, 
        {Arrowheads[{{0.024345060541474145`, 1.}}], 
         ArrowBox[{{-1.9662052226612605`, 
          2.813000102039208}, {-2.1587947773387395`, 3.032671373505753}}]}, 
        {Arrowheads[{{0.024834181220247744`, 1.}}], 
         ArrowBox[{{-1.598217852164272, 
          2.803541085228777}, {-1.776782147835728, 3.042130390316184}}]}, 
        {Arrowheads[{{0.02532911879301356, 1.}}], 
         ArrowBox[{{-1.2324075841332183`, 
          2.793678785816638}, {-1.3925924158667817`, 3.051992689728323}}]}, 
        {Arrowheads[{{0.025806336132554855`, 1.}}], 
         ArrowBox[{{-0.8691654162470059, 
          2.7838925979331357`}, {-1.005834583752994, 
          3.0617788776118253`}}]}, 
        {Arrowheads[{{0.026233280311868713`, 1.}}], 
         ArrowBox[{{-0.508725367452308, 
          2.7749068739645018`}, {-0.616274632547692, 
          3.0707646015804593`}}]}, 
        {Arrowheads[{{0.026570986300117966`, 1.}}], 
         ArrowBox[{{-0.150996567103944, 
          2.7676451367252484`}, {-0.224003432896056, 
          3.0780263388197127`}}]}, 
        {Arrowheads[{{0.026781009540386546`, 1.}}], 
         ArrowBox[{{0.20458266552630905`, 2.7630602968230087`}, {
          0.17041733447369095`, 3.0826111787219523`}}]}, 
        {Arrowheads[{{0.026835663497094042`, 1.}}], 
         ArrowBox[{{0.5590577696534635, 2.761858555780451}, {
          0.5659422303465365, 3.08381291976451}}]}, 
        {Arrowheads[{{0.026727237900439158`, 1.}}], 
         ArrowBox[{{0.9137607239768434, 2.7642391564025894`}, {
          0.9612392760231566, 3.0814323191423716`}}]}, 
        {Arrowheads[{{0.026470821879959444`, 1.}}], 
         ArrowBox[{{1.2699622626519018`, 2.769813191403249}, {
          1.3550377373480982`, 3.075858284141712}}]}, 
        {Arrowheads[{{0.026098881599004795`, 1.}}], 
         ArrowBox[{{1.6285577056842186`, 2.7777589846840853`}, {
          1.7464422943157814`, 3.0679124908608757`}}]}, 
        {Arrowheads[{{0.025651067989640636`, 1.}}], 
         ArrowBox[{{1.9899413735770328`, 2.787106492081133}, {
          2.135058626422967, 3.058564983463828}}]}, 
        {Arrowheads[{{0.025164755772881964`, 1.}}], 
         ArrowBox[{{2.354076520034966, 2.796986381069952}, {2.520923479965034,
           3.048685094475009}}]}, 
        {Arrowheads[{{0.024669593461185278`, 1.}}], 
         ArrowBox[{{2.720659531402359, 2.806755909106121}, {2.904340468597641,
           3.03891556643884}}]}}},
      AspectRatio->1,
      DisplayFunction->Identity,
      Frame->True,
      FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
      GridLinesStyle->Directive[
        GrayLevel[0.5, 0.4]],
      ImagePadding->{{15., 0.5}, {16., 0.5}},
      LabelStyle->Opacity[0],
      Method->{
       "VectorLengthFunction" -> (Sqrt[#]& ), "DefaultBoundaryStyle" -> 
        Automatic, 
        "DefaultGraphicsInteraction" -> {
         "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
          "Effects" -> {
           "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
            "Droplines" -> {
             "freeformCursorMode" -> True, 
              "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
        "TransparentPolygonMesh" -> True},
      PlotRange->{{-3, 3}, {-3, 3}},
      PlotRangeClipping->True,
      PlotRangePadding->{{
         Scaled[0.02], 
         Scaled[0.02]}, {
         Scaled[0.02], 
         Scaled[0.02]}},
      Prolog->{
        RGBColor[1, 0, 0], 
        DiskBox[{0.5, 0}, 0.2]},
      Ticks->{Automatic, Automatic}], {80.68562674094709, -78.96935933147633},
      ImageScaled[{0.5, 0.5}], {149.41782729805016, 150.41782729805016},
     BaseStyle->{Graphics3DBoxOptions -> {SphericalRegion -> False}}], 
    InsetBox[
     GraphicsBox[{{}, 
       {RGBColor[0, 0, 1], 
        {Arrowheads[{{0.023437499999999986`, 1.}}], 
         ArrowBox[{{-2.910005893867716, -3.024166835102262}, \
{-2.714994106132284, -2.821504640442699}}]}, 
        {Arrowheads[{{0.024029354453257726`, 1.}}], 
         ArrowBox[{{-2.529839623264911, -3.0335612971124313`}, \
{-2.345160376735089, -2.8121101784325298`}}]}, 
        {Arrowheads[{{0.024641900403865578`, 1.}}], 
         ArrowBox[{{-2.1477447107865673`, -3.043638786084266}, \
{-1.9772552892134327`, -2.802032689460695}}]}, 
        {Arrowheads[{{0.025253188443406255`, 1.}}], 
         ArrowBox[{{-1.7632595653302188`, -3.054055154083753}, \
{-1.6117404346697812`, -2.791616321461208}}]}, 
        {Arrowheads[{{0.025830169995799682`, 1.}}], 
         ArrowBox[{{-1.3759870473001687`, -3.064216469760736}, \
{-1.2490129526998313`, -2.781455005784225}}]}, 
        {Arrowheads[{{0.02632914383241547, 1.}}], 
         ArrowBox[{{-0.9857492530857516, -3.0732620217616686`}, \
{-0.8892507469142484, -2.7724094537832924`}}]}, 
        {Arrowheads[{{0.026700697580848528`, 1.}}], 
         ArrowBox[{{-0.5927757452703726, -3.0801531249083753`}, \
{-0.5322242547296274, -2.7655183506365857`}}]}, 
        {Arrowheads[{{0.026900034471024223`, 1.}}], 
         ArrowBox[{{-0.19783258945127188`, -3.0839048669026585`}, \
{-0.17716741054872812`, -2.7617666086423025`}}]}, 
        {Arrowheads[{{0.026900034471024223`, 1.}}], 
         ArrowBox[{{0.19783258945127188`, -3.0839048669026585`}, {
          0.17716741054872812`, -2.7617666086423025`}}]}, 
        {Arrowheads[{{0.026700697580848528`, 1.}}], 
         ArrowBox[{{0.5927757452703726, -3.0801531249083753`}, {
          0.5322242547296274, -2.7655183506365857`}}]}, 
        {Arrowheads[{{0.02632914383241547, 1.}}], 
         ArrowBox[{{0.9857492530857516, -3.0732620217616686`}, {
          0.8892507469142484, -2.7724094537832924`}}]}, 
        {Arrowheads[{{0.025830169995799682`, 1.}}], 
         ArrowBox[{{1.3759870473001687`, -3.064216469760736}, {
          1.2490129526998313`, -2.781455005784225}}]}, 
        {Arrowheads[{{0.025253188443406255`, 1.}}], 
         ArrowBox[{{1.7632595653302188`, -3.054055154083753}, {
          1.6117404346697812`, -2.791616321461208}}]}, 
        {Arrowheads[{{0.024641900403865578`, 1.}}], 
         ArrowBox[{{2.1477447107865673`, -3.043638786084266}, {
          1.9772552892134327`, -2.802032689460695}}]}, 
        {Arrowheads[{{0.024029354453257726`, 1.}}], 
         ArrowBox[{{2.529839623264911, -3.0335612971124313`}, {
          2.345160376735089, -2.8121101784325298`}}]}, 
        {Arrowheads[{{0.023437499999999986`, 1.}}], 
         ArrowBox[{{2.910005893867716, -3.024166835102262}, {
          2.714994106132284, -2.821504640442699}}]}, 
        {Arrowheads[{{0.024321413216362556`, 1.}}], 
         ArrowBox[{{-2.728717545287428, -2.70072995882426}, \
{-2.521282454712572, -2.495422463882372}}]}, 
        {Arrowheads[{{0.025058381392269593`, 1.}}], 
         ArrowBox[{{-2.3484273681626986`, -2.711730346362037}, \
{-2.1515726318373014`, -2.484422076344595}}]}, 
        {Arrowheads[{{0.02583016999579966, 1.}}], 
         ArrowBox[{{-1.965695781857384, -2.7237479731206538`}, \
{-1.784304218142616, -2.4724044495859783`}}]}, 
        {Arrowheads[{{0.026604551665693355`, 1.}}], 
         ArrowBox[{{-1.57981365499708, -2.7363175169460323`}, \
{-1.42018634500292, -2.4598349057605997`}}]}, 
        {Arrowheads[{{0.027329737726391513`, 1.}}], 
         ArrowBox[{{-1.1901584194716721`, -2.748553135441078}, \
{-1.0598415805283279`, -2.447599287265554}}]}, 
        {Arrowheads[{{0.02793510866744529, 1.}}], 
         ArrowBox[{{-0.796486830778215, -2.7591113169347663`}, \
{-0.703513169221785, -2.4370411057718657`}}]}, 
        {Arrowheads[{{0.028342018665776788`, 1.}}], 
         ArrowBox[{{-0.3992931588563801, -2.766384153015685}, \
{-0.3507068411436199, -2.429768269690947}}]}, 
        {Arrowheads[{{0.02848606122799698, 1.}}], 
         ArrowBox[{{0., -2.768992578721298}, {0., -2.427159843985334}}]}, 
        {Arrowheads[{{0.028342018665776788`, 1.}}], 
         ArrowBox[{{0.3992931588563801, -2.766384153015685}, {
          0.3507068411436199, -2.429768269690947}}]}, 
        {Arrowheads[{{0.02793510866744529, 1.}}], 
         ArrowBox[{{0.796486830778215, -2.7591113169347663`}, {
          0.703513169221785, -2.4370411057718657`}}]}, 
        {Arrowheads[{{0.027329737726391513`, 1.}}], 
         ArrowBox[{{1.1901584194716721`, -2.748553135441078}, {
          1.0598415805283279`, -2.447599287265554}}]}, 
        {Arrowheads[{{0.026604551665693355`, 1.}}], 
         ArrowBox[{{1.57981365499708, -2.7363175169460323`}, {
          1.42018634500292, -2.4598349057605997`}}]}, 
        {Arrowheads[{{0.02583016999579966, 1.}}], 
         ArrowBox[{{1.965695781857384, -2.7237479731206538`}, {
          1.784304218142616, -2.4724044495859783`}}]}, 
        {Arrowheads[{{0.025058381392269593`, 1.}}], 
         ArrowBox[{{2.3484273681626986`, -2.711730346362037}, {
          2.1515726318373014`, -2.484422076344595}}]}, 
        {Arrowheads[{{0.024321413216362556`, 1.}}], 
         ArrowBox[{{2.728717545287428, -2.70072995882426}, {
          2.521282454712572, -2.495422463882372}}]}, 
        {Arrowheads[{{0.024531631026647693`, 1.}}], 
         ArrowBox[{{-2.926971523654127, -2.365842915928911}, \
{-2.698028476345873, -2.180790453939392}}]}, 
        {Arrowheads[{{0.025389180025401133`, 1.}}], 
         ArrowBox[{{-2.5489037311179445`, -2.377216566252856}, \
{-2.3260962688820555`, -2.169416803615447}}]}, 
        {Arrowheads[{{0.026329143832415473`, 1.}}], 
         ArrowBox[{{-2.1686483567886534`, -2.3903149058146314`}, \
{-1.9563516432113466`, -2.1563184640536717`}}]}, 
        {Arrowheads[{{0.02732973772639148, 1.}}], 
         ArrowBox[{{-1.7852376292075083`, -2.4049839935109434`}, \
{-1.5897623707924917`, -2.1416493763573596`}}]}, 
        {Arrowheads[{{0.028342018665776802`, 1.}}], 
         ArrowBox[{{-1.3975260559973304`, -2.4205861338887242`}, \
{-1.2274739440026696`, -2.126047235979579}}]}, 
        {Arrowheads[{{0.029280111741826292`, 1.}}], 
         ArrowBox[{{-1.0044776276971112`, -2.4357288007327123`}, \
{-0.8705223723028886, -2.1109045691355908`}}]}, 
        {Arrowheads[{{0.030022456114264254`, 1.}}], 
         ArrowBox[{{-0.6057669642324424, -2.4481780390604815`}, \
{-0.5192330357675576, -2.0984553308078215`}}]}, 
        {Arrowheads[{{0.030438000321360164`, 1.}}], 
         ArrowBox[{{-0.20251192928529527`, -2.4553266546264894`}, \
{-0.17248807071470473`, -2.0913067152418137`}}]}, 
        {Arrowheads[{{0.030438000321360164`, 1.}}], 
         ArrowBox[{{0.20251192928529527`, -2.4553266546264894`}, {
          0.17248807071470473`, -2.0913067152418137`}}]}, 
        {Arrowheads[{{0.030022456114264254`, 1.}}], 
         ArrowBox[{{0.6057669642324424, -2.4481780390604815`}, {
          0.5192330357675576, -2.0984553308078215`}}]}, 
        {Arrowheads[{{0.029280111741826292`, 1.}}], 
         ArrowBox[{{1.0044776276971112`, -2.4357288007327123`}, {
          0.8705223723028886, -2.1109045691355908`}}]}, 
        {Arrowheads[{{0.028342018665776802`, 1.}}], 
         ArrowBox[{{1.3975260559973304`, -2.4205861338887242`}, {
          1.2274739440026696`, -2.126047235979579}}]}, 
        {Arrowheads[{{0.02732973772639148, 1.}}], 
         ArrowBox[{{1.7852376292075083`, -2.4049839935109434`}, {
          1.5897623707924917`, -2.1416493763573596`}}]}, 
        {Arrowheads[{{0.026329143832415473`, 1.}}], 
         ArrowBox[{{2.1686483567886534`, -2.3903149058146314`}, {
          1.9563516432113466`, -2.1563184640536717`}}]}, 
        {Arrowheads[{{0.025389180025401133`, 1.}}], 
         ArrowBox[{{2.5489037311179445`, -2.377216566252856}, {
          2.3260962688820555`, -2.169416803615447}}]}, 
        {Arrowheads[{{0.024531631026647693`, 1.}}], 
         ArrowBox[{{2.926971523654127, -2.365842915928911}, {
          2.698028476345873, -2.180790453939392}}]}, 
        {Arrowheads[{{0.025603146138310023`, 1.}}], 
         ArrowBox[{{-2.7483490557750283`, -2.0401200863726996`}, \
{-2.5016509442249717`, -1.8569942306572744`}}]}, 
        {Arrowheads[{{0.02670069758084855, 1.}}], 
         ArrowBox[{{-2.3711029810814903`, -2.0534354166055837`}, \
{-2.1288970189185097`, -1.8436789004243903`}}]}, 
        {Arrowheads[{{0.02793510866744528, 1.}}], 
         ArrowBox[{{-1.9912170769455375`, -2.0693334877010745`}, \
{-1.7587829230544625`, -1.8277808293288995`}}]}, 
        {Arrowheads[{{0.029280111741826292`, 1.}}], 
         ArrowBox[{{-1.607164204315378, -2.087767543485182}, \
{-1.392835795684622, -1.809346773544792}}]}, 
        {Arrowheads[{{0.030658641332554703`, 1.}}], 
         ArrowBox[{{-1.216975923997664, -2.107864131952035}, \
{-1.033024076002336, -1.7892501850779392`}}]}, 
        {Arrowheads[{{0.031917546642555514`, 1.}}], 
         ArrowBox[{{-0.8187907272562783, -2.1272807105612177`}, \
{-0.6812092727437217, -1.7698336064687563`}}]}, 
        {Arrowheads[{{0.032829905038718125`, 1.}}], 
         ArrowBox[{{-0.4122256132707062, -2.141987119098307}, \
{-0.3377743867292938, -1.755127197931667}}]}, 
        {Arrowheads[{{0.033167320748959506`, 1.}}], 
         ArrowBox[{{0., -2.147561083008744}, {0., -1.74955323402123}}]}, 
        {Arrowheads[{{0.032829905038718125`, 1.}}], 
         ArrowBox[{{0.4122256132707062, -2.141987119098307}, {
          0.3377743867292938, -1.755127197931667}}]}, 
        {Arrowheads[{{0.031917546642555514`, 1.}}], 
         ArrowBox[{{0.8187907272562783, -2.1272807105612177`}, {
          0.6812092727437217, -1.7698336064687563`}}]}, 
        {Arrowheads[{{0.030658641332554703`, 1.}}], 
         ArrowBox[{{1.216975923997664, -2.107864131952035}, {
          1.033024076002336, -1.7892501850779392`}}]}, 
        {Arrowheads[{{0.029280111741826292`, 1.}}], 
         ArrowBox[{{1.607164204315378, -2.087767543485182}, {
          1.392835795684622, -1.809346773544792}}]}, 
        {Arrowheads[{{0.02793510866744528, 1.}}], 
         ArrowBox[{{1.9912170769455375`, -2.0693334877010745`}, {
          1.7587829230544625`, -1.8277808293288995`}}]}, 
        {Arrowheads[{{0.02670069758084855, 1.}}], 
         ArrowBox[{{2.3711029810814903`, -2.0534354166055837`}, {
          2.1288970189185097`, -1.8436789004243903`}}]}, 
        {Arrowheads[{{0.025603146138310023`, 1.}}], 
         ArrowBox[{{2.7483490557750283`, -2.0401200863726996`}, {
          2.5016509442249717`, -1.8569942306572744`}}]}, 
        {Arrowheads[{{0.025677305515419458`, 1.}}], 
         ArrowBox[{{-2.945923193262525, -1.7008295486420808`}, \
{-2.679076806737475, -1.5467657155495642`}}]}, 
        {Arrowheads[{{0.026900034471024212`, 1.}}], 
         ArrowBox[{{-2.5718236628665343`, -1.7132804816125882`}, \
{-2.3031763371334657`, -1.5343147825790568`}}]}, 
        {Arrowheads[{{0.02834201866577681, 1.}}], 
         ArrowBox[{{-2.1961123737100907`, -1.728990095634803}, \
{-1.9288876262899093`, -1.518605168556842}}]}, 
        {Arrowheads[{{0.030022456114264236`, 1.}}], 
         ArrowBox[{{-1.8173008926973273`, -1.7486985993289152`}, \
{-1.5576991073026727`, -1.4988966648627298`}}]}, 
        {Arrowheads[{{0.031917546642555535`, 1.}}], 
         ArrowBox[{{-1.432883772698487, -1.7727339254676817`}, \
{-1.192116227301513, -1.4748613387239633`}}]}, 
        {Arrowheads[{{0.03390191306604375, 1.}}], 
         ArrowBox[{{-1.0392057391981313`, -1.7999571398083354`}, \
{-0.8357942608018687, -1.4476381243833096`}}]}, 
        {Arrowheads[{{0.03567448011942978, 1.}}], 
         ArrowBox[{{-0.6325632880823504, -1.826052923269099}, \
{-0.4924367119176496, -1.421542340922546}}]}, 
        {Arrowheads[{{0.03676400961151064, 1.}}], 
         ArrowBox[{{-0.2128027267351473, -1.842925673472355}, \
{-0.1621972732648527, -1.40466959071929}}]}, 
        {Arrowheads[{{0.03676400961151064, 1.}}], 
         ArrowBox[{{0.2128027267351473, -1.842925673472355}, {
          0.1621972732648527, -1.40466959071929}}]}, 
        {Arrowheads[{{0.03567448011942978, 1.}}], 
         ArrowBox[{{0.6325632880823504, -1.826052923269099}, {
          0.4924367119176496, -1.421542340922546}}]}, 
        {Arrowheads[{{0.03390191306604375, 1.}}], 
         ArrowBox[{{1.0392057391981313`, -1.7999571398083354`}, {
          0.8357942608018687, -1.4476381243833096`}}]}, 
        {Arrowheads[{{0.031917546642555535`, 1.}}], 
         ArrowBox[{{1.432883772698487, -1.7727339254676817`}, {
          1.192116227301513, -1.4748613387239633`}}]}, 
        {Arrowheads[{{0.030022456114264236`, 1.}}], 
         ArrowBox[{{1.8173008926973273`, -1.7486985993289152`}, {
          1.5576991073026727`, -1.4988966648627298`}}]}, 
        {Arrowheads[{{0.02834201866577681, 1.}}], 
         ArrowBox[{{2.1961123737100907`, -1.728990095634803}, {
          1.9288876262899093`, -1.518605168556842}}]}, 
        {Arrowheads[{{0.026900034471024212`, 1.}}], 
         ArrowBox[{{2.5718236628665343`, -1.7132804816125882`}, {
          2.3031763371334657`, -1.5343147825790568`}}]}, 
        {Arrowheads[{{0.025677305515419458`, 1.}}], 
         ArrowBox[{{2.945923193262525, -1.7008295486420808`}, {
          2.679076806737475, -1.5467657155495642`}}]}, 
        {Arrowheads[{{0.026900034471024237`, 1.}}], 
         ArrowBox[{{-2.7696562523178065`, -1.3706243852900704`}, \
{-2.4803437476821935`, -1.2274518260632457`}}]}, 
        {Arrowheads[{{0.02848606122799699, 1.}}], 
         ArrowBox[{{-2.398017916063226, -1.384496289360649}, \
{-2.101982083936774, -1.213579921992667}}]}, 
        {Arrowheads[{{0.030438000321360178`, 1.}}], 
         ArrowBox[{{-2.0251192928529527`, -1.4030438026437082`}, \
{-1.7248807071470473`, -1.1950324087096078`}}]}, 
        {Arrowheads[{{0.03282990503871814, 1.}}], 
         ArrowBox[{{-1.648902453082825, -1.4279914127322049`}, \
{-1.351097546917175, -1.1700847986211111`}}]}, 
        {Arrowheads[{{0.03567448011942977, 1.}}], 
         ArrowBox[{{-1.2651265761647008`, -1.4608423386152791`}, \
{-0.9848734238352993, -1.1372338727380369`}}]}, 
        {Arrowheads[{{0.03876682066627735, 1.}}], 
         ArrowBox[{{-0.866300461998832, -1.5004764148023686`}, \
{-0.633699538001168, -1.0975997965509474`}}]}, 
        {Arrowheads[{{0.0414279346697812, 1.}}], 
         ArrowBox[{{-0.4439402504716008, -1.5378541386833318`}, \
{-0.3060597495283992, -1.0602220726699843`}}]}, 
        {Arrowheads[{{0.04252983979088457, 1.}}], 
         ArrowBox[{{0., -1.5542171444219655`}, {
          0., -1.0438590669313506`}}]}, 
        {Arrowheads[{{0.0414279346697812, 1.}}], 
         ArrowBox[{{0.4439402504716008, -1.5378541386833318`}, {
          0.3060597495283992, -1.0602220726699843`}}]}, 
        {Arrowheads[{{0.03876682066627735, 1.}}], 
         ArrowBox[{{0.866300461998832, -1.5004764148023686`}, {
          0.633699538001168, -1.0975997965509474`}}]}, 
        {Arrowheads[{{0.03567448011942977, 1.}}], 
         ArrowBox[{{1.2651265761647008`, -1.4608423386152791`}, {
          0.9848734238352993, -1.1372338727380369`}}]}, 
        {Arrowheads[{{0.03282990503871814, 1.}}], 
         ArrowBox[{{1.648902453082825, -1.4279914127322049`}, {
          1.351097546917175, -1.1700847986211111`}}]}, 
        {Arrowheads[{{0.030438000321360178`, 1.}}], 
         ArrowBox[{{2.0251192928529527`, -1.4030438026437082`}, {
          1.7248807071470473`, -1.1950324087096078`}}]}, 
        {Arrowheads[{{0.02848606122799699, 1.}}], 
         ArrowBox[{{2.398017916063226, -1.384496289360649}, {
          2.101982083936774, -1.213579921992667}}]}, 
        {Arrowheads[{{0.026900034471024237`, 1.}}], 
         ArrowBox[{{2.7696562523178065`, -1.3706243852900704`}, {
          2.4803437476821935`, -1.2274518260632457`}}]}, 
        {Arrowheads[{{0.02670069758084853, 1.}}], 
         ArrowBox[{{-2.9638787263518624`, -1.0267177083027919`}, \
{-2.6611212736481376`, -0.9218394502121952}}]}, 
        {Arrowheads[{{0.028342018665776788`, 1.}}], 
         ArrowBox[{{-2.595405532566471, -1.0373940573808818`}, \
{-2.279594467433529, -0.9111631011341053}}]}, 
        {Arrowheads[{{0.030438000321360178`, 1.}}], 
         ArrowBox[{{-2.227631222138248, -1.0522828519827812`}, \
{-1.897368777861752, -0.8962743065322059}}]}, 
        {Arrowheads[{{0.03316732074895953, 1.}}], 
         ArrowBox[{{-1.859842454064394, -1.073780541504372}, \
{-1.515157545935606, -0.874776617010615}}]}, 
        {Arrowheads[{{0.036764009611510634`, 1.}}], 
         ArrowBox[{{-1.489619087146031, -1.105755404083413}, \
{-1.135380912853969, -0.842801754431574}}]}, 
        {Arrowheads[{{0.041427934669781195`, 1.}}], 
         ArrowBox[{{-1.109850626179002, -1.1533906040124988`}, \
{-0.765149373820998, -0.7951665545024882}}]}, 
        {Arrowheads[{{0.046875, 1.}}], 
         ArrowBox[{{-0.703125, -1.2178482240718669`}, {-0.421875, \
-0.7307089344431201}}]}, 
        {Arrowheads[{{0.046875, 1.}}], 
         ArrowBox[{{-0.24065125401692258`, -1.2504605965874214`}, \
{-0.13434874598307742`, -0.6980965619275656}}]}, 
        {Arrowheads[{{0.046875, 1.}}], 
         ArrowBox[{{0.24065125401692258`, -1.2504605965874214`}, {
          0.13434874598307742`, -0.6980965619275656}}]}, 
        {Arrowheads[{{0.046875, 1.}}], 
         ArrowBox[{{0.703125, -1.2178482240718669`}, {
          0.421875, -0.7307089344431201}}]}, 
        {Arrowheads[{{0.041427934669781195`, 1.}}], 
         ArrowBox[{{1.109850626179002, -1.1533906040124988`}, {
          0.765149373820998, -0.7951665545024882}}]}, 
        {Arrowheads[{{0.036764009611510634`, 1.}}], 
         ArrowBox[{{1.489619087146031, -1.105755404083413}, {
          1.135380912853969, -0.842801754431574}}]}, 
        {Arrowheads[{{0.03316732074895953, 1.}}], 
         ArrowBox[{{1.859842454064394, -1.073780541504372}, {
          1.515157545935606, -0.874776617010615}}]}, 
        {Arrowheads[{{0.030438000321360178`, 1.}}], 
         ArrowBox[{{2.227631222138248, -1.0522828519827812`}, {
          1.897368777861752, -0.8962743065322059}}]}, 
        {Arrowheads[{{0.028342018665776788`, 1.}}], 
         ArrowBox[{{2.595405532566471, -1.0373940573808818`}, {
          2.279594467433529, -0.9111631011341053}}]}, 
        {Arrowheads[{{0.02670069758084853, 1.}}], 
         ArrowBox[{{2.9638787263518624`, -1.0267177083027919`}, {
          2.6611212736481376`, -0.9218394502121952}}]}, 
        {Arrowheads[{{0.02793510866744531, 1.}}], 
         ArrowBox[{{-2.7877039077237526`, -0.6897778292336916}, \
{-2.4622960922762474`, -0.6092602764429664}}]}, 
        {Arrowheads[{{0.030022456114264223`, 1.}}], 
         ArrowBox[{{-2.42306785692977, -0.6994794397315661}, \
{-2.07693214307023, -0.5995586659450919}}]}, 
        {Arrowheads[{{0.032829905038718146`, 1.}}], 
         ArrowBox[{{-2.061128066353531, -0.7139957063661024}, \
{-1.6888719336464688`, -0.5850423993105556}}]}, 
        {Arrowheads[{{0.03676400961151065, 1.}}], 
         ArrowBox[{{-1.7024218138811784`, -0.737170269388942}, \
{-1.2975781861188216`, -0.561867836287716}}]}, 
        {Arrowheads[{{0.04252983979088457, 1.}}], 
         ArrowBox[{{-1.3459915300667298`, -0.7771085722109827}, \
{-0.9040084699332702, -0.5219295334656753}}]}, 
        {Arrowheads[{{0.046875, 1.}}], 
         ArrowBox[{{-0.9626050160676903, -0.8336403977249476}, \
{-0.5373949839323097, -0.4653977079517104}}]}, 
        {Arrowheads[{{0.046875, 1.}}], 
         ArrowBox[{{-0.515625, -0.8930886976527024}, {-0.234375, \
-0.4059494080239556}}]}, 
        {Arrowheads[{{0.046875, 1.}}], 
         ArrowBox[{{0., -0.930769052838329}, {0., -0.368269052838329}}]}, 
        {Arrowheads[{{0.046875, 1.}}], 
         ArrowBox[{{0.515625, -0.8930886976527024}, {
          0.234375, -0.4059494080239556}}]}, 
        {Arrowheads[{{0.046875, 1.}}], 
         ArrowBox[{{0.9626050160676903, -0.8336403977249476}, {
          0.5373949839323097, -0.4653977079517104}}]}, 
        {Arrowheads[{{0.04252983979088457, 1.}}], 
         ArrowBox[{{1.3459915300667298`, -0.7771085722109827}, {
          0.9040084699332702, -0.5219295334656753}}]}, 
        {Arrowheads[{{0.03676400961151065, 1.}}], 
         ArrowBox[{{1.7024218138811784`, -0.737170269388942}, {
          1.2975781861188216`, -0.561867836287716}}]}, 
        {Arrowheads[{{0.032829905038718146`, 1.}}], 
         ArrowBox[{{2.061128066353531, -0.7139957063661024}, {
          1.6888719336464688`, -0.5850423993105556}}]}, 
        {Arrowheads[{{0.030022456114264223`, 1.}}], 
         ArrowBox[{{2.42306785692977, -0.6994794397315661}, {
          2.07693214307023, -0.5995586659450919}}]}, 
        {Arrowheads[{{0.02793510866744531, 1.}}], 
         ArrowBox[{{2.7877039077237526`, -0.6897778292336916}, {
          2.4622960922762474`, -0.6092602764429664}}]}, 
        {Arrowheads[{{0.027329737726391513`, 1.}}], 
         ArrowBox[{{-2.9753960486791806`, -0.34356914193013477`}, \
{-2.6496039513208194`, -0.30594991090819423`}}]}, 
        {Arrowheads[{{0.029280111741826337`, 1.}}], 
         ArrowBox[{{-2.6116418320124897`, -0.34796125724753035`}, \
{-2.2633581679875103`, -0.30155779559079865`}}]}, 
        {Arrowheads[{{0.031917546642555535`, 1.}}], 
         ArrowBox[{{-2.2516744999547655`, -0.3545467850935363}, \
{-1.8733255000452345`, -0.2949722677447927}}]}, 
        {Arrowheads[{{0.03567448011942976, 1.}}], 
         ArrowBox[{{-1.897689864247051, -0.3652105846538198}, \
{-1.477310135752949, -0.2843084681845092}}]}, 
        {Arrowheads[{{0.04142793466978121, 1.}}], 
         ArrowBox[{{-1.553790876650603, -0.38446353467083294`}, \
{-1.071209123349397, -0.26505551816749606`}}]}, 
        {Arrowheads[{{0.04687500000000002, 1.}}], 
         ArrowBox[{{-1.203256270084613, -0.4168201988624738}, \
{-0.671743729915387, -0.2326988539758552}}]}, 
        {Arrowheads[{{0.046875, 1.}}], 
         ArrowBox[{{-0.8060696448143734, -0.4653845264191645}, \
{-0.3189303551856266, -0.1841345264191645}}]}, 
        {Arrowheads[{{0.046875, 1.}}], 
         ArrowBox[{{-0.328125, -0.5683291712335379}, {-0.046875, \
-0.08118988160479113}}]}, 
        {Arrowheads[{{0.046875, 1.}}], 
         ArrowBox[{{0.328125, -0.5683291712335379}, {
          0.046875, -0.08118988160479113}}]}, 
        {Arrowheads[{{0.046875, 1.}}], 
         ArrowBox[{{0.8060696448143734, -0.4653845264191645}, {
          0.3189303551856266, -0.1841345264191645}}]}, 
        {Arrowheads[{{0.04687500000000002, 1.}}], 
         ArrowBox[{{1.203256270084613, -0.4168201988624738}, {
          0.671743729915387, -0.2326988539758552}}]}, 
        {Arrowheads[{{0.04142793466978121, 1.}}], 
         ArrowBox[{{1.553790876650603, -0.38446353467083294`}, {
          1.071209123349397, -0.26505551816749606`}}]}, 
        {Arrowheads[{{0.03567448011942976, 1.}}], 
         ArrowBox[{{1.897689864247051, -0.3652105846538198}, {
          1.477310135752949, -0.2843084681845092}}]}, 
        {Arrowheads[{{0.031917546642555535`, 1.}}], 
         ArrowBox[{{2.2516744999547655`, -0.3545467850935363}, {
          1.8733255000452345`, -0.2949722677447927}}]}, 
        {Arrowheads[{{0.029280111741826337`, 1.}}], 
         ArrowBox[{{2.6116418320124897`, -0.34796125724753035`}, {
          2.2633581679875103`, -0.30155779559079865`}}]}, 
        {Arrowheads[{{0.027329737726391513`, 1.}}], 
         ArrowBox[{{2.9753960486791806`, -0.34356914193013477`}, {
          2.6496039513208194`, -0.30594991090819423`}}]}, 
        {Arrowheads[{{0.02834201866577679, 1.}}], 
         ArrowBox[{{-2.7950521119946607`, 0.}, {-2.4549478880053393`, 
          0.}}]}, 
        {Arrowheads[{{0.030658641332554692`, 1.}}], 
         ArrowBox[{{-2.433951847995328, 0.}, {-2.066048152004672, 0.}}]}, 
        {Arrowheads[{{0.033901913066043766`, 1.}}], 
         ArrowBox[{{-2.0784114783962626`, 0.}, {-1.6715885216037374`, 
          0.}}]}, 
        {Arrowheads[{{0.038766820666277346`, 1.}}], 
         ArrowBox[{{-1.732600923997664, 0.}, {-1.267399076002336, 0.}}]}, 
        {Arrowheads[{{0.046875, 1.}}], 
         ArrowBox[{{-1.40625, 0.}, {-0.84375, 0.}}]}, 
        {Arrowheads[{{0.046875, 1.}}], 
         ArrowBox[{{-1.03125, 0.}, {-0.46875, 0.}}]}, 
        {Arrowheads[{{0.046875, 1.}}], 
         ArrowBox[{{-0.65625, 0.}, {-0.09375, 0.}}]}, 
        {Arrowheads[{{0.046875, 1.}}], 
         ArrowBox[{{-0.28125, 0.}, {0.28125, 0.}}]}, 
        {Arrowheads[{{0.046875, 1.}}], 
         ArrowBox[{{0.65625, 0.}, {0.09375, 0.}}]}, 
        {Arrowheads[{{0.046875, 1.}}], 
         ArrowBox[{{1.03125, 0.}, {0.46875, 0.}}]}, 
        {Arrowheads[{{0.046875, 1.}}], 
         ArrowBox[{{1.40625, 0.}, {0.84375, 0.}}]}, 
        {Arrowheads[{{0.038766820666277346`, 1.}}], 
         ArrowBox[{{1.732600923997664, 0.}, {1.267399076002336, 0.}}]}, 
        {Arrowheads[{{0.033901913066043766`, 1.}}], 
         ArrowBox[{{2.0784114783962626`, 0.}, {1.6715885216037374`, 0.}}]}, 
        {Arrowheads[{{0.030658641332554692`, 1.}}], 
         ArrowBox[{{2.433951847995328, 0.}, {2.066048152004672, 0.}}]}, 
        {Arrowheads[{{0.02834201866577679, 1.}}], 
         ArrowBox[{{2.7950521119946607`, 0.}, {2.4549478880053393`, 0.}}]}, 
        {Arrowheads[{{0.027329737726391513`, 1.}}], 
         ArrowBox[{{-2.9753960486791806`, 
          0.34356914193013477`}, {-2.6496039513208194`, 
          0.30594991090819423`}}]}, 
        {Arrowheads[{{0.029280111741826337`, 1.}}], 
         ArrowBox[{{-2.6116418320124897`, 
          0.34796125724753035`}, {-2.2633581679875103`, 
          0.30155779559079865`}}]}, 
        {Arrowheads[{{0.031917546642555535`, 1.}}], 
         ArrowBox[{{-2.2516744999547655`, 
          0.3545467850935363}, {-1.8733255000452345`, 
          0.2949722677447927}}]}, 
        {Arrowheads[{{0.03567448011942976, 1.}}], 
         ArrowBox[{{-1.897689864247051, 
          0.3652105846538198}, {-1.477310135752949, 0.2843084681845092}}]}, 
        {Arrowheads[{{0.04142793466978121, 1.}}], 
         ArrowBox[{{-1.553790876650603, 
          0.38446353467083294`}, {-1.071209123349397, 
          0.26505551816749606`}}]}, 
        {Arrowheads[{{0.04687500000000002, 1.}}], 
         ArrowBox[{{-1.203256270084613, 
          0.4168201988624738}, {-0.671743729915387, 0.2326988539758552}}]}, 
        {Arrowheads[{{0.046875, 1.}}], 
         ArrowBox[{{-0.8060696448143734, 
          0.4653845264191645}, {-0.3189303551856266, 0.1841345264191645}}]}, 
        {Arrowheads[{{0.046875, 1.}}], 
         ArrowBox[{{-0.328125, 0.5683291712335379}, {-0.046875, 
          0.08118988160479113}}]}, 
        {Arrowheads[{{0.046875, 1.}}], 
         ArrowBox[{{0.328125, 0.5683291712335379}, {0.046875, 
          0.08118988160479113}}]}, 
        {Arrowheads[{{0.046875, 1.}}], 
         ArrowBox[{{0.8060696448143734, 0.4653845264191645}, {
          0.3189303551856266, 0.1841345264191645}}]}, 
        {Arrowheads[{{0.04687500000000002, 1.}}], 
         ArrowBox[{{1.203256270084613, 0.4168201988624738}, {
          0.671743729915387, 0.2326988539758552}}]}, 
        {Arrowheads[{{0.04142793466978121, 1.}}], 
         ArrowBox[{{1.553790876650603, 0.38446353467083294`}, {
          1.071209123349397, 0.26505551816749606`}}]}, 
        {Arrowheads[{{0.03567448011942976, 1.}}], 
         ArrowBox[{{1.897689864247051, 0.3652105846538198}, {
          1.477310135752949, 0.2843084681845092}}]}, 
        {Arrowheads[{{0.031917546642555535`, 1.}}], 
         ArrowBox[{{2.2516744999547655`, 0.3545467850935363}, {
          1.8733255000452345`, 0.2949722677447927}}]}, 
        {Arrowheads[{{0.029280111741826337`, 1.}}], 
         ArrowBox[{{2.6116418320124897`, 0.34796125724753035`}, {
          2.2633581679875103`, 0.30155779559079865`}}]}, 
        {Arrowheads[{{0.027329737726391513`, 1.}}], 
         ArrowBox[{{2.9753960486791806`, 0.34356914193013477`}, {
          2.6496039513208194`, 0.30594991090819423`}}]}, 
        {Arrowheads[{{0.02793510866744531, 1.}}], 
         ArrowBox[{{-2.7877039077237526`, 
          0.6897778292336916}, {-2.4622960922762474`, 
          0.6092602764429664}}]}, 
        {Arrowheads[{{0.030022456114264223`, 1.}}], 
         ArrowBox[{{-2.42306785692977, 
          0.6994794397315661}, {-2.07693214307023, 0.5995586659450919}}]}, 
        {Arrowheads[{{0.032829905038718146`, 1.}}], 
         ArrowBox[{{-2.061128066353531, 
          0.7139957063661024}, {-1.6888719336464688`, 
          0.5850423993105556}}]}, 
        {Arrowheads[{{0.03676400961151065, 1.}}], 
         ArrowBox[{{-1.7024218138811784`, 
          0.737170269388942}, {-1.2975781861188216`, 0.561867836287716}}]}, 
        {Arrowheads[{{0.04252983979088457, 1.}}], 
         ArrowBox[{{-1.3459915300667298`, 
          0.7771085722109827}, {-0.9040084699332702, 0.5219295334656753}}]}, 
        {Arrowheads[{{0.046875, 1.}}], 
         ArrowBox[{{-0.9626050160676903, 
          0.8336403977249476}, {-0.5373949839323097, 0.4653977079517104}}]}, 
        {Arrowheads[{{0.046875, 1.}}], 
         ArrowBox[{{-0.515625, 0.8930886976527024}, {-0.234375, 
          0.4059494080239556}}]}, 
        {Arrowheads[{{0.046875, 1.}}], 
         ArrowBox[{{0., 0.930769052838329}, {0., 0.368269052838329}}]}, 
        {Arrowheads[{{0.046875, 1.}}], 
         ArrowBox[{{0.515625, 0.8930886976527024}, {0.234375, 
          0.4059494080239556}}]}, 
        {Arrowheads[{{0.046875, 1.}}], 
         ArrowBox[{{0.9626050160676903, 0.8336403977249476}, {
          0.5373949839323097, 0.4653977079517104}}]}, 
        {Arrowheads[{{0.04252983979088457, 1.}}], 
         ArrowBox[{{1.3459915300667298`, 0.7771085722109827}, {
          0.9040084699332702, 0.5219295334656753}}]}, 
        {Arrowheads[{{0.03676400961151065, 1.}}], 
         ArrowBox[{{1.7024218138811784`, 0.737170269388942}, {
          1.2975781861188216`, 0.561867836287716}}]}, 
        {Arrowheads[{{0.032829905038718146`, 1.}}], 
         ArrowBox[{{2.061128066353531, 0.7139957063661024}, {
          1.6888719336464688`, 0.5850423993105556}}]}, 
        {Arrowheads[{{0.030022456114264223`, 1.}}], 
         ArrowBox[{{2.42306785692977, 0.6994794397315661}, {2.07693214307023, 
          0.5995586659450919}}]}, 
        {Arrowheads[{{0.02793510866744531, 1.}}], 
         ArrowBox[{{2.7877039077237526`, 0.6897778292336916}, {
          2.4622960922762474`, 0.6092602764429664}}]}, 
        {Arrowheads[{{0.02670069758084853, 1.}}], 
         ArrowBox[{{-2.9638787263518624`, 
          1.0267177083027919`}, {-2.6611212736481376`, 0.9218394502121952}}]}, 
        {Arrowheads[{{0.028342018665776788`, 1.}}], 
         ArrowBox[{{-2.595405532566471, 
          1.0373940573808818`}, {-2.279594467433529, 0.9111631011341053}}]}, 
        {Arrowheads[{{0.030438000321360178`, 1.}}], 
         ArrowBox[{{-2.227631222138248, 
          1.0522828519827812`}, {-1.897368777861752, 0.8962743065322059}}]}, 
        {Arrowheads[{{0.03316732074895953, 1.}}], 
         ArrowBox[{{-1.859842454064394, 
          1.073780541504372}, {-1.515157545935606, 0.874776617010615}}]}, 
        {Arrowheads[{{0.036764009611510634`, 1.}}], 
         ArrowBox[{{-1.489619087146031, 
          1.105755404083413}, {-1.135380912853969, 0.842801754431574}}]}, 
        {Arrowheads[{{0.041427934669781195`, 1.}}], 
         ArrowBox[{{-1.109850626179002, 
          1.1533906040124988`}, {-0.765149373820998, 0.7951665545024882}}]}, 
        {Arrowheads[{{0.046875, 1.}}], 
         ArrowBox[{{-0.703125, 1.2178482240718669`}, {-0.421875, 
          0.7307089344431201}}]}, 
        {Arrowheads[{{0.046875, 1.}}], 
         ArrowBox[{{-0.24065125401692258`, 
          1.2504605965874214`}, {-0.13434874598307742`, 
          0.6980965619275656}}]}, 
        {Arrowheads[{{0.046875, 1.}}], 
         ArrowBox[{{0.24065125401692258`, 1.2504605965874214`}, {
          0.13434874598307742`, 0.6980965619275656}}]}, 
        {Arrowheads[{{0.046875, 1.}}], 
         ArrowBox[{{0.703125, 1.2178482240718669`}, {0.421875, 
          0.7307089344431201}}]}, 
        {Arrowheads[{{0.041427934669781195`, 1.}}], 
         ArrowBox[{{1.109850626179002, 1.1533906040124988`}, {
          0.765149373820998, 0.7951665545024882}}]}, 
        {Arrowheads[{{0.036764009611510634`, 1.}}], 
         ArrowBox[{{1.489619087146031, 1.105755404083413}, {1.135380912853969,
           0.842801754431574}}]}, 
        {Arrowheads[{{0.03316732074895953, 1.}}], 
         ArrowBox[{{1.859842454064394, 1.073780541504372}, {1.515157545935606,
           0.874776617010615}}]}, 
        {Arrowheads[{{0.030438000321360178`, 1.}}], 
         ArrowBox[{{2.227631222138248, 1.0522828519827812`}, {
          1.897368777861752, 0.8962743065322059}}]}, 
        {Arrowheads[{{0.028342018665776788`, 1.}}], 
         ArrowBox[{{2.595405532566471, 1.0373940573808818`}, {
          2.279594467433529, 0.9111631011341053}}]}, 
        {Arrowheads[{{0.02670069758084853, 1.}}], 
         ArrowBox[{{2.9638787263518624`, 1.0267177083027919`}, {
          2.6611212736481376`, 0.9218394502121952}}]}, 
        {Arrowheads[{{0.026900034471024237`, 1.}}], 
         ArrowBox[{{-2.7696562523178065`, 
          1.3706243852900704`}, {-2.4803437476821935`, 
          1.2274518260632457`}}]}, 
        {Arrowheads[{{0.02848606122799699, 1.}}], 
         ArrowBox[{{-2.398017916063226, 
          1.384496289360649}, {-2.101982083936774, 1.213579921992667}}]}, 
        {Arrowheads[{{0.030438000321360178`, 1.}}], 
         ArrowBox[{{-2.0251192928529527`, 
          1.4030438026437082`}, {-1.7248807071470473`, 
          1.1950324087096078`}}]}, 
        {Arrowheads[{{0.03282990503871814, 1.}}], 
         ArrowBox[{{-1.648902453082825, 
          1.4279914127322049`}, {-1.351097546917175, 
          1.1700847986211111`}}]}, 
        {Arrowheads[{{0.03567448011942977, 1.}}], 
         ArrowBox[{{-1.2651265761647008`, 
          1.4608423386152791`}, {-0.9848734238352993, 1.1372338727380369`}}]}, 
        {Arrowheads[{{0.03876682066627735, 1.}}], 
         ArrowBox[{{-0.866300461998832, 
          1.5004764148023686`}, {-0.633699538001168, 
          1.0975997965509474`}}]}, 
        {Arrowheads[{{0.0414279346697812, 1.}}], 
         ArrowBox[{{-0.4439402504716008, 
          1.5378541386833318`}, {-0.3060597495283992, 1.0602220726699843`}}]}, 
        {Arrowheads[{{0.04252983979088457, 1.}}], 
         ArrowBox[{{0., 1.5542171444219655`}, {0., 1.0438590669313506`}}]}, 
        {Arrowheads[{{0.0414279346697812, 1.}}], 
         ArrowBox[{{0.4439402504716008, 1.5378541386833318`}, {
          0.3060597495283992, 1.0602220726699843`}}]}, 
        {Arrowheads[{{0.03876682066627735, 1.}}], 
         ArrowBox[{{0.866300461998832, 1.5004764148023686`}, {
          0.633699538001168, 1.0975997965509474`}}]}, 
        {Arrowheads[{{0.03567448011942977, 1.}}], 
         ArrowBox[{{1.2651265761647008`, 1.4608423386152791`}, {
          0.9848734238352993, 1.1372338727380369`}}]}, 
        {Arrowheads[{{0.03282990503871814, 1.}}], 
         ArrowBox[{{1.648902453082825, 1.4279914127322049`}, {
          1.351097546917175, 1.1700847986211111`}}]}, 
        {Arrowheads[{{0.030438000321360178`, 1.}}], 
         ArrowBox[{{2.0251192928529527`, 1.4030438026437082`}, {
          1.7248807071470473`, 1.1950324087096078`}}]}, 
        {Arrowheads[{{0.02848606122799699, 1.}}], 
         ArrowBox[{{2.398017916063226, 1.384496289360649}, {2.101982083936774,
           1.213579921992667}}]}, 
        {Arrowheads[{{0.026900034471024237`, 1.}}], 
         ArrowBox[{{2.7696562523178065`, 1.3706243852900704`}, {
          2.4803437476821935`, 1.2274518260632457`}}]}, 
        {Arrowheads[{{0.025677305515419458`, 1.}}], 
         ArrowBox[{{-2.945923193262525, 
          1.7008295486420808`}, {-2.679076806737475, 
          1.5467657155495642`}}]}, 
        {Arrowheads[{{0.026900034471024212`, 1.}}], 
         ArrowBox[{{-2.5718236628665343`, 
          1.7132804816125882`}, {-2.3031763371334657`, 
          1.5343147825790568`}}]}, 
        {Arrowheads[{{0.02834201866577681, 1.}}], 
         ArrowBox[{{-2.1961123737100907`, 
          1.728990095634803}, {-1.9288876262899093`, 1.518605168556842}}]}, 
        {Arrowheads[{{0.030022456114264236`, 1.}}], 
         ArrowBox[{{-1.8173008926973273`, 
          1.7486985993289152`}, {-1.5576991073026727`, 
          1.4988966648627298`}}]}, 
        {Arrowheads[{{0.031917546642555535`, 1.}}], 
         ArrowBox[{{-1.432883772698487, 
          1.7727339254676817`}, {-1.192116227301513, 
          1.4748613387239633`}}]}, 
        {Arrowheads[{{0.03390191306604375, 1.}}], 
         ArrowBox[{{-1.0392057391981313`, 
          1.7999571398083354`}, {-0.8357942608018687, 1.4476381243833096`}}]}, 
        {Arrowheads[{{0.03567448011942978, 1.}}], 
         ArrowBox[{{-0.6325632880823504, 
          1.826052923269099}, {-0.4924367119176496, 1.421542340922546}}]}, 
        {Arrowheads[{{0.03676400961151064, 1.}}], 
         ArrowBox[{{-0.2128027267351473, 
          1.842925673472355}, {-0.1621972732648527, 1.40466959071929}}]}, 
        {Arrowheads[{{0.03676400961151064, 1.}}], 
         ArrowBox[{{0.2128027267351473, 1.842925673472355}, {
          0.1621972732648527, 1.40466959071929}}]}, 
        {Arrowheads[{{0.03567448011942978, 1.}}], 
         ArrowBox[{{0.6325632880823504, 1.826052923269099}, {
          0.4924367119176496, 1.421542340922546}}]}, 
        {Arrowheads[{{0.03390191306604375, 1.}}], 
         ArrowBox[{{1.0392057391981313`, 1.7999571398083354`}, {
          0.8357942608018687, 1.4476381243833096`}}]}, 
        {Arrowheads[{{0.031917546642555535`, 1.}}], 
         ArrowBox[{{1.432883772698487, 1.7727339254676817`}, {
          1.192116227301513, 1.4748613387239633`}}]}, 
        {Arrowheads[{{0.030022456114264236`, 1.}}], 
         ArrowBox[{{1.8173008926973273`, 1.7486985993289152`}, {
          1.5576991073026727`, 1.4988966648627298`}}]}, 
        {Arrowheads[{{0.02834201866577681, 1.}}], 
         ArrowBox[{{2.1961123737100907`, 1.728990095634803}, {
          1.9288876262899093`, 1.518605168556842}}]}, 
        {Arrowheads[{{0.026900034471024212`, 1.}}], 
         ArrowBox[{{2.5718236628665343`, 1.7132804816125882`}, {
          2.3031763371334657`, 1.5343147825790568`}}]}, 
        {Arrowheads[{{0.025677305515419458`, 1.}}], 
         ArrowBox[{{2.945923193262525, 1.7008295486420808`}, {
          2.679076806737475, 1.5467657155495642`}}]}, 
        {Arrowheads[{{0.025603146138310023`, 1.}}], 
         ArrowBox[{{-2.7483490557750283`, 
          2.0401200863726996`}, {-2.5016509442249717`, 
          1.8569942306572744`}}]}, 
        {Arrowheads[{{0.02670069758084855, 1.}}], 
         ArrowBox[{{-2.3711029810814903`, 
          2.0534354166055837`}, {-2.1288970189185097`, 
          1.8436789004243903`}}]}, 
        {Arrowheads[{{0.02793510866744528, 1.}}], 
         ArrowBox[{{-1.9912170769455375`, 
          2.0693334877010745`}, {-1.7587829230544625`, 
          1.8277808293288995`}}]}, 
        {Arrowheads[{{0.029280111741826292`, 1.}}], 
         ArrowBox[{{-1.607164204315378, 
          2.087767543485182}, {-1.392835795684622, 1.809346773544792}}]}, 
        {Arrowheads[{{0.030658641332554703`, 1.}}], 
         ArrowBox[{{-1.216975923997664, 
          2.107864131952035}, {-1.033024076002336, 1.7892501850779392`}}]}, 
        {Arrowheads[{{0.031917546642555514`, 1.}}], 
         ArrowBox[{{-0.8187907272562783, 
          2.1272807105612177`}, {-0.6812092727437217, 1.7698336064687563`}}]}, 
        {Arrowheads[{{0.032829905038718125`, 1.}}], 
         ArrowBox[{{-0.4122256132707062, 
          2.141987119098307}, {-0.3377743867292938, 1.755127197931667}}]}, 
        {Arrowheads[{{0.033167320748959506`, 1.}}], 
         ArrowBox[{{0., 2.147561083008744}, {0., 1.74955323402123}}]}, 
        {Arrowheads[{{0.032829905038718125`, 1.}}], 
         ArrowBox[{{0.4122256132707062, 2.141987119098307}, {
          0.3377743867292938, 1.755127197931667}}]}, 
        {Arrowheads[{{0.031917546642555514`, 1.}}], 
         ArrowBox[{{0.8187907272562783, 2.1272807105612177`}, {
          0.6812092727437217, 1.7698336064687563`}}]}, 
        {Arrowheads[{{0.030658641332554703`, 1.}}], 
         ArrowBox[{{1.216975923997664, 2.107864131952035}, {1.033024076002336,
           1.7892501850779392`}}]}, 
        {Arrowheads[{{0.029280111741826292`, 1.}}], 
         ArrowBox[{{1.607164204315378, 2.087767543485182}, {1.392835795684622,
           1.809346773544792}}]}, 
        {Arrowheads[{{0.02793510866744528, 1.}}], 
         ArrowBox[{{1.9912170769455375`, 2.0693334877010745`}, {
          1.7587829230544625`, 1.8277808293288995`}}]}, 
        {Arrowheads[{{0.02670069758084855, 1.}}], 
         ArrowBox[{{2.3711029810814903`, 2.0534354166055837`}, {
          2.1288970189185097`, 1.8436789004243903`}}]}, 
        {Arrowheads[{{0.025603146138310023`, 1.}}], 
         ArrowBox[{{2.7483490557750283`, 2.0401200863726996`}, {
          2.5016509442249717`, 1.8569942306572744`}}]}, 
        {Arrowheads[{{0.024531631026647693`, 1.}}], 
         ArrowBox[{{-2.926971523654127, 
          2.365842915928911}, {-2.698028476345873, 2.180790453939392}}]}, 
        {Arrowheads[{{0.025389180025401133`, 1.}}], 
         ArrowBox[{{-2.5489037311179445`, 
          2.377216566252856}, {-2.3260962688820555`, 2.169416803615447}}]}, 
        {Arrowheads[{{0.026329143832415473`, 1.}}], 
         ArrowBox[{{-2.1686483567886534`, 
          2.3903149058146314`}, {-1.9563516432113466`, 
          2.1563184640536717`}}]}, 
        {Arrowheads[{{0.02732973772639148, 1.}}], 
         ArrowBox[{{-1.7852376292075083`, 
          2.4049839935109434`}, {-1.5897623707924917`, 
          2.1416493763573596`}}]}, 
        {Arrowheads[{{0.028342018665776802`, 1.}}], 
         ArrowBox[{{-1.3975260559973304`, 
          2.4205861338887242`}, {-1.2274739440026696`, 
          2.126047235979579}}]}, 
        {Arrowheads[{{0.029280111741826292`, 1.}}], 
         ArrowBox[{{-1.0044776276971112`, 
          2.4357288007327123`}, {-0.8705223723028886, 2.1109045691355908`}}]}, 
        {Arrowheads[{{0.030022456114264254`, 1.}}], 
         ArrowBox[{{-0.6057669642324424, 
          2.4481780390604815`}, {-0.5192330357675576, 2.0984553308078215`}}]}, 
        {Arrowheads[{{0.030438000321360164`, 1.}}], 
         ArrowBox[{{-0.20251192928529527`, 
          2.4553266546264894`}, {-0.17248807071470473`, 
          2.0913067152418137`}}]}, 
        {Arrowheads[{{0.030438000321360164`, 1.}}], 
         ArrowBox[{{0.20251192928529527`, 2.4553266546264894`}, {
          0.17248807071470473`, 2.0913067152418137`}}]}, 
        {Arrowheads[{{0.030022456114264254`, 1.}}], 
         ArrowBox[{{0.6057669642324424, 2.4481780390604815`}, {
          0.5192330357675576, 2.0984553308078215`}}]}, 
        {Arrowheads[{{0.029280111741826292`, 1.}}], 
         ArrowBox[{{1.0044776276971112`, 2.4357288007327123`}, {
          0.8705223723028886, 2.1109045691355908`}}]}, 
        {Arrowheads[{{0.028342018665776802`, 1.}}], 
         ArrowBox[{{1.3975260559973304`, 2.4205861338887242`}, {
          1.2274739440026696`, 2.126047235979579}}]}, 
        {Arrowheads[{{0.02732973772639148, 1.}}], 
         ArrowBox[{{1.7852376292075083`, 2.4049839935109434`}, {
          1.5897623707924917`, 2.1416493763573596`}}]}, 
        {Arrowheads[{{0.026329143832415473`, 1.}}], 
         ArrowBox[{{2.1686483567886534`, 2.3903149058146314`}, {
          1.9563516432113466`, 2.1563184640536717`}}]}, 
        {Arrowheads[{{0.025389180025401133`, 1.}}], 
         ArrowBox[{{2.5489037311179445`, 2.377216566252856}, {
          2.3260962688820555`, 2.169416803615447}}]}, 
        {Arrowheads[{{0.024531631026647693`, 1.}}], 
         ArrowBox[{{2.926971523654127, 2.365842915928911}, {2.698028476345873,
           2.180790453939392}}]}, 
        {Arrowheads[{{0.024321413216362556`, 1.}}], 
         ArrowBox[{{-2.728717545287428, 
          2.70072995882426}, {-2.521282454712572, 2.495422463882372}}]}, 
        {Arrowheads[{{0.025058381392269593`, 1.}}], 
         ArrowBox[{{-2.3484273681626986`, 
          2.711730346362037}, {-2.1515726318373014`, 2.484422076344595}}]}, 
        {Arrowheads[{{0.02583016999579966, 1.}}], 
         ArrowBox[{{-1.965695781857384, 
          2.7237479731206538`}, {-1.784304218142616, 
          2.4724044495859783`}}]}, 
        {Arrowheads[{{0.026604551665693355`, 1.}}], 
         ArrowBox[{{-1.57981365499708, 
          2.7363175169460323`}, {-1.42018634500292, 2.4598349057605997`}}]}, 
        {Arrowheads[{{0.027329737726391513`, 1.}}], 
         ArrowBox[{{-1.1901584194716721`, 
          2.748553135441078}, {-1.0598415805283279`, 2.447599287265554}}]}, 
        {Arrowheads[{{0.02793510866744529, 1.}}], 
         ArrowBox[{{-0.796486830778215, 
          2.7591113169347663`}, {-0.703513169221785, 
          2.4370411057718657`}}]}, 
        {Arrowheads[{{0.028342018665776788`, 1.}}], 
         ArrowBox[{{-0.3992931588563801, 
          2.766384153015685}, {-0.3507068411436199, 2.429768269690947}}]}, 
        {Arrowheads[{{0.02848606122799698, 1.}}], 
         ArrowBox[{{0., 2.768992578721298}, {0., 2.427159843985334}}]}, 
        {Arrowheads[{{0.028342018665776788`, 1.}}], 
         ArrowBox[{{0.3992931588563801, 2.766384153015685}, {
          0.3507068411436199, 2.429768269690947}}]}, 
        {Arrowheads[{{0.02793510866744529, 1.}}], 
         ArrowBox[{{0.796486830778215, 2.7591113169347663`}, {
          0.703513169221785, 2.4370411057718657`}}]}, 
        {Arrowheads[{{0.027329737726391513`, 1.}}], 
         ArrowBox[{{1.1901584194716721`, 2.748553135441078}, {
          1.0598415805283279`, 2.447599287265554}}]}, 
        {Arrowheads[{{0.026604551665693355`, 1.}}], 
         ArrowBox[{{1.57981365499708, 2.7363175169460323`}, {1.42018634500292,
           2.4598349057605997`}}]}, 
        {Arrowheads[{{0.02583016999579966, 1.}}], 
         ArrowBox[{{1.965695781857384, 2.7237479731206538`}, {
          1.784304218142616, 2.4724044495859783`}}]}, 
        {Arrowheads[{{0.025058381392269593`, 1.}}], 
         ArrowBox[{{2.3484273681626986`, 2.711730346362037}, {
          2.1515726318373014`, 2.484422076344595}}]}, 
        {Arrowheads[{{0.024321413216362556`, 1.}}], 
         ArrowBox[{{2.728717545287428, 2.70072995882426}, {2.521282454712572, 
          2.495422463882372}}]}, 
        {Arrowheads[{{0.023437499999999986`, 1.}}], 
         ArrowBox[{{-2.910005893867716, 
          3.024166835102262}, {-2.714994106132284, 2.821504640442699}}]}, 
        {Arrowheads[{{0.024029354453257726`, 1.}}], 
         ArrowBox[{{-2.529839623264911, 
          3.0335612971124313`}, {-2.345160376735089, 
          2.8121101784325298`}}]}, 
        {Arrowheads[{{0.024641900403865578`, 1.}}], 
         ArrowBox[{{-2.1477447107865673`, 
          3.043638786084266}, {-1.9772552892134327`, 2.802032689460695}}]}, 
        {Arrowheads[{{0.025253188443406255`, 1.}}], 
         ArrowBox[{{-1.7632595653302188`, 
          3.054055154083753}, {-1.6117404346697812`, 2.791616321461208}}]}, 
        {Arrowheads[{{0.025830169995799682`, 1.}}], 
         ArrowBox[{{-1.3759870473001687`, 
          3.064216469760736}, {-1.2490129526998313`, 2.781455005784225}}]}, 
        {Arrowheads[{{0.02632914383241547, 1.}}], 
         ArrowBox[{{-0.9857492530857516, 
          3.0732620217616686`}, {-0.8892507469142484, 2.7724094537832924`}}]}, 
        {Arrowheads[{{0.026700697580848528`, 1.}}], 
         ArrowBox[{{-0.5927757452703726, 
          3.0801531249083753`}, {-0.5322242547296274, 2.7655183506365857`}}]}, 
        {Arrowheads[{{0.026900034471024223`, 1.}}], 
         ArrowBox[{{-0.19783258945127188`, 
          3.0839048669026585`}, {-0.17716741054872812`, 
          2.7617666086423025`}}]}, 
        {Arrowheads[{{0.026900034471024223`, 1.}}], 
         ArrowBox[{{0.19783258945127188`, 3.0839048669026585`}, {
          0.17716741054872812`, 2.7617666086423025`}}]}, 
        {Arrowheads[{{0.026700697580848528`, 1.}}], 
         ArrowBox[{{0.5927757452703726, 3.0801531249083753`}, {
          0.5322242547296274, 2.7655183506365857`}}]}, 
        {Arrowheads[{{0.02632914383241547, 1.}}], 
         ArrowBox[{{0.9857492530857516, 3.0732620217616686`}, {
          0.8892507469142484, 2.7724094537832924`}}]}, 
        {Arrowheads[{{0.025830169995799682`, 1.}}], 
         ArrowBox[{{1.3759870473001687`, 3.064216469760736}, {
          1.2490129526998313`, 2.781455005784225}}]}, 
        {Arrowheads[{{0.025253188443406255`, 1.}}], 
         ArrowBox[{{1.7632595653302188`, 3.054055154083753}, {
          1.6117404346697812`, 2.791616321461208}}]}, 
        {Arrowheads[{{0.024641900403865578`, 1.}}], 
         ArrowBox[{{2.1477447107865673`, 3.043638786084266}, {
          1.9772552892134327`, 2.802032689460695}}]}, 
        {Arrowheads[{{0.024029354453257726`, 1.}}], 
         ArrowBox[{{2.529839623264911, 3.0335612971124313`}, {
          2.345160376735089, 2.8121101784325298`}}]}, 
        {Arrowheads[{{0.023437499999999986`, 1.}}], 
         ArrowBox[{{2.910005893867716, 3.024166835102262}, {2.714994106132284,
           2.821504640442699}}]}}},
      AspectRatio->1,
      DisplayFunction->Identity,
      Epilog->{
        RGBColor[0, 0, 1], 
        DiskBox[{0, 0}, 0.2]},
      Frame->True,
      FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
      GridLinesStyle->Directive[
        GrayLevel[0.5, 0.4]],
      ImagePadding->{{15., 0.5}, {16., 0.5}},
      LabelStyle->Opacity[0],
      Method->{
       "VectorLengthFunction" -> (Sqrt[#]& ), "DefaultBoundaryStyle" -> 
        Automatic, 
        "DefaultGraphicsInteraction" -> {
         "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
          "Effects" -> {
           "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
            "Droplines" -> {
             "freeformCursorMode" -> True, 
              "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
        "TransparentPolygonMesh" -> True},
      PlotRange->{{-3, 3}, {-3, 3}},
      PlotRangeClipping->True,
      PlotRangePadding->{{
         Scaled[0.02], 
         Scaled[0.02]}, {
         Scaled[0.02], 
         Scaled[0.02]}},
      Ticks->{Automatic, Automatic}], {242.05688022284124, -78.96935933147633},
      ImageScaled[{0.5, 0.5}], {149.41782729805016, 150.41782729805016},
     BaseStyle->{Graphics3DBoxOptions -> {SphericalRegion -> False}}], 
    InsetBox[
     GraphicsBox[{{{}, 
        {RGBColor[1, 0, 0], 
         {Arrowheads[{{0.02343750000000001, 1.}}], 
          ArrowBox[{{-2.7070547088739305`, -2.829794450139847}, \
{-2.9179452911260695`, -3.015877025405114}}]}, 
         {Arrowheads[{{0.023876743512748183`, 1.}}], 
          ArrowBox[{{-2.3359463912995198`, -2.8217890937522165`}, \
{-2.5390536087004802`, -3.0238823817927445`}}]}, 
         {Arrowheads[{{0.024345060541474145`, 1.}}], 
          ArrowBox[{{-1.9662052226612605`, -2.813000102039208}, \
{-2.1587947773387395`, -3.032671373505753}}]}, 
         {Arrowheads[{{0.024834181220247744`, 1.}}], 
          ArrowBox[{{-1.598217852164272, -2.803541085228777}, \
{-1.776782147835728, -3.042130390316184}}]}, 
         {Arrowheads[{{0.02532911879301356, 1.}}], 
          ArrowBox[{{-1.2324075841332183`, -2.793678785816638}, \
{-1.3925924158667817`, -3.051992689728323}}]}, 
         {Arrowheads[{{0.025806336132554855`, 1.}}], 
          ArrowBox[{{-0.8691654162470059, -2.7838925979331357`}, \
{-1.005834583752994, -3.0617788776118253`}}]}, 
         {Arrowheads[{{0.026233280311868713`, 1.}}], 
          ArrowBox[{{-0.508725367452308, -2.7749068739645018`}, \
{-0.616274632547692, -3.0707646015804593`}}]}, 
         {Arrowheads[{{0.026570986300117966`, 1.}}], 
          ArrowBox[{{-0.150996567103944, -2.7676451367252484`}, \
{-0.224003432896056, -3.0780263388197127`}}]}, 
         {Arrowheads[{{0.026781009540386546`, 1.}}], 
          ArrowBox[{{0.20458266552630905`, -2.7630602968230087`}, {
           0.17041733447369095`, -3.0826111787219523`}}]}, 
         {Arrowheads[{{0.026835663497094042`, 1.}}], 
          ArrowBox[{{0.5590577696534635, -2.761858555780451}, {
           0.5659422303465365, -3.08381291976451}}]}, 
         {Arrowheads[{{0.026727237900439158`, 1.}}], 
          ArrowBox[{{0.9137607239768434, -2.7642391564025894`}, {
           0.9612392760231566, -3.0814323191423716`}}]}, 
         {Arrowheads[{{0.026470821879959444`, 1.}}], 
          ArrowBox[{{1.2699622626519018`, -2.769813191403249}, {
           1.3550377373480982`, -3.075858284141712}}]}, 
         {Arrowheads[{{0.026098881599004795`, 1.}}], 
          ArrowBox[{{1.6285577056842186`, -2.7777589846840853`}, {
           1.7464422943157814`, -3.0679124908608757`}}]}, 
         {Arrowheads[{{0.025651067989640636`, 1.}}], 
          ArrowBox[{{1.9899413735770328`, -2.787106492081133}, {
           2.135058626422967, -3.058564983463828}}]}, 
         {Arrowheads[{{0.025164755772881964`, 1.}}], 
          ArrowBox[{{2.354076520034966, -2.796986381069952}, {
           2.520923479965034, -3.048685094475009}}]}, 
         {Arrowheads[{{0.024669593461185278`, 1.}}], 
          ArrowBox[{{2.720659531402359, -2.806755909106121}, {
           2.904340468597641, -3.03891556643884}}]}, 
         {Arrowheads[{{0.02401619735703311, 1.}}], 
          ArrowBox[{{-2.5141953441486162`, -2.505954950401421}, \
{-2.7358046558513838`, -2.690197472305211}}]}, 
         {Arrowheads[{{0.024552573484838417`, 1.}}], 
          ArrowBox[{{-2.142916338164377, -2.4969083879206853`}, \
{-2.357083661835623, -2.6992440347859468`}}]}, 
         {Arrowheads[{{0.02513300744592264, 1.}}], 
          ArrowBox[{{-1.7732550839975794`, -2.4867747183461453`}, \
{-1.9767449160024206`, -2.7093777043604867`}}]}, 
         {Arrowheads[{{0.02574715915044841, 1.}}], 
          ArrowBox[{{-1.4057662809463338`, -2.475663019462975}, \
{-1.5942337190536662`, -2.720489403243657}}]}, 
         {Arrowheads[{{0.02637367257076846, 1.}}], 
          ArrowBox[{{-1.0410872456091025`, -2.4639151461150854`}, \
{-1.2089127543908975`, -2.7322372765915466`}}]}, 
         {Arrowheads[{{0.026976320987290584`, 1.}}], 
          ArrowBox[{{-0.6798256893925128, -2.452221645723371}, \
{-0.8201743106074872, -2.743930776983261}}]}, 
         {Arrowheads[{{0.027502818281410435`, 1.}}], 
          ArrowBox[{{-0.32233113596814345`, -2.441690242530266}, \
{-0.42766886403185655`, -2.754462180176366}}]}, 
         {Arrowheads[{{0.027890418831252452`, 1.}}], 
          ArrowBox[{{
           0.03162476236668289, -2.4337491257641553`}, {-0.03162476236668289, \
-2.7624032969424768`}}]}, 
         {Arrowheads[{{0.028081077871624362`, 1.}}], 
          ArrowBox[{{0.38309694288951257`, -2.4297844137058835`}, {
           0.36690305711048743`, -2.7663680090007485`}}]}, 
         {Arrowheads[{{0.028042160264011667`, 1.}}], 
          ArrowBox[{{0.7338842890828473, -2.4305968307017105`}, {
           0.7661157109171527, -2.7655555920049215`}}]}, 
         {Arrowheads[{{0.02778055675657137, 1.}}], 
          ArrowBox[{{1.086014411001902, -2.4360161611748268`}, {
           1.163985588998098, -2.7601362615318052`}}]}, 
         {Arrowheads[{{0.027339563950025878`, 1.}}], 
          ArrowBox[{{1.4410760323137033`, -2.444987252628997}, {
           1.5589239676862967`, -2.751165170077635}}]}, 
         {Arrowheads[{{0.026781009540386577`, 1.}}], 
          ArrowBox[{{1.7998362716842402`, -2.4560535971760076`}, {
           1.9501637283157598`, -2.7400988255306244`}}]}, 
         {Arrowheads[{{0.026165358653906446`, 1.}}], 
          ArrowBox[{{2.1622946358098885`, -2.4678675140330832`}, {
           2.3377053641901115`, -2.728284908673549}}]}, 
         {Arrowheads[{{0.02553974055427605, 1.}}], 
          ArrowBox[{{2.5279827365104217`, -2.4794605669472594`}, {
           2.7220172634895783`, -2.7166918557593727`}}]}, 
         {Arrowheads[{{0.024099676679852577`, 1.}}], 
          ArrowBox[{{-2.6932775122697366`, -2.191496165514811}, \
{-2.9317224877302634`, -2.355137204353492}}]}, 
         {Arrowheads[{{0.024696324146672343`, 1.}}], 
          ArrowBox[{{-2.3203152554561415`, -2.182627992171156}, \
{-2.5546847445438585`, -2.364005377697147}}]}, 
         {Arrowheads[{{0.025363167830929234`, 1.}}], 
          ArrowBox[{{-1.9486616379243484`, -2.172325212585994}, \
{-2.1763383620756516`, -2.374308157282309}}]}, 
         {Arrowheads[{{0.02609888159900482, 1.}}], 
          ArrowBox[{{-1.5789220894182976`, -2.160479210309844}, \
{-1.7960779105817024`, -2.386154159558459}}]}, 
         {Arrowheads[{{0.026891224166846084`, 1.}}], 
          ArrowBox[{{-1.2119154695014873`, -2.1471591724218553`}, \
{-1.4130845304985127`, -2.3994741974464477`}}]}, 
         {Arrowheads[{{0.027709101799197045`, 1.}}], 
          ArrowBox[{{-0.8486451693622332, -2.132798306481398}, \
{-1.0263548306377668`, -2.4138350633869052`}}]}, 
         {Arrowheads[{{0.028493852410030388`, 1.}}], 
          ArrowBox[{{-0.49011162567715383`, -2.1184350857403773`}, \
{-0.6348883743228462, -2.4281982841279257`}}]}, 
         {Arrowheads[{{0.029156041542347046`, 1.}}], 
          ArrowBox[{{-0.1368605594264499, -2.105870161048213}, \
{-0.2381394405735501, -2.44076320882009}}]}, 
         {Arrowheads[{{0.029588854747557736`, 1.}}], 
          ArrowBox[{{0.21167711434640898`, -2.0974375251349437`}, {
           0.16332288565359102`, -2.4491958447333593`}}]}, 
         {Arrowheads[{{0.02970434883878871, 1.}}], 
          ArrowBox[{{0.5576019039831361, -2.095157910541416}, {
           0.5673980960168639, -2.451475459326887}}]}, 
         {Arrowheads[{{0.029476404523663385`, 1.}}], 
          ArrowBox[{{0.9040768988940203, -2.0996451571479464`}, {
           0.9709231011059797, -2.4469882127203566`}}]}, 
         {Arrowheads[{{0.028955473828209646`, 1.}}], 
          ArrowBox[{{1.2540289534384033`, -2.1097188932614874`}, {
           1.3709710465615967`, -2.4369144766068156`}}]}, 
         {Arrowheads[{{0.02824088617779116, 1.}}], 
          ArrowBox[{{1.6090465352435386`, -2.12312757300004}, {
           1.7659534647564614`, -2.423505796868263}}]}, 
         {Arrowheads[{{0.027436611884558218`, 1.}}], 
          ArrowBox[{{1.969254633000853, -2.1376518858352913`}, {
           2.155745366999147, -2.4089814840330117`}}]}, 
         {Arrowheads[{{0.026622248488570765`, 1.}}], 
          ArrowBox[{{2.33388810251067, -2.1517462821882525`}, {
           2.54111189748933, -2.3948870876800505`}}]}, 
         {Arrowheads[{{0.025846445228098796`, 1.}}], 
          ArrowBox[{{2.701909895653085, -2.1646004343826055`}, {
           2.923090104346915, -2.3820329354856975`}}]}, 
         {Arrowheads[{{0.024764359284653037`, 1.}}], 
          ArrowBox[{{-2.498916431311434, -1.8699392256064362`}, \
{-2.751083568688566, -2.027175091423538}}]}, 
         {Arrowheads[{{0.025503553404489374`, 1.}}], 
          ArrowBox[{{-2.125144574057701, -1.8600888188788764`}, \
{-2.374855425942299, -2.0370254981510976`}}]}, 
         {Arrowheads[{{0.02634983874958137, 1.}}], 
          ArrowBox[{{-1.7527737904101248`, -1.8482772613973006`}, \
{-1.9972262095898752`, -2.0488370556326734`}}]}, 
         {Arrowheads[{{0.027307799567962556`, 1.}}], 
          ArrowBox[{{-1.3826433600151284`, -1.8342190980440929`}, \
{-1.6173566399848716`, -2.062895218985881}}]}, 
         {Arrowheads[{{0.028365296955365868`, 1.}}], 
          ArrowBox[{{-1.0159982854616088`, -1.817851883958563}, \
{-1.2340017145383912`, -2.079262433071411}}]}, 
         {Arrowheads[{{0.029476404523663385`, 1.}}], 
          ArrowBox[{{-0.6545054254114866, -1.799695848983954}, \
{-0.8454945745885134, -2.09741846804602}}]}, 
         {Arrowheads[{{0.030539854751886045`, 1.}}], 
          ArrowBox[{{-0.2999371876573572, -1.7813980952823885`}, \
{-0.4500628123426428, -2.1157162217475856`}}]}, 
         {Arrowheads[{{0.03138964772031195, 1.}}], 
          ArrowBox[{{
           0.04681098734119277, -1.7661293895533157`}, {-0.04681098734119277, \
-2.1309849274766584`}}]}, 
         {Arrowheads[{{0.03183175949218799, 1.}}], 
          ArrowBox[{{0.3872269175044623, -1.7579583774758496`}, {
           0.3627730824955377, -2.1391559395541244`}}]}, 
         {Arrowheads[{{0.03174012468722872, 1.}}], 
          ArrowBox[{{0.7257650907438781, -1.7596647348470769`}, {
           0.7742349092561219, -2.137449582182897}}]}, 
         {Arrowheads[{{0.031142385894604194`, 1.}}], 
          ArrowBox[{{1.0679302802898984`, -1.7706313811140877`}, {
           1.1820697197101016`, -2.1264829359158863`}}]}, 
         {Arrowheads[{{0.030199703088278764`, 1.}}], 
          ArrowBox[{{1.417267771494251, -1.7873486824202125`}, {
           1.582732228505749, -2.1097656346097615`}}]}, 
         {Arrowheads[{{0.029104971031446446`, 1.}}], 
          ArrowBox[{{1.7743160106418632`, -1.8058746070883367`}, {
           1.9756839893581368`, -2.0912397099416373`}}]}, 
         {Arrowheads[{{0.02800364226870596, 1.}}], 
          ArrowBox[{{2.137730562406663, -1.8235494920550162`}, {
           2.362269437593337, -2.073564824974958}}]}, 
         {Arrowheads[{{0.026976320987290567`, 1.}}], 
          ArrowBox[{{2.5057036719672716`, -1.8391662342925286`}, {
           2.7442963280327284`, -2.0579480827374454`}}]}, 
         {Arrowheads[{{0.024750611776070422`, 1.}}], 
          ArrowBox[{{-2.679155844589049, -1.5584319192474845`}, \
{-2.945844155410951, -1.6891633449441605`}}]}, 
         {Arrowheads[{{0.025539740554276085`, 1.}}], 
          ArrowBox[{{-2.3033879004702884`, -1.549662854342037}, \
{-2.5716120995297116`, -1.697932409849608}}]}, 
         {Arrowheads[{{0.02647082187995947, 1.}}], 
          ArrowBox[{{-1.9283425206713822`, -1.5387851063351383`}, \
{-2.1966574793286178`, -1.7088101578565067`}}]}, 
         {Arrowheads[{{0.027570275186807085`, 1.}}], 
          ArrowBox[{{-1.5546738467851116`, -1.5251997838349163`}, \
{-1.8203261532148884`, -1.7223954803567287`}}]}, 
         {Arrowheads[{{0.028858781263565586`, 1.}}], 
          ArrowBox[{{-1.1835332860967842`, -1.5082578557343211`}, \
{-1.4414667139032158`, -1.7393374084573239`}}]}, 
         {Arrowheads[{{0.0303327098213714, 1.}}], 
          ArrowBox[{{-0.8168639653401129, -1.4875273660602368`}, \
{-1.0581360346598871`, -1.7600678981314082`}}]}, 
         {Arrowheads[{{0.0319251000393457, 1.}}], 
          ArrowBox[{{-0.4576196998318448, -1.4635111539155408`}, \
{-0.6673803001681552, -1.7840841102761043`}}]}, 
         {Arrowheads[{{0.03344601714271432, 1.}}], 
          ArrowBox[{{-0.10925946531497259`, -1.4390022939787919`}, \
{-0.2657405346850274, -1.8085929702128531`}}]}, 
         {Arrowheads[{{0.034551558739378326`, 1.}}], 
          ArrowBox[{{0.22667778507172948`, -1.4202238892790757`}, {
           0.14832221492827052`, -1.8273713749125693`}}]}, 
         {Arrowheads[{{0.03486412887679517, 1.}}], 
          ArrowBox[{{0.5544544317976626, -1.4147676385626893`}, {
           0.5705455682023374, -1.8328276256289557`}}]}, 
         {Arrowheads[{{0.03425466251412329, 1.}}], 
          ArrowBox[{{0.8840312907303178, -1.4253465155167828`}, {
           0.9909687092696822, -1.8222487486748622`}}]}, 
         {Arrowheads[{{0.03296541092513824, 1.}}], 
          ArrowBox[{{1.2239921332957446`, -1.446912875940472}, {
           1.4010078667042554`, -1.800682388251173}}]}, 
         {Arrowheads[{{0.03138964772031193, 1.}}], 
          ArrowBox[{{1.5763239050646671`, -1.47177449129443}, {
           1.7986760949353329`, -1.775820772897215}}]}, 
         {Arrowheads[{{0.029823026644856327`, 1.}}], 
          ArrowBox[{{1.9384287095105095`, -1.494858964762762}, {
           2.1865712904894905`, -1.752736299428883}}]}, 
         {Arrowheads[{{0.02840767700424747, 1.}}], 
          ArrowBox[{{2.306865762121309, -1.5143145011858556`}, {
           2.568134237878691, -1.7332807630057894`}}]}, 
         {Arrowheads[{{0.02718355173745576, 1.}}], 
          ArrowBox[{{2.679019222185699, -1.5300697311465596`}, {
           2.945980777814301, -1.7175255330450854`}}]}, 
         {Arrowheads[{{0.025467811485932624`, 1.}}], 
          ArrowBox[{{-2.4838987379360953`, -1.2403834124990323`}, \
{-2.7661012620639047`, -1.3576927988542837`}}]}, 
         {Arrowheads[{{0.02644625785840735, 1.}}], 
          ArrowBox[{{-2.106524645672029, -1.2312635774957508`}, \
{-2.393475354327971, -1.3668126338575652`}}]}, 
         {Arrowheads[{{0.027639022469113986`, 1.}}], 
          ArrowBox[{{-1.7295073316615452`, -1.21945893924793}, \
{-2.0204926683384548`, -1.378617272105386}}]}, 
         {Arrowheads[{{0.029104971031446433`, 1.}}], 
          ArrowBox[{{-1.3535505609336194`, -1.203916404725558}, \
{-1.6464494390663806`, -1.394159806627758}}]}, 
         {Arrowheads[{{0.03090727481441062, 1.}}], 
          ArrowBox[{{-0.9801510231498896, -1.1832446653710769`}, \
{-1.2698489768501104`, -1.4148315459822391`}}]}, 
         {Arrowheads[{{0.03308165355997636, 1.}}], 
          ArrowBox[{{-0.6123720020911955, -1.1560108947234384`}, \
{-0.8876279979088045, -1.4420653166298776`}}]}, 
         {Arrowheads[{{0.03554219832343682, 1.}}], 
          ArrowBox[{{-0.25586379822625543`, -1.1221667161113125`}, \
{-0.49413620177374457`, -1.4759094952420035`}}]}, 
         {Arrowheads[{{0.037890608915675694`, 1.}}], 
          ArrowBox[{{
           0.0816642510993401, -1.0868681575774786`}, {-0.0816642510993401, \
-1.5112080537758374`}}]}, 
         {Arrowheads[{{0.03929580154364731, 1.}}], 
          ArrowBox[{{0.3975831309704036, -1.0643473242683306`}, {
           0.3524168690295964, -1.5337288870849854`}}]}, 
         {Arrowheads[{{0.038992318678128884`, 1.}}], 
          ArrowBox[{{0.7057868664582395, -1.0692999247081874`}, {
           0.7942131335417605, -1.5287762866451287`}}]}, 
         {Arrowheads[{{0.0371641229902051, 1.}}], 
          ArrowBox[{{1.0283238553397178`, -1.0981005123588732`}, {
           1.2216761446602822`, -1.4999756989944428`}}]}, 
         {Arrowheads[{{0.03470579931652076, 1.}}], 
          ArrowBox[{{1.3729779653275271`, -1.134031642376534}, {
           1.6270220346724729`, -1.464044568976782}}]}, 
         {Arrowheads[{{0.032316627985300786`, 1.}}], 
          ArrowBox[{{1.73405416941395, -1.1658788294820939`}, {
           2.01594583058605, -1.4321973818712221`}}]}, 
         {Arrowheads[{{0.030265714237414837`, 1.}}], 
          ArrowBox[{{2.1041879480992423`, -1.1908007275703798`}, {
           2.3958120519007577`, -1.4072754837829362`}}]}, 
         {Arrowheads[{{0.02858197410631264, 1.}}], 
          ArrowBox[{{2.478682207663397, -1.209592276131373}, {
           2.771317792336603, -1.388483935221943}}]}, 
         {Arrowheads[{{0.025295472175760766`, 1.}}], 
          ArrowBox[{{-2.6668945449723047`, -0.9314528356026939}, \
{-2.9581054550276953`, -1.0171043229122931`}}]}, 
         {Arrowheads[{{0.026279390079816486`, 1.}}], 
          ArrowBox[{{-2.2878405458727253`, -0.9246411323333836}, \
{-2.5871594541272747`, -1.0239160261816034`}}]}, 
         {Arrowheads[{{0.02750281828141042, 1.}}], 
          ArrowBox[{{-1.9082554696209915`, -0.9156338409488498}, \
{-2.2167445303790085`, -1.0329233175661372`}}]}, 
         {Arrowheads[{{0.029054528012464553`, 1.}}], 
          ArrowBox[{{-1.5282534282255003`, -0.9033526255660256}, \
{-1.8467465717744997`, -1.0452045329489614`}}]}, 
         {Arrowheads[{{0.031062715342689718`, 1.}}], 
          ArrowBox[{{-1.1483374747685975`, -0.8860358030645152}, \
{-1.4766625252314025`, -1.0625213554504718`}}]}, 
         {Arrowheads[{{0.033702960300813926`, 1.}}], 
          ArrowBox[{{-0.7701065404674516, -0.8608261535668027}, \
{-1.1048934595325484`, -1.0877310049481843`}}]}, 
         {Arrowheads[{{0.0371641229902051, 1.}}], 
          ArrowBox[{{-0.3981505540775203, -0.8235753842691549}, \
{-0.7268494459224797, -1.1249817742458321`}}]}, 
         {Arrowheads[{{0.041421423078516845`, 1.}}], 
          ArrowBox[{{-0.044209215895446685`, -0.7712165551730186}, \
{-0.3307907841045533, -1.1773406033419684`}}]}, 
         {Arrowheads[{{0.045496252804832375`, 1.}}], 
          ArrowBox[{{0.27087377888190545`, -0.7143448613810415}, {
           0.10412622111809455`, -1.2342122971339455`}}]}, 
         {Arrowheads[{{0.04687500000000002, 1.}}], 
          ArrowBox[{{0.5444948137594364, -0.693605502941929}, {
           0.5805051862405636, -1.254951655573058}}]}, 
         {Arrowheads[{{0.044291190519396034`, 1.}}], 
          ArrowBox[{{0.8286382732694775, -0.731851954218566}, {
           1.0463617267305225`, -1.216705204296421}}]}, 
         {Arrowheads[{{0.03994207492635575, 1.}}], 
          ArrowBox[{{1.1590112261632761`, -0.7902283337121174}, {
           1.4659887738367239`, -1.1583288248028696`}}]}, 
         {Arrowheads[{{0.03591115851478668, 1.}}], 
          ArrowBox[{{1.5209227078595202`, -0.8376110529221781}, {
           1.8540772921404798`, -1.110946105592809}}]}, 
         {Arrowheads[{{0.03274019958493003, 1.}}], 
          ArrowBox[{{1.8958087823595706`, -0.8703402223311454}, {
           2.2291912176404294`, -1.0782169361838416`}}]}, 
         {Arrowheads[{{0.03033270982137139, 1.}}], 
          ArrowBox[{{2.2749036054584133`, -0.8925164196361421}, {
           2.6000963945415867`, -1.0560407388788449`}}]}, 
         {Arrowheads[{{0.028493852410030395`, 1.}}], 
          ArrowBox[{{2.6549488323561583`, -0.9079007510315904}, {
           2.9700511676438417`, -1.0406564074833966`}}]}, 
         {Arrowheads[{{0.025991160704169004`, 1.}}], 
          ArrowBox[{{-2.4723161382835745`, -0.6177843081196887}, \
{-2.7776838617164255`, -0.6812537975569694}}]}, 
         {Arrowheads[{{0.027183551737455753`, 1.}}], 
          ArrowBox[{{-2.091266102058669, -0.6120278924586238}, \
{-2.408733897941331, -0.6870102132180342}}]}, 
         {Arrowheads[{{0.028717969755743426`, 1.}}], 
          ArrowBox[{{-1.7087955213670711`, -0.6040651684007929}, \
{-2.041204478632929, -0.6949729372758651}}]}, 
         {Arrowheads[{{0.030756804204593088`, 1.}}], 
          ArrowBox[{{-1.3244829854223292`, -0.5925182303055792}, \
{-1.6755170145776708`, -0.7065198753710789}}]}, 
         {Arrowheads[{{0.03357301388447952, 1.}}], 
          ArrowBox[{{-0.9379503512150427, -0.5747545539382997}, \
{-1.3120496487849573`, -0.7242835517383583}}]}, 
         {Arrowheads[{{0.037639882113991795`, 1.}}], 
          ArrowBox[{{-0.5496000335549653, -0.5453881757229596}, \
{-0.9503999664450347, -0.7536499299536984}}]}, 
         {Arrowheads[{{0.04374290949045362, 1.}}], 
          ArrowBox[{{-0.16425845466989444`, -0.4930840255051908}, \
{-0.5857415453301056, -0.8059540801714672}}]}, 
         {Arrowheads[{{0.046875, 1.}}], 
          ArrowBox[{{
           0.17156089162418026`, -0.4266549171746554}, \
{-0.17156089162418026`, -0.8723831885020026}}]}, 
         {Arrowheads[{{0.046875, 1.}}], 
          ArrowBox[{{0.42815125401692256`, -0.37333703550840114`}, {
           0.32184874598307744`, -0.9257010701682569}}]}, 
         {Arrowheads[{{0.046875, 1.}}], 
          ArrowBox[{{0.6489720176099392, -0.3870406551096901}, {
           0.8510279823900608, -0.9119974505669679}}]}, 
         {Arrowheads[{{0.04687499999999999, 1.}}], 
          ArrowBox[{{0.929988212264568, -0.44685685817876564`}, {
           1.320011787735432, -0.8521812474978924}}]}, 
         {Arrowheads[{{0.04142142307851684, 1.}}], 
          ArrowBox[{{1.2915770413024679`, -0.5141443701153459}, {
           1.7084229586975321`, -0.7848937355613121}}]}, 
         {Arrowheads[{{0.03610399673243863, 1.}}], 
          ArrowBox[{{1.6791298034838684`, -0.5569943804598452}, {
           2.0708701965161316`, -0.7420437252168128}}]}, 
         {Arrowheads[{{0.03252413975826109, 1.}}], 
          ArrowBox[{{2.0670498907668606`, -0.5816164347435989}, {
           2.4329501092331394`, -0.7174216709330591}}]}, 
         {Arrowheads[{{0.030007341479058734`, 1.}}], 
          ArrowBox[{{2.4528194261310725`, -0.5968910230705616}, {
           2.7971805738689275`, -0.7021470826060964}}]}, 
         {Arrowheads[{{0.025613488107262886`, 1.}}], 
          ArrowBox[{{-2.6595523767816114`, -0.30976444787325036`}, \
{-2.9654476232183886`, -0.33975460496507864`}}]}, 
         {Arrowheads[{{0.02672723790043917, 1.}}], 
          ArrowBox[{{-2.2781077181302343`, -0.30713768404473213`}, \
{-2.5968922818697657`, -0.3423813687935969}}]}, 
         {Arrowheads[{{0.02816013992614846, 1.}}], 
          ArrowBox[{{-1.8948799436238226`, -0.30351612734518163`}, \
{-2.2301200563761774`, -0.3460029254931474}}]}, 
         {Arrowheads[{{0.030070539397068302`, 1.}}], 
          ArrowBox[{{-1.5090328251745309`, -0.29826402233793675`}, \
{-1.8659671748254691`, -0.35125503050039225`}}]}, 
         {Arrowheads[{{0.032740199584930026`, 1.}}], 
          ArrowBox[{{-1.1191381875371023`, -0.2901134074437151}, \
{-1.5058618124628977`, -0.3594056453946139}}]}, 
         {Arrowheads[{{0.03671951085472884, 1.}}], 
          ArrowBox[{{-0.7225989299893127, -0.2762091474809784}, \
{-1.1524010700106873`, -0.3733099053573506}}]}, 
         {Arrowheads[{{0.0432261639737414, 1.}}], 
          ArrowBox[{{-0.3144705061394658, -0.24894781727645188`}, \
{-0.8105294938605342, -0.4005712355618771}}]}, 
         {Arrowheads[{{0.046875, 1.}}], 
          ArrowBox[{{
           0.06680468348797458, -0.20463171758173881`}, {-0.4418046834879746, \
-0.4448873352565902}}]}, 
         {Arrowheads[{{0.04687499999999999, 1.}}], 
          ArrowBox[{{
           0.3825117877354321, -0.12209733175960114`}, \
{-0.007511787735432096, -0.5274217210787279}}]}, 
         {Arrowheads[{{0.046875, 1.}}], 
          ArrowBox[{{0.5093487459830774, -0.04857750908923664}, {
           0.6156512540169226, -0.6009415437490924}}]}, 
         {Arrowheads[{{0.046875, 1.}}], 
          ArrowBox[{{0.7116688869711658, -0.15712339997811986`}, {
           1.1633311130288342`, -0.49239565286020914`}}]}, 
         {Arrowheads[{{0.04687499999999999, 1.}}], 
          ArrowBox[{{1.0513392857142858`, -0.22037253578443305`}, {
           1.5736607142857142`, -0.42914651705389595`}}]}, 
         {Arrowheads[{{0.040647420527110824`, 1.}}], 
          ArrowBox[{{1.4522541454377795`, -0.2604240886762606}, {
           1.9227458545622205`, -0.3890949641620684}}]}, 
         {Arrowheads[{{0.03519380242396191, 1.}}], 
          ArrowBox[{{1.8557556485746525`, -0.28178851991757525`}, {
           2.2692443514253475`, -0.36773053292075375`}}]}, 
         {Arrowheads[{{0.031740124687228734`, 1.}}], 
          ArrowBox[{{2.249679453265055, -0.29327745580784614`}, {
           2.625320546734945, -0.35624159703048286`}}]}, 
         {Arrowheads[{{0.029366866771308786`, 1.}}], 
          ArrowBox[{{2.638011070482787, -0.3002549028016955}, {
           2.986988929517213, -0.3492641500366335}}]}, 
         {Arrowheads[{{0.026187836128434006`, 1.}}], 
          ArrowBox[{{-2.467872983229396, 0.}, {-2.782127016770604, 0.}}]}, 
         {Arrowheads[{{0.027469561193532794`, 1.}}], 
          ArrowBox[{{-2.0851826328388032`, 0.}, {-2.4148173671611968`, 0.}}]}, 
         {Arrowheads[{{0.02915604154234706, 1.}}], 
          ArrowBox[{{-1.7000637507459175`, 0.}, {-2.0499362492540825`, 0.}}]}, 
         {Arrowheads[{{0.031474952021966596`, 1.}}], 
          ArrowBox[{{-1.3111502878682004`, 0.}, {-1.6888497121317996`, 0.}}]}, 
         {Arrowheads[{{0.034864128876795165`, 1.}}], 
          ArrowBox[{{-0.915815226739229, 0.}, {-1.334184773260771, 0.}}]}, 
         {Arrowheads[{{0.04028681184452091, 1.}}], 
          ArrowBox[{{-0.5082791289328745, 0.}, {-0.9917208710671255, 0.}}]}, 
         {Arrowheads[{{0.046875, 1.}}], 
          ArrowBox[{{-0.09375, 0.}, {-0.65625, 0.}}]}, 
         {Arrowheads[{{0.046875, 1.}}], 
          ArrowBox[{{0.28125, 0.}, {-0.28125, 0.}}]}, 
         {Arrowheads[{{0.046875, 1.}}], 
          ArrowBox[{{0.65625, 0.}, {0.09375, 0.}}]}, 
         {Arrowheads[{{0.046875, 1.}}], 
          ArrowBox[{{0.46875, 0.}, {1.03125, 0.}}]}, 
         {Arrowheads[{{0.046875, 1.}}], 
          ArrowBox[{{0.84375, 0.}, {1.40625, 0.}}]}, 
         {Arrowheads[{{0.046161385059557136`, 1.}}], 
          ArrowBox[{{1.2230316896426572`, 0.}, {1.7769683103573428`, 0.}}]}, 
         {Arrowheads[{{0.038150603402689574`, 1.}}], 
          ArrowBox[{{1.6460963795838626`, 0.}, {2.1039036204161374`, 0.}}]}, 
         {Arrowheads[{{0.03357301388447953, 1.}}], 
          ArrowBox[{{2.0485619166931226`, 0.}, {2.4514380833068774`, 0.}}]}, 
         {Arrowheads[{{0.030611044196225956`, 1.}}], 
          ArrowBox[{{2.4413337348226443`, 0.}, {2.8086662651773557`, 0.}}]}, 
         {Arrowheads[{{0.025613488107262886`, 1.}}], 
          ArrowBox[{{-2.6595523767816114`, 
           0.30976444787325036`}, {-2.9654476232183886`, 
           0.33975460496507864`}}]}, 
         {Arrowheads[{{0.02672723790043917, 1.}}], 
          ArrowBox[{{-2.2781077181302343`, 
           0.30713768404473213`}, {-2.5968922818697657`, 
           0.3423813687935969}}]}, 
         {Arrowheads[{{0.02816013992614846, 1.}}], 
          ArrowBox[{{-1.8948799436238226`, 
           0.30351612734518163`}, {-2.2301200563761774`, 
           0.3460029254931474}}]}, 
         {Arrowheads[{{0.030070539397068302`, 1.}}], 
          ArrowBox[{{-1.5090328251745309`, 
           0.29826402233793675`}, {-1.8659671748254691`, 
           0.35125503050039225`}}]}, 
         {Arrowheads[{{0.032740199584930026`, 1.}}], 
          ArrowBox[{{-1.1191381875371023`, 
           0.2901134074437151}, {-1.5058618124628977`, 0.3594056453946139}}]}, 
         {Arrowheads[{{0.03671951085472884, 1.}}], 
          ArrowBox[{{-0.7225989299893127, 
           0.2762091474809784}, {-1.1524010700106873`, 0.3733099053573506}}]}, 
         {Arrowheads[{{0.0432261639737414, 1.}}], 
          ArrowBox[{{-0.3144705061394658, 
           0.24894781727645188`}, {-0.8105294938605342, 
           0.4005712355618771}}]}, 
         {Arrowheads[{{0.046875, 1.}}], 
          ArrowBox[{{0.06680468348797458, 
           0.20463171758173881`}, {-0.4418046834879746, 
           0.4448873352565902}}]}, 
         {Arrowheads[{{0.04687499999999999, 1.}}], 
          ArrowBox[{{0.3825117877354321, 
           0.12209733175960114`}, {-0.007511787735432096, 
           0.5274217210787279}}]}, 
         {Arrowheads[{{0.046875, 1.}}], 
          ArrowBox[{{0.5093487459830774, 0.04857750908923664}, {
           0.6156512540169226, 0.6009415437490924}}]}, 
         {Arrowheads[{{0.046875, 1.}}], 
          ArrowBox[{{0.7116688869711658, 0.15712339997811986`}, {
           1.1633311130288342`, 0.49239565286020914`}}]}, 
         {Arrowheads[{{0.04687499999999999, 1.}}], 
          ArrowBox[{{1.0513392857142858`, 0.22037253578443305`}, {
           1.5736607142857142`, 0.42914651705389595`}}]}, 
         {Arrowheads[{{0.040647420527110824`, 1.}}], 
          ArrowBox[{{1.4522541454377795`, 0.2604240886762606}, {
           1.9227458545622205`, 0.3890949641620684}}]}, 
         {Arrowheads[{{0.03519380242396191, 1.}}], 
          ArrowBox[{{1.8557556485746525`, 0.28178851991757525`}, {
           2.2692443514253475`, 0.36773053292075375`}}]}, 
         {Arrowheads[{{0.031740124687228734`, 1.}}], 
          ArrowBox[{{2.249679453265055, 0.29327745580784614`}, {
           2.625320546734945, 0.35624159703048286`}}]}, 
         {Arrowheads[{{0.029366866771308786`, 1.}}], 
          ArrowBox[{{2.638011070482787, 0.3002549028016955}, {
           2.986988929517213, 0.3492641500366335}}]}, 
         {Arrowheads[{{0.025991160704169004`, 1.}}], 
          ArrowBox[{{-2.4723161382835745`, 
           0.6177843081196887}, {-2.7776838617164255`, 0.6812537975569694}}]}, 
         {Arrowheads[{{0.027183551737455753`, 1.}}], 
          ArrowBox[{{-2.091266102058669, 
           0.6120278924586238}, {-2.408733897941331, 0.6870102132180342}}]}, 
         {Arrowheads[{{0.028717969755743426`, 1.}}], 
          ArrowBox[{{-1.7087955213670711`, 
           0.6040651684007929}, {-2.041204478632929, 0.6949729372758651}}]}, 
         {Arrowheads[{{0.030756804204593088`, 1.}}], 
          ArrowBox[{{-1.3244829854223292`, 
           0.5925182303055792}, {-1.6755170145776708`, 0.7065198753710789}}]}, 
         {Arrowheads[{{0.03357301388447952, 1.}}], 
          ArrowBox[{{-0.9379503512150427, 
           0.5747545539382997}, {-1.3120496487849573`, 0.7242835517383583}}]}, 
         {Arrowheads[{{0.037639882113991795`, 1.}}], 
          ArrowBox[{{-0.5496000335549653, 
           0.5453881757229596}, {-0.9503999664450347, 
           0.7536499299536984}}]}, 
         {Arrowheads[{{0.04374290949045362, 1.}}], 
          ArrowBox[{{-0.16425845466989444`, 
           0.4930840255051908}, {-0.5857415453301056, 
           0.8059540801714672}}]}, 
         {Arrowheads[{{0.046875, 1.}}], 
          ArrowBox[{{0.17156089162418026`, 
           0.4266549171746554}, {-0.17156089162418026`, 
           0.8723831885020026}}]}, 
         {Arrowheads[{{0.046875, 1.}}], 
          ArrowBox[{{0.42815125401692256`, 0.37333703550840114`}, {
           0.32184874598307744`, 0.9257010701682569}}]}, 
         {Arrowheads[{{0.046875, 1.}}], 
          ArrowBox[{{0.6489720176099392, 0.3870406551096901}, {
           0.8510279823900608, 0.9119974505669679}}]}, 
         {Arrowheads[{{0.04687499999999999, 1.}}], 
          ArrowBox[{{0.929988212264568, 0.44685685817876564`}, {
           1.320011787735432, 0.8521812474978924}}]}, 
         {Arrowheads[{{0.04142142307851684, 1.}}], 
          ArrowBox[{{1.2915770413024679`, 0.5141443701153459}, {
           1.7084229586975321`, 0.7848937355613121}}]}, 
         {Arrowheads[{{0.03610399673243863, 1.}}], 
          ArrowBox[{{1.6791298034838684`, 0.5569943804598452}, {
           2.0708701965161316`, 0.7420437252168128}}]}, 
         {Arrowheads[{{0.03252413975826109, 1.}}], 
          ArrowBox[{{2.0670498907668606`, 0.5816164347435989}, {
           2.4329501092331394`, 0.7174216709330591}}]}, 
         {Arrowheads[{{0.030007341479058734`, 1.}}], 
          ArrowBox[{{2.4528194261310725`, 0.5968910230705616}, {
           2.7971805738689275`, 0.7021470826060964}}]}, 
         {Arrowheads[{{0.025295472175760766`, 1.}}], 
          ArrowBox[{{-2.6668945449723047`, 
           0.9314528356026939}, {-2.9581054550276953`, 
           1.0171043229122931`}}]}, 
         {Arrowheads[{{0.026279390079816486`, 1.}}], 
          ArrowBox[{{-2.2878405458727253`, 
           0.9246411323333836}, {-2.5871594541272747`, 
           1.0239160261816034`}}]}, 
         {Arrowheads[{{0.02750281828141042, 1.}}], 
          ArrowBox[{{-1.9082554696209915`, 
           0.9156338409488498}, {-2.2167445303790085`, 
           1.0329233175661372`}}]}, 
         {Arrowheads[{{0.029054528012464553`, 1.}}], 
          ArrowBox[{{-1.5282534282255003`, 
           0.9033526255660256}, {-1.8467465717744997`, 
           1.0452045329489614`}}]}, 
         {Arrowheads[{{0.031062715342689718`, 1.}}], 
          ArrowBox[{{-1.1483374747685975`, 
           0.8860358030645152}, {-1.4766625252314025`, 
           1.0625213554504718`}}]}, 
         {Arrowheads[{{0.033702960300813926`, 1.}}], 
          ArrowBox[{{-0.7701065404674516, 
           0.8608261535668027}, {-1.1048934595325484`, 
           1.0877310049481843`}}]}, 
         {Arrowheads[{{0.0371641229902051, 1.}}], 
          ArrowBox[{{-0.3981505540775203, 
           0.8235753842691549}, {-0.7268494459224797, 1.1249817742458321`}}]}, 
         {Arrowheads[{{0.041421423078516845`, 1.}}], 
          ArrowBox[{{-0.044209215895446685`, 
           0.7712165551730186}, {-0.3307907841045533, 1.1773406033419684`}}]}, 
         {Arrowheads[{{0.045496252804832375`, 1.}}], 
          ArrowBox[{{0.27087377888190545`, 0.7143448613810415}, {
           0.10412622111809455`, 1.2342122971339455`}}]}, 
         {Arrowheads[{{0.04687500000000002, 1.}}], 
          ArrowBox[{{0.5444948137594364, 0.693605502941929}, {
           0.5805051862405636, 1.254951655573058}}]}, 
         {Arrowheads[{{0.044291190519396034`, 1.}}], 
          ArrowBox[{{0.8286382732694775, 0.731851954218566}, {
           1.0463617267305225`, 1.216705204296421}}]}, 
         {Arrowheads[{{0.03994207492635575, 1.}}], 
          ArrowBox[{{1.1590112261632761`, 0.7902283337121174}, {
           1.4659887738367239`, 1.1583288248028696`}}]}, 
         {Arrowheads[{{0.03591115851478668, 1.}}], 
          ArrowBox[{{1.5209227078595202`, 0.8376110529221781}, {
           1.8540772921404798`, 1.110946105592809}}]}, 
         {Arrowheads[{{0.03274019958493003, 1.}}], 
          ArrowBox[{{1.8958087823595706`, 0.8703402223311454}, {
           2.2291912176404294`, 1.0782169361838416`}}]}, 
         {Arrowheads[{{0.03033270982137139, 1.}}], 
          ArrowBox[{{2.2749036054584133`, 0.8925164196361421}, {
           2.6000963945415867`, 1.0560407388788449`}}]}, 
         {Arrowheads[{{0.028493852410030395`, 1.}}], 
          ArrowBox[{{2.6549488323561583`, 0.9079007510315904}, {
           2.9700511676438417`, 1.0406564074833966`}}]}, 
         {Arrowheads[{{0.025467811485932624`, 1.}}], 
          ArrowBox[{{-2.4838987379360953`, 
           1.2403834124990323`}, {-2.7661012620639047`, 
           1.3576927988542837`}}]}, 
         {Arrowheads[{{0.02644625785840735, 1.}}], 
          ArrowBox[{{-2.106524645672029, 
           1.2312635774957508`}, {-2.393475354327971, 1.3668126338575652`}}]}, 
         {Arrowheads[{{0.027639022469113986`, 1.}}], 
          ArrowBox[{{-1.7295073316615452`, 
           1.21945893924793}, {-2.0204926683384548`, 1.378617272105386}}]}, 
         {Arrowheads[{{0.029104971031446433`, 1.}}], 
          ArrowBox[{{-1.3535505609336194`, 
           1.203916404725558}, {-1.6464494390663806`, 1.394159806627758}}]}, 
         {Arrowheads[{{0.03090727481441062, 1.}}], 
          ArrowBox[{{-0.9801510231498896, 
           1.1832446653710769`}, {-1.2698489768501104`, 
           1.4148315459822391`}}]}, 
         {Arrowheads[{{0.03308165355997636, 1.}}], 
          ArrowBox[{{-0.6123720020911955, 
           1.1560108947234384`}, {-0.8876279979088045, 
           1.4420653166298776`}}]}, 
         {Arrowheads[{{0.03554219832343682, 1.}}], 
          ArrowBox[{{-0.25586379822625543`, 
           1.1221667161113125`}, {-0.49413620177374457`, 
           1.4759094952420035`}}]}, 
         {Arrowheads[{{0.037890608915675694`, 1.}}], 
          ArrowBox[{{0.0816642510993401, 
           1.0868681575774786`}, {-0.0816642510993401, 
           1.5112080537758374`}}]}, 
         {Arrowheads[{{0.03929580154364731, 1.}}], 
          ArrowBox[{{0.3975831309704036, 1.0643473242683306`}, {
           0.3524168690295964, 1.5337288870849854`}}]}, 
         {Arrowheads[{{0.038992318678128884`, 1.}}], 
          ArrowBox[{{0.7057868664582395, 1.0692999247081874`}, {
           0.7942131335417605, 1.5287762866451287`}}]}, 
         {Arrowheads[{{0.0371641229902051, 1.}}], 
          ArrowBox[{{1.0283238553397178`, 1.0981005123588732`}, {
           1.2216761446602822`, 1.4999756989944428`}}]}, 
         {Arrowheads[{{0.03470579931652076, 1.}}], 
          ArrowBox[{{1.3729779653275271`, 1.134031642376534}, {
           1.6270220346724729`, 1.464044568976782}}]}, 
         {Arrowheads[{{0.032316627985300786`, 1.}}], 
          ArrowBox[{{1.73405416941395, 1.1658788294820939`}, {
           2.01594583058605, 1.4321973818712221`}}]}, 
         {Arrowheads[{{0.030265714237414837`, 1.}}], 
          ArrowBox[{{2.1041879480992423`, 1.1908007275703798`}, {
           2.3958120519007577`, 1.4072754837829362`}}]}, 
         {Arrowheads[{{0.02858197410631264, 1.}}], 
          ArrowBox[{{2.478682207663397, 1.209592276131373}, {
           2.771317792336603, 1.388483935221943}}]}, 
         {Arrowheads[{{0.024750611776070422`, 1.}}], 
          ArrowBox[{{-2.679155844589049, 
           1.5584319192474845`}, {-2.945844155410951, 1.6891633449441605`}}]}, 
         {Arrowheads[{{0.025539740554276085`, 1.}}], 
          ArrowBox[{{-2.3033879004702884`, 
           1.549662854342037}, {-2.5716120995297116`, 1.697932409849608}}]}, 
         {Arrowheads[{{0.02647082187995947, 1.}}], 
          ArrowBox[{{-1.9283425206713822`, 
           1.5387851063351383`}, {-2.1966574793286178`, 
           1.7088101578565067`}}]}, 
         {Arrowheads[{{0.027570275186807085`, 1.}}], 
          ArrowBox[{{-1.5546738467851116`, 
           1.5251997838349163`}, {-1.8203261532148884`, 
           1.7223954803567287`}}]}, 
         {Arrowheads[{{0.028858781263565586`, 1.}}], 
          ArrowBox[{{-1.1835332860967842`, 
           1.5082578557343211`}, {-1.4414667139032158`, 
           1.7393374084573239`}}]}, 
         {Arrowheads[{{0.0303327098213714, 1.}}], 
          ArrowBox[{{-0.8168639653401129, 
           1.4875273660602368`}, {-1.0581360346598871`, 
           1.7600678981314082`}}]}, 
         {Arrowheads[{{0.0319251000393457, 1.}}], 
          ArrowBox[{{-0.4576196998318448, 
           1.4635111539155408`}, {-0.6673803001681552, 
           1.7840841102761043`}}]}, 
         {Arrowheads[{{0.03344601714271432, 1.}}], 
          ArrowBox[{{-0.10925946531497259`, 
           1.4390022939787919`}, {-0.2657405346850274, 
           1.8085929702128531`}}]}, 
         {Arrowheads[{{0.034551558739378326`, 1.}}], 
          ArrowBox[{{0.22667778507172948`, 1.4202238892790757`}, {
           0.14832221492827052`, 1.8273713749125693`}}]}, 
         {Arrowheads[{{0.03486412887679517, 1.}}], 
          ArrowBox[{{0.5544544317976626, 1.4147676385626893`}, {
           0.5705455682023374, 1.8328276256289557`}}]}, 
         {Arrowheads[{{0.03425466251412329, 1.}}], 
          ArrowBox[{{0.8840312907303178, 1.4253465155167828`}, {
           0.9909687092696822, 1.8222487486748622`}}]}, 
         {Arrowheads[{{0.03296541092513824, 1.}}], 
          ArrowBox[{{1.2239921332957446`, 1.446912875940472}, {
           1.4010078667042554`, 1.800682388251173}}]}, 
         {Arrowheads[{{0.03138964772031193, 1.}}], 
          ArrowBox[{{1.5763239050646671`, 1.47177449129443}, {
           1.7986760949353329`, 1.775820772897215}}]}, 
         {Arrowheads[{{0.029823026644856327`, 1.}}], 
          ArrowBox[{{1.9384287095105095`, 1.494858964762762}, {
           2.1865712904894905`, 1.752736299428883}}]}, 
         {Arrowheads[{{0.02840767700424747, 1.}}], 
          ArrowBox[{{2.306865762121309, 1.5143145011858556`}, {
           2.568134237878691, 1.7332807630057894`}}]}, 
         {Arrowheads[{{0.02718355173745576, 1.}}], 
          ArrowBox[{{2.679019222185699, 1.5300697311465596`}, {
           2.945980777814301, 1.7175255330450854`}}]}, 
         {Arrowheads[{{0.024764359284653037`, 1.}}], 
          ArrowBox[{{-2.498916431311434, 
           1.8699392256064362`}, {-2.751083568688566, 2.027175091423538}}]}, 
         {Arrowheads[{{0.025503553404489374`, 1.}}], 
          ArrowBox[{{-2.125144574057701, 
           1.8600888188788764`}, {-2.374855425942299, 2.0370254981510976`}}]}, 
         {Arrowheads[{{0.02634983874958137, 1.}}], 
          ArrowBox[{{-1.7527737904101248`, 
           1.8482772613973006`}, {-1.9972262095898752`, 
           2.0488370556326734`}}]}, 
         {Arrowheads[{{0.027307799567962556`, 1.}}], 
          ArrowBox[{{-1.3826433600151284`, 
           1.8342190980440929`}, {-1.6173566399848716`, 2.062895218985881}}]}, 
         {Arrowheads[{{0.028365296955365868`, 1.}}], 
          ArrowBox[{{-1.0159982854616088`, 
           1.817851883958563}, {-1.2340017145383912`, 2.079262433071411}}]}, 
         {Arrowheads[{{0.029476404523663385`, 1.}}], 
          ArrowBox[{{-0.6545054254114866, 
           1.799695848983954}, {-0.8454945745885134, 2.09741846804602}}]}, 
         {Arrowheads[{{0.030539854751886045`, 1.}}], 
          ArrowBox[{{-0.2999371876573572, 
           1.7813980952823885`}, {-0.4500628123426428, 
           2.1157162217475856`}}]}, 
         {Arrowheads[{{0.03138964772031195, 1.}}], 
          ArrowBox[{{0.04681098734119277, 
           1.7661293895533157`}, {-0.04681098734119277, 
           2.1309849274766584`}}]}, 
         {Arrowheads[{{0.03183175949218799, 1.}}], 
          ArrowBox[{{0.3872269175044623, 1.7579583774758496`}, {
           0.3627730824955377, 2.1391559395541244`}}]}, 
         {Arrowheads[{{0.03174012468722872, 1.}}], 
          ArrowBox[{{0.7257650907438781, 1.7596647348470769`}, {
           0.7742349092561219, 2.137449582182897}}]}, 
         {Arrowheads[{{0.031142385894604194`, 1.}}], 
          ArrowBox[{{1.0679302802898984`, 1.7706313811140877`}, {
           1.1820697197101016`, 2.1264829359158863`}}]}, 
         {Arrowheads[{{0.030199703088278764`, 1.}}], 
          ArrowBox[{{1.417267771494251, 1.7873486824202125`}, {
           1.582732228505749, 2.1097656346097615`}}]}, 
         {Arrowheads[{{0.029104971031446446`, 1.}}], 
          ArrowBox[{{1.7743160106418632`, 1.8058746070883367`}, {
           1.9756839893581368`, 2.0912397099416373`}}]}, 
         {Arrowheads[{{0.02800364226870596, 1.}}], 
          ArrowBox[{{2.137730562406663, 1.8235494920550162`}, {
           2.362269437593337, 2.073564824974958}}]}, 
         {Arrowheads[{{0.026976320987290567`, 1.}}], 
          ArrowBox[{{2.5057036719672716`, 1.8391662342925286`}, {
           2.7442963280327284`, 2.0579480827374454`}}]}, 
         {Arrowheads[{{0.024099676679852577`, 1.}}], 
          ArrowBox[{{-2.6932775122697366`, 
           2.191496165514811}, {-2.9317224877302634`, 2.355137204353492}}]}, 
         {Arrowheads[{{0.024696324146672343`, 1.}}], 
          ArrowBox[{{-2.3203152554561415`, 
           2.182627992171156}, {-2.5546847445438585`, 2.364005377697147}}]}, 
         {Arrowheads[{{0.025363167830929234`, 1.}}], 
          ArrowBox[{{-1.9486616379243484`, 
           2.172325212585994}, {-2.1763383620756516`, 2.374308157282309}}]}, 
         {Arrowheads[{{0.02609888159900482, 1.}}], 
          ArrowBox[{{-1.5789220894182976`, 
           2.160479210309844}, {-1.7960779105817024`, 2.386154159558459}}]}, 
         {Arrowheads[{{0.026891224166846084`, 1.}}], 
          ArrowBox[{{-1.2119154695014873`, 
           2.1471591724218553`}, {-1.4130845304985127`, 
           2.3994741974464477`}}]}, 
         {Arrowheads[{{0.027709101799197045`, 1.}}], 
          ArrowBox[{{-0.8486451693622332, 
           2.132798306481398}, {-1.0263548306377668`, 2.4138350633869052`}}]}, 
         {Arrowheads[{{0.028493852410030388`, 1.}}], 
          ArrowBox[{{-0.49011162567715383`, 
           2.1184350857403773`}, {-0.6348883743228462, 
           2.4281982841279257`}}]}, 
         {Arrowheads[{{0.029156041542347046`, 1.}}], 
          ArrowBox[{{-0.1368605594264499, 
           2.105870161048213}, {-0.2381394405735501, 2.44076320882009}}]}, 
         {Arrowheads[{{0.029588854747557736`, 1.}}], 
          ArrowBox[{{0.21167711434640898`, 2.0974375251349437`}, {
           0.16332288565359102`, 2.4491958447333593`}}]}, 
         {Arrowheads[{{0.02970434883878871, 1.}}], 
          ArrowBox[{{0.5576019039831361, 2.095157910541416}, {
           0.5673980960168639, 2.451475459326887}}]}, 
         {Arrowheads[{{0.029476404523663385`, 1.}}], 
          ArrowBox[{{0.9040768988940203, 2.0996451571479464`}, {
           0.9709231011059797, 2.4469882127203566`}}]}, 
         {Arrowheads[{{0.028955473828209646`, 1.}}], 
          ArrowBox[{{1.2540289534384033`, 2.1097188932614874`}, {
           1.3709710465615967`, 2.4369144766068156`}}]}, 
         {Arrowheads[{{0.02824088617779116, 1.}}], 
          ArrowBox[{{1.6090465352435386`, 2.12312757300004}, {
           1.7659534647564614`, 2.423505796868263}}]}, 
         {Arrowheads[{{0.027436611884558218`, 1.}}], 
          ArrowBox[{{1.969254633000853, 2.1376518858352913`}, {
           2.155745366999147, 2.4089814840330117`}}]}, 
         {Arrowheads[{{0.026622248488570765`, 1.}}], 
          ArrowBox[{{2.33388810251067, 2.1517462821882525`}, {
           2.54111189748933, 2.3948870876800505`}}]}, 
         {Arrowheads[{{0.025846445228098796`, 1.}}], 
          ArrowBox[{{2.701909895653085, 2.1646004343826055`}, {
           2.923090104346915, 2.3820329354856975`}}]}, 
         {Arrowheads[{{0.02401619735703311, 1.}}], 
          ArrowBox[{{-2.5141953441486162`, 
           2.505954950401421}, {-2.7358046558513838`, 2.690197472305211}}]}, 
         {Arrowheads[{{0.024552573484838417`, 1.}}], 
          ArrowBox[{{-2.142916338164377, 
           2.4969083879206853`}, {-2.357083661835623, 2.6992440347859468`}}]}, 
         {Arrowheads[{{0.02513300744592264, 1.}}], 
          ArrowBox[{{-1.7732550839975794`, 
           2.4867747183461453`}, {-1.9767449160024206`, 
           2.7093777043604867`}}]}, 
         {Arrowheads[{{0.02574715915044841, 1.}}], 
          ArrowBox[{{-1.4057662809463338`, 
           2.475663019462975}, {-1.5942337190536662`, 2.720489403243657}}]}, 
         {Arrowheads[{{0.02637367257076846, 1.}}], 
          ArrowBox[{{-1.0410872456091025`, 
           2.4639151461150854`}, {-1.2089127543908975`, 
           2.7322372765915466`}}]}, 
         {Arrowheads[{{0.026976320987290584`, 1.}}], 
          ArrowBox[{{-0.6798256893925128, 
           2.452221645723371}, {-0.8201743106074872, 2.743930776983261}}]}, 
         {Arrowheads[{{0.027502818281410435`, 1.}}], 
          ArrowBox[{{-0.32233113596814345`, 
           2.441690242530266}, {-0.42766886403185655`, 
           2.754462180176366}}]}, 
         {Arrowheads[{{0.027890418831252452`, 1.}}], 
          ArrowBox[{{0.03162476236668289, 
           2.4337491257641553`}, {-0.03162476236668289, 
           2.7624032969424768`}}]}, 
         {Arrowheads[{{0.028081077871624362`, 1.}}], 
          ArrowBox[{{0.38309694288951257`, 2.4297844137058835`}, {
           0.36690305711048743`, 2.7663680090007485`}}]}, 
         {Arrowheads[{{0.028042160264011667`, 1.}}], 
          ArrowBox[{{0.7338842890828473, 2.4305968307017105`}, {
           0.7661157109171527, 2.7655555920049215`}}]}, 
         {Arrowheads[{{0.02778055675657137, 1.}}], 
          ArrowBox[{{1.086014411001902, 2.4360161611748268`}, {
           1.163985588998098, 2.7601362615318052`}}]}, 
         {Arrowheads[{{0.027339563950025878`, 1.}}], 
          ArrowBox[{{1.4410760323137033`, 2.444987252628997}, {
           1.5589239676862967`, 2.751165170077635}}]}, 
         {Arrowheads[{{0.026781009540386577`, 1.}}], 
          ArrowBox[{{1.7998362716842402`, 2.4560535971760076`}, {
           1.9501637283157598`, 2.7400988255306244`}}]}, 
         {Arrowheads[{{0.026165358653906446`, 1.}}], 
          ArrowBox[{{2.1622946358098885`, 2.4678675140330832`}, {
           2.3377053641901115`, 2.728284908673549}}]}, 
         {Arrowheads[{{0.02553974055427605, 1.}}], 
          ArrowBox[{{2.5279827365104217`, 2.4794605669472594`}, {
           2.7220172634895783`, 2.7166918557593727`}}]}, 
         {Arrowheads[{{0.02343750000000001, 1.}}], 
          ArrowBox[{{-2.7070547088739305`, 
           2.829794450139847}, {-2.9179452911260695`, 3.015877025405114}}]}, 
         {Arrowheads[{{0.023876743512748183`, 1.}}], 
          ArrowBox[{{-2.3359463912995198`, 
           2.8217890937522165`}, {-2.5390536087004802`, 
           3.0238823817927445`}}]}, 
         {Arrowheads[{{0.024345060541474145`, 1.}}], 
          ArrowBox[{{-1.9662052226612605`, 
           2.813000102039208}, {-2.1587947773387395`, 3.032671373505753}}]}, 
         {Arrowheads[{{0.024834181220247744`, 1.}}], 
          ArrowBox[{{-1.598217852164272, 
           2.803541085228777}, {-1.776782147835728, 3.042130390316184}}]}, 
         {Arrowheads[{{0.02532911879301356, 1.}}], 
          ArrowBox[{{-1.2324075841332183`, 
           2.793678785816638}, {-1.3925924158667817`, 3.051992689728323}}]}, 
         {Arrowheads[{{0.025806336132554855`, 1.}}], 
          ArrowBox[{{-0.8691654162470059, 
           2.7838925979331357`}, {-1.005834583752994, 3.0617788776118253`}}]}, 
         {Arrowheads[{{0.026233280311868713`, 1.}}], 
          ArrowBox[{{-0.508725367452308, 
           2.7749068739645018`}, {-0.616274632547692, 3.0707646015804593`}}]}, 
         {Arrowheads[{{0.026570986300117966`, 1.}}], 
          ArrowBox[{{-0.150996567103944, 
           2.7676451367252484`}, {-0.224003432896056, 3.0780263388197127`}}]}, 
         {Arrowheads[{{0.026781009540386546`, 1.}}], 
          ArrowBox[{{0.20458266552630905`, 2.7630602968230087`}, {
           0.17041733447369095`, 3.0826111787219523`}}]}, 
         {Arrowheads[{{0.026835663497094042`, 1.}}], 
          ArrowBox[{{0.5590577696534635, 2.761858555780451}, {
           0.5659422303465365, 3.08381291976451}}]}, 
         {Arrowheads[{{0.026727237900439158`, 1.}}], 
          ArrowBox[{{0.9137607239768434, 2.7642391564025894`}, {
           0.9612392760231566, 3.0814323191423716`}}]}, 
         {Arrowheads[{{0.026470821879959444`, 1.}}], 
          ArrowBox[{{1.2699622626519018`, 2.769813191403249}, {
           1.3550377373480982`, 3.075858284141712}}]}, 
         {Arrowheads[{{0.026098881599004795`, 1.}}], 
          ArrowBox[{{1.6285577056842186`, 2.7777589846840853`}, {
           1.7464422943157814`, 3.0679124908608757`}}]}, 
         {Arrowheads[{{0.025651067989640636`, 1.}}], 
          ArrowBox[{{1.9899413735770328`, 2.787106492081133}, {
           2.135058626422967, 3.058564983463828}}]}, 
         {Arrowheads[{{0.025164755772881964`, 1.}}], 
          ArrowBox[{{2.354076520034966, 2.796986381069952}, {
           2.520923479965034, 3.048685094475009}}]}, 
         {Arrowheads[{{0.024669593461185278`, 1.}}], 
          ArrowBox[{{2.720659531402359, 2.806755909106121}, {
           2.904340468597641, 3.03891556643884}}]}}}, {{}, 
        {RGBColor[0, 0, 1], 
         {Arrowheads[{{0.023437499999999986`, 1.}}], 
          ArrowBox[{{-2.910005893867716, -3.024166835102262}, \
{-2.714994106132284, -2.821504640442699}}]}, 
         {Arrowheads[{{0.024029354453257726`, 1.}}], 
          ArrowBox[{{-2.529839623264911, -3.0335612971124313`}, \
{-2.345160376735089, -2.8121101784325298`}}]}, 
         {Arrowheads[{{0.024641900403865578`, 1.}}], 
          ArrowBox[{{-2.1477447107865673`, -3.043638786084266}, \
{-1.9772552892134327`, -2.802032689460695}}]}, 
         {Arrowheads[{{0.025253188443406255`, 1.}}], 
          
          ArrowBox[{{-1.7632595653302188`, -3.054055154083753}, \
{-1.6117404346697812`, -2.791616321461208}}]}, 
         {Arrowheads[{{0.025830169995799682`, 1.}}], 
          ArrowBox[{{-1.3759870473001687`, -3.064216469760736}, \
{-1.2490129526998313`, -2.781455005784225}}]}, 
         {Arrowheads[{{0.02632914383241547, 1.}}], 
          ArrowBox[{{-0.9857492530857516, -3.0732620217616686`}, \
{-0.8892507469142484, -2.7724094537832924`}}]}, 
         {Arrowheads[{{0.026700697580848528`, 1.}}], 
          ArrowBox[{{-0.5927757452703726, -3.0801531249083753`}, \
{-0.5322242547296274, -2.7655183506365857`}}]}, 
         {Arrowheads[{{0.026900034471024223`, 1.}}], 
          ArrowBox[{{-0.19783258945127188`, -3.0839048669026585`}, \
{-0.17716741054872812`, -2.7617666086423025`}}]}, 
         {Arrowheads[{{0.026900034471024223`, 1.}}], 
          ArrowBox[{{0.19783258945127188`, -3.0839048669026585`}, {
           0.17716741054872812`, -2.7617666086423025`}}]}, 
         {Arrowheads[{{0.026700697580848528`, 1.}}], 
          ArrowBox[{{0.5927757452703726, -3.0801531249083753`}, {
           0.5322242547296274, -2.7655183506365857`}}]}, 
         {Arrowheads[{{0.02632914383241547, 1.}}], 
          ArrowBox[{{0.9857492530857516, -3.0732620217616686`}, {
           0.8892507469142484, -2.7724094537832924`}}]}, 
         {Arrowheads[{{0.025830169995799682`, 1.}}], 
          ArrowBox[{{1.3759870473001687`, -3.064216469760736}, {
           1.2490129526998313`, -2.781455005784225}}]}, 
         {Arrowheads[{{0.025253188443406255`, 1.}}], 
          ArrowBox[{{1.7632595653302188`, -3.054055154083753}, {
           1.6117404346697812`, -2.791616321461208}}]}, 
         {Arrowheads[{{0.024641900403865578`, 1.}}], 
          ArrowBox[{{2.1477447107865673`, -3.043638786084266}, {
           1.9772552892134327`, -2.802032689460695}}]}, 
         {Arrowheads[{{0.024029354453257726`, 1.}}], 
          ArrowBox[{{2.529839623264911, -3.0335612971124313`}, {
           2.345160376735089, -2.8121101784325298`}}]}, 
         {Arrowheads[{{0.023437499999999986`, 1.}}], 
          ArrowBox[{{2.910005893867716, -3.024166835102262}, {
           2.714994106132284, -2.821504640442699}}]}, 
         {Arrowheads[{{0.024321413216362556`, 1.}}], 
          ArrowBox[{{-2.728717545287428, -2.70072995882426}, \
{-2.521282454712572, -2.495422463882372}}]}, 
         {Arrowheads[{{0.025058381392269593`, 1.}}], 
          ArrowBox[{{-2.3484273681626986`, -2.711730346362037}, \
{-2.1515726318373014`, -2.484422076344595}}]}, 
         {Arrowheads[{{0.02583016999579966, 1.}}], 
          ArrowBox[{{-1.965695781857384, -2.7237479731206538`}, \
{-1.784304218142616, -2.4724044495859783`}}]}, 
         {Arrowheads[{{0.026604551665693355`, 1.}}], 
          ArrowBox[{{-1.57981365499708, -2.7363175169460323`}, \
{-1.42018634500292, -2.4598349057605997`}}]}, 
         {Arrowheads[{{0.027329737726391513`, 1.}}], 
          ArrowBox[{{-1.1901584194716721`, -2.748553135441078}, \
{-1.0598415805283279`, -2.447599287265554}}]}, 
         {Arrowheads[{{0.02793510866744529, 1.}}], 
          ArrowBox[{{-0.796486830778215, -2.7591113169347663`}, \
{-0.703513169221785, -2.4370411057718657`}}]}, 
         {Arrowheads[{{0.028342018665776788`, 1.}}], 
          ArrowBox[{{-0.3992931588563801, -2.766384153015685}, \
{-0.3507068411436199, -2.429768269690947}}]}, 
         {Arrowheads[{{0.02848606122799698, 1.}}], 
          ArrowBox[{{0., -2.768992578721298}, {0., -2.427159843985334}}]}, 
         {Arrowheads[{{0.028342018665776788`, 1.}}], 
          ArrowBox[{{0.3992931588563801, -2.766384153015685}, {
           0.3507068411436199, -2.429768269690947}}]}, 
         {Arrowheads[{{0.02793510866744529, 1.}}], 
          ArrowBox[{{0.796486830778215, -2.7591113169347663`}, {
           0.703513169221785, -2.4370411057718657`}}]}, 
         {Arrowheads[{{0.027329737726391513`, 1.}}], 
          ArrowBox[{{1.1901584194716721`, -2.748553135441078}, {
           1.0598415805283279`, -2.447599287265554}}]}, 
         {Arrowheads[{{0.026604551665693355`, 1.}}], 
          ArrowBox[{{1.57981365499708, -2.7363175169460323`}, {
           1.42018634500292, -2.4598349057605997`}}]}, 
         {Arrowheads[{{0.02583016999579966, 1.}}], 
          ArrowBox[{{1.965695781857384, -2.7237479731206538`}, {
           1.784304218142616, -2.4724044495859783`}}]}, 
         {Arrowheads[{{0.025058381392269593`, 1.}}], 
          ArrowBox[{{2.3484273681626986`, -2.711730346362037}, {
           2.1515726318373014`, -2.484422076344595}}]}, 
         {Arrowheads[{{0.024321413216362556`, 1.}}], 
          ArrowBox[{{2.728717545287428, -2.70072995882426}, {
           2.521282454712572, -2.495422463882372}}]}, 
         {Arrowheads[{{0.024531631026647693`, 1.}}], 
          ArrowBox[{{-2.926971523654127, -2.365842915928911}, \
{-2.698028476345873, -2.180790453939392}}]}, 
         {Arrowheads[{{0.025389180025401133`, 1.}}], 
          ArrowBox[{{-2.5489037311179445`, -2.377216566252856}, \
{-2.3260962688820555`, -2.169416803615447}}]}, 
         {Arrowheads[{{0.026329143832415473`, 1.}}], 
          ArrowBox[{{-2.1686483567886534`, -2.3903149058146314`}, \
{-1.9563516432113466`, -2.1563184640536717`}}]}, 
         {Arrowheads[{{0.02732973772639148, 1.}}], 
          ArrowBox[{{-1.7852376292075083`, -2.4049839935109434`}, \
{-1.5897623707924917`, -2.1416493763573596`}}]}, 
         {Arrowheads[{{0.028342018665776802`, 1.}}], 
          ArrowBox[{{-1.3975260559973304`, -2.4205861338887242`}, \
{-1.2274739440026696`, -2.126047235979579}}]}, 
         {Arrowheads[{{0.029280111741826292`, 1.}}], 
          ArrowBox[{{-1.0044776276971112`, -2.4357288007327123`}, \
{-0.8705223723028886, -2.1109045691355908`}}]}, 
         {Arrowheads[{{0.030022456114264254`, 1.}}], 
          ArrowBox[{{-0.6057669642324424, -2.4481780390604815`}, \
{-0.5192330357675576, -2.0984553308078215`}}]}, 
         {Arrowheads[{{0.030438000321360164`, 1.}}], 
          ArrowBox[{{-0.20251192928529527`, -2.4553266546264894`}, \
{-0.17248807071470473`, -2.0913067152418137`}}]}, 
         {Arrowheads[{{0.030438000321360164`, 1.}}], 
          ArrowBox[{{0.20251192928529527`, -2.4553266546264894`}, {
           0.17248807071470473`, -2.0913067152418137`}}]}, 
         {Arrowheads[{{0.030022456114264254`, 1.}}], 
          ArrowBox[{{0.6057669642324424, -2.4481780390604815`}, {
           0.5192330357675576, -2.0984553308078215`}}]}, 
         {Arrowheads[{{0.029280111741826292`, 1.}}], 
          ArrowBox[{{1.0044776276971112`, -2.4357288007327123`}, {
           0.8705223723028886, -2.1109045691355908`}}]}, 
         {Arrowheads[{{0.028342018665776802`, 1.}}], 
          ArrowBox[{{1.3975260559973304`, -2.4205861338887242`}, {
           1.2274739440026696`, -2.126047235979579}}]}, 
         {Arrowheads[{{0.02732973772639148, 1.}}], 
          ArrowBox[{{1.7852376292075083`, -2.4049839935109434`}, {
           1.5897623707924917`, -2.1416493763573596`}}]}, 
         {Arrowheads[{{0.026329143832415473`, 1.}}], 
          ArrowBox[{{2.1686483567886534`, -2.3903149058146314`}, {
           1.9563516432113466`, -2.1563184640536717`}}]}, 
         {Arrowheads[{{0.025389180025401133`, 1.}}], 
          ArrowBox[{{2.5489037311179445`, -2.377216566252856}, {
           2.3260962688820555`, -2.169416803615447}}]}, 
         {Arrowheads[{{0.024531631026647693`, 1.}}], 
          ArrowBox[{{2.926971523654127, -2.365842915928911}, {
           2.698028476345873, -2.180790453939392}}]}, 
         {Arrowheads[{{0.025603146138310023`, 1.}}], 
          ArrowBox[{{-2.7483490557750283`, -2.0401200863726996`}, \
{-2.5016509442249717`, -1.8569942306572744`}}]}, 
         {Arrowheads[{{0.02670069758084855, 1.}}], 
          ArrowBox[{{-2.3711029810814903`, -2.0534354166055837`}, \
{-2.1288970189185097`, -1.8436789004243903`}}]}, 
         {Arrowheads[{{0.02793510866744528, 1.}}], 
          ArrowBox[{{-1.9912170769455375`, -2.0693334877010745`}, \
{-1.7587829230544625`, -1.8277808293288995`}}]}, 
         {Arrowheads[{{0.029280111741826292`, 1.}}], 
          ArrowBox[{{-1.607164204315378, -2.087767543485182}, \
{-1.392835795684622, -1.809346773544792}}]}, 
         {Arrowheads[{{0.030658641332554703`, 1.}}], 
          ArrowBox[{{-1.216975923997664, -2.107864131952035}, \
{-1.033024076002336, -1.7892501850779392`}}]}, 
         {Arrowheads[{{0.031917546642555514`, 1.}}], 
          ArrowBox[{{-0.8187907272562783, -2.1272807105612177`}, \
{-0.6812092727437217, -1.7698336064687563`}}]}, 
         {Arrowheads[{{0.032829905038718125`, 1.}}], 
          ArrowBox[{{-0.4122256132707062, -2.141987119098307}, \
{-0.3377743867292938, -1.755127197931667}}]}, 
         {Arrowheads[{{0.033167320748959506`, 1.}}], 
          ArrowBox[{{0., -2.147561083008744}, {0., -1.74955323402123}}]}, 
         {Arrowheads[{{0.032829905038718125`, 1.}}], 
          ArrowBox[{{0.4122256132707062, -2.141987119098307}, {
           0.3377743867292938, -1.755127197931667}}]}, 
         {Arrowheads[{{0.031917546642555514`, 1.}}], 
          ArrowBox[{{0.8187907272562783, -2.1272807105612177`}, {
           0.6812092727437217, -1.7698336064687563`}}]}, 
         {Arrowheads[{{0.030658641332554703`, 1.}}], 
          ArrowBox[{{1.216975923997664, -2.107864131952035}, {
           1.033024076002336, -1.7892501850779392`}}]}, 
         {Arrowheads[{{0.029280111741826292`, 1.}}], 
          ArrowBox[{{1.607164204315378, -2.087767543485182}, {
           1.392835795684622, -1.809346773544792}}]}, 
         {Arrowheads[{{0.02793510866744528, 1.}}], 
          ArrowBox[{{1.9912170769455375`, -2.0693334877010745`}, {
           1.7587829230544625`, -1.8277808293288995`}}]}, 
         {Arrowheads[{{0.02670069758084855, 1.}}], 
          ArrowBox[{{2.3711029810814903`, -2.0534354166055837`}, {
           2.1288970189185097`, -1.8436789004243903`}}]}, 
         {Arrowheads[{{0.025603146138310023`, 1.}}], 
          ArrowBox[{{2.7483490557750283`, -2.0401200863726996`}, {
           2.5016509442249717`, -1.8569942306572744`}}]}, 
         {Arrowheads[{{0.025677305515419458`, 1.}}], 
          ArrowBox[{{-2.945923193262525, -1.7008295486420808`}, \
{-2.679076806737475, -1.5467657155495642`}}]}, 
         {Arrowheads[{{0.026900034471024212`, 1.}}], 
          ArrowBox[{{-2.5718236628665343`, -1.7132804816125882`}, \
{-2.3031763371334657`, -1.5343147825790568`}}]}, 
         {Arrowheads[{{0.02834201866577681, 1.}}], 
          ArrowBox[{{-2.1961123737100907`, -1.728990095634803}, \
{-1.9288876262899093`, -1.518605168556842}}]}, 
         {Arrowheads[{{0.030022456114264236`, 1.}}], 
          ArrowBox[{{-1.8173008926973273`, -1.7486985993289152`}, \
{-1.5576991073026727`, -1.4988966648627298`}}]}, 
         {Arrowheads[{{0.031917546642555535`, 1.}}], 
          ArrowBox[{{-1.432883772698487, -1.7727339254676817`}, \
{-1.192116227301513, -1.4748613387239633`}}]}, 
         {Arrowheads[{{0.03390191306604375, 1.}}], 
          ArrowBox[{{-1.0392057391981313`, -1.7999571398083354`}, \
{-0.8357942608018687, -1.4476381243833096`}}]}, 
         {Arrowheads[{{0.03567448011942978, 1.}}], 
          ArrowBox[{{-0.6325632880823504, -1.826052923269099}, \
{-0.4924367119176496, -1.421542340922546}}]}, 
         {Arrowheads[{{0.03676400961151064, 1.}}], 
          ArrowBox[{{-0.2128027267351473, -1.842925673472355}, \
{-0.1621972732648527, -1.40466959071929}}]}, 
         {Arrowheads[{{0.03676400961151064, 1.}}], 
          ArrowBox[{{0.2128027267351473, -1.842925673472355}, {
           0.1621972732648527, -1.40466959071929}}]}, 
         {Arrowheads[{{0.03567448011942978, 1.}}], 
          ArrowBox[{{0.6325632880823504, -1.826052923269099}, {
           0.4924367119176496, -1.421542340922546}}]}, 
         {Arrowheads[{{0.03390191306604375, 1.}}], 
          ArrowBox[{{1.0392057391981313`, -1.7999571398083354`}, {
           0.8357942608018687, -1.4476381243833096`}}]}, 
         {Arrowheads[{{0.031917546642555535`, 1.}}], 
          ArrowBox[{{1.432883772698487, -1.7727339254676817`}, {
           1.192116227301513, -1.4748613387239633`}}]}, 
         {Arrowheads[{{0.030022456114264236`, 1.}}], 
          ArrowBox[{{1.8173008926973273`, -1.7486985993289152`}, {
           1.5576991073026727`, -1.4988966648627298`}}]}, 
         {Arrowheads[{{0.02834201866577681, 1.}}], 
          ArrowBox[{{2.1961123737100907`, -1.728990095634803}, {
           1.9288876262899093`, -1.518605168556842}}]}, 
         {Arrowheads[{{0.026900034471024212`, 1.}}], 
          ArrowBox[{{2.5718236628665343`, -1.7132804816125882`}, {
           2.3031763371334657`, -1.5343147825790568`}}]}, 
         {Arrowheads[{{0.025677305515419458`, 1.}}], 
          ArrowBox[{{2.945923193262525, -1.7008295486420808`}, {
           2.679076806737475, -1.5467657155495642`}}]}, 
         {Arrowheads[{{0.026900034471024237`, 1.}}], 
          ArrowBox[{{-2.7696562523178065`, -1.3706243852900704`}, \
{-2.4803437476821935`, -1.2274518260632457`}}]}, 
         {Arrowheads[{{0.02848606122799699, 1.}}], 
          ArrowBox[{{-2.398017916063226, -1.384496289360649}, \
{-2.101982083936774, -1.213579921992667}}]}, 
         {Arrowheads[{{0.030438000321360178`, 1.}}], 
          ArrowBox[{{-2.0251192928529527`, -1.4030438026437082`}, \
{-1.7248807071470473`, -1.1950324087096078`}}]}, 
         {Arrowheads[{{0.03282990503871814, 1.}}], 
          ArrowBox[{{-1.648902453082825, -1.4279914127322049`}, \
{-1.351097546917175, -1.1700847986211111`}}]}, 
         {Arrowheads[{{0.03567448011942977, 1.}}], 
          ArrowBox[{{-1.2651265761647008`, -1.4608423386152791`}, \
{-0.9848734238352993, -1.1372338727380369`}}]}, 
         {Arrowheads[{{0.03876682066627735, 1.}}], 
          ArrowBox[{{-0.866300461998832, -1.5004764148023686`}, \
{-0.633699538001168, -1.0975997965509474`}}]}, 
         {Arrowheads[{{0.0414279346697812, 1.}}], 
          ArrowBox[{{-0.4439402504716008, -1.5378541386833318`}, \
{-0.3060597495283992, -1.0602220726699843`}}]}, 
         {Arrowheads[{{0.04252983979088457, 1.}}], 
          ArrowBox[{{0., -1.5542171444219655`}, {0., -1.0438590669313506`}}]}, 
         {Arrowheads[{{0.0414279346697812, 1.}}], 
          ArrowBox[{{0.4439402504716008, -1.5378541386833318`}, {
           0.3060597495283992, -1.0602220726699843`}}]}, 
         {Arrowheads[{{0.03876682066627735, 1.}}], 
          ArrowBox[{{0.866300461998832, -1.5004764148023686`}, {
           0.633699538001168, -1.0975997965509474`}}]}, 
         {Arrowheads[{{0.03567448011942977, 1.}}], 
          ArrowBox[{{1.2651265761647008`, -1.4608423386152791`}, {
           0.9848734238352993, -1.1372338727380369`}}]}, 
         {Arrowheads[{{0.03282990503871814, 1.}}], 
          ArrowBox[{{1.648902453082825, -1.4279914127322049`}, {
           1.351097546917175, -1.1700847986211111`}}]}, 
         {Arrowheads[{{0.030438000321360178`, 1.}}], 
          ArrowBox[{{2.0251192928529527`, -1.4030438026437082`}, {
           1.7248807071470473`, -1.1950324087096078`}}]}, 
         {Arrowheads[{{0.02848606122799699, 1.}}], 
          ArrowBox[{{2.398017916063226, -1.384496289360649}, {
           2.101982083936774, -1.213579921992667}}]}, 
         {Arrowheads[{{0.026900034471024237`, 1.}}], 
          ArrowBox[{{2.7696562523178065`, -1.3706243852900704`}, {
           2.4803437476821935`, -1.2274518260632457`}}]}, 
         {Arrowheads[{{0.02670069758084853, 1.}}], 
          ArrowBox[{{-2.9638787263518624`, -1.0267177083027919`}, \
{-2.6611212736481376`, -0.9218394502121952}}]}, 
         {Arrowheads[{{0.028342018665776788`, 1.}}], 
          ArrowBox[{{-2.595405532566471, -1.0373940573808818`}, \
{-2.279594467433529, -0.9111631011341053}}]}, 
         {Arrowheads[{{0.030438000321360178`, 1.}}], 
          ArrowBox[{{-2.227631222138248, -1.0522828519827812`}, \
{-1.897368777861752, -0.8962743065322059}}]}, 
         {Arrowheads[{{0.03316732074895953, 1.}}], 
          ArrowBox[{{-1.859842454064394, -1.073780541504372}, \
{-1.515157545935606, -0.874776617010615}}]}, 
         {Arrowheads[{{0.036764009611510634`, 1.}}], 
          ArrowBox[{{-1.489619087146031, -1.105755404083413}, \
{-1.135380912853969, -0.842801754431574}}]}, 
         {Arrowheads[{{0.041427934669781195`, 1.}}], 
          ArrowBox[{{-1.109850626179002, -1.1533906040124988`}, \
{-0.765149373820998, -0.7951665545024882}}]}, 
         {Arrowheads[{{0.046875, 1.}}], 
          ArrowBox[{{-0.703125, -1.2178482240718669`}, {-0.421875, \
-0.7307089344431201}}]}, 
         {Arrowheads[{{0.046875, 1.}}], 
          ArrowBox[{{-0.24065125401692258`, -1.2504605965874214`}, \
{-0.13434874598307742`, -0.6980965619275656}}]}, 
         {Arrowheads[{{0.046875, 1.}}], 
          ArrowBox[{{0.24065125401692258`, -1.2504605965874214`}, {
           0.13434874598307742`, -0.6980965619275656}}]}, 
         {Arrowheads[{{0.046875, 1.}}], 
          ArrowBox[{{0.703125, -1.2178482240718669`}, {
           0.421875, -0.7307089344431201}}]}, 
         {Arrowheads[{{0.041427934669781195`, 1.}}], 
          ArrowBox[{{1.109850626179002, -1.1533906040124988`}, {
           0.765149373820998, -0.7951665545024882}}]}, 
         {Arrowheads[{{0.036764009611510634`, 1.}}], 
          ArrowBox[{{1.489619087146031, -1.105755404083413}, {
           1.135380912853969, -0.842801754431574}}]}, 
         {Arrowheads[{{0.03316732074895953, 1.}}], 
          ArrowBox[{{1.859842454064394, -1.073780541504372}, {
           1.515157545935606, -0.874776617010615}}]}, 
         {Arrowheads[{{0.030438000321360178`, 1.}}], 
          ArrowBox[{{2.227631222138248, -1.0522828519827812`}, {
           1.897368777861752, -0.8962743065322059}}]}, 
         {Arrowheads[{{0.028342018665776788`, 1.}}], 
          ArrowBox[{{2.595405532566471, -1.0373940573808818`}, {
           2.279594467433529, -0.9111631011341053}}]}, 
         {Arrowheads[{{0.02670069758084853, 1.}}], 
          ArrowBox[{{2.9638787263518624`, -1.0267177083027919`}, {
           2.6611212736481376`, -0.9218394502121952}}]}, 
         {Arrowheads[{{0.02793510866744531, 1.}}], 
          ArrowBox[{{-2.7877039077237526`, -0.6897778292336916}, \
{-2.4622960922762474`, -0.6092602764429664}}]}, 
         {Arrowheads[{{0.030022456114264223`, 1.}}], 
          ArrowBox[{{-2.42306785692977, -0.6994794397315661}, \
{-2.07693214307023, -0.5995586659450919}}]}, 
         {Arrowheads[{{0.032829905038718146`, 1.}}], 
          ArrowBox[{{-2.061128066353531, -0.7139957063661024}, \
{-1.6888719336464688`, -0.5850423993105556}}]}, 
         {Arrowheads[{{0.03676400961151065, 1.}}], 
          ArrowBox[{{-1.7024218138811784`, -0.737170269388942}, \
{-1.2975781861188216`, -0.561867836287716}}]}, 
         {Arrowheads[{{0.04252983979088457, 1.}}], 
          ArrowBox[{{-1.3459915300667298`, -0.7771085722109827}, \
{-0.9040084699332702, -0.5219295334656753}}]}, 
         {Arrowheads[{{0.046875, 1.}}], 
          ArrowBox[{{-0.9626050160676903, -0.8336403977249476}, \
{-0.5373949839323097, -0.4653977079517104}}]}, 
         {Arrowheads[{{0.046875, 1.}}], 
          ArrowBox[{{-0.515625, -0.8930886976527024}, {-0.234375, \
-0.4059494080239556}}]}, 
         {Arrowheads[{{0.046875, 1.}}], 
          ArrowBox[{{0., -0.930769052838329}, {0., -0.368269052838329}}]}, 
         {Arrowheads[{{0.046875, 1.}}], 
          ArrowBox[{{0.515625, -0.8930886976527024}, {
           0.234375, -0.4059494080239556}}]}, 
         {Arrowheads[{{0.046875, 1.}}], 
          ArrowBox[{{0.9626050160676903, -0.8336403977249476}, {
           0.5373949839323097, -0.4653977079517104}}]}, 
         {Arrowheads[{{0.04252983979088457, 1.}}], 
          ArrowBox[{{1.3459915300667298`, -0.7771085722109827}, {
           0.9040084699332702, -0.5219295334656753}}]}, 
         {Arrowheads[{{0.03676400961151065, 1.}}], 
          ArrowBox[{{1.7024218138811784`, -0.737170269388942}, {
           1.2975781861188216`, -0.561867836287716}}]}, 
         {Arrowheads[{{0.032829905038718146`, 1.}}], 
          ArrowBox[{{2.061128066353531, -0.7139957063661024}, {
           1.6888719336464688`, -0.5850423993105556}}]}, 
         {Arrowheads[{{0.030022456114264223`, 1.}}], 
          ArrowBox[{{2.42306785692977, -0.6994794397315661}, {
           2.07693214307023, -0.5995586659450919}}]}, 
         {Arrowheads[{{0.02793510866744531, 1.}}], 
          ArrowBox[{{2.7877039077237526`, -0.6897778292336916}, {
           2.4622960922762474`, -0.6092602764429664}}]}, 
         {Arrowheads[{{0.027329737726391513`, 1.}}], 
          ArrowBox[{{-2.9753960486791806`, -0.34356914193013477`}, \
{-2.6496039513208194`, -0.30594991090819423`}}]}, 
         {Arrowheads[{{0.029280111741826337`, 1.}}], 
          ArrowBox[{{-2.6116418320124897`, -0.34796125724753035`}, \
{-2.2633581679875103`, -0.30155779559079865`}}]}, 
         {Arrowheads[{{0.031917546642555535`, 1.}}], 
          ArrowBox[{{-2.2516744999547655`, -0.3545467850935363}, \
{-1.8733255000452345`, -0.2949722677447927}}]}, 
         {Arrowheads[{{0.03567448011942976, 1.}}], 
          ArrowBox[{{-1.897689864247051, -0.3652105846538198}, \
{-1.477310135752949, -0.2843084681845092}}]}, 
         {Arrowheads[{{0.04142793466978121, 1.}}], 
          ArrowBox[{{-1.553790876650603, -0.38446353467083294`}, \
{-1.071209123349397, -0.26505551816749606`}}]}, 
         {Arrowheads[{{0.04687500000000002, 1.}}], 
          ArrowBox[{{-1.203256270084613, -0.4168201988624738}, \
{-0.671743729915387, -0.2326988539758552}}]}, 
         {Arrowheads[{{0.046875, 1.}}], 
          ArrowBox[{{-0.8060696448143734, -0.4653845264191645}, \
{-0.3189303551856266, -0.1841345264191645}}]}, 
         {Arrowheads[{{0.046875, 1.}}], 
          ArrowBox[{{-0.328125, -0.5683291712335379}, {-0.046875, \
-0.08118988160479113}}]}, 
         {Arrowheads[{{0.046875, 1.}}], 
          ArrowBox[{{0.328125, -0.5683291712335379}, {
           0.046875, -0.08118988160479113}}]}, 
         {Arrowheads[{{0.046875, 1.}}], 
          ArrowBox[{{0.8060696448143734, -0.4653845264191645}, {
           0.3189303551856266, -0.1841345264191645}}]}, 
         {Arrowheads[{{0.04687500000000002, 1.}}], 
          ArrowBox[{{1.203256270084613, -0.4168201988624738}, {
           0.671743729915387, -0.2326988539758552}}]}, 
         {Arrowheads[{{0.04142793466978121, 1.}}], 
          ArrowBox[{{1.553790876650603, -0.38446353467083294`}, {
           1.071209123349397, -0.26505551816749606`}}]}, 
         {Arrowheads[{{0.03567448011942976, 1.}}], 
          ArrowBox[{{1.897689864247051, -0.3652105846538198}, {
           1.477310135752949, -0.2843084681845092}}]}, 
         {Arrowheads[{{0.031917546642555535`, 1.}}], 
          ArrowBox[{{2.2516744999547655`, -0.3545467850935363}, {
           1.8733255000452345`, -0.2949722677447927}}]}, 
         {Arrowheads[{{0.029280111741826337`, 1.}}], 
          ArrowBox[{{2.6116418320124897`, -0.34796125724753035`}, {
           2.2633581679875103`, -0.30155779559079865`}}]}, 
         {Arrowheads[{{0.027329737726391513`, 1.}}], 
          ArrowBox[{{2.9753960486791806`, -0.34356914193013477`}, {
           2.6496039513208194`, -0.30594991090819423`}}]}, 
         {Arrowheads[{{0.02834201866577679, 1.}}], 
          ArrowBox[{{-2.7950521119946607`, 0.}, {-2.4549478880053393`, 0.}}]}, 
         {Arrowheads[{{0.030658641332554692`, 1.}}], 
          ArrowBox[{{-2.433951847995328, 0.}, {-2.066048152004672, 0.}}]}, 
         {Arrowheads[{{0.033901913066043766`, 1.}}], 
          ArrowBox[{{-2.0784114783962626`, 0.}, {-1.6715885216037374`, 0.}}]}, 
         {Arrowheads[{{0.038766820666277346`, 1.}}], 
          ArrowBox[{{-1.732600923997664, 0.}, {-1.267399076002336, 0.}}]}, 
         {Arrowheads[{{0.046875, 1.}}], 
          ArrowBox[{{-1.40625, 0.}, {-0.84375, 0.}}]}, 
         {Arrowheads[{{0.046875, 1.}}], 
          ArrowBox[{{-1.03125, 0.}, {-0.46875, 0.}}]}, 
         {Arrowheads[{{0.046875, 1.}}], 
          ArrowBox[{{-0.65625, 0.}, {-0.09375, 0.}}]}, 
         {Arrowheads[{{0.046875, 1.}}], 
          ArrowBox[{{-0.28125, 0.}, {0.28125, 0.}}]}, 
         {Arrowheads[{{0.046875, 1.}}], 
          ArrowBox[{{0.65625, 0.}, {0.09375, 0.}}]}, 
         {Arrowheads[{{0.046875, 1.}}], 
          ArrowBox[{{1.03125, 0.}, {0.46875, 0.}}]}, 
         {Arrowheads[{{0.046875, 1.}}], 
          ArrowBox[{{1.40625, 0.}, {0.84375, 0.}}]}, 
         {Arrowheads[{{0.038766820666277346`, 1.}}], 
          ArrowBox[{{1.732600923997664, 0.}, {1.267399076002336, 0.}}]}, 
         {Arrowheads[{{0.033901913066043766`, 1.}}], 
          ArrowBox[{{2.0784114783962626`, 0.}, {1.6715885216037374`, 0.}}]}, 
         {Arrowheads[{{0.030658641332554692`, 1.}}], 
          ArrowBox[{{2.433951847995328, 0.}, {2.066048152004672, 0.}}]}, 
         {Arrowheads[{{0.02834201866577679, 1.}}], 
          ArrowBox[{{2.7950521119946607`, 0.}, {2.4549478880053393`, 0.}}]}, 
         {Arrowheads[{{0.027329737726391513`, 1.}}], 
          ArrowBox[{{-2.9753960486791806`, 
           0.34356914193013477`}, {-2.6496039513208194`, 
           0.30594991090819423`}}]}, 
         {Arrowheads[{{0.029280111741826337`, 1.}}], 
          ArrowBox[{{-2.6116418320124897`, 
           0.34796125724753035`}, {-2.2633581679875103`, 
           0.30155779559079865`}}]}, 
         {Arrowheads[{{0.031917546642555535`, 1.}}], 
          ArrowBox[{{-2.2516744999547655`, 
           0.3545467850935363}, {-1.8733255000452345`, 0.2949722677447927}}]}, 
         {Arrowheads[{{0.03567448011942976, 1.}}], 
          ArrowBox[{{-1.897689864247051, 
           0.3652105846538198}, {-1.477310135752949, 0.2843084681845092}}]}, 
         {Arrowheads[{{0.04142793466978121, 1.}}], 
          ArrowBox[{{-1.553790876650603, 
           0.38446353467083294`}, {-1.071209123349397, 
           0.26505551816749606`}}]}, 
         {Arrowheads[{{0.04687500000000002, 1.}}], 
          ArrowBox[{{-1.203256270084613, 
           0.4168201988624738}, {-0.671743729915387, 0.2326988539758552}}]}, 
         {Arrowheads[{{0.046875, 1.}}], 
          ArrowBox[{{-0.8060696448143734, 
           0.4653845264191645}, {-0.3189303551856266, 
           0.1841345264191645}}]}, 
         {Arrowheads[{{0.046875, 1.}}], 
          ArrowBox[{{-0.328125, 0.5683291712335379}, {-0.046875, 
           0.08118988160479113}}]}, 
         {Arrowheads[{{0.046875, 1.}}], 
          ArrowBox[{{0.328125, 0.5683291712335379}, {0.046875, 
           0.08118988160479113}}]}, 
         {Arrowheads[{{0.046875, 1.}}], 
          ArrowBox[{{0.8060696448143734, 0.4653845264191645}, {
           0.3189303551856266, 0.1841345264191645}}]}, 
         {Arrowheads[{{0.04687500000000002, 1.}}], 
          ArrowBox[{{1.203256270084613, 0.4168201988624738}, {
           0.671743729915387, 0.2326988539758552}}]}, 
         {Arrowheads[{{0.04142793466978121, 1.}}], 
          ArrowBox[{{1.553790876650603, 0.38446353467083294`}, {
           1.071209123349397, 0.26505551816749606`}}]}, 
         {Arrowheads[{{0.03567448011942976, 1.}}], 
          ArrowBox[{{1.897689864247051, 0.3652105846538198}, {
           1.477310135752949, 0.2843084681845092}}]}, 
         {Arrowheads[{{0.031917546642555535`, 1.}}], 
          ArrowBox[{{2.2516744999547655`, 0.3545467850935363}, {
           1.8733255000452345`, 0.2949722677447927}}]}, 
         {Arrowheads[{{0.029280111741826337`, 1.}}], 
          ArrowBox[{{2.6116418320124897`, 0.34796125724753035`}, {
           2.2633581679875103`, 0.30155779559079865`}}]}, 
         {Arrowheads[{{0.027329737726391513`, 1.}}], 
          ArrowBox[{{2.9753960486791806`, 0.34356914193013477`}, {
           2.6496039513208194`, 0.30594991090819423`}}]}, 
         {Arrowheads[{{0.02793510866744531, 1.}}], 
          ArrowBox[{{-2.7877039077237526`, 
           0.6897778292336916}, {-2.4622960922762474`, 0.6092602764429664}}]}, 
         {Arrowheads[{{0.030022456114264223`, 1.}}], 
          ArrowBox[{{-2.42306785692977, 
           0.6994794397315661}, {-2.07693214307023, 0.5995586659450919}}]}, 
         {Arrowheads[{{0.032829905038718146`, 1.}}], 
          ArrowBox[{{-2.061128066353531, 
           0.7139957063661024}, {-1.6888719336464688`, 0.5850423993105556}}]}, 
         {Arrowheads[{{0.03676400961151065, 1.}}], 
          ArrowBox[{{-1.7024218138811784`, 
           0.737170269388942}, {-1.2975781861188216`, 0.561867836287716}}]}, 
         {Arrowheads[{{0.04252983979088457, 1.}}], 
          ArrowBox[{{-1.3459915300667298`, 
           0.7771085722109827}, {-0.9040084699332702, 
           0.5219295334656753}}]}, 
         {Arrowheads[{{0.046875, 1.}}], 
          ArrowBox[{{-0.9626050160676903, 
           0.8336403977249476}, {-0.5373949839323097, 
           0.4653977079517104}}]}, 
         {Arrowheads[{{0.046875, 1.}}], 
          ArrowBox[{{-0.515625, 0.8930886976527024}, {-0.234375, 
           0.4059494080239556}}]}, 
         {Arrowheads[{{0.046875, 1.}}], 
          ArrowBox[{{0., 0.930769052838329}, {0., 0.368269052838329}}]}, 
         {Arrowheads[{{0.046875, 1.}}], 
          ArrowBox[{{0.515625, 0.8930886976527024}, {0.234375, 
           0.4059494080239556}}]}, 
         {Arrowheads[{{0.046875, 1.}}], 
          ArrowBox[{{0.9626050160676903, 0.8336403977249476}, {
           0.5373949839323097, 0.4653977079517104}}]}, 
         {Arrowheads[{{0.04252983979088457, 1.}}], 
          ArrowBox[{{1.3459915300667298`, 0.7771085722109827}, {
           0.9040084699332702, 0.5219295334656753}}]}, 
         {Arrowheads[{{0.03676400961151065, 1.}}], 
          ArrowBox[{{1.7024218138811784`, 0.737170269388942}, {
           1.2975781861188216`, 0.561867836287716}}]}, 
         {Arrowheads[{{0.032829905038718146`, 1.}}], 
          ArrowBox[{{2.061128066353531, 0.7139957063661024}, {
           1.6888719336464688`, 0.5850423993105556}}]}, 
         {Arrowheads[{{0.030022456114264223`, 1.}}], 
          ArrowBox[{{2.42306785692977, 0.6994794397315661}, {2.07693214307023,
            0.5995586659450919}}]}, 
         {Arrowheads[{{0.02793510866744531, 1.}}], 
          ArrowBox[{{2.7877039077237526`, 0.6897778292336916}, {
           2.4622960922762474`, 0.6092602764429664}}]}, 
         {Arrowheads[{{0.02670069758084853, 1.}}], 
          ArrowBox[{{-2.9638787263518624`, 
           1.0267177083027919`}, {-2.6611212736481376`, 
           0.9218394502121952}}]}, 
         {Arrowheads[{{0.028342018665776788`, 1.}}], 
          ArrowBox[{{-2.595405532566471, 
           1.0373940573808818`}, {-2.279594467433529, 
           0.9111631011341053}}]}, 
         {Arrowheads[{{0.030438000321360178`, 1.}}], 
          ArrowBox[{{-2.227631222138248, 
           1.0522828519827812`}, {-1.897368777861752, 
           0.8962743065322059}}]}, 
         {Arrowheads[{{0.03316732074895953, 1.}}], 
          ArrowBox[{{-1.859842454064394, 
           1.073780541504372}, {-1.515157545935606, 0.874776617010615}}]}, 
         {Arrowheads[{{0.036764009611510634`, 1.}}], 
          ArrowBox[{{-1.489619087146031, 
           1.105755404083413}, {-1.135380912853969, 0.842801754431574}}]}, 
         {Arrowheads[{{0.041427934669781195`, 1.}}], 
          ArrowBox[{{-1.109850626179002, 
           1.1533906040124988`}, {-0.765149373820998, 
           0.7951665545024882}}]}, 
         {Arrowheads[{{0.046875, 1.}}], 
          ArrowBox[{{-0.703125, 1.2178482240718669`}, {-0.421875, 
           0.7307089344431201}}]}, 
         {Arrowheads[{{0.046875, 1.}}], 
          ArrowBox[{{-0.24065125401692258`, 
           1.2504605965874214`}, {-0.13434874598307742`, 
           0.6980965619275656}}]}, 
         {Arrowheads[{{0.046875, 1.}}], 
          ArrowBox[{{0.24065125401692258`, 1.2504605965874214`}, {
           0.13434874598307742`, 0.6980965619275656}}]}, 
         {Arrowheads[{{0.046875, 1.}}], 
          ArrowBox[{{0.703125, 1.2178482240718669`}, {0.421875, 
           0.7307089344431201}}]}, 
         {Arrowheads[{{0.041427934669781195`, 1.}}], 
          ArrowBox[{{1.109850626179002, 1.1533906040124988`}, {
           0.765149373820998, 0.7951665545024882}}]}, 
         {Arrowheads[{{0.036764009611510634`, 1.}}], 
          ArrowBox[{{1.489619087146031, 1.105755404083413}, {
           1.135380912853969, 0.842801754431574}}]}, 
         {Arrowheads[{{0.03316732074895953, 1.}}], 
          ArrowBox[{{1.859842454064394, 1.073780541504372}, {
           1.515157545935606, 0.874776617010615}}]}, 
         {Arrowheads[{{0.030438000321360178`, 1.}}], 
          ArrowBox[{{2.227631222138248, 1.0522828519827812`}, {
           1.897368777861752, 0.8962743065322059}}]}, 
         {Arrowheads[{{0.028342018665776788`, 1.}}], 
          ArrowBox[{{2.595405532566471, 1.0373940573808818`}, {
           2.279594467433529, 0.9111631011341053}}]}, 
         {Arrowheads[{{0.02670069758084853, 1.}}], 
          ArrowBox[{{2.9638787263518624`, 1.0267177083027919`}, {
           2.6611212736481376`, 0.9218394502121952}}]}, 
         {Arrowheads[{{0.026900034471024237`, 1.}}], 
          ArrowBox[{{-2.7696562523178065`, 
           1.3706243852900704`}, {-2.4803437476821935`, 
           1.2274518260632457`}}]}, 
         {Arrowheads[{{0.02848606122799699, 1.}}], 
          ArrowBox[{{-2.398017916063226, 
           1.384496289360649}, {-2.101982083936774, 1.213579921992667}}]}, 
         {Arrowheads[{{0.030438000321360178`, 1.}}], 
          ArrowBox[{{-2.0251192928529527`, 
           1.4030438026437082`}, {-1.7248807071470473`, 
           1.1950324087096078`}}]}, 
         {Arrowheads[{{0.03282990503871814, 1.}}], 
          ArrowBox[{{-1.648902453082825, 
           1.4279914127322049`}, {-1.351097546917175, 1.1700847986211111`}}]}, 
         {Arrowheads[{{0.03567448011942977, 1.}}], 
          ArrowBox[{{-1.2651265761647008`, 
           1.4608423386152791`}, {-0.9848734238352993, 
           1.1372338727380369`}}]}, 
         {Arrowheads[{{0.03876682066627735, 1.}}], 
          ArrowBox[{{-0.866300461998832, 
           1.5004764148023686`}, {-0.633699538001168, 1.0975997965509474`}}]}, 
         {Arrowheads[{{0.0414279346697812, 1.}}], 
          ArrowBox[{{-0.4439402504716008, 
           1.5378541386833318`}, {-0.3060597495283992, 
           1.0602220726699843`}}]}, 
         {Arrowheads[{{0.04252983979088457, 1.}}], 
          ArrowBox[{{0., 1.5542171444219655`}, {0., 1.0438590669313506`}}]}, 
         {Arrowheads[{{0.0414279346697812, 1.}}], 
          ArrowBox[{{0.4439402504716008, 1.5378541386833318`}, {
           0.3060597495283992, 1.0602220726699843`}}]}, 
         {Arrowheads[{{0.03876682066627735, 1.}}], 
          ArrowBox[{{0.866300461998832, 1.5004764148023686`}, {
           0.633699538001168, 1.0975997965509474`}}]}, 
         {Arrowheads[{{0.03567448011942977, 1.}}], 
          ArrowBox[{{1.2651265761647008`, 1.4608423386152791`}, {
           0.9848734238352993, 1.1372338727380369`}}]}, 
         {Arrowheads[{{0.03282990503871814, 1.}}], 
          ArrowBox[{{1.648902453082825, 1.4279914127322049`}, {
           1.351097546917175, 1.1700847986211111`}}]}, 
         {Arrowheads[{{0.030438000321360178`, 1.}}], 
          ArrowBox[{{2.0251192928529527`, 1.4030438026437082`}, {
           1.7248807071470473`, 1.1950324087096078`}}]}, 
         {Arrowheads[{{0.02848606122799699, 1.}}], 
          ArrowBox[{{2.398017916063226, 1.384496289360649}, {
           2.101982083936774, 1.213579921992667}}]}, 
         {Arrowheads[{{0.026900034471024237`, 1.}}], 
          ArrowBox[{{2.7696562523178065`, 1.3706243852900704`}, {
           2.4803437476821935`, 1.2274518260632457`}}]}, 
         {Arrowheads[{{0.025677305515419458`, 1.}}], 
          ArrowBox[{{-2.945923193262525, 
           1.7008295486420808`}, {-2.679076806737475, 1.5467657155495642`}}]}, 
         {Arrowheads[{{0.026900034471024212`, 1.}}], 
          ArrowBox[{{-2.5718236628665343`, 
           1.7132804816125882`}, {-2.3031763371334657`, 
           1.5343147825790568`}}]}, 
         {Arrowheads[{{0.02834201866577681, 1.}}], 
          ArrowBox[{{-2.1961123737100907`, 
           1.728990095634803}, {-1.9288876262899093`, 1.518605168556842}}]}, 
         {Arrowheads[{{0.030022456114264236`, 1.}}], 
          ArrowBox[{{-1.8173008926973273`, 
           1.7486985993289152`}, {-1.5576991073026727`, 
           1.4988966648627298`}}]}, 
         {Arrowheads[{{0.031917546642555535`, 1.}}], 
          ArrowBox[{{-1.432883772698487, 
           1.7727339254676817`}, {-1.192116227301513, 1.4748613387239633`}}]}, 
         {Arrowheads[{{0.03390191306604375, 1.}}], 
          ArrowBox[{{-1.0392057391981313`, 
           1.7999571398083354`}, {-0.8357942608018687, 
           1.4476381243833096`}}]}, 
         {Arrowheads[{{0.03567448011942978, 1.}}], 
          ArrowBox[{{-0.6325632880823504, 
           1.826052923269099}, {-0.4924367119176496, 1.421542340922546}}]}, 
         {Arrowheads[{{0.03676400961151064, 1.}}], 
          ArrowBox[{{-0.2128027267351473, 
           1.842925673472355}, {-0.1621972732648527, 1.40466959071929}}]}, 
         {Arrowheads[{{0.03676400961151064, 1.}}], 
          ArrowBox[{{0.2128027267351473, 1.842925673472355}, {
           0.1621972732648527, 1.40466959071929}}]}, 
         {Arrowheads[{{0.03567448011942978, 1.}}], 
          ArrowBox[{{0.6325632880823504, 1.826052923269099}, {
           0.4924367119176496, 1.421542340922546}}]}, 
         {Arrowheads[{{0.03390191306604375, 1.}}], 
          ArrowBox[{{1.0392057391981313`, 1.7999571398083354`}, {
           0.8357942608018687, 1.4476381243833096`}}]}, 
         {Arrowheads[{{0.031917546642555535`, 1.}}], 
          ArrowBox[{{1.432883772698487, 1.7727339254676817`}, {
           1.192116227301513, 1.4748613387239633`}}]}, 
         {Arrowheads[{{0.030022456114264236`, 1.}}], 
          ArrowBox[{{1.8173008926973273`, 1.7486985993289152`}, {
           1.5576991073026727`, 1.4988966648627298`}}]}, 
         {Arrowheads[{{0.02834201866577681, 1.}}], 
          ArrowBox[{{2.1961123737100907`, 1.728990095634803}, {
           1.9288876262899093`, 1.518605168556842}}]}, 
         {Arrowheads[{{0.026900034471024212`, 1.}}], 
          ArrowBox[{{2.5718236628665343`, 1.7132804816125882`}, {
           2.3031763371334657`, 1.5343147825790568`}}]}, 
         {Arrowheads[{{0.025677305515419458`, 1.}}], 
          ArrowBox[{{2.945923193262525, 1.7008295486420808`}, {
           2.679076806737475, 1.5467657155495642`}}]}, 
         {Arrowheads[{{0.025603146138310023`, 1.}}], 
          ArrowBox[{{-2.7483490557750283`, 
           2.0401200863726996`}, {-2.5016509442249717`, 
           1.8569942306572744`}}]}, 
         {Arrowheads[{{0.02670069758084855, 1.}}], 
          ArrowBox[{{-2.3711029810814903`, 
           2.0534354166055837`}, {-2.1288970189185097`, 
           1.8436789004243903`}}]}, 
         {Arrowheads[{{0.02793510866744528, 1.}}], 
          ArrowBox[{{-1.9912170769455375`, 
           2.0693334877010745`}, {-1.7587829230544625`, 
           1.8277808293288995`}}]}, 
         {Arrowheads[{{0.029280111741826292`, 1.}}], 
          ArrowBox[{{-1.607164204315378, 
           2.087767543485182}, {-1.392835795684622, 1.809346773544792}}]}, 
         {Arrowheads[{{0.030658641332554703`, 1.}}], 
          ArrowBox[{{-1.216975923997664, 
           2.107864131952035}, {-1.033024076002336, 1.7892501850779392`}}]}, 
         {Arrowheads[{{0.031917546642555514`, 1.}}], 
          ArrowBox[{{-0.8187907272562783, 
           2.1272807105612177`}, {-0.6812092727437217, 
           1.7698336064687563`}}]}, 
         {Arrowheads[{{0.032829905038718125`, 1.}}], 
          ArrowBox[{{-0.4122256132707062, 
           2.141987119098307}, {-0.3377743867292938, 1.755127197931667}}]}, 
         {Arrowheads[{{0.033167320748959506`, 1.}}], 
          ArrowBox[{{0., 2.147561083008744}, {0., 1.74955323402123}}]}, 
         {Arrowheads[{{0.032829905038718125`, 1.}}], 
          ArrowBox[{{0.4122256132707062, 2.141987119098307}, {
           0.3377743867292938, 1.755127197931667}}]}, 
         {Arrowheads[{{0.031917546642555514`, 1.}}], 
          ArrowBox[{{0.8187907272562783, 2.1272807105612177`}, {
           0.6812092727437217, 1.7698336064687563`}}]}, 
         {Arrowheads[{{0.030658641332554703`, 1.}}], 
          ArrowBox[{{1.216975923997664, 2.107864131952035}, {
           1.033024076002336, 1.7892501850779392`}}]}, 
         {Arrowheads[{{0.029280111741826292`, 1.}}], 
          ArrowBox[{{1.607164204315378, 2.087767543485182}, {
           1.392835795684622, 1.809346773544792}}]}, 
         {Arrowheads[{{0.02793510866744528, 1.}}], 
          ArrowBox[{{1.9912170769455375`, 2.0693334877010745`}, {
           1.7587829230544625`, 1.8277808293288995`}}]}, 
         {Arrowheads[{{0.02670069758084855, 1.}}], 
          ArrowBox[{{2.3711029810814903`, 2.0534354166055837`}, {
           2.1288970189185097`, 1.8436789004243903`}}]}, 
         {Arrowheads[{{0.025603146138310023`, 1.}}], 
          ArrowBox[{{2.7483490557750283`, 2.0401200863726996`}, {
           2.5016509442249717`, 1.8569942306572744`}}]}, 
         {Arrowheads[{{0.024531631026647693`, 1.}}], 
          ArrowBox[{{-2.926971523654127, 
           2.365842915928911}, {-2.698028476345873, 2.180790453939392}}]}, 
         {Arrowheads[{{0.025389180025401133`, 1.}}], 
          ArrowBox[{{-2.5489037311179445`, 
           2.377216566252856}, {-2.3260962688820555`, 2.169416803615447}}]}, 
         {Arrowheads[{{0.026329143832415473`, 1.}}], 
          ArrowBox[{{-2.1686483567886534`, 
           2.3903149058146314`}, {-1.9563516432113466`, 
           2.1563184640536717`}}]}, 
         {Arrowheads[{{0.02732973772639148, 1.}}], 
          ArrowBox[{{-1.7852376292075083`, 
           2.4049839935109434`}, {-1.5897623707924917`, 
           2.1416493763573596`}}]}, 
         {Arrowheads[{{0.028342018665776802`, 1.}}], 
          ArrowBox[{{-1.3975260559973304`, 
           2.4205861338887242`}, {-1.2274739440026696`, 2.126047235979579}}]}, 
         {Arrowheads[{{0.029280111741826292`, 1.}}], 
          ArrowBox[{{-1.0044776276971112`, 
           2.4357288007327123`}, {-0.8705223723028886, 
           2.1109045691355908`}}]}, 
         {Arrowheads[{{0.030022456114264254`, 1.}}], 
          ArrowBox[{{-0.6057669642324424, 
           2.4481780390604815`}, {-0.5192330357675576, 
           2.0984553308078215`}}]}, 
         {Arrowheads[{{0.030438000321360164`, 1.}}], 
          ArrowBox[{{-0.20251192928529527`, 
           2.4553266546264894`}, {-0.17248807071470473`, 
           2.0913067152418137`}}]}, 
         {Arrowheads[{{0.030438000321360164`, 1.}}], 
          ArrowBox[{{0.20251192928529527`, 2.4553266546264894`}, {
           0.17248807071470473`, 2.0913067152418137`}}]}, 
         {Arrowheads[{{0.030022456114264254`, 1.}}], 
          ArrowBox[{{0.6057669642324424, 2.4481780390604815`}, {
           0.5192330357675576, 2.0984553308078215`}}]}, 
         {Arrowheads[{{0.029280111741826292`, 1.}}], 
          ArrowBox[{{1.0044776276971112`, 2.4357288007327123`}, {
           0.8705223723028886, 2.1109045691355908`}}]}, 
         {Arrowheads[{{0.028342018665776802`, 1.}}], 
          ArrowBox[{{1.3975260559973304`, 2.4205861338887242`}, {
           1.2274739440026696`, 2.126047235979579}}]}, 
         {Arrowheads[{{0.02732973772639148, 1.}}], 
          ArrowBox[{{1.7852376292075083`, 2.4049839935109434`}, {
           1.5897623707924917`, 2.1416493763573596`}}]}, 
         {Arrowheads[{{0.026329143832415473`, 1.}}], 
          ArrowBox[{{2.1686483567886534`, 2.3903149058146314`}, {
           1.9563516432113466`, 2.1563184640536717`}}]}, 
         {Arrowheads[{{0.025389180025401133`, 1.}}], 
          ArrowBox[{{2.5489037311179445`, 2.377216566252856}, {
           2.3260962688820555`, 2.169416803615447}}]}, 
         {Arrowheads[{{0.024531631026647693`, 1.}}], 
          ArrowBox[{{2.926971523654127, 2.365842915928911}, {
           2.698028476345873, 2.180790453939392}}]}, 
         {Arrowheads[{{0.024321413216362556`, 1.}}], 
          ArrowBox[{{-2.728717545287428, 
           2.70072995882426}, {-2.521282454712572, 2.495422463882372}}]}, 
         {Arrowheads[{{0.025058381392269593`, 1.}}], 
          ArrowBox[{{-2.3484273681626986`, 
           2.711730346362037}, {-2.1515726318373014`, 2.484422076344595}}]}, 
         {Arrowheads[{{0.02583016999579966, 1.}}], 
          ArrowBox[{{-1.965695781857384, 
           2.7237479731206538`}, {-1.784304218142616, 2.4724044495859783`}}]}, 
         {Arrowheads[{{0.026604551665693355`, 1.}}], 
          ArrowBox[{{-1.57981365499708, 
           2.7363175169460323`}, {-1.42018634500292, 
           2.4598349057605997`}}]}, 
         {Arrowheads[{{0.027329737726391513`, 1.}}], 
          ArrowBox[{{-1.1901584194716721`, 
           2.748553135441078}, {-1.0598415805283279`, 2.447599287265554}}]}, 
         {Arrowheads[{{0.02793510866744529, 1.}}], 
          ArrowBox[{{-0.796486830778215, 
           2.7591113169347663`}, {-0.703513169221785, 2.4370411057718657`}}]}, 
         {Arrowheads[{{0.028342018665776788`, 1.}}], 
          ArrowBox[{{-0.3992931588563801, 
           2.766384153015685}, {-0.3507068411436199, 2.429768269690947}}]}, 
         {Arrowheads[{{0.02848606122799698, 1.}}], 
          ArrowBox[{{0., 2.768992578721298}, {0., 2.427159843985334}}]}, 
         {Arrowheads[{{0.028342018665776788`, 1.}}], 
          ArrowBox[{{0.3992931588563801, 2.766384153015685}, {
           0.3507068411436199, 2.429768269690947}}]}, 
         {Arrowheads[{{0.02793510866744529, 1.}}], 
          ArrowBox[{{0.796486830778215, 2.7591113169347663`}, {
           0.703513169221785, 2.4370411057718657`}}]}, 
         {Arrowheads[{{0.027329737726391513`, 1.}}], 
          ArrowBox[{{1.1901584194716721`, 2.748553135441078}, {
           1.0598415805283279`, 2.447599287265554}}]}, 
         {Arrowheads[{{0.026604551665693355`, 1.}}], 
          ArrowBox[{{1.57981365499708, 2.7363175169460323`}, {
           1.42018634500292, 2.4598349057605997`}}]}, 
         {Arrowheads[{{0.02583016999579966, 1.}}], 
          ArrowBox[{{1.965695781857384, 2.7237479731206538`}, {
           1.784304218142616, 2.4724044495859783`}}]}, 
         {Arrowheads[{{0.025058381392269593`, 1.}}], 
          ArrowBox[{{2.3484273681626986`, 2.711730346362037}, {
           2.1515726318373014`, 2.484422076344595}}]}, 
         {Arrowheads[{{0.024321413216362556`, 1.}}], 
          ArrowBox[{{2.728717545287428, 2.70072995882426}, {2.521282454712572,
            2.495422463882372}}]}, 
         {Arrowheads[{{0.023437499999999986`, 1.}}], 
          ArrowBox[{{-2.910005893867716, 
           3.024166835102262}, {-2.714994106132284, 2.821504640442699}}]}, 
         {Arrowheads[{{0.024029354453257726`, 1.}}], 
          ArrowBox[{{-2.529839623264911, 
           3.0335612971124313`}, {-2.345160376735089, 2.8121101784325298`}}]}, 
         {Arrowheads[{{0.024641900403865578`, 1.}}], 
          ArrowBox[{{-2.1477447107865673`, 
           3.043638786084266}, {-1.9772552892134327`, 2.802032689460695}}]}, 
         {Arrowheads[{{0.025253188443406255`, 1.}}], 
          ArrowBox[{{-1.7632595653302188`, 
           3.054055154083753}, {-1.6117404346697812`, 2.791616321461208}}]}, 
         {Arrowheads[{{0.025830169995799682`, 1.}}], 
          ArrowBox[{{-1.3759870473001687`, 
           3.064216469760736}, {-1.2490129526998313`, 2.781455005784225}}]}, 
         {Arrowheads[{{0.02632914383241547, 1.}}], 
          ArrowBox[{{-0.9857492530857516, 
           3.0732620217616686`}, {-0.8892507469142484, 
           2.7724094537832924`}}]}, 
         {Arrowheads[{{0.026700697580848528`, 1.}}], 
          ArrowBox[{{-0.5927757452703726, 
           3.0801531249083753`}, {-0.5322242547296274, 
           2.7655183506365857`}}]}, 
         {Arrowheads[{{0.026900034471024223`, 1.}}], 
          ArrowBox[{{-0.19783258945127188`, 
           3.0839048669026585`}, {-0.17716741054872812`, 
           2.7617666086423025`}}]}, 
         {Arrowheads[{{0.026900034471024223`, 1.}}], 
          ArrowBox[{{0.19783258945127188`, 3.0839048669026585`}, {
           0.17716741054872812`, 2.7617666086423025`}}]}, 
         {Arrowheads[{{0.026700697580848528`, 1.}}], 
          ArrowBox[{{0.5927757452703726, 3.0801531249083753`}, {
           0.5322242547296274, 2.7655183506365857`}}]}, 
         {Arrowheads[{{0.02632914383241547, 1.}}], 
          ArrowBox[{{0.9857492530857516, 3.0732620217616686`}, {
           0.8892507469142484, 2.7724094537832924`}}]}, 
         {Arrowheads[{{0.025830169995799682`, 1.}}], 
          ArrowBox[{{1.3759870473001687`, 3.064216469760736}, {
           1.2490129526998313`, 2.781455005784225}}]}, 
         {Arrowheads[{{0.025253188443406255`, 1.}}], 
          ArrowBox[{{1.7632595653302188`, 3.054055154083753}, {
           1.6117404346697812`, 2.791616321461208}}]}, 
         {Arrowheads[{{0.024641900403865578`, 1.}}], 
          ArrowBox[{{2.1477447107865673`, 3.043638786084266}, {
           1.9772552892134327`, 2.802032689460695}}]}, 
         {Arrowheads[{{0.024029354453257726`, 1.}}], 
          ArrowBox[{{2.529839623264911, 3.0335612971124313`}, {
           2.345160376735089, 2.8121101784325298`}}]}, 
         {Arrowheads[{{0.023437499999999986`, 1.}}], 
          ArrowBox[{{2.910005893867716, 3.024166835102262}, {
           2.714994106132284, 2.821504640442699}}]}}}},
      AspectRatio->1,
      DisplayFunction->Identity,
      Epilog->{
        RGBColor[0, 0, 1], 
        DiskBox[{-0.5, 0}, 0.2]},
      Frame->True,
      FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
      GridLinesStyle->Directive[
        GrayLevel[0.5, 0.4]],
      ImagePadding->{{15., 0.5}, {16., 0.5}},
      LabelStyle->Opacity[0],
      Method->{
       "VectorLengthFunction" -> (Sqrt[#]& ), "DefaultBoundaryStyle" -> 
        Automatic, 
        "DefaultGraphicsInteraction" -> {
         "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
          "Effects" -> {
           "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
            "Droplines" -> {
             "freeformCursorMode" -> True, 
              "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
        "TransparentPolygonMesh" -> True},
      PlotRange->{{-3, 3}, {-3, 3}},
      PlotRangeClipping->True,
      PlotRangePadding->{{
         Scaled[0.02], 
         Scaled[0.02]}, {
         Scaled[0.02], 
         Scaled[0.02]}},
      Prolog->{
        RGBColor[1, 0, 0], 
        DiskBox[{0.5, 0}, 0.2]},
      Ticks->{Automatic, Automatic}], {403.4281337047354, -78.96935933147633},
      ImageScaled[{0.5, 0.5}], {149.41782729805016, 150.41782729805016},
     BaseStyle->{Graphics3DBoxOptions -> {SphericalRegion -> False}}], 
    InsetBox[
     GraphicsBox[{{}, 
       {RGBColor[0.2947336, 0.4054232, 0.5678384000000001], 
        {Arrowheads[{{0.02343750000000001, 1.}}], 
         {LABColor[
          0.1886675222501131, 0.5225961012766809, -0.8572107619122568], 
          ArrowBox[{{-2.86199657429872, -3.0544620260195146`}, \
{-2.76300342570128, -2.7912094495254465`}}]}}, 
        {Arrowheads[{{0.023731667197329373`, 1.}}], 
         {LABColor[
          0.19068668618246906`, 0.522592495879912, -0.8523850701959159], 
          ArrowBox[{{-2.471487259031758, -3.061110027610617}, \
{-2.403512740968242, -2.784561447934344}}]}}, 
        {Arrowheads[{{0.024023873576110688`, 1.}}], 
         {LABColor[
          0.1928440497125467, 0.5225886437154709, -0.8472290889754688], 
          ArrowBox[{{-2.0769980385894042`, -3.0662480138672916`}, \
{-2.0480019614105958`, -2.7794234616776694`}}]}}, 
        {Arrowheads[{{0.0242961929057525, 1.}}], 
         {LABColor[
          0.19499065781721425`, 0.5225848107557984, -0.842098812635381], 
          ArrowBox[{{-1.677831018201207, -3.0682918838119724`}, \
{-1.697168981798793, -2.7773795917329887`}}]}}, 
        {Arrowheads[{{0.02452597698353563, 1.}}], 
         {LABColor[
          0.1969040951093907, 0.522581394143348, -0.8375258018250009], 
          ArrowBox[{{-1.2736928775828278`, -3.06478240008473}, \
{-1.3513071224171722`, -2.780889075460231}}]}}, 
        {Arrowheads[{{0.024691278476525285`, 1.}}], 
         {LABColor[
          0.1983383845788535, 0.5225788330919464, -0.8340979281884381], 
          ArrowBox[{{-0.8654102335417606, -3.0522606115525543`}, \
{-1.0095897664582394`, -2.7934108639924067`}}]}}, 
        {Arrowheads[{{0.024781895461904305`, 1.}}], 
         {LABColor[
          0.19914517732150241`, 0.5225773924917549, -0.8321697375187176], 
          ArrowBox[{{-0.45614014069623865`, -3.0267429303316833`}, \
{-0.6688598593037614, -2.8189285452132777`}}]}}, 
        {Arrowheads[{{0.024811330153864483`, 1.}}], 
         {LABColor[
          0.19941037177992743`, 0.5225769189634653, -0.8315359372211123], 
          ArrowBox[{{-0.05258530243160961, -2.985761885947751}, \
{-0.32241469756839036`, -2.85990958959721}}]}}, 
        {Arrowheads[{{0.024813667454937516`, 1.}}], 
         {LABColor[
          0.19943149563028734`, 0.5225768812449518, -0.8314854523703948], 
          ArrowBox[{{0.33608046974958616`, -2.9323065002182616`}, {
           0.038919530250413864`, -2.9133649753266995`}}]}}, 
        {Arrowheads[{{0.024813318541590485`, 1.}}], 
         {LABColor[
          0.19942834163840506`, 0.5225768868766849, -0.8314929902390422], 
          ArrowBox[{{0.7040577873376562, -2.8767204386003113`}, {
           0.4209422126623438, -2.9689510369446497`}}]}}, 
        {Arrowheads[{{0.02479706388222634, 1.}}], 
         {LABColor[
          0.19928164700729287`, 0.5225771488129946, -0.8318435824098146], 
          ArrowBox[{{1.054450337864897, -2.830863915719538}, {
           0.8205496621351029, -3.014807559825423}}]}}, 
        {Arrowheads[{{0.024729682132872074`, 1.}}], 
         {LABColor[
          0.1986785300961532, 0.5225782257318756, -0.833284998946349], 
          ArrowBox[{{1.3961546719811313`, -2.800287974521275}, {
           1.2288453280188687`, -3.045383501023686}}]}}, 
        {Arrowheads[{{0.024589119906748554`, 1.}}], 
         {LABColor[
          0.19744626462935294`, 0.522580426051454, -0.836230046230614], 
          ArrowBox[{{1.7370347296099815`, -2.7838652229038563`}, {
           1.6379652703900185`, -3.0618062526411047`}}]}}, 
        {Arrowheads[{{0.0243786946155309, 1.}}], 
         {LABColor[
          0.19566690347087007`, 0.5225836032590442, -0.8404826223911097], 
          ArrowBox[{{2.0813376426508823`, -2.7777816435144382`}, {
           2.0436623573491177`, -3.067889832030523}}]}}, 
        {Arrowheads[{{0.024117906492649457`, 1.}}], 
         {LABColor[
          0.19357044289842154`, 0.5225873466758382, -0.8454930488631671], 
          ArrowBox[{{2.4305101759014027`, -2.7782972126373275`}, {
           2.4444898240985973`, -3.0673742629076335`}}]}}, 
        {Arrowheads[{{0.023830049896753334`, 1.}}], 
         {LABColor[
          0.1913961686440194, 0.5225912290358813, -0.8506894457928008], 
          ArrowBox[{{2.784529087877078, -2.782618070961358}, {
           2.840470912122922, -3.063053404583603}}]}}, 
        {Arrowheads[{{0.024001313198217564`, 1.}}], 
         {LABColor[
          0.19267210167001436`, 0.5225889507439925, -0.8476400354227546], 
          ArrowBox[{{-2.682016430874636, -2.730316129225793}, \
{-2.567983569125364, -2.465836293480839}}]}}, 
        {Arrowheads[{{0.024391710599466168`, 1.}}], 
         {LABColor[
          0.19577469263385466`, 0.5225834107919077, -0.8402250121680906], 
          ArrowBox[{{-2.290674206983809, -2.738660735896703}, \
{-2.209325793016191, -2.457491686809929}}]}}, 
        {Arrowheads[{{0.024785593296064907`, 1.}}], 
         {LABColor[
          0.19917840904753992`, 0.5225773331535528, -0.8320903155052352], 
          ArrowBox[{{-1.894381776410161, -2.74552135235346}, \
{-1.855618223589839, -2.450631070353172}}]}}, 
        {Arrowheads[{{0.025155138174041098`, 1.}}], 
         {LABColor[
          0.20262152277027642`, 0.5225711851677988, -0.8238614614216332], 
          ArrowBox[{{-1.4920458185224323`, -2.7487972986404157`}, \
{-1.5079541814775677`, -2.4473551240662164`}}]}}, 
        {Arrowheads[{{0.025462960511511312`, 1.}}], 
         {LABColor[
          0.20567411256395007`, 0.5225657344972501, -0.8165659382376739], 
          ArrowBox[{{-1.0831316935740265`, -2.745005071028361}, \
{-1.1668683064259735`, -2.451147351678271}}]}}, 
        {Arrowheads[{{0.02567249851842687, 1.}}], 
         {LABColor[
          0.20784799668969686`, 0.5225618528338163, -0.8113704736942571], 
          ArrowBox[{{-0.6689127553583616, -2.729040470763499}, \
{-0.8310872446416384, -2.467111951943133}}]}}, 
        {Arrowheads[{{0.02577105604541721, 1.}}], 
         {LABColor[
          0.2088973736866346, 0.5225599790778653, -0.8088625198821402], 
          ArrowBox[{{-0.2546653393431362, -2.695178597079181}, \
{-0.4953346606568638, -2.500973825627451}}]}}, 
        {Arrowheads[{{0.02579165151857173, 1.}}], 
         {LABColor[
          0.2091188331050338, 0.5225595836423791, -0.8083332439458235], 
          ArrowBox[{{
           0.14857327994984873`, -2.641360329167358}, {-0.14857327994984873`, \
-2.554792093539274}}]}}, 
        {Arrowheads[{{0.025791778711914307`, 1.}}], 
         {LABColor[
          0.20912020312516022`, 0.5225595811960863, -0.8083299696724129], 
          ArrowBox[{{0.5281779261914383, -2.5760695419967985`}, {
           0.2218220738085617, -2.6200828807098335`}}]}}, 
        {Arrowheads[{{0.02578366477937984, 1.}}], 
         {LABColor[
          0.2090328640009021, 0.5225597371478599, -0.8085387054177832], 
          ArrowBox[{{0.8816579694175997, -2.516842693706781}, {
           0.6183420305824003, -2.679309728999851}}]}}, 
        {Arrowheads[{{0.025717076139806897`, 1.}}], 
         {LABColor[
          0.20832050059294926`, 0.5225610091360765, -0.810241215125735], 
          ArrowBox[{{1.2195918417330776`, -2.47616791932998}, {
           1.0304081582669224`, -2.719984503376652}}]}}, 
        {Arrowheads[{{0.02554512245255222, 1.}}], 
         {LABColor[
          0.2065172509844849, 0.5225642289986185, -0.8145508833793216], 
          ArrowBox[{{1.5545047160071868`, -2.454824146610263}, {
           1.4454952839928132`, -2.741328276096369}}]}}, 
        {Arrowheads[{{0.025266595174197534`, 1.}}], 
         {LABColor[
          0.20370743926990692`, 0.5225692461673163, -0.8212661801901631], 
          ArrowBox[{{1.893536547805496, -2.44761416851015}, {
           1.856463452194504, -2.748538254196482}}]}}, 
        {Arrowheads[{{0.02491317627011058, 1.}}], 
         {LABColor[
          0.20033979783534409`, 0.5225752593905878, -0.8293146596196734], 
          ArrowBox[{{2.239012654150258, -2.4490015089442894`}, {
           2.260987345849742, -2.7471509137623427`}}]}}, 
        {Arrowheads[{{0.02452375625013471, 1.}}], 
         {LABColor[
          0.19688515551502989`, 0.5225814279616781, -0.837571066422963], 
          ArrowBox[{{2.590815855232037, -2.4549595785370717`}, {
           2.659184144767963, -2.7411928441695603`}}]}}, 
        {Arrowheads[{{0.024221094609071375`, 1.}}], 
         {LABColor[
          0.19438557192283817`, 0.5225858911904742, -0.8435449349345042], 
          ArrowBox[{{-2.8912254789625775`, -2.395472774542201}, \
{-2.7337745210374225`, -2.151160595326102}}]}}, 
        {Arrowheads[{{0.024713947974904078`, 1.}}], 
         {LABColor[
          0.1985388551736173, 0.5225784751338713, -0.8336188143963287], 
          ArrowBox[{{-2.503756793821248, -2.4059744753377093`}, \
{-2.371243206178752, -2.1406588945305938`}}]}}, 
        {Arrowheads[{{0.025247259949309864`, 1.}}], 
         {LABColor[
          0.20351748116923576`, 0.5225695853543983, -0.8217201696945176], 
          ArrowBox[{{-2.1116693398547475`, -2.4165983825663937`}, \
{-2.0133306601452525`, -2.1300349873019093`}}]}}, 
        {Arrowheads[{{0.025797164119956903`, 1.}}], 
         {LABColor[
          0.20917823650596903`, 0.5225594775723239, -0.8081912730561785], 
          ArrowBox[{{-1.7132999253629215`, -2.4259342992845907`}, \
{-1.6617000746370785`, -2.1206990705837123`}}]}}, 
        {Arrowheads[{{0.026318913402821165`, 1.}}], 
         {LABColor[
          0.2150440654531421, 0.5225490036130804, -0.7941722616692144], 
          ArrowBox[{{-1.3068598671156164`, -2.431129410018137}, \
{-1.3181401328843836`, -2.115503959850166}}]}}, 
        {Arrowheads[{{0.02674708005743251, 1.}}], 
         {LABColor[
          0.22021777934106923`, 0.5225397654868262, -0.7818073675407043], 
          ArrowBox[{{-0.8913388671889182, -2.4270169657248872`}, \
{-0.9836611328110818, -2.119616404143416}}]}}, 
        {Arrowheads[{{0.027016917619239158`, 1.}}], 
         {LABColor[
          0.22364504838324442`, 0.5225336457931584, -0.7736163813798141], 
          ArrowBox[{{-0.4688531964277993, -2.405631364149728}, \
{-0.6561468035722007, -2.1410020057185752`}}]}}, 
        {Arrowheads[{{0.027116779221484644`, 1.}}], 
         {LABColor[
          0.22494609119900993`, 0.522531322665507, -0.7705069599811669], 
          ArrowBox[{{-0.04891283839292737, -2.3585522901128435`}, \
{-0.32608716160707263`, -2.1880810797554595`}}]}}, 
        {Arrowheads[{{0.027125437475668947`, 1.}}], 
         {LABColor[
          0.22505972656482465`, 0.5225311197594554, -0.7702353776521107], 
          ArrowBox[{{0.34971328607278485`, -2.2865555186569604`}, {
           0.025286713927215154`, -2.2600778512113426`}}]}}, 
        {Arrowheads[{{0.027124135521650994`, 1.}}], 
         {LABColor[
          0.22504263057564686`, 0.5225311502858645, -0.7702762361341963], 
          ArrowBox[{{0.7123808476262654, -2.209900553583207}, {
           0.41261915237373453`, -2.336732816285096}}]}}, 
        {Arrowheads[{{0.02706695208611593, 1.}}], 
         {LABColor[
          0.224294713721448, 0.5225324857579212, -0.7720637166403521], 
          ArrowBox[{{1.0471805749815244`, -2.1535482095323264`}, {
           0.8278194250184756, -2.3930851603359766`}}]}}, 
        {Arrowheads[{{0.026856914453201555`, 1.}}], 
         {LABColor[
          0.22159725630536048`, 0.5225373023080272, -0.7785104928032005], 
          ArrowBox[{{1.3739852357950264`, -2.1243665438757855`}, {
           1.2510147642049736`, -2.4222668259925175`}}]}}, 
        {Arrowheads[{{0.02647562322519974, 1.}}], 
         {LABColor[
          0.21690000168006987`, 0.5225456896738956, -0.7897366752699011], 
          ArrowBox[{{1.7056448454650976`, -2.1155026326799042`}, {
           1.6693551545349024`, -2.431130737188399}}]}}, 
        {Arrowheads[{{0.025977091800332742`, 1.}}], 
         {LABColor[
          0.21114665724655343`, 0.5225559627820365, -0.803486854801724], 
          ArrowBox[{{2.046203029748715, -2.1183084803024816`}, {
           2.078796970251285, -2.4283248895658214`}}]}}, 
        {Arrowheads[{{0.02543044934622704, 1.}}], 
         {LABColor[
          0.20534378579434304`, 0.5225663243250738, -0.8173554012080817], 
          ArrowBox[{{2.395332120639817, -2.126676482082063}, {
           2.479667879360183, -2.41995688778624}}]}}, 
        {Arrowheads[{{0.024888036064112374`, 1.}}], 
         {LABColor[
          0.20010866677627653`, 0.5225756720956487, -0.8298670502499033], 
          ArrowBox[{{2.7513504794059136`, -2.137082869969799}, {
           2.8736495205940864`, -2.4095504998985042`}}]}}, 
        {Arrowheads[{{0.024958260105418326`, 1.}}], 
         {LABColor[
          0.2007570865488254, 0.5225745142844798, -0.8283173623444493], 
          ArrowBox[{{-2.714831568895799, -2.0683704304816146`}, \
{-2.535168431104201, -1.8287438865483594`}}]}}, 
        {Arrowheads[{{0.02563224313367557, 1.}}], 
         {LABColor[
          0.20742432934233257`, 0.5225626093295425, -0.8123830155567073], 
          ArrowBox[{{-2.327838335607051, -2.0811981079997635`}, \
{-2.172161664392949, -1.8159162090302106`}}]}}, 
        {Arrowheads[{{0.02638623500560941, 1.}}], 
         {LABColor[
          0.21583603811026267`, 0.5225475894754696, -0.7922794901959365], 
          ArrowBox[{{-1.9352857917083508`, -2.094947136443335}, \
{-1.8147142082916492`, -1.8021671805866388`}}]}}, 
        {Arrowheads[{{0.027188087915744452`, 1.}}], 
         {LABColor[
          0.22588593735376722`, 0.5225296444866154, -0.7682607789103931], 
          ArrowBox[{{-1.534587182793028, -2.1079768664213643`}, \
{-1.465412817206972, -1.7891374506086097`}}]}}, 
        {Arrowheads[{{0.027963136513839717`, 1.}}], 
         {LABColor[
          0.23668166312853536`, 0.5225103677581621, -0.7424595828765479], 
          ArrowBox[{{-1.1226533371606624`, -2.1163195658249006`}, \
{-1.1273466628393376`, -1.7807947512050735`}}]}}, 
        {Arrowheads[{{0.028588141549979563`, 1.}}], 
         {LABColor[
          0.24616193547549858`, 0.5224934398887896, -0.7198022488184777], 
          ArrowBox[{{-0.6974632072075903, -2.111842281980744}, \
{-0.8025367927924097, -1.7852720350492302`}}]}}, 
        {Arrowheads[{{0.028939437219914935`, 1.}}], 
         {LABColor[
          0.2517940688112151, 0.5224833832138434, -0.7063417572021373], 
          ArrowBox[{{-0.26292023597046993`, -2.081176174696224}, \
{-0.48707976402953007`, -1.8159381423337502`}}]}}, 
        {Arrowheads[{{0.02902514161301359, 1.}}], 
         {LABColor[
          0.25320127127666164`, 0.5224808705286964, -0.7029786200284278], 
          ArrowBox[{{
           0.16218421776759473`, -2.0119984538257794`}, \
{-0.16218421776759473`, -1.8851158632041947`}}]}}, 
        {Arrowheads[{{0.02902569172416258, 1.}}], 
         {LABColor[
          0.25321034569170653`, 0.5224808543255213, -0.702956932671195], 
          ArrowBox[{{0.5460663174461506, -1.91590776161714}, {
           0.20393368255384936`, -1.981206555412834}}]}}, 
        {Arrowheads[{{0.02899067987430595, 1.}}], 
         {LABColor[
          0.252633872081872, 0.5224818836704185, -0.7043346731701656], 
          ArrowBox[{{0.8813339639687044, -1.834504834501188}, {
           0.6186660360312956, -2.062609482528786}}]}}, 
        {Arrowheads[{{0.028739503729383966`, 1.}}], 
         {LABColor[
          0.24856185748458562`, 0.5224891546146132, -0.7140665660571468], 
          ArrowBox[{{1.1968727561483072`, -1.7918126734137503`}, {
           1.0531272438516928`, -2.1053016436162237`}}]}}, 
        {Arrowheads[{{0.028195191119489538`, 1.}}], 
         {LABColor[
          0.24012082944850247`, 0.5225042268208467, -0.734240162870358], 
          ArrowBox[{{1.5176020050500862`, -1.7803042349156026`}, {
           1.4823979949499138`, -2.1168100821143714`}}]}}, 
        {Arrowheads[{{0.027454612535647, 1.}}], 
         {LABColor[
          0.22947841991662027`, 0.5225232297895138, -0.7596749414422928], 
          ArrowBox[{{1.8513265067606157`, -1.7855394518104237`}, {
           1.8986734932393843`, -2.1115748652195503`}}]}}, 
        {Arrowheads[{{0.02665084995815786, 1.}}], 
         {LABColor[
          0.21902671862976342`, 0.5225418922316493, -0.7846539377057632], 
          ArrowBox[{{2.1972265944492886`, -1.7976114444575786`}, {
           2.3027734055507114`, -2.0995028725723954`}}]}}, 
        {Arrowheads[{{0.025875593088592677`, 1.}}], 
         {LABColor[
          0.21002920865770713`, 0.5225579580858685, -0.8061574960073344], 
          ArrowBox[{{2.5522828361345646`, -1.8113861648024723`}, {
           2.6977171638654354`, -2.0857281522275017`}}]}}, 
        {Arrowheads[{{0.025098017283833988`, 1.}}], 
         {LABColor[
          0.20207352169857615`, 0.522572163672447, -0.8251711541067459], 
          ArrowBox[{{-2.922566722950929, -1.726569678274295}, \
{-2.702433277049071, -1.52102558591735}}]}}, 
        {Arrowheads[{{0.02589183005670199, 1.}}], 
         {LABColor[
          0.21020674396568323`, 0.5225576410807876, -0.805733196300248], 
          ArrowBox[{{-2.5408721972955592`, -1.7397636440085933`}, \
{-2.3341278027044408`, -1.5078316201830517`}}]}}, 
        {Arrowheads[{{0.026840840540849866`, 1.}}], 
         {LABColor[
          0.22139404030056856`, 0.522537665168276, -0.7789961679756012], 
          ArrowBox[{{-2.1551757530197317`, -1.7555045444278696`}, \
{-1.9698242469802683`, -1.4920907197637754`}}]}}, 
        {Arrowheads[{{0.027951378921124283`, 1.}}], 
         {LABColor[
          0.23650994700323735`, 0.5225106743725748, -0.7428699750542874], 
          ArrowBox[{{-1.7628653485738286`, -1.7736179552955376`}, \
{-1.6121346514261714`, -1.4739773088961075`}}]}}, 
        {Arrowheads[{{0.02918668466313642, 1.}}], 
         {LABColor[
          0.2558890409013261, 0.5224760712770036, -0.6965549971589157], 
          ArrowBox[{{-1.3597741895929578`, -1.792416145957267}, \
{-1.2652258104070422`, -1.455179118234378}}]}}, 
        {Arrowheads[{{0.03041822469947698, 1.}}], 
         {LABColor[
          0.27789807726797233`, 0.5224367721852693, -0.6439546001444718], 
          ArrowBox[{{-0.9401896770989464, -1.8062871600593382`}, \
{-0.9348103229010536, -1.4413081041323068`}}]}}, 
        {Arrowheads[{{0.031390665276589215`, 1.}}], 
         {LABColor[
          0.2971737373995833, 0.5224023537798866, -0.5978868233119178], 
          ArrowBox[{{-0.4997168909882037, -1.8013694215699954`}, \
{-0.6252831090117963, -1.4462258426216497`}}]}}, 
        {Arrowheads[{{0.03184462965486321, 1.}}], 
         {LABColor[
          0.30674534196787717`, 0.5223852628287107, -0.5750112102241722], 
          ArrowBox[{{-0.04669994406050004, -1.7529573781865757`}, \
{-0.32830005593949996`, -1.4946378860050693`}}]}}, 
        {Arrowheads[{{0.031891308054376115`, 1.}}], 
         {LABColor[
          0.30775021652082035`, 0.5223834685358311, -0.5726096148269915], 
          ArrowBox[{{
           0.37763527136841446`, -1.6453052502983927`}, \
{-0.002635271368414488, -1.6022900138932523`}}]}}, 
        {Arrowheads[{{0.03188421378186246, 1.}}], 
         {LABColor[
          0.30759724520217824`, 0.5223837416797246, -0.5729752079387639], 
          ArrowBox[{{0.7260290575180168, -1.5245204517731552`}, {
           0.39897094248198317`, -1.7230748124184898`}}]}}, 
        {Arrowheads[{{0.03160566800201416, 1.}}], 
         {LABColor[
          0.30166148360357214`, 0.5223943405099364, -0.5871613545500227], 
          ArrowBox[{{1.0260868599004451`, -1.4561270465785459`}, {
           0.8489131400995549, -1.7914682176130992`}}]}}, 
        {Arrowheads[{{0.0307866751429514, 1.}}], 
         {LABColor[
          0.28500450493791973`, 0.5224240830266778, -0.626970625445782], 
          ArrowBox[{{1.3292823504359093`, -1.4398415234646582`}, {
           1.2957176495640907`, -1.8077537407269868`}}]}}, 
        {Arrowheads[{{0.02960766738568706, 1.}}], 
         {LABColor[
          0.2631104554363098, 0.5224631767991385, -0.679296210121712], 
          ArrowBox[{{1.6529531847034726`, -1.4495431618471635`}, {
           1.7220468152965274`, -1.7980521023444815`}}]}}, 
        {Arrowheads[{{0.02835319247701475, 1.}}], 
         {LABColor[
          0.24251703878522768`, 0.522499948175977, -0.728513353193562], 
          ArrowBox[{{1.9950428155804594`, -1.4676244746033156`}, {
           2.1299571844195406`, -1.7799707895883294`}}]}}, 
        {Arrowheads[{{0.0271936149201851, 1.}}], 
         {LABColor[
          0.2259591589693728, 0.522529513742909, -0.7680857832410357], 
          ArrowBox[{{2.349690161917449, -1.4862797450290868`}, {
           2.525309838082551, -1.7613155191625582`}}]}}, 
        {Arrowheads[{{0.026190120466479977`, 1.}}], 
         {LABColor[
          0.21355129938015815`, 0.522551669079658, -0.7977398912001303], 
          ArrowBox[{{2.7121461204358748`, -1.502874906282254}, {
           2.9128538795641252`, -1.744720357909391}}]}}, 
        {Arrowheads[{{0.025991927018943973`, 1.}}], 
         {LABColor[
          0.21131151294810685`, 0.5225556684175204, -0.8030928586627133], 
          ArrowBox[{{-2.7490164478855204`, -1.3935939641918762`}, \
{-2.5009835521144796`, -1.2044822471614398`}}]}}, 
        {Arrowheads[{{0.027087373716230365`, 1.}}], 
         {LABColor[
          0.2245611489788212, 0.5225320100140747, -0.7714269509009072], 
          ArrowBox[{{-2.3700101139751144`, -1.408636015684186}, \
{-2.1299898860248856`, -1.18944019566913}}]}}, 
        {Arrowheads[{{0.02846691932091737, 1.}}], 
         {LABColor[
          0.2442691445865845, 0.522496819635251, -0.7243259158506739], 
          ArrowBox[{{-1.9871182526266187`, -1.4278893969794773`}, \
{-1.7628817473733813`, -1.1701868143738388`}}]}}, 
        {Arrowheads[{{0.030184256576467335`, 1.}}], 
         {LABColor[
          0.2735102104186496, 0.5224446071117493, -0.6544413626939974], 
          ArrowBox[{{-1.5967270135374367`, -1.4521495071946147`}, \
{-1.4032729864625633`, -1.1459267041587013`}}]}}, 
        {Arrowheads[{{0.032227438305346946`, 1.}}], 
         {LABColor[
          0.31510019052035176`, 0.5223703445036091, -0.5550435776784006], 
          ArrowBox[{{-1.1919285961113533`, -1.480450462181559}, \
{-1.0580714038886467`, -1.117625749171757}}]}}, 
        {Arrowheads[{{0.03437540751753092, 1.}}], 
         {LABColor[
          0.36679144999084556`, 0.5222780451628316, -0.4315042856789969], 
          ArrowBox[{{-0.761202017786904, -1.5049861231698338`}, \
{-0.738797982213096, -1.0930900881834822`}}]}}, 
        {Arrowheads[{{0.036026202407569353`, 1.}}], 
         {LABColor[
          0.4133663028268924, 0.5229337974090943, -0.2974000900816106], 
          ArrowBox[{{-0.2937630915814497, -1.4993491290063732`}, \
{-0.4562369084185503, -1.0987270823469428`}}]}}, 
        {Arrowheads[{{0.0365722105211353, 1.}}], 
         {LABColor[
          0.431540271788281, 0.5241180450783748, -0.2164346052149655], 
          ArrowBox[{{
           0.18830911308684273`, -1.4116908237749235`}, \
{-0.18830911308684273`, -1.1863853875783925`}}]}}, 
        {Arrowheads[{{0.03657582271295278, 1.}}], 
         {LABColor[
          0.4316624955607966, 0.5241260093936017, -0.21589009526092198`], 
          ArrowBox[{{0.5861467148628081, -1.2392256165184505`}, {
           0.1638532851371919, -1.3588505948348655`}}]}}, 
        {Arrowheads[{{0.03633532148961237, 1.}}], 
         {LABColor[
          0.42358193189221804`, 0.5235994657029353, -0.2518892078825092], 
          ArrowBox[{{0.8685817113441502, -1.11609664265141}, {
           0.6314182886558498, -1.481979568701906}}]}}, 
        {Arrowheads[{{0.035021015519658465`, 1.}}], 
         {LABColor[
          0.383924487775652, 0.5222474526001962, -0.39055725944253583`], 
          ArrowBox[{{1.1403986033358624`, -1.0894769975856802`}, {
           1.1096013966641376`, -1.5085992137676358`}}]}}, 
        {Arrowheads[{{0.03295283915393704, 1.}}], 
         {LABColor[
          0.3316437044424862, 0.5223408045882579, -0.5155054813337103], 
          ArrowBox[{{1.4480830445679604`, -1.10825903020543}, {
           1.5519169554320396`, -1.489817181147886}}]}}, 
        {Arrowheads[{{0.030833775013670354`, 1.}}], 
         {LABColor[
          0.2859302599228331, 0.5224224300088232, -0.6247581215027044], 
          ArrowBox[{{1.7861330133779163`, -1.1367770837826692`}, {
           1.9638669866220837`, -1.4612991275706468`}}]}}, 
        {Arrowheads[{{0.029000148591920075`, 1.}}], 
         {LABColor[
          0.2527895613882384, 0.5224816056733163, -0.7039625842159128], 
          ArrowBox[{{2.141923508326044, -1.1626717527585964`}, {
           2.358076491673956, -1.4354044585947197`}}]}}, 
        {Arrowheads[{{0.0275125503694623, 1.}}], 
         {LABColor[
          0.23027600247221025`, 0.5225218056349304, -0.7577687626175166], 
          ArrowBox[{{2.5070584986124755`, -1.1835406699803803`}, {
           2.7429415013875245`, -1.4145355413729357`}}]}}, 
        {Arrowheads[{{0.025924386118567025`, 1.}}], 
         {LABColor[
          0.2105641185691077, 0.5225570029566512, -0.8048790904816264], 
          ArrowBox[{{-2.9512288195499274`, -1.0446275044004367`}, \
{-2.6737711804500726`, -0.9039296541145503}}]}}, 
        {Arrowheads[{{0.027088509526882815`, 1.}}], 
         {LABColor[
          0.2245759892529225, 0.5225319835154455, -0.7713914834548761], 
          ArrowBox[{{-2.577559315452967, -1.0567390709902926`}, \
{-2.297440684547033, -0.8918180875246944}}]}}, 
        {Arrowheads[{{0.028627174122206913`, 1.}}], 
         {LABColor[
          0.2467769353304753, 0.5224923417518555, -0.7183324326940143], 
          ArrowBox[{{-2.2029237397856782`, -1.0731912520584932`}, \
{-1.9220762602143218`, -0.8753659064564938}}]}}, 
        {Arrowheads[{{0.03069863325113212, 1.}}], 
         {LABColor[
          0.2832845597230006, 0.5224271541418167, -0.6310812007404343], 
          ArrowBox[{{-1.8255723258259282`, -1.096191055430235}, \
{-1.5494276741740718`, -0.852366103084752}}]}}, 
        {Arrowheads[{{0.03350935037370773, 1.}}], 
         {LABColor[
          0.3449669609757634, 0.5223170147288575, -0.48366362458446566`], 
          ArrowBox[{{-1.441037563497701, -1.128880167279477}, \
{-1.183962436502299, -0.81967699123551}}]}}, 
        {Arrowheads[{{0.037221848941646755`, 1.}}], 
         {LABColor[
          0.4539426956465224, 0.5255778262795378, -0.1166312483519622], 
          ArrowBox[{{-1.037931474867886, -1.1737536309474552`}, \
{-0.8370685251321139, -0.7748035275675318}}]}}, 
        {Arrowheads[{{0.041517396612853995`, 1.}}], 
         {LABColor[0.6233792658845, 0.5366186101513213, 0.6382128967329566], 
          ArrowBox[{{-0.5903494336011965, -1.2218213049078694`}, \
{-0.5346505663988035, -0.7267358536071176}}]}}, 
        {Arrowheads[{{0.04468199677331503, 1.}}], 
         {LABColor[
          0.7351580015712259, 0.33116357568048016`, 0.78271026377405], 
          ArrowBox[{{-0.06668233509375736, -1.2136034670774236`}, \
{-0.30831766490624263`, -0.7349536914375634}}]}}, 
        {Arrowheads[{{0.04514931833809588, 1.}}], 
         {LABColor[0.751979219180494, 0.2928059048979982, 0.7920941185814016],
           ArrowBox[{{
           0.45402278548882524`, -1.0227574291354309`}, \
{-0.07902278548882524, -0.9257997293795561}}]}}, 
        {Arrowheads[{{0.04507994805301042, 1.}}], 
         {LABColor[0.7494625299020786, 0.298544748603942, 0.7906901627363231],
           ArrowBox[{{0.7438717895138042, -0.7736208214677769}, {
           0.38112821048619583`, -1.1749363370472101`}}]}}, 
        {Arrowheads[{{0.04283009526647644, 1.}}], 
         {LABColor[
          0.6715652669470386, 0.47617502702323805`, 0.7472345329216639], 
          ArrowBox[{{0.950245553519523, -0.717614275068623}, {
           0.924754446480477, -1.230942883446364}}]}}, 
        {Arrowheads[{{0.03863619311307138, 1.}}], 
         {LABColor[
          0.5056436482794555, 0.5289467509643552, 0.11369778472200259`], 
          ArrowBox[{{1.2295054512409258`, -0.7578274301868146}, {
           1.3954945487590742`, -1.1907297283281724`}}]}}, 
        {Arrowheads[{{0.03464503206721355, 1.}}], 
         {LABColor[
          0.3738569727648975, 0.5222654290435694, -0.4146180714514196], 
          ArrowBox[{{1.565367067243841, -0.8060716720682919}, {
           1.809632932756159, -1.1424854864466951`}}]}}, 
        {Arrowheads[{{0.03154254989423161, 1.}}], 
         {LABColor[
          0.3003355356363789, 0.5223967081079507, -0.5903302979027883], 
          ArrowBox[{{1.9264490244591488`, -0.8427198456353353}, {
           2.198550975540851, -1.1058373128796517`}}]}}, 
        {Arrowheads[{{0.029249045348604303`, 1.}}], 
         {LABColor[0.2569389630730592, 0.5224741965475945, -0.69404574040876],
           ArrowBox[{{2.2974188404043847`, -0.868564302722499}, {
           2.5775811595956153`, -1.079992855792488}}]}}, 
        {Arrowheads[{{0.02755309184252072, 1.}}], 
         {LABColor[
          0.2308376374684683, 0.5225208027856975, -0.7564264855960133], 
          ArrowBox[{{2.672156668434717, -0.8869059713753729}, {
           2.952843331565283, -1.0616511871396141`}}]}}, 
        {Arrowheads[{{0.026857840101263932`, 1.}}], 
         {LABColor[
          0.22160897282921319`, 0.5225372813871318, -0.778482490949961], 
          ArrowBox[{{-2.777039704433835, -0.7029259528818084}, \
{-2.472960295566165, -0.5961121527948496}}]}}, 
        {Arrowheads[{{0.028413229032557944`, 1.}}], 
         {LABColor[
          0.24343912473582752`, 0.5224983017095095, -0.7263096180424631], 
          ArrowBox[{{-2.4078069848096346`, -0.7140184526132813}, \
{-2.0921930151903654`, -0.5850196530633767}}]}}, 
        {Arrowheads[{{0.030595734394996407`, 1.}}], 
         {LABColor[
          0.2812917663118314, 0.5224307124516748, -0.6358438683488227], 
          ArrowBox[{{-2.039855291477216, -0.7302797830607101}, \
{-1.710144708522784, -0.5687583226159479}}]}}, 
        {Arrowheads[{{0.03379065189397653, 1.}}], 
         {LABColor[
          0.351910114181239, 0.5223046171113426, -0.4670698669543684], 
          ArrowBox[{{-1.6727439283502687`, -0.7556540084996644}, \
{-1.3272560716497313`, -0.5433840971769937}}]}}, 
        {Arrowheads[{{0.03868003968335643, 1.}}], 
         {LABColor[0.507310578664028, 0.5290553710696815, 0.1211240011479569],
           ArrowBox[{{-1.3032435225192607`, -0.798147729736641}, \
{-0.9467564774807393, -0.500890375940017}}]}}, 
        {Arrowheads[{{0.046336263136433804`, 1.}}], 
         {LABColor[
          0.7961050875249951, 0.1921850360485901, 0.8167100977222318], 
          ArrowBox[{{-0.9155659049380472, -0.8728611788562469}, \
{-0.5844340950619528, -0.4261769268204111}}]}}, 
        {Arrowheads[{{0.04687500000000001, 1.}}], 
         {LABColor[
          0.8167969189733053, 0.14500114740169545`, 0.8282532063436999], 
          ArrowBox[{{-0.4314799367014271, -0.9250396133237542}, \
{-0.3185200632985729, -0.37399849235290383`}}]}}, 
        {Arrowheads[{{0.046875, 1.}}], 
         {LABColor[
          0.8167969189733053, 0.14500114740169545`, 0.8282532063436999], 
          ArrowBox[{{
           0.17050768717460954`, -0.8731899966695864}, \
{-0.17050768717460954`, -0.4258481090070716}}]}}, 
        {Arrowheads[{{0.04687499999999999, 1.}}], 
         {LABColor[
          0.8167969189733053, 0.14500114740169545`, 0.8282532063436999], 
          ArrowBox[{{0.6231248032965647, -0.5170968323123122}, {
           0.12687519670343528`, -0.7819412733643458}}]}}, 
        {Arrowheads[{{0.046875, 1.}}], 
         {LABColor[
          0.8167969189733053, 0.14500114740169545`, 0.8282532063436999], 
          ArrowBox[{{0.755868523105242, -0.3683302853945294}, {
           0.744131476894758, -0.9307078202821286}}]}}, 
        {Arrowheads[{{0.04687499999999999, 1.}}], 
         {LABColor[
          0.8167969189733053, 0.14500114740169545`, 0.8282532063436999], 
          ArrowBox[{{0.9846163336245068, -0.40581023331188226`}, {
           1.2653836663754932`, -0.8932278723647757}}]}}, 
        {Arrowheads[{{0.040865175047418864`, 1.}}], 
         {LABColor[
          0.5952690927281566, 0.5347869020024743, 0.5129813744317986], 
          ArrowBox[{{1.3223575865294919`, -0.4805166147612536}, {
           1.6776424134705081`, -0.8185214909154044}}]}}, 
        {Arrowheads[{{0.0351867044940986, 1.}}], 
         {LABColor[
          0.3884404949424901, 0.5222393888677835, -0.3797642485201793], 
          ArrowBox[{{1.6998135068694729`, -0.5316995177085025}, {
           2.050186493130527, -0.7673385879681555}}]}}, 
        {Arrowheads[{{0.031522243683882935`, 1.}}], 
         {LABColor[
          0.2999104541752335, 0.5223974671287027, -0.5913462194200798], 
          ArrowBox[{{2.082546078492714, -0.561594934082375}, {
           2.417453921507286, -0.737443171594283}}]}}, 
        {Arrowheads[{{0.02905640041409811, 1.}}], 
         {LABColor[
          0.25371775368884564`, 0.5224799483034177, -0.7017442552212059], 
          ArrowBox[{{2.4649853826561676`, -0.5803150008096701}, {
           2.7850146173438324`, -0.7187231048669879}}]}}, 
        {Arrowheads[{{0.02645025200377905, 1.}}], 
         {LABColor[
          0.21659657735349122`, 0.5225462314650148, -0.7904618428681547], 
          ArrowBox[{{-2.9691740976721275`, -0.35004582778784427`}, \
{-2.6558259023278725`, -0.29947322505048474`}}]}}, 
        {Arrowheads[{{0.02789947501122211, 1.}}], 
         {LABColor[
          0.23575483061352517`, 0.5225120227000425, -0.7446746620578115], 
          ArrowBox[{{-2.6021121277769783`, -0.3551659862788866}, \
{-2.2728878722230217`, -0.2943530665594424}}]}}, 
        {Arrowheads[{{0.0299508674497676, 1.}}], 
         {LABColor[
          0.26922974779099296`, 0.52245225025844, -0.6646714350092688], 
          ArrowBox[{{-2.2381506331298078`, -0.36271760430603145`}, \
{-1.8868493668701922`, -0.28680144853229755`}}]}}, 
        {Arrowheads[{{0.033020173101551434`, 1.}}], 
         {LABColor[
          0.3332265705180991, 0.5223379782401129, -0.5117225177086371], 
          ArrowBox[{{-1.8792110184208308`, -0.37474783860990574`}, \
{-1.4957889815791692`, -0.27477121422842327`}}]}}, 
        {Arrowheads[{{0.03797356644211574, 1.}}], 
         {LABColor[
          0.4809218921376339, 0.5273358380067249, 0.003561744706194414], 
          ArrowBox[{{-1.5288797773908103`, -0.39611423808083035`}, \
{-1.0961202226091897`, -0.25340481475749865`}}]}}, 
        {Arrowheads[{{0.04687499999999998, 1.}}], 
         {LABColor[
          0.8167969189733053, 0.14500114740169545`, 0.8282532063436999], 
          ArrowBox[{{-1.1937520600328433`, -0.44067520365448937`}, \
{-0.6812479399671567, -0.20884384918383964`}}]}}, 
        {Arrowheads[{{0.04687499999999999, 1.}}], 
         {LABColor[
          0.8167969189733053, 0.14500114740169545`, 0.8282532063436999], 
          ArrowBox[{{-0.7883591222654408, -0.4923579136115377}, \
{-0.3366408777345592, -0.1571611392267913}}]}}, 
        {Arrowheads[{{0.046875, 1.}}], 
         {LABColor[
          0.8167969189733053, 0.14500114740169545`, 0.8282532063436999], 
          ArrowBox[{{-0.28450868933259355`, -0.5887498230097254}, \
{-0.09049131066740644, -0.060769229828603555`}}]}}, 
        {Arrowheads[{{0.046875, 1.}}], 
         {LABColor[
          0.8167969189733053, 0.14500114740169545`, 0.8282532063436999], 
          ArrowBox[{{
           0.45087316199888444`, -0.4234314071081904}, {-0.07587316199888444, \
-0.22608764573013862`}}]}}, 
        {Arrowheads[{{0.04687499999999998, 1.}}], 
         {LABColor[
          0.8167969189733053, 0.14500114740169545`, 0.8282532063436999], 
          ArrowBox[{{0.5742178875537982, -0.043753737134892834`}, {
           0.5507821124462018, -0.6057653157034362}}]}}, 
        {Arrowheads[{{0.04687500000000001, 1.}}], 
         {LABColor[
          0.8167969189733053, 0.14500114740169545`, 0.8282532063436999], 
          ArrowBox[{{0.7346214320467166, -0.12997285037271375`}, {
           1.1403785679532834`, -0.5195462024656152}}]}}, 
        {Arrowheads[{{0.04687500000000001, 1.}}], 
         {LABColor[
          0.8167969189733053, 0.14500114740169545`, 0.8282532063436999], 
          ArrowBox[{{1.062795401462163, -0.19534091891213834`}, {
           1.562204598537837, -0.45417813392619066`}}]}}, 
        {Arrowheads[{{0.04033549546542633, 1.}}], 
         {LABColor[0.573068306074086, 0.5333402598349251, 0.4140763163409305],
           ArrowBox[{{1.4599490057895388`, -0.24235307015679353`}, {
           1.9150509942104612`, -0.4071659826815355}}]}}, 
        {Arrowheads[{{0.034396756796420916`, 1.}}], 
         {LABColor[
          0.3673462171634736, 0.5222770545767085, -0.43017842238154513`], 
          ArrowBox[{{1.8637727881360313`, -0.2690780853745051}, {
           2.261227211863969, -0.3804409674638239}}]}}, 
        {Arrowheads[{{0.030831265157648946`, 1.}}], 
         {LABColor[
          0.2858808292703364, 0.5224225182716492, -0.6248762580672815], 
          ArrowBox[{{2.257185459418725, -0.28344275913360556`}, {
           2.617814540581275, -0.36607629370472344`}}]}}, 
        {Arrowheads[{{0.028501309478337036`, 1.}}], 
         {LABColor[
          0.24480347704205924`, 0.5224958655371326, -0.7230488904131465], 
          ArrowBox[{{2.6446250149081827`, -0.29217614888245036`}, {
           2.9803749850918173`, -0.35734290395587864`}}]}}, 
        {Arrowheads[{{0.027207098177690996`, 1.}}], 
         {LABColor[
          0.22613801169986394`, 0.5225291943854531, -0.7676583349659624], 
          ArrowBox[{{-2.788242589066146, 0.}, {-2.461757410933854, 0.}}]}}, 
        {Arrowheads[{{0.028979150464706782`, 1.}}], 
         {LABColor[
          0.2524445141501045, 0.5224822217858456, -0.7047872283035607], 
          ArrowBox[{{-2.4238749027882407`, 0.}, {-2.0761250972117593`, 
           0.}}]}}, 
        {Arrowheads[{{0.031584873725966224`, 1.}}], 
         {LABColor[
          0.3012238707313992, 0.5223951219066373, -0.5882072254564751], 
          ArrowBox[{{-2.0645092423557974`, 0.}, {-1.6854907576442026`, 
           0.}}]}}, 
        {Arrowheads[{{0.03570701782641681, 1.}}], 
         {LABColor[
          0.4030191891951917, 0.5222595613504681, -0.3434967393023054], 
          ArrowBox[{{-1.7142421069585008`, 0.}, {-1.2857578930414992`, 
           0.}}]}}, 
        {Arrowheads[{{0.042980777287639015`, 1.}}], 
         {LABColor[
          0.6765565455374501, 0.4647933407861389, 0.7500189587987572], 
          ArrowBox[{{-1.382884663725834, 0.}, {-0.8671153362741659, 0.}}]}}, 
        {Arrowheads[{{0.046875, 1.}}], 
         {LABColor[
          0.8167969189733053, 0.14500114740169545`, 0.8282532063436999], 
          ArrowBox[{{-1.03125, 0.}, {-0.46875, 0.}}]}}, 
        {Arrowheads[{{0.046875, 1.}}], 
         {LABColor[
          0.8167969189733053, 0.14500114740169545`, 0.8282532063436999], 
          ArrowBox[{{-0.65625, 0.}, {-0.09375, 0.}}]}}, 
        {Arrowheads[{{0.046875, 1.}}], 
         {LABColor[
          0.8167969189733053, 0.14500114740169545`, 0.8282532063436999], 
          ArrowBox[{{-0.28125, 0.}, {0.28125, 0.}}]}}, 
        {Arrowheads[{{0.046875, 1.}}], 
         {LABColor[
          0.8167969189733053, 0.14500114740169545`, 0.8282532063436999], 
          ArrowBox[{{0.65625, 0.}, {0.09375, 0.}}]}}, 
        {Arrowheads[{{0.046875, 1.}}], 
         {LABColor[
          0.8167969189733053, 0.14500114740169545`, 0.8282532063436999], 
          ArrowBox[{{0.46875, 0.}, {1.03125, 0.}}]}}, 
        {Arrowheads[{{0.046875, 1.}}], 
         {LABColor[
          0.8167969189733053, 0.14500114740169545`, 0.8282532063436999], 
          ArrowBox[{{0.84375, 0.}, {1.40625, 0.}}]}}, 
        {Arrowheads[{{0.04675186179257684, 1.}}], 
         {LABColor[
          0.8120308838812729, 0.15586920756502204`, 0.8255944344076106], 
          ArrowBox[{{1.219488829244539, 0.}, {1.780511170755461, 0.}}]}}, 
        {Arrowheads[{{0.03764793054196014, 1.}}], 
         {LABColor[
          0.46909562570186714`, 0.5265652177590179, -0.049124567137315334`], 
          ArrowBox[{{1.6491124167482392`, 0.}, {2.100887583251761, 0.}}]}}, 
        {Arrowheads[{{0.032739209821737024`, 1.}}], 
         {LABColor[
          0.3266748975021019, 0.5223496768349345, -0.527380659028833], 
          ArrowBox[{{2.053564741069578, 0.}, {2.446435258930422, 0.}}]}}, 
        {Arrowheads[{{0.029731638278585198`, 1.}}], 
         {LABColor[
          0.2652968132989012, 0.5224592728627382, -0.6740709340272875], 
          ArrowBox[{{2.446610170328489, 0.}, {2.803389829671511, 0.}}]}}, 
        {Arrowheads[{{0.02645025200377905, 1.}}], 
         {LABColor[
          0.21659657735349122`, 0.5225462314650148, -0.7904618428681547], 
          ArrowBox[{{-2.9691740976721275`, 
           0.35004582778784427`}, {-2.6558259023278725`, 
           0.29947322505048474`}}]}}, 
        {Arrowheads[{{0.02789947501122211, 1.}}], 
         {LABColor[
          0.23575483061352517`, 0.5225120227000425, -0.7446746620578115], 
          ArrowBox[{{-2.6021121277769783`, 
           0.3551659862788866}, {-2.2728878722230217`, 
           0.2943530665594424}}]}}, 
        {Arrowheads[{{0.0299508674497676, 1.}}], 
         {LABColor[
          0.26922974779099296`, 0.52245225025844, -0.6646714350092688], 
          ArrowBox[{{-2.2381506331298078`, 
           0.36271760430603145`}, {-1.8868493668701922`, 
           0.28680144853229755`}}]}}, 
        {Arrowheads[{{0.033020173101551434`, 1.}}], 
         {LABColor[
          0.3332265705180991, 0.5223379782401129, -0.5117225177086371], 
          ArrowBox[{{-1.8792110184208308`, 
           0.37474783860990574`}, {-1.4957889815791692`, 
           0.27477121422842327`}}]}}, 
        {Arrowheads[{{0.03797356644211574, 1.}}], 
         {LABColor[
          0.4809218921376339, 0.5273358380067249, 0.003561744706194414], 
          ArrowBox[{{-1.5288797773908103`, 
           0.39611423808083035`}, {-1.0961202226091897`, 
           0.25340481475749865`}}]}}, 
        {Arrowheads[{{0.04687499999999998, 1.}}], 
         {LABColor[
          0.8167969189733053, 0.14500114740169545`, 0.8282532063436999], 
          ArrowBox[{{-1.1937520600328433`, 
           0.44067520365448937`}, {-0.6812479399671567, 
           0.20884384918383964`}}]}}, 
        {Arrowheads[{{0.04687499999999999, 1.}}], 
         {LABColor[
          0.8167969189733053, 0.14500114740169545`, 0.8282532063436999], 
          ArrowBox[{{-0.7883591222654408, 
           0.4923579136115377}, {-0.3366408777345592, 0.1571611392267913}}]}}, 
        {Arrowheads[{{0.046875, 1.}}], 
         {LABColor[
          0.8167969189733053, 0.14500114740169545`, 0.8282532063436999], 
          ArrowBox[{{-0.28450868933259355`, 
           0.5887498230097254}, {-0.09049131066740644, 
           0.060769229828603555`}}]}}, 
        {Arrowheads[{{0.046875, 1.}}], 
         {LABColor[
          0.8167969189733053, 0.14500114740169545`, 0.8282532063436999], 
          ArrowBox[{{0.45087316199888444`, 
           0.4234314071081904}, {-0.07587316199888444, 
           0.22608764573013862`}}]}}, 
        {Arrowheads[{{0.04687499999999998, 1.}}], 
         {LABColor[
          0.8167969189733053, 0.14500114740169545`, 0.8282532063436999], 
          ArrowBox[{{0.5742178875537982, 0.043753737134892834`}, {
           0.5507821124462018, 0.6057653157034362}}]}}, 
        {Arrowheads[{{0.04687500000000001, 1.}}], 
         {LABColor[
          0.8167969189733053, 0.14500114740169545`, 0.8282532063436999], 
          ArrowBox[{{0.7346214320467166, 0.12997285037271375`}, {
           1.1403785679532834`, 0.5195462024656152}}]}}, 
        {Arrowheads[{{0.04687500000000001, 1.}}], 
         {LABColor[
          0.8167969189733053, 0.14500114740169545`, 0.8282532063436999], 
          ArrowBox[{{1.062795401462163, 0.19534091891213834`}, {
           1.562204598537837, 0.45417813392619066`}}]}}, 
        {Arrowheads[{{0.04033549546542633, 1.}}], 
         {LABColor[0.573068306074086, 0.5333402598349251, 0.4140763163409305],
           ArrowBox[{{1.4599490057895388`, 0.24235307015679353`}, {
           1.9150509942104612`, 0.4071659826815355}}]}}, 
        {Arrowheads[{{0.034396756796420916`, 1.}}], 
         {LABColor[
          0.3673462171634736, 0.5222770545767085, -0.43017842238154513`], 
          ArrowBox[{{1.8637727881360313`, 0.2690780853745051}, {
           2.261227211863969, 0.3804409674638239}}]}}, 
        {Arrowheads[{{0.030831265157648946`, 1.}}], 
         {LABColor[
          0.2858808292703364, 0.5224225182716492, -0.6248762580672815], 
          ArrowBox[{{2.257185459418725, 0.28344275913360556`}, {
           2.617814540581275, 0.36607629370472344`}}]}}, 
        {Arrowheads[{{0.028501309478337036`, 1.}}], 
         {LABColor[
          0.24480347704205924`, 0.5224958655371326, -0.7230488904131465], 
          ArrowBox[{{2.6446250149081827`, 0.29217614888245036`}, {
           2.9803749850918173`, 0.35734290395587864`}}]}}, 
        {Arrowheads[{{0.026857840101263932`, 1.}}], 
         {LABColor[
          0.22160897282921319`, 0.5225372813871318, -0.778482490949961], 
          ArrowBox[{{-2.777039704433835, 
           0.7029259528818084}, {-2.472960295566165, 
           0.5961121527948496}}]}}, 
        {Arrowheads[{{0.028413229032557944`, 1.}}], 
         {LABColor[
          0.24343912473582752`, 0.5224983017095095, -0.7263096180424631], 
          ArrowBox[{{-2.4078069848096346`, 
           0.7140184526132813}, {-2.0921930151903654`, 
           0.5850196530633767}}]}}, 
        {Arrowheads[{{0.030595734394996407`, 1.}}], 
         {LABColor[
          0.2812917663118314, 0.5224307124516748, -0.6358438683488227], 
          ArrowBox[{{-2.039855291477216, 
           0.7302797830607101}, {-1.710144708522784, 
           0.5687583226159479}}]}}, 
        {Arrowheads[{{0.03379065189397653, 1.}}], 
         {LABColor[
          0.351910114181239, 0.5223046171113426, -0.4670698669543684], 
          ArrowBox[{{-1.6727439283502687`, 
           0.7556540084996644}, {-1.3272560716497313`, 
           0.5433840971769937}}]}}, 
        {Arrowheads[{{0.03868003968335643, 1.}}], 
         {LABColor[0.507310578664028, 0.5290553710696815, 0.1211240011479569],
           ArrowBox[{{-1.3032435225192607`, 
           0.798147729736641}, {-0.9467564774807393, 0.500890375940017}}]}}, 
        {Arrowheads[{{0.046336263136433804`, 1.}}], 
         {LABColor[
          0.7961050875249951, 0.1921850360485901, 0.8167100977222318], 
          ArrowBox[{{-0.9155659049380472, 
           0.8728611788562469}, {-0.5844340950619528, 0.4261769268204111}}]}}, 
        {Arrowheads[{{0.04687500000000001, 1.}}], 
         {LABColor[
          0.8167969189733053, 0.14500114740169545`, 0.8282532063436999], 
          ArrowBox[{{-0.4314799367014271, 
           0.9250396133237542}, {-0.3185200632985729, 
           0.37399849235290383`}}]}}, 
        {Arrowheads[{{0.046875, 1.}}], 
         {LABColor[
          0.8167969189733053, 0.14500114740169545`, 0.8282532063436999], 
          ArrowBox[{{0.17050768717460954`, 
           0.8731899966695864}, {-0.17050768717460954`, 
           0.4258481090070716}}]}}, 
        {Arrowheads[{{0.04687499999999999, 1.}}], 
         {LABColor[
          0.8167969189733053, 0.14500114740169545`, 0.8282532063436999], 
          ArrowBox[{{0.6231248032965647, 0.5170968323123122}, {
           0.12687519670343528`, 0.7819412733643458}}]}}, 
        {Arrowheads[{{0.046875, 1.}}], 
         {LABColor[
          0.8167969189733053, 0.14500114740169545`, 0.8282532063436999], 
          ArrowBox[{{0.755868523105242, 0.3683302853945294}, {
           0.744131476894758, 0.9307078202821286}}]}}, 
        {Arrowheads[{{0.04687499999999999, 1.}}], 
         {LABColor[
          0.8167969189733053, 0.14500114740169545`, 0.8282532063436999], 
          ArrowBox[{{0.9846163336245068, 0.40581023331188226`}, {
           1.2653836663754932`, 0.8932278723647757}}]}}, 
        {Arrowheads[{{0.040865175047418864`, 1.}}], 
         {LABColor[
          0.5952690927281566, 0.5347869020024743, 0.5129813744317986], 
          ArrowBox[{{1.3223575865294919`, 0.4805166147612536}, {
           1.6776424134705081`, 0.8185214909154044}}]}}, 
        {Arrowheads[{{0.0351867044940986, 1.}}], 
         {LABColor[
          0.3884404949424901, 0.5222393888677835, -0.3797642485201793], 
          ArrowBox[{{1.6998135068694729`, 0.5316995177085025}, {
           2.050186493130527, 0.7673385879681555}}]}}, 
        {Arrowheads[{{0.031522243683882935`, 1.}}], 
         {LABColor[
          0.2999104541752335, 0.5223974671287027, -0.5913462194200798], 
          ArrowBox[{{2.082546078492714, 0.561594934082375}, {
           2.417453921507286, 0.737443171594283}}]}}, 
        {Arrowheads[{{0.02905640041409811, 1.}}], 
         {LABColor[
          0.25371775368884564`, 0.5224799483034177, -0.7017442552212059], 
          ArrowBox[{{2.4649853826561676`, 0.5803150008096701}, {
           2.7850146173438324`, 0.7187231048669879}}]}}, 
        {Arrowheads[{{0.025924386118567025`, 1.}}], 
         {LABColor[
          0.2105641185691077, 0.5225570029566512, -0.8048790904816264], 
          ArrowBox[{{-2.9512288195499274`, 
           1.0446275044004367`}, {-2.6737711804500726`, 
           0.9039296541145503}}]}}, 
        {Arrowheads[{{0.027088509526882815`, 1.}}], 
         {LABColor[
          0.2245759892529225, 0.5225319835154455, -0.7713914834548761], 
          ArrowBox[{{-2.577559315452967, 
           1.0567390709902926`}, {-2.297440684547033, 0.8918180875246944}}]}}, 
        {Arrowheads[{{0.028627174122206913`, 1.}}], 
         {LABColor[
          0.2467769353304753, 0.5224923417518555, -0.7183324326940143], 
          ArrowBox[{{-2.2029237397856782`, 
           1.0731912520584932`}, {-1.9220762602143218`, 
           0.8753659064564938}}]}}, 
        {Arrowheads[{{0.03069863325113212, 1.}}], 
         {LABColor[
          0.2832845597230006, 0.5224271541418167, -0.6310812007404343], 
          ArrowBox[{{-1.8255723258259282`, 
           1.096191055430235}, {-1.5494276741740718`, 
           0.852366103084752}}]}}, 
        {Arrowheads[{{0.03350935037370773, 1.}}], 
         {LABColor[
          0.3449669609757634, 0.5223170147288575, -0.48366362458446566`], 
          ArrowBox[{{-1.441037563497701, 
           1.128880167279477}, {-1.183962436502299, 0.81967699123551}}]}}, 
        {Arrowheads[{{0.037221848941646755`, 1.}}], 
         {LABColor[
          0.4539426956465224, 0.5255778262795378, -0.1166312483519622], 
          ArrowBox[{{-1.037931474867886, 
           1.1737536309474552`}, {-0.8370685251321139, 
           0.7748035275675318}}]}}, 
        {Arrowheads[{{0.041517396612853995`, 1.}}], 
         {LABColor[0.6233792658845, 0.5366186101513213, 0.6382128967329566], 
          ArrowBox[{{-0.5903494336011965, 
           1.2218213049078694`}, {-0.5346505663988035, 
           0.7267358536071176}}]}}, 
        {Arrowheads[{{0.04468199677331503, 1.}}], 
         {LABColor[
          0.7351580015712259, 0.33116357568048016`, 0.78271026377405], 
          ArrowBox[{{-0.06668233509375736, 
           1.2136034670774236`}, {-0.30831766490624263`, 
           0.7349536914375634}}]}}, 
        {Arrowheads[{{0.04514931833809588, 1.}}], 
         {LABColor[0.751979219180494, 0.2928059048979982, 0.7920941185814016],
           ArrowBox[{{0.45402278548882524`, 
           1.0227574291354309`}, {-0.07902278548882524, 
           0.9257997293795561}}]}}, 
        {Arrowheads[{{0.04507994805301042, 1.}}], 
         {LABColor[0.7494625299020786, 0.298544748603942, 0.7906901627363231],
           ArrowBox[{{0.7438717895138042, 0.7736208214677769}, {
           0.38112821048619583`, 1.1749363370472101`}}]}}, 
        {Arrowheads[{{0.04283009526647644, 1.}}], 
         {LABColor[
          0.6715652669470386, 0.47617502702323805`, 0.7472345329216639], 
          ArrowBox[{{0.950245553519523, 0.717614275068623}, {
           0.924754446480477, 1.230942883446364}}]}}, 
        {Arrowheads[{{0.03863619311307138, 1.}}], 
         {LABColor[
          0.5056436482794555, 0.5289467509643552, 0.11369778472200259`], 
          ArrowBox[{{1.2295054512409258`, 0.7578274301868146}, {
           1.3954945487590742`, 1.1907297283281724`}}]}}, 
        {Arrowheads[{{0.03464503206721355, 1.}}], 
         {LABColor[
          0.3738569727648975, 0.5222654290435694, -0.4146180714514196], 
          ArrowBox[{{1.565367067243841, 0.8060716720682919}, {
           1.809632932756159, 1.1424854864466951`}}]}}, 
        {Arrowheads[{{0.03154254989423161, 1.}}], 
         {LABColor[
          0.3003355356363789, 0.5223967081079507, -0.5903302979027883], 
          ArrowBox[{{1.9264490244591488`, 0.8427198456353353}, {
           2.198550975540851, 1.1058373128796517`}}]}}, 
        {Arrowheads[{{0.029249045348604303`, 1.}}], 
         {LABColor[0.2569389630730592, 0.5224741965475945, -0.69404574040876],
           ArrowBox[{{2.2974188404043847`, 0.868564302722499}, {
           2.5775811595956153`, 1.079992855792488}}]}}, 
        {Arrowheads[{{0.02755309184252072, 1.}}], 
         {LABColor[
          0.2308376374684683, 0.5225208027856975, -0.7564264855960133], 
          ArrowBox[{{2.672156668434717, 0.8869059713753729}, {
           2.952843331565283, 1.0616511871396141`}}]}}, 
        {Arrowheads[{{0.025991927018943973`, 1.}}], 
         {LABColor[
          0.21131151294810685`, 0.5225556684175204, -0.8030928586627133], 
          ArrowBox[{{-2.7490164478855204`, 
           1.3935939641918762`}, {-2.5009835521144796`, 
           1.2044822471614398`}}]}}, 
        {Arrowheads[{{0.027087373716230365`, 1.}}], 
         {LABColor[
          0.2245611489788212, 0.5225320100140747, -0.7714269509009072], 
          ArrowBox[{{-2.3700101139751144`, 
           1.408636015684186}, {-2.1299898860248856`, 1.18944019566913}}]}}, 
        {Arrowheads[{{0.02846691932091737, 1.}}], 
         {LABColor[
          0.2442691445865845, 0.522496819635251, -0.7243259158506739], 
          ArrowBox[{{-1.9871182526266187`, 
           1.4278893969794773`}, {-1.7628817473733813`, 
           1.1701868143738388`}}]}}, 
        {Arrowheads[{{0.030184256576467335`, 1.}}], 
         {LABColor[
          0.2735102104186496, 0.5224446071117493, -0.6544413626939974], 
          ArrowBox[{{-1.5967270135374367`, 
           1.4521495071946147`}, {-1.4032729864625633`, 
           1.1459267041587013`}}]}}, 
        {Arrowheads[{{0.032227438305346946`, 1.}}], 
         {LABColor[
          0.31510019052035176`, 0.5223703445036091, -0.5550435776784006], 
          ArrowBox[{{-1.1919285961113533`, 
           1.480450462181559}, {-1.0580714038886467`, 
           1.117625749171757}}]}}, 
        {Arrowheads[{{0.03437540751753092, 1.}}], 
         {LABColor[
          0.36679144999084556`, 0.5222780451628316, -0.4315042856789969], 
          ArrowBox[{{-0.761202017786904, 
           1.5049861231698338`}, {-0.738797982213096, 
           1.0930900881834822`}}]}}, 
        {Arrowheads[{{0.036026202407569353`, 1.}}], 
         {LABColor[
          0.4133663028268924, 0.5229337974090943, -0.2974000900816106], 
          ArrowBox[{{-0.2937630915814497, 
           1.4993491290063732`}, {-0.4562369084185503, 
           1.0987270823469428`}}]}}, 
        {Arrowheads[{{0.0365722105211353, 1.}}], 
         {LABColor[
          0.431540271788281, 0.5241180450783748, -0.2164346052149655], 
          ArrowBox[{{0.18830911308684273`, 
           1.4116908237749235`}, {-0.18830911308684273`, 
           1.1863853875783925`}}]}}, 
        {Arrowheads[{{0.03657582271295278, 1.}}], 
         {LABColor[
          0.4316624955607966, 0.5241260093936017, -0.21589009526092198`], 
          ArrowBox[{{0.5861467148628081, 1.2392256165184505`}, {
           0.1638532851371919, 1.3588505948348655`}}]}}, 
        {Arrowheads[{{0.03633532148961237, 1.}}], 
         {LABColor[
          0.42358193189221804`, 0.5235994657029353, -0.2518892078825092], 
          ArrowBox[{{0.8685817113441502, 1.11609664265141}, {
           0.6314182886558498, 1.481979568701906}}]}}, 
        {Arrowheads[{{0.035021015519658465`, 1.}}], 
         {LABColor[
          0.383924487775652, 0.5222474526001962, -0.39055725944253583`], 
          ArrowBox[{{1.1403986033358624`, 1.0894769975856802`}, {
           1.1096013966641376`, 1.5085992137676358`}}]}}, 
        {Arrowheads[{{0.03295283915393704, 1.}}], 
         {LABColor[
          0.3316437044424862, 0.5223408045882579, -0.5155054813337103], 
          ArrowBox[{{1.4480830445679604`, 1.10825903020543}, {
           1.5519169554320396`, 1.489817181147886}}]}}, 
        {Arrowheads[{{0.030833775013670354`, 1.}}], 
         {LABColor[
          0.2859302599228331, 0.5224224300088232, -0.6247581215027044], 
          ArrowBox[{{1.7861330133779163`, 1.1367770837826692`}, {
           1.9638669866220837`, 1.4612991275706468`}}]}}, 
        {Arrowheads[{{0.029000148591920075`, 1.}}], 
         {LABColor[
          0.2527895613882384, 0.5224816056733163, -0.7039625842159128], 
          ArrowBox[{{2.141923508326044, 1.1626717527585964`}, {
           2.358076491673956, 1.4354044585947197`}}]}}, 
        {Arrowheads[{{0.0275125503694623, 1.}}], 
         {LABColor[
          0.23027600247221025`, 0.5225218056349304, -0.7577687626175166], 
          ArrowBox[{{2.5070584986124755`, 1.1835406699803803`}, {
           2.7429415013875245`, 1.4145355413729357`}}]}}, 
        {Arrowheads[{{0.025098017283833988`, 1.}}], 
         {LABColor[
          0.20207352169857615`, 0.522572163672447, -0.8251711541067459], 
          ArrowBox[{{-2.922566722950929, 
           1.726569678274295}, {-2.702433277049071, 1.52102558591735}}]}}, 
        {Arrowheads[{{0.02589183005670199, 1.}}], 
         {LABColor[
          0.21020674396568323`, 0.5225576410807876, -0.805733196300248], 
          ArrowBox[{{-2.5408721972955592`, 
           1.7397636440085933`}, {-2.3341278027044408`, 
           1.5078316201830517`}}]}}, 
        {Arrowheads[{{0.026840840540849866`, 1.}}], 
         {LABColor[
          0.22139404030056856`, 0.522537665168276, -0.7789961679756012], 
          ArrowBox[{{-2.1551757530197317`, 
           1.7555045444278696`}, {-1.9698242469802683`, 
           1.4920907197637754`}}]}}, 
        {Arrowheads[{{0.027951378921124283`, 1.}}], 
         {LABColor[
          0.23650994700323735`, 0.5225106743725748, -0.7428699750542874], 
          ArrowBox[{{-1.7628653485738286`, 
           1.7736179552955376`}, {-1.6121346514261714`, 
           1.4739773088961075`}}]}}, 
        {Arrowheads[{{0.02918668466313642, 1.}}], 
         {LABColor[
          0.2558890409013261, 0.5224760712770036, -0.6965549971589157], 
          ArrowBox[{{-1.3597741895929578`, 
           1.792416145957267}, {-1.2652258104070422`, 
           1.455179118234378}}]}}, 
        {Arrowheads[{{0.03041822469947698, 1.}}], 
         {LABColor[
          0.27789807726797233`, 0.5224367721852693, -0.6439546001444718], 
          ArrowBox[{{-0.9401896770989464, 
           1.8062871600593382`}, {-0.9348103229010536, 
           1.4413081041323068`}}]}}, 
        {Arrowheads[{{0.031390665276589215`, 1.}}], 
         {LABColor[
          0.2971737373995833, 0.5224023537798866, -0.5978868233119178], 
          ArrowBox[{{-0.4997168909882037, 
           1.8013694215699954`}, {-0.6252831090117963, 
           1.4462258426216497`}}]}}, 
        {Arrowheads[{{0.03184462965486321, 1.}}], 
         {LABColor[
          0.30674534196787717`, 0.5223852628287107, -0.5750112102241722], 
          ArrowBox[{{-0.04669994406050004, 
           1.7529573781865757`}, {-0.32830005593949996`, 
           1.4946378860050693`}}]}}, 
        {Arrowheads[{{0.031891308054376115`, 1.}}], 
         {LABColor[
          0.30775021652082035`, 0.5223834685358311, -0.5726096148269915], 
          ArrowBox[{{0.37763527136841446`, 
           1.6453052502983927`}, {-0.002635271368414488, 
           1.6022900138932523`}}]}}, 
        {Arrowheads[{{0.03188421378186246, 1.}}], 
         {LABColor[
          0.30759724520217824`, 0.5223837416797246, -0.5729752079387639], 
          ArrowBox[{{0.7260290575180168, 1.5245204517731552`}, {
           0.39897094248198317`, 1.7230748124184898`}}]}}, 
        {Arrowheads[{{0.03160566800201416, 1.}}], 
         {LABColor[
          0.30166148360357214`, 0.5223943405099364, -0.5871613545500227], 
          ArrowBox[{{1.0260868599004451`, 1.4561270465785459`}, {
           0.8489131400995549, 1.7914682176130992`}}]}}, 
        {Arrowheads[{{0.0307866751429514, 1.}}], 
         {LABColor[
          0.28500450493791973`, 0.5224240830266778, -0.626970625445782], 
          ArrowBox[{{1.3292823504359093`, 1.4398415234646582`}, {
           1.2957176495640907`, 1.8077537407269868`}}]}}, 
        {Arrowheads[{{0.02960766738568706, 1.}}], 
         {LABColor[
          0.2631104554363098, 0.5224631767991385, -0.679296210121712], 
          ArrowBox[{{1.6529531847034726`, 1.4495431618471635`}, {
           1.7220468152965274`, 1.7980521023444815`}}]}}, 
        {Arrowheads[{{0.02835319247701475, 1.}}], 
         {LABColor[
          0.24251703878522768`, 0.522499948175977, -0.728513353193562], 
          ArrowBox[{{1.9950428155804594`, 1.4676244746033156`}, {
           2.1299571844195406`, 1.7799707895883294`}}]}}, 
        {Arrowheads[{{0.0271936149201851, 1.}}], 
         {LABColor[
          0.2259591589693728, 0.522529513742909, -0.7680857832410357], 
          ArrowBox[{{2.349690161917449, 1.4862797450290868`}, {
           2.525309838082551, 1.7613155191625582`}}]}}, 
        {Arrowheads[{{0.026190120466479977`, 1.}}], 
         {LABColor[
          0.21355129938015815`, 0.522551669079658, -0.7977398912001303], 
          ArrowBox[{{2.7121461204358748`, 1.502874906282254}, {
           2.9128538795641252`, 1.744720357909391}}]}}, 
        {Arrowheads[{{0.024958260105418326`, 1.}}], 
         {LABColor[
          0.2007570865488254, 0.5225745142844798, -0.8283173623444493], 
          ArrowBox[{{-2.714831568895799, 
           2.0683704304816146`}, {-2.535168431104201, 
           1.8287438865483594`}}]}}, 
        {Arrowheads[{{0.02563224313367557, 1.}}], 
         {LABColor[
          0.20742432934233257`, 0.5225626093295425, -0.8123830155567073], 
          ArrowBox[{{-2.327838335607051, 
           2.0811981079997635`}, {-2.172161664392949, 
           1.8159162090302106`}}]}}, 
        {Arrowheads[{{0.02638623500560941, 1.}}], 
         {LABColor[
          0.21583603811026267`, 0.5225475894754696, -0.7922794901959365], 
          ArrowBox[{{-1.9352857917083508`, 
           2.094947136443335}, {-1.8147142082916492`, 
           1.8021671805866388`}}]}}, 
        {Arrowheads[{{0.027188087915744452`, 1.}}], 
         {LABColor[
          0.22588593735376722`, 0.5225296444866154, -0.7682607789103931], 
          ArrowBox[{{-1.534587182793028, 
           2.1079768664213643`}, {-1.465412817206972, 
           1.7891374506086097`}}]}}, 
        {Arrowheads[{{0.027963136513839717`, 1.}}], 
         {LABColor[
          0.23668166312853536`, 0.5225103677581621, -0.7424595828765479], 
          ArrowBox[{{-1.1226533371606624`, 
           2.1163195658249006`}, {-1.1273466628393376`, 
           1.7807947512050735`}}]}}, 
        {Arrowheads[{{0.028588141549979563`, 1.}}], 
         {LABColor[
          0.24616193547549858`, 0.5224934398887896, -0.7198022488184777], 
          ArrowBox[{{-0.6974632072075903, 
           2.111842281980744}, {-0.8025367927924097, 1.7852720350492302`}}]}}, 
        {Arrowheads[{{0.028939437219914935`, 1.}}], 
         {LABColor[
          0.2517940688112151, 0.5224833832138434, -0.7063417572021373], 
          ArrowBox[{{-0.26292023597046993`, 
           2.081176174696224}, {-0.48707976402953007`, 
           1.8159381423337502`}}]}}, 
        {Arrowheads[{{0.02902514161301359, 1.}}], 
         {LABColor[
          0.25320127127666164`, 0.5224808705286964, -0.7029786200284278], 
          ArrowBox[{{0.16218421776759473`, 
           2.0119984538257794`}, {-0.16218421776759473`, 
           1.8851158632041947`}}]}}, 
        {Arrowheads[{{0.02902569172416258, 1.}}], 
         {LABColor[
          0.25321034569170653`, 0.5224808543255213, -0.702956932671195], 
          ArrowBox[{{0.5460663174461506, 1.91590776161714}, {
           0.20393368255384936`, 1.981206555412834}}]}}, 
        {Arrowheads[{{0.02899067987430595, 1.}}], 
         {LABColor[
          0.252633872081872, 0.5224818836704185, -0.7043346731701656], 
          ArrowBox[{{0.8813339639687044, 1.834504834501188}, {
           0.6186660360312956, 2.062609482528786}}]}}, 
        {Arrowheads[{{0.028739503729383966`, 1.}}], 
         {LABColor[
          0.24856185748458562`, 0.5224891546146132, -0.7140665660571468], 
          ArrowBox[{{1.1968727561483072`, 1.7918126734137503`}, {
           1.0531272438516928`, 2.1053016436162237`}}]}}, 
        {Arrowheads[{{0.028195191119489538`, 1.}}], 
         {LABColor[
          0.24012082944850247`, 0.5225042268208467, -0.734240162870358], 
          ArrowBox[{{1.5176020050500862`, 1.7803042349156026`}, {
           1.4823979949499138`, 2.1168100821143714`}}]}}, 
        {Arrowheads[{{0.027454612535647, 1.}}], 
         {LABColor[
          0.22947841991662027`, 0.5225232297895138, -0.7596749414422928], 
          ArrowBox[{{1.8513265067606157`, 1.7855394518104237`}, {
           1.8986734932393843`, 2.1115748652195503`}}]}}, 
        {Arrowheads[{{0.02665084995815786, 1.}}], 
         {LABColor[
          0.21902671862976342`, 0.5225418922316493, -0.7846539377057632], 
          ArrowBox[{{2.1972265944492886`, 1.7976114444575786`}, {
           2.3027734055507114`, 2.0995028725723954`}}]}}, 
        {Arrowheads[{{0.025875593088592677`, 1.}}], 
         {LABColor[
          0.21002920865770713`, 0.5225579580858685, -0.8061574960073344], 
          ArrowBox[{{2.5522828361345646`, 1.8113861648024723`}, {
           2.6977171638654354`, 2.0857281522275017`}}]}}, 
        {Arrowheads[{{0.024221094609071375`, 1.}}], 
         {LABColor[
          0.19438557192283817`, 0.5225858911904742, -0.8435449349345042], 
          ArrowBox[{{-2.8912254789625775`, 
           2.395472774542201}, {-2.7337745210374225`, 
           2.151160595326102}}]}}, 
        {Arrowheads[{{0.024713947974904078`, 1.}}], 
         {LABColor[
          0.1985388551736173, 0.5225784751338713, -0.8336188143963287], 
          ArrowBox[{{-2.503756793821248, 
           2.4059744753377093`}, {-2.371243206178752, 
           2.1406588945305938`}}]}}, 
        {Arrowheads[{{0.025247259949309864`, 1.}}], 
         {LABColor[
          0.20351748116923576`, 0.5225695853543983, -0.8217201696945176], 
          ArrowBox[{{-2.1116693398547475`, 
           2.4165983825663937`}, {-2.0133306601452525`, 
           2.1300349873019093`}}]}}, 
        {Arrowheads[{{0.025797164119956903`, 1.}}], 
         {LABColor[
          0.20917823650596903`, 0.5225594775723239, -0.8081912730561785], 
          ArrowBox[{{-1.7132999253629215`, 
           2.4259342992845907`}, {-1.6617000746370785`, 
           2.1206990705837123`}}]}}, 
        {Arrowheads[{{0.026318913402821165`, 1.}}], 
         {LABColor[
          0.2150440654531421, 0.5225490036130804, -0.7941722616692144], 
          ArrowBox[{{-1.3068598671156164`, 
           2.431129410018137}, {-1.3181401328843836`, 
           2.115503959850166}}]}}, 
        {Arrowheads[{{0.02674708005743251, 1.}}], 
         {LABColor[
          0.22021777934106923`, 0.5225397654868262, -0.7818073675407043], 
          ArrowBox[{{-0.8913388671889182, 
           2.4270169657248872`}, {-0.9836611328110818, 2.119616404143416}}]}}, 
        {Arrowheads[{{0.027016917619239158`, 1.}}], 
         {LABColor[
          0.22364504838324442`, 0.5225336457931584, -0.7736163813798141], 
          ArrowBox[{{-0.4688531964277993, 
           2.405631364149728}, {-0.6561468035722007, 2.1410020057185752`}}]}}, 
        {Arrowheads[{{0.027116779221484644`, 1.}}], 
         {LABColor[
          0.22494609119900993`, 0.522531322665507, -0.7705069599811669], 
          ArrowBox[{{-0.04891283839292737, 
           2.3585522901128435`}, {-0.32608716160707263`, 
           2.1880810797554595`}}]}}, 
        {Arrowheads[{{0.027125437475668947`, 1.}}], 
         {LABColor[
          0.22505972656482465`, 0.5225311197594554, -0.7702353776521107], 
          ArrowBox[{{0.34971328607278485`, 2.2865555186569604`}, {
           0.025286713927215154`, 2.2600778512113426`}}]}}, 
        {Arrowheads[{{0.027124135521650994`, 1.}}], 
         {LABColor[
          0.22504263057564686`, 0.5225311502858645, -0.7702762361341963], 
          ArrowBox[{{0.7123808476262654, 2.209900553583207}, {
           0.41261915237373453`, 2.336732816285096}}]}}, 
        {Arrowheads[{{0.02706695208611593, 1.}}], 
         {LABColor[
          0.224294713721448, 0.5225324857579212, -0.7720637166403521], 
          ArrowBox[{{1.0471805749815244`, 2.1535482095323264`}, {
           0.8278194250184756, 2.3930851603359766`}}]}}, 
        {Arrowheads[{{0.026856914453201555`, 1.}}], 
         {LABColor[
          0.22159725630536048`, 0.5225373023080272, -0.7785104928032005], 
          ArrowBox[{{1.3739852357950264`, 2.1243665438757855`}, {
           1.2510147642049736`, 2.4222668259925175`}}]}}, 
        {Arrowheads[{{0.02647562322519974, 1.}}], 
         {LABColor[
          0.21690000168006987`, 0.5225456896738956, -0.7897366752699011], 
          ArrowBox[{{1.7056448454650976`, 2.1155026326799042`}, {
           1.6693551545349024`, 2.431130737188399}}]}}, 
        {Arrowheads[{{0.025977091800332742`, 1.}}], 
         {LABColor[
          0.21114665724655343`, 0.5225559627820365, -0.803486854801724], 
          ArrowBox[{{2.046203029748715, 2.1183084803024816`}, {
           2.078796970251285, 2.4283248895658214`}}]}}, 
        {Arrowheads[{{0.02543044934622704, 1.}}], 
         {LABColor[
          0.20534378579434304`, 0.5225663243250738, -0.8173554012080817], 
          ArrowBox[{{2.395332120639817, 2.126676482082063}, {
           2.479667879360183, 2.41995688778624}}]}}, 
        {Arrowheads[{{0.024888036064112374`, 1.}}], 
         {LABColor[
          0.20010866677627653`, 0.5225756720956487, -0.8298670502499033], 
          ArrowBox[{{2.7513504794059136`, 2.137082869969799}, {
           2.8736495205940864`, 2.4095504998985042`}}]}}, 
        {Arrowheads[{{0.024001313198217564`, 1.}}], 
         {LABColor[
          0.19267210167001436`, 0.5225889507439925, -0.8476400354227546], 
          ArrowBox[{{-2.682016430874636, 
           2.730316129225793}, {-2.567983569125364, 2.465836293480839}}]}}, 
        {Arrowheads[{{0.024391710599466168`, 1.}}], 
         {LABColor[
          0.19577469263385466`, 0.5225834107919077, -0.8402250121680906], 
          ArrowBox[{{-2.290674206983809, 
           2.738660735896703}, {-2.209325793016191, 2.457491686809929}}]}}, 
        {Arrowheads[{{0.024785593296064907`, 1.}}], 
         {LABColor[
          0.19917840904753992`, 0.5225773331535528, -0.8320903155052352], 
          ArrowBox[{{-1.894381776410161, 
           2.74552135235346}, {-1.855618223589839, 2.450631070353172}}]}}, 
        {Arrowheads[{{0.025155138174041098`, 1.}}], 
         {LABColor[
          0.20262152277027642`, 0.5225711851677988, -0.8238614614216332], 
          ArrowBox[{{-1.4920458185224323`, 
           2.7487972986404157`}, {-1.5079541814775677`, 
           2.4473551240662164`}}]}}, 
        {Arrowheads[{{0.025462960511511312`, 1.}}], 
         {LABColor[
          0.20567411256395007`, 0.5225657344972501, -0.8165659382376739], 
          ArrowBox[{{-1.0831316935740265`, 
           2.745005071028361}, {-1.1668683064259735`, 
           2.451147351678271}}]}}, 
        {Arrowheads[{{0.02567249851842687, 1.}}], 
         {LABColor[
          0.20784799668969686`, 0.5225618528338163, -0.8113704736942571], 
          ArrowBox[{{-0.6689127553583616, 
           2.729040470763499}, {-0.8310872446416384, 2.467111951943133}}]}}, 
        {Arrowheads[{{0.02577105604541721, 1.}}], 
         {LABColor[
          0.2088973736866346, 0.5225599790778653, -0.8088625198821402], 
          ArrowBox[{{-0.2546653393431362, 
           2.695178597079181}, {-0.4953346606568638, 2.500973825627451}}]}}, 
        {Arrowheads[{{0.02579165151857173, 1.}}], 
         {LABColor[
          0.2091188331050338, 0.5225595836423791, -0.8083332439458235], 
          ArrowBox[{{0.14857327994984873`, 
           2.641360329167358}, {-0.14857327994984873`, 2.554792093539274}}]}}, 
        {Arrowheads[{{0.025791778711914307`, 1.}}], 
         {LABColor[
          0.20912020312516022`, 0.5225595811960863, -0.8083299696724129], 
          ArrowBox[{{0.5281779261914383, 2.5760695419967985`}, {
           0.2218220738085617, 2.6200828807098335`}}]}}, 
        {Arrowheads[{{0.02578366477937984, 1.}}], 
         {LABColor[
          0.2090328640009021, 0.5225597371478599, -0.8085387054177832], 
          ArrowBox[{{0.8816579694175997, 2.516842693706781}, {
           0.6183420305824003, 2.679309728999851}}]}}, 
        {Arrowheads[{{0.025717076139806897`, 1.}}], 
         {LABColor[
          0.20832050059294926`, 0.5225610091360765, -0.810241215125735], 
          ArrowBox[{{1.2195918417330776`, 2.47616791932998}, {
           1.0304081582669224`, 2.719984503376652}}]}}, 
        {Arrowheads[{{0.02554512245255222, 1.}}], 
         {LABColor[
          0.2065172509844849, 0.5225642289986185, -0.8145508833793216], 
          ArrowBox[{{1.5545047160071868`, 2.454824146610263}, {
           1.4454952839928132`, 2.741328276096369}}]}}, 
        {Arrowheads[{{0.025266595174197534`, 1.}}], 
         {LABColor[
          0.20370743926990692`, 0.5225692461673163, -0.8212661801901631], 
          ArrowBox[{{1.893536547805496, 2.44761416851015}, {1.856463452194504,
            2.748538254196482}}]}}, 
        {Arrowheads[{{0.02491317627011058, 1.}}], 
         {LABColor[
          0.20033979783534409`, 0.5225752593905878, -0.8293146596196734], 
          ArrowBox[{{2.239012654150258, 2.4490015089442894`}, {
           2.260987345849742, 2.7471509137623427`}}]}}, 
        {Arrowheads[{{0.02452375625013471, 1.}}], 
         {LABColor[
          0.19688515551502989`, 0.5225814279616781, -0.837571066422963], 
          ArrowBox[{{2.590815855232037, 2.4549595785370717`}, {
           2.659184144767963, 2.7411928441695603`}}]}}, 
        {Arrowheads[{{0.02343750000000001, 1.}}], 
         {LABColor[
          0.1886675222501131, 0.5225961012766809, -0.8572107619122568], 
          ArrowBox[{{-2.86199657429872, 
           3.0544620260195146`}, {-2.76300342570128, 2.7912094495254465`}}]}}, 
        {Arrowheads[{{0.023731667197329373`, 1.}}], 
         {LABColor[
          0.19068668618246906`, 0.522592495879912, -0.8523850701959159], 
          ArrowBox[{{-2.471487259031758, 
           3.061110027610617}, {-2.403512740968242, 2.784561447934344}}]}}, 
        {Arrowheads[{{0.024023873576110688`, 1.}}], 
         {LABColor[
          0.1928440497125467, 0.5225886437154709, -0.8472290889754688], 
          ArrowBox[{{-2.0769980385894042`, 
           3.0662480138672916`}, {-2.0480019614105958`, 
           2.7794234616776694`}}]}}, 
        {Arrowheads[{{0.0242961929057525, 1.}}], 
         {LABColor[
          0.19499065781721425`, 0.5225848107557984, -0.842098812635381], 
          ArrowBox[{{-1.677831018201207, 
           3.0682918838119724`}, {-1.697168981798793, 
           2.7773795917329887`}}]}}, 
        {Arrowheads[{{0.02452597698353563, 1.}}], 
         {LABColor[
          0.1969040951093907, 0.522581394143348, -0.8375258018250009], 
          ArrowBox[{{-1.2736928775828278`, 
           3.06478240008473}, {-1.3513071224171722`, 2.780889075460231}}]}}, 
        {Arrowheads[{{0.024691278476525285`, 1.}}], 
         {LABColor[
          0.1983383845788535, 0.5225788330919464, -0.8340979281884381], 
          ArrowBox[{{-0.8654102335417606, 
           3.0522606115525543`}, {-1.0095897664582394`, 
           2.7934108639924067`}}]}}, 
        {Arrowheads[{{0.024781895461904305`, 1.}}], 
         {LABColor[
          0.19914517732150241`, 0.5225773924917549, -0.8321697375187176], 
          ArrowBox[{{-0.45614014069623865`, 
           3.0267429303316833`}, {-0.6688598593037614, 
           2.8189285452132777`}}]}}, 
        {Arrowheads[{{0.024811330153864483`, 1.}}], 
         {LABColor[
          0.19941037177992743`, 0.5225769189634653, -0.8315359372211123], 
          ArrowBox[{{-0.05258530243160961, 
           2.985761885947751}, {-0.32241469756839036`, 
           2.85990958959721}}]}}, 
        {Arrowheads[{{0.024813667454937516`, 1.}}], 
         {LABColor[
          0.19943149563028734`, 0.5225768812449518, -0.8314854523703948], 
          ArrowBox[{{0.33608046974958616`, 2.9323065002182616`}, {
           0.038919530250413864`, 2.9133649753266995`}}]}}, 
        {Arrowheads[{{0.024813318541590485`, 1.}}], 
         {LABColor[
          0.19942834163840506`, 0.5225768868766849, -0.8314929902390422], 
          ArrowBox[{{0.7040577873376562, 2.8767204386003113`}, {
           0.4209422126623438, 2.9689510369446497`}}]}}, 
        {Arrowheads[{{0.02479706388222634, 1.}}], 
         {LABColor[
          0.19928164700729287`, 0.5225771488129946, -0.8318435824098146], 
          ArrowBox[{{1.054450337864897, 2.830863915719538}, {
           0.8205496621351029, 3.014807559825423}}]}}, 
        {Arrowheads[{{0.024729682132872074`, 1.}}], 
         {LABColor[
          0.1986785300961532, 0.5225782257318756, -0.833284998946349], 
          ArrowBox[{{1.3961546719811313`, 2.800287974521275}, {
           1.2288453280188687`, 3.045383501023686}}]}}, 
        {Arrowheads[{{0.024589119906748554`, 1.}}], 
         {LABColor[
          0.19744626462935294`, 0.522580426051454, -0.836230046230614], 
          ArrowBox[{{1.7370347296099815`, 2.7838652229038563`}, {
           1.6379652703900185`, 3.0618062526411047`}}]}}, 
        {Arrowheads[{{0.0243786946155309, 1.}}], 
         {LABColor[
          0.19566690347087007`, 0.5225836032590442, -0.8404826223911097], 
          ArrowBox[{{2.0813376426508823`, 2.7777816435144382`}, {
           2.0436623573491177`, 3.067889832030523}}]}}, 
        {Arrowheads[{{0.024117906492649457`, 1.}}], 
         {LABColor[
          0.19357044289842154`, 0.5225873466758382, -0.8454930488631671], 
          ArrowBox[{{2.4305101759014027`, 2.7782972126373275`}, {
           2.4444898240985973`, 3.0673742629076335`}}]}}, 
        {Arrowheads[{{0.023830049896753334`, 1.}}], 
         {LABColor[
          0.1913961686440194, 0.5225912290358813, -0.8506894457928008], 
          ArrowBox[{{2.784529087877078, 2.782618070961358}, {
           2.840470912122922, 3.063053404583603}}]}}}},
      AspectRatio->1,
      DisplayFunction->Identity,
      Frame->True,
      FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
      GridLinesStyle->Directive[
        GrayLevel[0.5, 0.4]],
      ImagePadding->{{15., 0.5}, {16., 0.5}},
      LabelStyle->Opacity[0],
      Method->{
       "VectorLengthFunction" -> (Sqrt[#]& ), "DefaultBoundaryStyle" -> 
        Automatic, 
        "DefaultGraphicsInteraction" -> {
         "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
          "Effects" -> {
           "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
            "Droplines" -> {
             "freeformCursorMode" -> True, 
              "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
        "TransparentPolygonMesh" -> True},
      PlotRange->{{-3, 3}, {-3, 3}},
      PlotRangeClipping->True,
      PlotRangePadding->{{
         Scaled[0.02], 
         Scaled[0.02]}, {
         Scaled[0.02], 
         Scaled[0.02]}},
      Ticks->{Automatic, Automatic}], {564.7993871866296, -78.96935933147633},
      ImageScaled[{0.5, 0.5}], {149.41782729805016, 150.41782729805016},
     BaseStyle->{Graphics3DBoxOptions -> {SphericalRegion -> False}}]}, {}},
  ImageSize->{1075.1047973632812`, 273.},
  PlotRange->{{0, 645.4850139275767}, {-157.93871866295265`, 0}},
  PlotRangePadding->{6, 5}]], "Output",
 CellChangeTimes->{
  3.920380166984128*^9, {3.920383598468319*^9, 3.920383642031961*^9}, 
   3.920383695274289*^9, {3.920383813920516*^9, 3.920383829541391*^9}, 
   3.920971624180781*^9, {3.920972054724449*^9, 3.920972083186108*^9}, 
   3.920972163546698*^9, {3.9209722177383833`*^9, 3.920972228388218*^9}, {
   3.9209723677984743`*^9, 3.920972384868678*^9}, 3.920972560489881*^9, 
   3.920972633168303*^9, {3.9209726873091803`*^9, 3.920972745967887*^9}, {
   3.9209727950491*^9, 3.920972806142518*^9}, {3.92097287318435*^9, 
   3.920972886767408*^9}, 3.9209939943386908`*^9, {3.921006100448579*^9, 
   3.921006113293054*^9}, 3.9210061687021027`*^9, 3.9210069103249273`*^9},
 CellLabel->
  "Out[2950]=",ExpressionUUID->"628a3968-dd03-457b-bf15-a6cdba65cc1f"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"VectorPlot", "[", 
  RowBox[{
   RowBox[{"\[Mu]field", "[", 
    RowBox[{"x", ",", "y"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", 
     RowBox[{"-", "3"}], ",", "3"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"y", ",", 
     RowBox[{"-", "3"}], ",", "3"}], "}"}], ",", 
   RowBox[{"VectorScaling", "->", "Automatic"}], ",", 
   RowBox[{"VectorSizes", "->", "1.5"}], ",", 
   RowBox[{"LabelStyle", "->", 
    RowBox[{"Opacity", "[", "0", "]"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.920384310230754*^9, 3.9203843111092243`*^9}},
 CellLabel->
  "In[1737]:=",ExpressionUUID->"0afecf0e-3ec1-42c8-9085-70cbd4660459"],

Cell[BoxData[
 GraphicsBox[{{}, 
   {RGBColor[0.2947336, 0.4054232, 0.5678384000000001], 
    {Arrowheads[{{0.023437499999999983`, 1.}}], 
     {LABColor[0.1886675222501131, 0.5225961012766809, -0.8572107619122568], 
      ArrowBox[{{-2.852300345229779, -3.05771095100527}, {-2.772699654770221, \
-2.7879605245396912`}}]}}, 
    {Arrowheads[{{0.023772049520917705`, 1.}}], 
     {LABColor[0.19126941188753788`, 0.5225914553713428, -0.8509923875301908],
       ArrowBox[{{-2.4595209027139866`, -3.063757886588626}, \
{-2.4154790972860134`, -2.781913588956335}}]}}, 
    {Arrowheads[{{0.024092985612148617`, 1.}}], 
     {LABColor[0.1939436373986191, 0.5225866803038692, -0.8446011343537365], 
      ArrowBox[{{-2.0622189885768405`, -3.067393378310915}, \
{-2.0627810114231595`, -2.778278097234046}}]}}, 
    {Arrowheads[{{0.024376206502166726`, 1.}}], 
     {LABColor[0.1964485516254857, 0.5225822075567508, -0.8386145259159411], 
      ArrowBox[{{-1.6598599798663334`, -3.0664574953536925`}, \
{-1.7151400201336666`, -2.7792139801912685`}}]}}, 
    {Arrowheads[{{0.024595162453253397`, 1.}}], 
     {LABColor[0.1984782287678722, 0.5225785833877103, -0.8337637082007927], 
      ArrowBox[{{-1.2527352286601092`, -3.057762994790327}, \
{-1.3722647713398908`, -2.787908480754634}}]}}, 
    {Arrowheads[{{0.02473114633658845, 1.}}], 
     {LABColor[0.19977965974530087`, 0.5225762595669616, -0.8306533591169325],
       ArrowBox[{{-0.8430420861852641, -3.037275102005908}, \
{-1.031957913814736, -2.808396373539053}}]}}, 
    {Arrowheads[{{0.024788185784081627`, 1.}}], 
     {LABColor[0.20033488155114046`, 0.5225752681690505, -0.8293264092708912],
       ArrowBox[{{-0.4362951226984074, -3.001529311246248}, \
{-0.6887048773015926, -2.844142164298713}}]}}, 
    {Arrowheads[{{0.02479861681343028, 1.}}], 
     {LABColor[0.20043701336272815`, 0.5225750858036181, -0.8290823198092799],
       ArrowBox[{{-0.04143291540264227, -2.951179644492706}, \
{-0.33356708459735773`, -2.894491831052255}}]}}, 
    {Arrowheads[{{0.02479861681343028, 1.}}], 
     {LABColor[0.20043701336272815`, 0.5225750858036181, -0.8290823198092799],
       ArrowBox[{{0.33356708459735773`, -2.894491831052255}, {
       0.04143291540264227, -2.951179644492706}}]}}, 
    {Arrowheads[{{0.024788185784081627`, 1.}}], 
     {LABColor[0.20033488155114046`, 0.5225752681690505, -0.8293264092708912],
       ArrowBox[{{0.6887048773015926, -2.844142164298713}, {
       0.4362951226984074, -3.001529311246248}}]}}, 
    {Arrowheads[{{0.02473114633658845, 1.}}], 
     {LABColor[0.19977965974530087`, 0.5225762595669616, -0.8306533591169325],
       ArrowBox[{{1.031957913814736, -2.808396373539053}, {
       0.8430420861852641, -3.037275102005908}}]}}, 
    {Arrowheads[{{0.024595162453253397`, 1.}}], 
     {LABColor[0.1984782287678722, 0.5225785833877103, -0.8337637082007927], 
      ArrowBox[{{1.3722647713398908`, -2.787908480754634}, {
       1.2527352286601092`, -3.057762994790327}}]}}, 
    {Arrowheads[{{0.024376206502166726`, 1.}}], 
     {LABColor[0.1964485516254857, 0.5225822075567508, -0.8386145259159411], 
      ArrowBox[{{1.7151400201336666`, -2.7792139801912685`}, {
       1.6598599798663334`, -3.0664574953536925`}}]}}, 
    {Arrowheads[{{0.024092985612148617`, 1.}}], 
     {LABColor[0.1939436373986191, 0.5225866803038692, -0.8446011343537365], 
      ArrowBox[{{2.0627810114231595`, -2.778278097234046}, {
       2.0622189885768405`, -3.067393378310915}}]}}, 
    {Arrowheads[{{0.023772049520917705`, 1.}}], 
     {LABColor[0.19126941188753788`, 0.5225914553713428, -0.8509923875301908],
       ArrowBox[{{2.4154790972860134`, -2.781913588956335}, {
       2.4595209027139866`, -3.063757886588626}}]}}, 
    {Arrowheads[{{0.023437499999999983`, 1.}}], 
     {LABColor[0.1886675222501131, 0.5225961012766809, -0.8572107619122568], 
      ArrowBox[{{2.772699654770221, -2.7879605245396912`}, {
       2.852300345229779, -3.05771095100527}}]}}, 
    {Arrowheads[{{0.024142910573129308`, 1.}}], 
     {LABColor[0.19437532605167943`, 0.5225859094853883, -0.8435694220079831],
       ArrowBox[{{-2.6720793111925936`, -2.735069726424458}, \
{-2.5779206888074064`, -2.461082696282174}}]}}, 
    {Arrowheads[{{0.02459217880482063, 1.}}], 
     {LABColor[0.1984500250704274, 0.5225786337479204, -0.8338311135000597], 
      ArrowBox[{{-2.277884909706338, -2.7429704524808605`}, \
{-2.222115090293662, -2.4531819702257716`}}]}}, 
    {Arrowheads[{{0.025028319559488397`, 1.}}], 
     {LABColor[0.2027327958517151, 0.5225709864798161, -0.8235955248234473], 
      ArrowBox[{{-1.8778894863664752`, -2.748218327188698}, \
{-1.8721105136335248`, -2.447934095517934}}]}}, 
    {Arrowheads[{{0.0254123288858346, 1.}}], 
     {LABColor[0.20677045373994238`, 0.5225637768825808, -0.8139457425980378],
       ArrowBox[{{-1.4711851275141852`, -2.747802680830466}, \
{-1.5288148724858148`, -2.448349741876166}}]}}, 
    {Arrowheads[{{0.02569952802611859, 1.}}], 
     {LABColor[0.20995350614278063`, 0.5225580932594412, -0.8063384208908138],
       ArrowBox[{{-1.0581470491094642`, -2.737027460447294}, \
{-1.1918529508905358`, -2.459124962259338}}]}}, 
    {Arrowheads[{{0.02586070673771242, 1.}}], 
     {LABColor[0.21180108522326876`, 0.5225547942426847, -0.8019228076158712],
       ArrowBox[{{-0.6424129567355086, -2.709883946455442}, \
{-0.8575870432644914, -2.48626847625119}}]}}, 
    {Arrowheads[{{0.025912340446827845`, 1.}}], 
     {LABColor[0.21240226702826387`, 0.5225537207791077, -0.8004860158775229],
       ArrowBox[{{-0.23331756531354086`, -2.6620939092881875`}, \
{-0.5166824346864591, -2.5340585134184446`}}]}}, 
    {Arrowheads[{{0.025916539858333237`, 1.}}], 
     {LABColor[0.21245136025801684`, 0.52255363311878, -0.8003686857349075], 
      ArrowBox[{{
       0.1554992391499994, -2.598076211353316}, {-0.1554992391499994, \
-2.598076211353316}}]}}, 
    {Arrowheads[{{0.025912340446827845`, 1.}}], 
     {LABColor[0.21240226702826387`, 0.5225537207791077, -0.8004860158775229],
       ArrowBox[{{0.5166824346864591, -2.5340585134184446`}, {
       0.23331756531354086`, -2.6620939092881875`}}]}}, 
    {Arrowheads[{{0.02586070673771242, 1.}}], 
     {LABColor[0.21180108522326876`, 0.5225547942426847, -0.8019228076158712],
       ArrowBox[{{0.8575870432644914, -2.48626847625119}, {
       0.6424129567355086, -2.709883946455442}}]}}, 
    {Arrowheads[{{0.02569952802611859, 1.}}], 
     {LABColor[0.20995350614278063`, 0.5225580932594412, -0.8063384208908138],
       ArrowBox[{{1.1918529508905358`, -2.459124962259338}, {
       1.0581470491094642`, -2.737027460447294}}]}}, 
    {Arrowheads[{{0.0254123288858346, 1.}}], 
     {LABColor[0.20677045373994238`, 0.5225637768825808, -0.8139457425980378],
       ArrowBox[{{1.5288148724858148`, -2.448349741876166}, {
       1.4711851275141852`, -2.747802680830466}}]}}, 
    {Arrowheads[{{0.025028319559488397`, 1.}}], 
     {LABColor[0.2027327958517151, 0.5225709864798161, -0.8235955248234473], 
      ArrowBox[{{1.8721105136335248`, -2.447934095517934}, {
       1.8778894863664752`, -2.748218327188698}}]}}, 
    {Arrowheads[{{0.02459217880482063, 1.}}], 
     {LABColor[0.1984500250704274, 0.5225786337479204, -0.8338311135000597], 
      ArrowBox[{{2.222115090293662, -2.4531819702257716`}, {
       2.277884909706338, -2.7429704524808605`}}]}}, 
    {Arrowheads[{{0.024142910573129308`, 1.}}], 
     {LABColor[0.19437532605167943`, 0.5225859094853883, -0.8435694220079831],
       ArrowBox[{{2.5779206888074064`, -2.461082696282174}, {
       2.6720793111925936`, -2.735069726424458}}]}}, 
    {Arrowheads[{{0.02445822386812607, 1.}}], 
     {LABColor[0.19719932143650037`, 0.522580866990486, -0.8368202269985346], 
      ArrowBox[{{-2.883748214277058, -2.4016095596175564`}, \
{-2.741251785722942, -2.1450238102507466`}}]}}, 
    {Arrowheads[{{0.025048644541601873`, 1.}}], 
     {LABColor[0.20294024050510417`, 0.5225706160689392, -0.8230997434114394],
       ArrowBox[{{-2.4937892404626476`, -2.412669355412736}, \
{-2.3812107595373524`, -2.133964014455567}}]}}, 
    {Arrowheads[{{0.0256722240347895, 1.}}], 
     {LABColor[0.2096448822563781, 0.5225586443348369, -0.8070760151535736], 
      ArrowBox[{{-2.0980841235214847`, -2.4231834300156905`}, \
{-2.0269158764785153`, -2.1234499398526125`}}]}}, 
    {Arrowheads[{{0.026288511115827414`, 1.}}], 
     {LABColor[0.2169184265598746, 0.5225456567746342, -0.7896926408116663], 
      ArrowBox[{{-1.6947198906898773`, -2.430882425433657}, \
{-1.6802801093101227`, -2.115750944434646}}]}}, 
    {Arrowheads[{{0.02683116125936845, 1.}}], 
     {LABColor[0.22385565563704413`, 0.5225332697351771, -0.7731130415252454],
       ArrowBox[{{-1.2820763228231316`, -2.4314027488043806`}, \
{-1.3429236771768684`, -2.1152306210639225`}}]}}, 
    {Arrowheads[{{0.027219900529694776`, 1.}}], 
     {LABColor[0.22913201220125887`, 0.5225238483312962, -0.7605028369963429],
       ArrowBox[{{-0.8606406303430965, -2.417420344673995}, \
{-1.0143593696569035`, -2.129213025194308}}]}}, 
    {Arrowheads[{{0.027407983481300677`, 1.}}], 
     {LABColor[0.2317767676836434, 0.5225191258851798, -0.7541820155818091], 
      ArrowBox[{{-0.4369461020104899, -2.3795208788534348`}, \
{-0.6880538979895101, -2.1671124910148682`}}]}}, 
    {Arrowheads[{{0.027446616570634852`, 1.}}], 
     {LABColor[0.23232743228707758`, 0.5225181426245588, -0.7528659572010643],
       ArrowBox[{{-0.02776917435101467, -2.313384960911657}, \
{-0.34723082564898533`, -2.233248408956646}}]}}, 
    {Arrowheads[{{0.027446616570634852`, 1.}}], 
     {LABColor[0.23232743228707758`, 0.5225181426245588, -0.7528659572010643],
       ArrowBox[{{0.34723082564898533`, -2.233248408956646}, {
       0.02776917435101467, -2.313384960911657}}]}}, 
    {Arrowheads[{{0.027407983481300677`, 1.}}], 
     {LABColor[0.2317767676836434, 0.5225191258851798, -0.7541820155818091], 
      ArrowBox[{{0.6880538979895101, -2.1671124910148682`}, {
       0.4369461020104899, -2.3795208788534348`}}]}}, 
    {Arrowheads[{{0.02721990052969478, 1.}}], 
     {LABColor[0.22913201220125887`, 0.5225238483312962, -0.7605028369963429],
       ArrowBox[{{1.0143593696569035`, -2.129213025194308}, {
       0.8606406303430965, -2.417420344673995}}]}}, 
    {Arrowheads[{{0.02683116125936845, 1.}}], 
     {LABColor[0.22385565563704413`, 0.5225332697351771, -0.7731130415252454],
       ArrowBox[{{1.3429236771768684`, -2.1152306210639225`}, {
       1.2820763228231316`, -2.4314027488043806`}}]}}, 
    {Arrowheads[{{0.026288511115827414`, 1.}}], 
     {LABColor[0.2169184265598746, 0.5225456567746342, -0.7896926408116663], 
      ArrowBox[{{1.6802801093101227`, -2.115750944434646}, {
       1.6947198906898773`, -2.430882425433657}}]}}, 
    {Arrowheads[{{0.0256722240347895, 1.}}], 
     {LABColor[0.2096448822563781, 0.5225586443348369, -0.8070760151535736], 
      ArrowBox[{{2.0269158764785153`, -2.1234499398526125`}, {
       2.0980841235214847`, -2.4231834300156905`}}]}}, 
    {Arrowheads[{{0.025048644541601873`, 1.}}], 
     {LABColor[0.20294024050510417`, 0.5225706160689392, -0.8230997434114394],
       ArrowBox[{{2.3812107595373524`, -2.133964014455567}, {
       2.4937892404626476`, -2.412669355412736}}]}}, 
    {Arrowheads[{{0.02445822386812607, 1.}}], 
     {LABColor[0.19719932143650037`, 0.522580866990486, -0.8368202269985346], 
      ArrowBox[{{2.741251785722942, -2.1450238102507466`}, {
       2.883748214277058, -2.4016095596175564`}}]}}, 
    {Arrowheads[{{0.02541436353426367, 1.}}], 
     {LABColor[0.2067925124035188, 0.5225637374948753, -0.8138930235946975], 
      ArrowBox[{{-2.70816289693526, -2.076369395925952}, {-2.54183710306474, \
-1.8207449211040219`}}]}}, 
    {Arrowheads[{{0.02623915379222988, 1.}}], 
     {LABColor[0.21631219675978824`, 0.5225467392518552, -0.791141496983073], 
      ArrowBox[{{-2.318256695535357, -2.0904260360637856`}, \
{-2.181743304464643, -1.8066882809661884`}}]}}, 
    {Arrowheads[{{0.027140120874227448`, 1.}}], 
     {LABColor[0.22802828241991355`, 0.5225258191389774, -0.7631406909999563],
       ArrowBox[{{-1.9210879436958799`, -2.1047397543581914`}, \
{-1.8289120563041201`, -1.7923745626717826`}}]}}, 
    {Arrowheads[{{0.02805518194307648, 1.}}], 
     {LABColor[0.2413353985481123, 0.5225020580997057, -0.7313374089388969], 
      ArrowBox[{{-1.5134548673449586`, -2.116349658239075}, \
{-1.4865451326550414`, -1.7807646587908992`}}]}}, 
    {Arrowheads[{{0.028864634835633396`, 1.}}], 
     {LABColor[0.254289256561796, 0.5224789278342133, -0.7003783945123908], 
      ArrowBox[{{-1.0922705805172381`, -2.118624210854122}, \
{-1.1577294194827619`, -1.7784901061758522`}}]}}, 
    {Arrowheads[{{0.029411668930401046`, 1.}}], 
     {LABColor[0.26367218109559915`, 0.5224621737880186, -0.6779537164205068],
       ArrowBox[{{-0.6581647430711206, -2.099248735182634}, \
{-0.8418352569288794, -1.79786558184734}}]}}, 
    {Arrowheads[{{0.029621489104600735`, 1.}}], 
     {LABColor[0.2674056200608809, 0.5224555074007249, -0.6690310008353473], 
      ArrowBox[{{-0.22418717204639924`, -2.042594731476548}, \
{-0.5258128279536007, -1.854519585553426}}]}}, 
    {Arrowheads[{{0.029640918410834577`, 1.}}], 
     {LABColor[0.2677551090490836, 0.5224548833570558, -0.668195741207193], 
      ArrowBox[{{
       0.17784551046500746`, -1.948557158514987}, {-0.17784551046500746`, \
-1.948557158514987}}]}}, 
    {Arrowheads[{{0.029621489104600707`, 1.}}], 
     {LABColor[0.2674056200608809, 0.5224555074007249, -0.6690310008353473], 
      ArrowBox[{{0.5258128279536007, -1.8545195855534264`}, {
       0.22418717204639926`, -2.0425947314765476`}}]}}, 
    {Arrowheads[{{0.029411668930401046`, 1.}}], 
     {LABColor[0.26367218109559915`, 0.5224621737880186, -0.6779537164205068],
       ArrowBox[{{0.8418352569288794, -1.79786558184734}, {
       0.6581647430711206, -2.099248735182634}}]}}, 
    {Arrowheads[{{0.028864634835633396`, 1.}}], 
     {LABColor[0.254289256561796, 0.5224789278342133, -0.7003783945123908], 
      ArrowBox[{{1.1577294194827619`, -1.7784901061758522`}, {
       1.0922705805172381`, -2.118624210854122}}]}}, 
    {Arrowheads[{{0.028055181943076463`, 1.}}], 
     {LABColor[0.2413353985481123, 0.5225020580997057, -0.7313374089388969], 
      ArrowBox[{{1.4865451326550414`, -1.7807646587908992`}, {
       1.5134548673449586`, -2.116349658239075}}]}}, 
    {Arrowheads[{{0.027140120874227486`, 1.}}], 
     {LABColor[0.22802828241991355`, 0.5225258191389774, -0.7631406909999563],
       ArrowBox[{{1.8289120563041201`, -1.7923745626717822`}, {
       1.9210879436958799`, -2.104739754358192}}]}}, 
    {Arrowheads[{{0.02623915379222988, 1.}}], 
     {LABColor[0.21631219675978824`, 0.5225467392518552, -0.791141496983073], 
      ArrowBox[{{2.181743304464643, -1.8066882809661884`}, {
       2.318256695535357, -2.0904260360637856`}}]}}, 
    {Arrowheads[{{0.025414363534263625`, 1.}}], 
     {LABColor[0.2067925124035188, 0.5225637374948753, -0.8138930235946975], 
      ArrowBox[{{2.54183710306474, -1.8207449211040223`}, {
       2.70816289693526, -2.0763693959259517`}}]}}, 
    {Arrowheads[{{0.02564556258633195, 1.}}], 
     {LABColor[0.20934474005279885`, 0.5225591802654336, -0.8077933386567955],
       ArrowBox[{{-2.9191919894920852`, -1.7346752000323606`}, \
{-2.7058080105079148`, -1.5129200641592844`}}]}}, 
    {Arrowheads[{{0.026652399012847175`, 1.}}], 
     {LABColor[0.22151525667467525`, 0.5225374487256601, -0.7787064674500331],
       ArrowBox[{{-2.5357490644612675`, -1.7499710633938828`}, \
{-2.3392509355387325`, -1.4976242007977623`}}]}}, 
    {Arrowheads[{{0.027846338179285696`, 1.}}], 
     {LABColor[0.2381733809463524, 0.5225077041633374, -0.7388944586183316], 
      ArrowBox[{{-2.146795011651649, -1.7680523332686908`}, \
{-1.978204988348351, -1.4795429309229542`}}]}}, 
    {Arrowheads[{{0.029213867724144613`, 1.}}], 
     {LABColor[0.26022090486804267`, 0.5224683363486509, -0.6862020784456201],
       ArrowBox[{{-1.7486238659346849`, -1.788078110058775}, \
{-1.6263761340653151`, -1.45951715413287}}]}}, 
    {Arrowheads[{{0.03066314968831119, 1.}}], 
     {LABColor[0.2870447701216108, 0.5224204399517479, -0.6220945028891611], 
      ArrowBox[{{-1.335583431050897, -1.8063226719341925`}, \
{-1.289416568949103, -1.4412725922574525`}}]}}, 
    {Arrowheads[{{0.031962857677327976`, 1.}}], 
     {LABColor[0.31412698794222316`, 0.522372082243361, -0.5573694787824862], 
      ArrowBox[{{-0.9012575260263594, -1.8121190510388372`}, \
{-0.9737424739736406, -1.4354762131528078`}}]}}, 
    {Arrowheads[{{0.03277096204113039, 1.}}], 
     {LABColor[0.3324085415233697, 0.5223394389036317, -0.5136775624082455], 
      ArrowBox[{{-0.446431555413751, -1.78251061355283}, {-0.678568444586249, \
-1.465084650638815}}]}}, 
    {Arrowheads[{{0.032979743251898716`, 1.}}], 
     {LABColor[0.33731160232222035`, 0.5223306840525377, -0.5019595144070006],
       ArrowBox[{{-0.0010763361577331432`, -1.6901459726796473`}, \
{-0.37392366384226683`, -1.5574492915119977`}}]}}, 
    {Arrowheads[{{0.032979743251898716`, 1.}}], 
     {LABColor[0.33731160232222035`, 0.5223306840525377, -0.5019595144070006],
       ArrowBox[{{0.37392366384226683`, -1.5574492915119977`}, {
       0.0010763361577331432`, -1.6901459726796473`}}]}}, 
    {Arrowheads[{{0.03277096204113039, 1.}}], 
     {LABColor[0.3324085415233697, 0.5223394389036317, -0.5136775624082455], 
      ArrowBox[{{0.678568444586249, -1.465084650638815}, {
       0.446431555413751, -1.78251061355283}}]}}, 
    {Arrowheads[{{0.031962857677327976`, 1.}}], 
     {LABColor[0.31412698794222316`, 0.522372082243361, -0.5573694787824862], 
      ArrowBox[{{0.9737424739736407, -1.4354762131528078`}, {
       0.9012575260263593, -1.8121190510388372`}}]}}, 
    {Arrowheads[{{0.03066314968831119, 1.}}], 
     {LABColor[0.2870447701216108, 0.5224204399517479, -0.6220945028891611], 
      ArrowBox[{{1.289416568949103, -1.4412725922574525`}, {
       1.335583431050897, -1.8063226719341925`}}]}}, 
    {Arrowheads[{{0.029213867724144613`, 1.}}], 
     {LABColor[0.26022090486804267`, 0.5224683363486509, -0.6862020784456201],
       ArrowBox[{{1.6263761340653151`, -1.45951715413287}, {
       1.7486238659346849`, -1.788078110058775}}]}}, 
    {Arrowheads[{{0.027846338179285685`, 1.}}], 
     {LABColor[0.2381733809463524, 0.5225077041633374, -0.7388944586183316], 
      ArrowBox[{{1.978204988348351, -1.4795429309229542`}, {
       2.146795011651649, -1.7680523332686908`}}]}}, 
    {Arrowheads[{{0.026652399012847175`, 1.}}], 
     {LABColor[0.22151525667467525`, 0.5225374487256601, -0.7787064674500331],
       ArrowBox[{{2.3392509355387325`, -1.4976242007977623`}, {
       2.5357490644612675`, -1.7499710633938828`}}]}}, 
    {Arrowheads[{{0.02564556258633195, 1.}}], 
     {LABColor[0.20934474005279885`, 0.5225591802654336, -0.8077933386567955],
       ArrowBox[{{2.7058080105079148`, -1.5129200641592844`}, {
       2.9191919894920852`, -1.7346752000323606`}}]}}, 
    {Arrowheads[{{0.026850507569419136`, 1.}}], 
     {LABColor[0.22411218904904032`, 0.5225328116719561, -0.7724999406564169],
       ArrowBox[{{-2.7480001430290355`, -1.4030821158709623`}, \
{-2.5019998569709645`, -1.1949940954823537`}}]}}, 
    {Arrowheads[{{0.02828171592279591, 1.}}], 
     {LABColor[0.24484880781281154`, 0.52249578459501, -0.7229405523424185], 
      ArrowBox[{{-2.367659050289708, -1.4213129775199036`}, \
{-2.132340949710292, -1.1767632338334124`}}]}}, 
    {Arrowheads[{{0.03008105930891509, 1.}}], 
     {LABColor[0.2758435971464585, 0.5224404406422347, -0.6488646956275107], 
      ArrowBox[{{-1.981541326467938, -1.4447236245305408`}, \
{-1.768458673532062, -1.1533525868227752`}}]}}, 
    {Arrowheads[{{0.03228708754440001, 1.}}], 
     {LABColor[0.32132905889006713`, 0.5223592223051909, -0.5401569218639614],
       ArrowBox[{{-1.5839893664899418`, -1.4736067257439807`}, \
{-1.4160106335100582`, -1.1244694856093354`}}]}}, 
    {Arrowheads[{{0.03479066947316373, 1.}}], 
     {LABColor[0.3829382063657235, 0.5222492136933654, -0.39291441824158374`],
       ArrowBox[{{-1.1644489111591876`, -1.5040206609696094`}, \
{-1.0855510888408124`, -1.0940555503837066`}}]}}, 
    {Arrowheads[{{0.037110404208666445`, 1.}}], 
     {LABColor[0.4557863577416988, 0.5256979625328675, -0.10841768774869784`],
       ArrowBox[{{-0.707920756890336, -1.5176882667066003`}, \
{-0.792079243109664, -1.0803879446467157`}}]}}, 
    {Arrowheads[{{0.03837860828705306, 1.}}], 
     {LABColor[0.5013931864840477, 0.5286697834243934, 0.0947618714438691], 
      ArrowBox[{{-0.21533533839240349`, -1.4649664893232475`}, \
{-0.5346646616075965, -1.1331097220300685`}}]}}, 
    {Arrowheads[{{0.03853652819987618, 1.}}], 
     {LABColor[0.5072884666776927, 0.5290539302138983, 0.12102549169750049`], 
      ArrowBox[{{
       0.23121916919925706`, -1.299038105676658}, {-0.23121916919925706`, \
-1.299038105676658}}]}}, 
    {Arrowheads[{{0.03837860828705306, 1.}}], 
     {LABColor[0.5013931864840477, 0.5286697834243934, 0.0947618714438691], 
      ArrowBox[{{0.5346646616075965, -1.1331097220300685`}, {
       0.21533533839240349`, -1.4649664893232475`}}]}}, 
    {Arrowheads[{{0.037110404208666445`, 1.}}], 
     {LABColor[0.4557863577416988, 0.5256979625328675, -0.10841768774869784`],
       ArrowBox[{{0.792079243109664, -1.0803879446467157`}, {
       0.707920756890336, -1.5176882667066003`}}]}}, 
    {Arrowheads[{{0.03479066947316373, 1.}}], 
     {LABColor[0.3829382063657235, 0.5222492136933654, -0.39291441824158374`],
       ArrowBox[{{1.0855510888408124`, -1.0940555503837066`}, {
       1.1644489111591876`, -1.5040206609696094`}}]}}, 
    {Arrowheads[{{0.03228708754440001, 1.}}], 
     {LABColor[0.32132905889006713`, 0.5223592223051909, -0.5401569218639614],
       ArrowBox[{{1.4160106335100582`, -1.1244694856093354`}, {
       1.5839893664899418`, -1.4736067257439807`}}]}}, 
    {Arrowheads[{{0.030081059308915078`, 1.}}], 
     {LABColor[0.2758435971464585, 0.5224404406422347, -0.6488646956275107], 
      ArrowBox[{{1.768458673532062, -1.1533525868227752`}, {
       1.981541326467938, -1.4447236245305408`}}]}}, 
    {Arrowheads[{{0.02828171592279591, 1.}}], 
     {LABColor[0.24484880781281154`, 0.52249578459501, -0.7229405523424185], 
      ArrowBox[{{2.132340949710292, -1.1767632338334124`}, {
       2.367659050289708, -1.4213129775199036`}}]}}, 
    {Arrowheads[{{0.026850507569419136`, 1.}}], 
     {LABColor[0.22411218904904032`, 0.5225328116719561, -0.7724999406564169],
       ArrowBox[{{2.5019998569709645`, -1.1949940954823537`}, {
       2.7480001430290355`, -1.4030821158709623`}}]}}, 
    {Arrowheads[{{0.026809627384801225`, 1.}}], 
     {LABColor[0.2235708607107115, 0.5225337782618454, -0.7737936858725598], 
      ArrowBox[{{-2.95328042055846, -1.052099485997334}, {-2.67171957944154, \
-0.896457672517653}}]}}, 
    {Arrowheads[{{0.028367203129640254`, 1.}}], 
     {LABColor[0.24619726068955256`, 0.5224933768124784, -0.7197178234827699],
       ArrowBox[{{-2.5801009634626286`, -1.0671984420526346`}, \
{-2.2948990365373714`, -0.8813587164623524}}]}}, 
    {Arrowheads[{{0.030451139054922305`, 1.}}], 
     {LABColor[0.2828985795232711, 0.5224278433437892, -0.6320036723746879], 
      ArrowBox[{{-2.205340691845564, -1.0882010268426834`}, \
{-1.919659308154436, -0.8603561316723036}}]}}, 
    {Arrowheads[{{0.03328234517749694, 1.}}], 
     {LABColor[0.34454905880859693`, 0.5223177609303418, -0.4846623879805527],
       ArrowBox[{{-1.8259629255059502`, -1.1181734724220518`}, \
{-1.5490370744940498`, -0.8303836860929352}}]}}, 
    {Arrowheads[{{0.03711615906347244, 1.}}], 
     {LABColor[0.4559863377432851, 0.5257109935802565, -0.10752677185539616`],
       ArrowBox[{{-1.43395444077979, -1.160940713353748}, {-1.19104555922021, \
-0.7876164451612391}}]}}, 
    {Arrowheads[{{0.04199733793455592, 1.}}], 
     {LABColor[0.6473388731499926, 0.5314188303613416, 0.7337196395781556], 
      ArrowBox[{{-1.0088176980704864`, -1.2159596420471572`}, \
{-0.8661823019295136, -0.7325975164678298}}]}}, 
    {Arrowheads[{{0.046875, 1.}}], 
     {LABColor[0.8167969189733053, 0.14500114740169545`, 0.8282532063436999], 
      ArrowBox[{{-0.5093487459830774, -1.2504605965874214`}, \
{-0.6156512540169226, -0.6980965619275656}}]}}, 
    {Arrowheads[{{0.04687499999999999, 1.}}], 
     {LABColor[0.8167969189733053, 0.14500114740169545`, 0.8282532063436999], 
      ArrowBox[{{
       0.05115617577028031, -1.1230898431682104`}, {-0.4261561757702803, \
-0.8254673153467766}}]}}, 
    {Arrowheads[{{0.046875, 1.}}], 
     {LABColor[0.8167969189733053, 0.14500114740169545`, 0.8282532063436999], 
      ArrowBox[{{
       0.4261561757702803, -0.8254673153467764}, {-0.05115617577028031, \
-1.1230898431682106`}}]}}, 
    {Arrowheads[{{0.046875, 1.}}], 
     {LABColor[0.8167969189733053, 0.14500114740169545`, 0.8282532063436999], 
      ArrowBox[{{0.6156512540169226, -0.6980965619275656}, {
       0.5093487459830774, -1.2504605965874214`}}]}}, 
    {Arrowheads[{{0.04199733793455592, 1.}}], 
     {LABColor[0.6473388731499926, 0.5314188303613416, 0.7337196395781556], 
      ArrowBox[{{0.8661823019295138, -0.7325975164678298}, {
       1.0088176980704862`, -1.2159596420471572`}}]}}, 
    {Arrowheads[{{0.03711615906347244, 1.}}], 
     {LABColor[0.4559863377432851, 0.5257109935802565, -0.10752677185539616`],
       ArrowBox[{{1.19104555922021, -0.7876164451612391}, {
       1.43395444077979, -1.160940713353748}}]}}, 
    {Arrowheads[{{0.03328234517749693, 1.}}], 
     {LABColor[0.34454905880859693`, 0.5223177609303418, -0.4846623879805527],
       ArrowBox[{{1.5490370744940498`, -0.8303836860929354}, {
       1.8259629255059502`, -1.1181734724220516`}}]}}, 
    {Arrowheads[{{0.030451139054922305`, 1.}}], 
     {LABColor[0.2828985795232711, 0.5224278433437892, -0.6320036723746879], 
      ArrowBox[{{1.919659308154436, -0.8603561316723036}, {
       2.205340691845564, -1.0882010268426834`}}]}}, 
    {Arrowheads[{{0.028367203129640254`, 1.}}], 
     {LABColor[0.24619726068955256`, 0.5224933768124784, -0.7197178234827699],
       ArrowBox[{{2.2948990365373714`, -0.8813587164623524}, {
       2.5801009634626286`, -1.0671984420526346`}}]}}, 
    {Arrowheads[{{0.026809627384801225`, 1.}}], 
     {LABColor[0.2235708607107115, 0.5225337782618454, -0.7737936858725598], 
      ArrowBox[{{2.67171957944154, -0.896457672517653}, {
       2.95328042055846, -1.052099485997334}}]}}, 
    {Arrowheads[{{0.02810565871841034, 1.}}], 
     {LABColor[0.24211073540815065`, 0.5225006736667901, -0.7294843961136851],
       ArrowBox[{{-2.782485442137536, -0.7098161952796751}, \
{-2.467514557862464, -0.5892219103969829}}]}}, 
    {Arrowheads[{{0.03025212659831732, 1.}}], 
     {LABColor[0.2790758828300792, 0.5224346691086938, -0.641139709063346], 
      ArrowBox[{{-2.41541133980884, -0.724258403628838}, {-2.08458866019116, \
-0.57477970204782}}]}}, 
    {Arrowheads[{{0.0333351144545491, 1.}}], 
     {LABColor[0.3458270497244331, 0.5223154789639076, -0.4816080593659793], 
      ArrowBox[{{-2.0500464997113803`, -0.7462816372597763}, \
{-1.6999535002886197`, -0.5527564684168818}}]}}, 
    {Arrowheads[{{0.03796741126590752, 1.}}], 
     {LABColor[0.4862675220880942, 0.5276841686230651, 0.02737665942164308], 
      ArrowBox[{{-1.685159514378871, -0.7822248541110123}, \
{-1.314840485621129, -0.5168132515656457}}]}}, 
    {Arrowheads[{{0.045226256335402844`, 1.}}], 
     {LABColor[0.7558791484422168, 0.28391283864257394`, 0.794269726245545], 
      ArrowBox[{{-1.3131525994783535`, -0.8450529699619285}, \
{-0.9368474005216465, -0.45398513571472954`}}]}}, 
    {Arrowheads[{{0.04687499999999998, 1.}}], 
     {LABColor[0.8167969189733053, 0.14500114740169545`, 0.8282532063436999], 
      ArrowBox[{{-0.8719373394643293, -0.9029610535887194}, \
{-0.6280626605356707, -0.39607705208793864`}}]}}, 
    {Arrowheads[{{0.046875, 1.}}], 
     {LABColor[0.8167969189733053, 0.14500114740169545`, 0.8282532063436999], 
      ArrowBox[{{-0.32184874598307744`, -0.9257010701682569}, \
{-0.42815125401692256`, -0.37333703550840114`}}]}}, 
    {Arrowheads[{{0.046875, 1.}}], 
     {LABColor[0.8167969189733053, 0.14500114740169545`, 0.8282532063436999], 
      ArrowBox[{{
       0.28125, -0.649519052838329}, {-0.28125, -0.649519052838329}}]}}, 
    {Arrowheads[{{0.046875, 1.}}], 
     {LABColor[0.8167969189733053, 0.14500114740169545`, 0.8282532063436999], 
      ArrowBox[{{0.42815125401692256`, -0.37333703550840114`}, {
       0.32184874598307744`, -0.9257010701682569}}]}}, 
    {Arrowheads[{{0.04687499999999998, 1.}}], 
     {LABColor[0.8167969189733053, 0.14500114740169545`, 0.8282532063436999], 
      ArrowBox[{{0.6280626605356707, -0.39607705208793864`}, {
       0.8719373394643293, -0.9029610535887194}}]}}, 
    {Arrowheads[{{0.045226256335402844`, 1.}}], 
     {LABColor[0.7558791484422168, 0.28391283864257394`, 0.794269726245545], 
      ArrowBox[{{0.9368474005216465, -0.45398513571472954`}, {
       1.3131525994783535`, -0.8450529699619285}}]}}, 
    {Arrowheads[{{0.03796741126590752, 1.}}], 
     {LABColor[0.4862675220880942, 0.5276841686230651, 0.02737665942164308], 
      ArrowBox[{{1.314840485621129, -0.5168132515656457}, {
       1.685159514378871, -0.7822248541110123}}]}}, 
    {Arrowheads[{{0.0333351144545491, 1.}}], 
     {LABColor[0.3458270497244331, 0.5223154789639076, -0.4816080593659793], 
      ArrowBox[{{1.6999535002886197`, -0.5527564684168818}, {
       2.0500464997113803`, -0.7462816372597763}}]}}, 
    {Arrowheads[{{0.03025212659831732, 1.}}], 
     {LABColor[0.2790758828300792, 0.5224346691086938, -0.641139709063346], 
      ArrowBox[{{2.08458866019116, -0.57477970204782}, {
       2.41541133980884, -0.724258403628838}}]}}, 
    {Arrowheads[{{0.02810565871841034, 1.}}], 
     {LABColor[0.24211073540815065`, 0.5225006736667901, -0.7294843961136851],
       ArrowBox[{{2.467514557862464, -0.5892219103969829}, {
       2.782485442137536, -0.7098161952796751}}]}}, 
    {Arrowheads[{{0.027573858518466474`, 1.}}], 
     {LABColor[0.23415898120453443`, 0.5225148722310838, -0.7484886551418244],
       ArrowBox[{{-2.9754840171029775`, -0.35317864706789254`}, \
{-2.6495159828970225`, -0.29634040577043647`}}]}}, 
    {Arrowheads[{{0.02958008895936484, 1.}}], 
     {LABColor[0.26666305908345656`, 0.5224568333093873, -0.670805681088007], 
      ArrowBox[{{-2.6114788366834474`, -0.3598409210416149}, \
{-2.2635211633165526`, -0.2896781317967141}}]}}, 
    {Arrowheads[{{0.03250151412043147, 1.}}], 
     {LABColor[0.32618993159858073`, 0.5223505427846841, -0.5285397010985866],
       ArrowBox[{{-2.252160731696724, -0.3701175464002553}, \
{-1.872839268303276, -0.2794015064380737}}]}}, 
    {Arrowheads[{{0.03703693231193715, 1.}}], 
     {LABColor[0.4532388127922376, 0.5255319600391252, -0.11976706401818038`],
       ArrowBox[{{-1.9006914891581723`, -0.3874637984695233}, \
{-1.4743085108418277`, -0.2620552543688057}}]}}, 
    {Arrowheads[{{0.044728291363011714`, 1.}}], 
     {LABColor[0.7382107863887094, 0.32420226540444685`, 0.7844132849316604], 
      ArrowBox[{{-1.5631276338133393`, -0.42071842859237385`}, \
{-1.0618723661866607`, -0.22880062424595515`}}]}}, 
    {Arrowheads[{{0.04687500000000001, 1.}}], 
     {LABColor[0.8167969189733053, 0.14500114740169545`, 0.8282532063436999], 
      ArrowBox[{{-1.1836459877439003`, -0.46082464030799253`}, \
{-0.6913540122560997, -0.18869441253033647`}}]}}, 
    {Arrowheads[{{0.04687499999999999, 1.}}], 
     {LABColor[0.8167969189733053, 0.14500114740169545`, 0.8282532063436999], 
      ArrowBox[{{-0.757511787735432, -0.5274217210787279}, \
{-0.36748821226456796`, -0.12209733175960114`}}]}}, 
    {Arrowheads[{{0.046875, 1.}}], 
     {LABColor[0.8167969189733053, 0.14500114740169545`, 0.8282532063436999], 
      ArrowBox[{{-0.13434874598307744`, -0.6009415437490924}, \
{-0.24065125401692256`, -0.04857750908923664}}]}}, 
    {Arrowheads[{{0.046875, 1.}}], 
     {LABColor[0.8167969189733053, 0.14500114740169545`, 0.8282532063436999], 
      ArrowBox[{{0.24065125401692256`, -0.04857750908923664}, {
       0.13434874598307744`, -0.6009415437490924}}]}}, 
    {Arrowheads[{{0.04687499999999999, 1.}}], 
     {LABColor[0.8167969189733053, 0.14500114740169545`, 0.8282532063436999], 
      ArrowBox[{{0.36748821226456796`, -0.12209733175960114`}, {
       0.757511787735432, -0.5274217210787279}}]}}, 
    {Arrowheads[{{0.04687500000000001, 1.}}], 
     {LABColor[0.8167969189733053, 0.14500114740169545`, 0.8282532063436999], 
      ArrowBox[{{0.6913540122560997, -0.18869441253033647`}, {
       1.1836459877439003`, -0.46082464030799253`}}]}}, 
    {Arrowheads[{{0.044728291363011714`, 1.}}], 
     {LABColor[0.7382107863887094, 0.32420226540444685`, 0.7844132849316604], 
      ArrowBox[{{1.0618723661866607`, -0.22880062424595515`}, {
       1.5631276338133393`, -0.42071842859237385`}}]}}, 
    {Arrowheads[{{0.03703693231193715, 1.}}], 
     {LABColor[0.4532388127922376, 0.5255319600391252, -0.11976706401818038`],
       ArrowBox[{{1.4743085108418277`, -0.2620552543688057}, {
       1.9006914891581723`, -0.3874637984695233}}]}}, 
    {Arrowheads[{{0.03250151412043145, 1.}}], 
     {LABColor[0.32618993159858073`, 0.5223505427846841, -0.5285397010985866],
       ArrowBox[{{1.872839268303276, -0.2794015064380737}, {
       2.252160731696724, -0.3701175464002553}}]}}, 
    {Arrowheads[{{0.02958008895936484, 1.}}], 
     {LABColor[0.26666305908345656`, 0.5224568333093873, -0.670805681088007], 
      ArrowBox[{{2.2635211633165526`, -0.2896781317967141}, {
       2.6114788366834474`, -0.3598409210416149}}]}}, 
    {Arrowheads[{{0.027573858518466474`, 1.}}], 
     {LABColor[0.23415898120453443`, 0.5225148722310838, -0.7484886551418244],
       ArrowBox[{{2.6495159828970225`, -0.29634040577043647`}, {
       2.9754840171029775`, -0.35317864706789254`}}]}}, 
    {Arrowheads[{{0.02862569546919654, 1.}}], 
     {LABColor[0.2503499755138172, 0.5224859617708516, -0.709793061452974], 
      ArrowBox[{{-2.796754172815179, 0.}, {-2.453245827184821, 0.}}]}}, 
    {Arrowheads[{{0.03112600639725079, 1.}}], 
     {LABColor[0.2963612552550051, 0.5224038045390113, -0.599828611342071], 
      ArrowBox[{{-2.4367560383835047`, 0.}, {-2.0632439616164953`, 0.}}]}}, 
    {Arrowheads[{{0.03493550779380442, 1.}}], 
     {LABColor[
      0.38682740168408847`, 0.5222422691892517, -0.38361945346417364`], 
      ArrowBox[{{-2.0846130467628265`, 0.}, {-1.6653869532371735`, 0.}}]}}, 
    {Arrowheads[{{0.04126480904226896, 1.}}], 
     {LABColor[0.6166968282743448, 0.5361831708049819, 0.6084424705620526], 
      ArrowBox[{{-1.7475888542536138`, 0.}, {-1.2524111457463862`, 0.}}]}}, 
    {Arrowheads[{{0.046875, 1.}}], 
     {LABColor[0.8167969189733053, 0.14500114740169545`, 0.8282532063436999], 
      ArrowBox[{{-1.40625, 0.}, {-0.84375, 0.}}]}}, 
    {Arrowheads[{{0.046875, 1.}}], 
     {LABColor[0.8167969189733053, 0.14500114740169545`, 0.8282532063436999], 
      ArrowBox[{{-1.03125, 0.}, {-0.46875, 0.}}]}}, 
    {Arrowheads[{{0.046875, 1.}}], 
     {LABColor[0.8167969189733053, 0.14500114740169545`, 0.8282532063436999], 
      ArrowBox[{{-0.65625, 0.}, {-0.09375, 0.}}]}}, 
    {Arrowheads[{{0.046875, 1.}}], 
     {LABColor[0.8167969189733053, 0.14500114740169545`, 0.8282532063436999], 
      ArrowBox[{{-0.28125, 0.}, {0.28125, 0.}}]}}, 
    {Arrowheads[{{0.046875, 1.}}], 
     {LABColor[0.8167969189733053, 0.14500114740169545`, 0.8282532063436999], 
      ArrowBox[{{0.09375, 0.}, {0.65625, 0.}}]}}, 
    {Arrowheads[{{0.046875, 1.}}], 
     {LABColor[0.8167969189733053, 0.14500114740169545`, 0.8282532063436999], 
      ArrowBox[{{0.46875, 0.}, {1.03125, 0.}}]}}, 
    {Arrowheads[{{0.046875, 1.}}], 
     {LABColor[0.8167969189733053, 0.14500114740169545`, 0.8282532063436999], 
      ArrowBox[{{0.84375, 0.}, {1.40625, 0.}}]}}, 
    {Arrowheads[{{0.04126480904226896, 1.}}], 
     {LABColor[0.6166968282743448, 0.5361831708049819, 0.6084424705620526], 
      ArrowBox[{{1.2524111457463862`, 0.}, {1.7475888542536138`, 0.}}]}}, 
    {Arrowheads[{{0.03493550779380442, 1.}}], 
     {LABColor[
      0.38682740168408847`, 0.5222422691892517, -0.38361945346417364`], 
      ArrowBox[{{1.6653869532371735`, 0.}, {2.0846130467628265`, 0.}}]}}, 
    {Arrowheads[{{0.03112600639725079, 1.}}], 
     {LABColor[0.2963612552550051, 0.5224038045390113, -0.599828611342071], 
      ArrowBox[{{2.0632439616164953`, 0.}, {2.4367560383835047`, 0.}}]}}, 
    {Arrowheads[{{0.02862569546919654, 1.}}], 
     {LABColor[0.2503499755138172, 0.5224859617708516, -0.709793061452974], 
      ArrowBox[{{2.453245827184821, 0.}, {2.796754172815179, 0.}}]}}, 
    {Arrowheads[{{0.027573858518466474`, 1.}}], 
     {LABColor[0.23415898120453443`, 0.5225148722310838, -0.7484886551418244],
       ArrowBox[{{-2.9754840171029775`, 
       0.35317864706789254`}, {-2.6495159828970225`, 
       0.29634040577043647`}}]}}, 
    {Arrowheads[{{0.02958008895936484, 1.}}], 
     {LABColor[0.26666305908345656`, 0.5224568333093873, -0.670805681088007], 
      ArrowBox[{{-2.6114788366834474`, 
       0.3598409210416149}, {-2.2635211633165526`, 0.2896781317967141}}]}}, 
    {Arrowheads[{{0.03250151412043147, 1.}}], 
     {LABColor[0.32618993159858073`, 0.5223505427846841, -0.5285397010985866],
       ArrowBox[{{-2.252160731696724, 
       0.3701175464002553}, {-1.872839268303276, 0.2794015064380737}}]}}, 
    {Arrowheads[{{0.03703693231193715, 1.}}], 
     {LABColor[0.4532388127922376, 0.5255319600391252, -0.11976706401818038`],
       ArrowBox[{{-1.9006914891581723`, 
       0.3874637984695233}, {-1.4743085108418277`, 0.2620552543688057}}]}}, 
    {Arrowheads[{{0.044728291363011714`, 1.}}], 
     {LABColor[0.7382107863887094, 0.32420226540444685`, 0.7844132849316604], 
      ArrowBox[{{-1.5631276338133393`, 
       0.42071842859237385`}, {-1.0618723661866607`, 
       0.22880062424595515`}}]}}, 
    {Arrowheads[{{0.04687500000000001, 1.}}], 
     {LABColor[0.8167969189733053, 0.14500114740169545`, 0.8282532063436999], 
      ArrowBox[{{-1.1836459877439003`, 
       0.46082464030799253`}, {-0.6913540122560997, 0.18869441253033647`}}]}}, 
    {Arrowheads[{{0.04687499999999999, 1.}}], 
     {LABColor[0.8167969189733053, 0.14500114740169545`, 0.8282532063436999], 
      ArrowBox[{{-0.757511787735432, 
       0.5274217210787279}, {-0.36748821226456796`, 0.12209733175960114`}}]}}, 
    {Arrowheads[{{0.046875, 1.}}], 
     {LABColor[0.8167969189733053, 0.14500114740169545`, 0.8282532063436999], 
      ArrowBox[{{-0.13434874598307744`, 
       0.6009415437490924}, {-0.24065125401692256`, 
       0.04857750908923664}}]}}, 
    {Arrowheads[{{0.046875, 1.}}], 
     {LABColor[0.8167969189733053, 0.14500114740169545`, 0.8282532063436999], 
      ArrowBox[{{0.24065125401692256`, 0.04857750908923664}, {
       0.13434874598307744`, 0.6009415437490924}}]}}, 
    {Arrowheads[{{0.04687499999999999, 1.}}], 
     {LABColor[0.8167969189733053, 0.14500114740169545`, 0.8282532063436999], 
      ArrowBox[{{0.36748821226456796`, 0.12209733175960114`}, {
       0.757511787735432, 0.5274217210787279}}]}}, 
    {Arrowheads[{{0.04687500000000001, 1.}}], 
     {LABColor[0.8167969189733053, 0.14500114740169545`, 0.8282532063436999], 
      ArrowBox[{{0.6913540122560997, 0.18869441253033647`}, {
       1.1836459877439003`, 0.46082464030799253`}}]}}, 
    {Arrowheads[{{0.044728291363011714`, 1.}}], 
     {LABColor[0.7382107863887094, 0.32420226540444685`, 0.7844132849316604], 
      ArrowBox[{{1.0618723661866607`, 0.22880062424595515`}, {
       1.5631276338133393`, 0.42071842859237385`}}]}}, 
    {Arrowheads[{{0.03703693231193715, 1.}}], 
     {LABColor[0.4532388127922376, 0.5255319600391252, -0.11976706401818038`],
       ArrowBox[{{1.4743085108418277`, 0.2620552543688057}, {
       1.9006914891581723`, 0.3874637984695233}}]}}, 
    {Arrowheads[{{0.03250151412043145, 1.}}], 
     {LABColor[0.32618993159858073`, 0.5223505427846841, -0.5285397010985866],
       ArrowBox[{{1.872839268303276, 0.2794015064380737}, {2.252160731696724, 
       0.3701175464002553}}]}}, 
    {Arrowheads[{{0.02958008895936484, 1.}}], 
     {LABColor[0.26666305908345656`, 0.5224568333093873, -0.670805681088007], 
      ArrowBox[{{2.2635211633165526`, 0.2896781317967141}, {
       2.6114788366834474`, 0.3598409210416149}}]}}, 
    {Arrowheads[{{0.027573858518466474`, 1.}}], 
     {LABColor[0.23415898120453443`, 0.5225148722310838, -0.7484886551418244],
       ArrowBox[{{2.6495159828970225`, 0.29634040577043647`}, {
       2.9754840171029775`, 0.35317864706789254`}}]}}, 
    {Arrowheads[{{0.02810565871841034, 1.}}], 
     {LABColor[0.24211073540815065`, 0.5225006736667901, -0.7294843961136851],
       ArrowBox[{{-2.782485442137536, 
       0.7098161952796751}, {-2.467514557862464, 0.5892219103969829}}]}}, 
    {Arrowheads[{{0.03025212659831732, 1.}}], 
     {LABColor[0.2790758828300792, 0.5224346691086938, -0.641139709063346], 
      ArrowBox[{{-2.41541133980884, 0.724258403628838}, {-2.08458866019116, 
       0.57477970204782}}]}}, 
    {Arrowheads[{{0.0333351144545491, 1.}}], 
     {LABColor[0.3458270497244331, 0.5223154789639076, -0.4816080593659793], 
      ArrowBox[{{-2.0500464997113803`, 
       0.7462816372597763}, {-1.6999535002886197`, 0.5527564684168818}}]}}, 
    {Arrowheads[{{0.03796741126590752, 1.}}], 
     {LABColor[0.4862675220880942, 0.5276841686230651, 0.02737665942164308], 
      ArrowBox[{{-1.685159514378871, 0.7822248541110123}, {-1.314840485621129,
        0.5168132515656457}}]}}, 
    {Arrowheads[{{0.045226256335402844`, 1.}}], 
     {LABColor[0.7558791484422168, 0.28391283864257394`, 0.794269726245545], 
      ArrowBox[{{-1.3131525994783535`, 
       0.8450529699619285}, {-0.9368474005216465, 0.45398513571472954`}}]}}, 
    {Arrowheads[{{0.04687499999999998, 1.}}], 
     {LABColor[0.8167969189733053, 0.14500114740169545`, 0.8282532063436999], 
      ArrowBox[{{-0.8719373394643293, 
       0.9029610535887194}, {-0.6280626605356707, 0.39607705208793864`}}]}}, 
    {Arrowheads[{{0.046875, 1.}}], 
     {LABColor[0.8167969189733053, 0.14500114740169545`, 0.8282532063436999], 
      ArrowBox[{{-0.32184874598307744`, 
       0.9257010701682569}, {-0.42815125401692256`, 0.37333703550840114`}}]}}, 
    {Arrowheads[{{0.046875, 1.}}], 
     {LABColor[0.8167969189733053, 0.14500114740169545`, 0.8282532063436999], 
      ArrowBox[{{0.28125, 0.649519052838329}, {-0.28125, 
       0.649519052838329}}]}}, 
    {Arrowheads[{{0.046875, 1.}}], 
     {LABColor[0.8167969189733053, 0.14500114740169545`, 0.8282532063436999], 
      ArrowBox[{{0.42815125401692256`, 0.37333703550840114`}, {
       0.32184874598307744`, 0.9257010701682569}}]}}, 
    {Arrowheads[{{0.04687499999999998, 1.}}], 
     {LABColor[0.8167969189733053, 0.14500114740169545`, 0.8282532063436999], 
      ArrowBox[{{0.6280626605356707, 0.39607705208793864`}, {
       0.8719373394643293, 0.9029610535887194}}]}}, 
    {Arrowheads[{{0.045226256335402844`, 1.}}], 
     {LABColor[0.7558791484422168, 0.28391283864257394`, 0.794269726245545], 
      ArrowBox[{{0.9368474005216465, 0.45398513571472954`}, {
       1.3131525994783535`, 0.8450529699619285}}]}}, 
    {Arrowheads[{{0.03796741126590752, 1.}}], 
     {LABColor[0.4862675220880942, 0.5276841686230651, 0.02737665942164308], 
      ArrowBox[{{1.314840485621129, 0.5168132515656457}, {1.685159514378871, 
       0.7822248541110123}}]}}, 
    {Arrowheads[{{0.0333351144545491, 1.}}], 
     {LABColor[0.3458270497244331, 0.5223154789639076, -0.4816080593659793], 
      ArrowBox[{{1.6999535002886197`, 0.5527564684168818}, {
       2.0500464997113803`, 0.7462816372597763}}]}}, 
    {Arrowheads[{{0.03025212659831732, 1.}}], 
     {LABColor[0.2790758828300792, 0.5224346691086938, -0.641139709063346], 
      ArrowBox[{{2.08458866019116, 0.57477970204782}, {2.41541133980884, 
       0.724258403628838}}]}}, 
    {Arrowheads[{{0.02810565871841034, 1.}}], 
     {LABColor[0.24211073540815065`, 0.5225006736667901, -0.7294843961136851],
       ArrowBox[{{2.467514557862464, 0.5892219103969829}, {2.782485442137536, 
       0.7098161952796751}}]}}, 
    {Arrowheads[{{0.026809627384801225`, 1.}}], 
     {LABColor[0.2235708607107115, 0.5225337782618454, -0.7737936858725598], 
      ArrowBox[{{-2.95328042055846, 1.052099485997334}, {-2.67171957944154, 
       0.896457672517653}}]}}, 
    {Arrowheads[{{0.028367203129640254`, 1.}}], 
     {LABColor[0.24619726068955256`, 0.5224933768124784, -0.7197178234827699],
       ArrowBox[{{-2.5801009634626286`, 
       1.0671984420526346`}, {-2.2948990365373714`, 0.8813587164623524}}]}}, 
    {Arrowheads[{{0.030451139054922305`, 1.}}], 
     {LABColor[0.2828985795232711, 0.5224278433437892, -0.6320036723746879], 
      ArrowBox[{{-2.205340691845564, 
       1.0882010268426834`}, {-1.919659308154436, 0.8603561316723036}}]}}, 
    {Arrowheads[{{0.03328234517749694, 1.}}], 
     {LABColor[0.34454905880859693`, 0.5223177609303418, -0.4846623879805527],
       ArrowBox[{{-1.8259629255059502`, 
       1.1181734724220518`}, {-1.5490370744940498`, 0.8303836860929352}}]}}, 
    {Arrowheads[{{0.03711615906347244, 1.}}], 
     {LABColor[0.4559863377432851, 0.5257109935802565, -0.10752677185539616`],
       ArrowBox[{{-1.43395444077979, 1.160940713353748}, {-1.19104555922021, 
       0.7876164451612391}}]}}, 
    {Arrowheads[{{0.04199733793455592, 1.}}], 
     {LABColor[0.6473388731499926, 0.5314188303613416, 0.7337196395781556], 
      ArrowBox[{{-1.0088176980704864`, 
       1.2159596420471572`}, {-0.8661823019295136, 0.7325975164678298}}]}}, 
    {Arrowheads[{{0.046875, 1.}}], 
     {LABColor[0.8167969189733053, 0.14500114740169545`, 0.8282532063436999], 
      ArrowBox[{{-0.5093487459830774, 
       1.2504605965874214`}, {-0.6156512540169226, 0.6980965619275656}}]}}, 
    {Arrowheads[{{0.04687499999999999, 1.}}], 
     {LABColor[0.8167969189733053, 0.14500114740169545`, 0.8282532063436999], 
      ArrowBox[{{0.05115617577028031, 
       1.1230898431682104`}, {-0.4261561757702803, 0.8254673153467766}}]}}, 
    {Arrowheads[{{0.046875, 1.}}], 
     {LABColor[0.8167969189733053, 0.14500114740169545`, 0.8282532063436999], 
      ArrowBox[{{0.4261561757702803, 
       0.8254673153467764}, {-0.05115617577028031, 1.1230898431682106`}}]}}, 
    {Arrowheads[{{0.046875, 1.}}], 
     {LABColor[0.8167969189733053, 0.14500114740169545`, 0.8282532063436999], 
      ArrowBox[{{0.6156512540169226, 0.6980965619275656}, {0.5093487459830774,
        1.2504605965874214`}}]}}, 
    {Arrowheads[{{0.04199733793455592, 1.}}], 
     {LABColor[0.6473388731499926, 0.5314188303613416, 0.7337196395781556], 
      ArrowBox[{{0.8661823019295138, 0.7325975164678298}, {
       1.0088176980704862`, 1.2159596420471572`}}]}}, 
    {Arrowheads[{{0.03711615906347244, 1.}}], 
     {LABColor[0.4559863377432851, 0.5257109935802565, -0.10752677185539616`],
       ArrowBox[{{1.19104555922021, 0.7876164451612391}, {1.43395444077979, 
       1.160940713353748}}]}}, 
    {Arrowheads[{{0.03328234517749693, 1.}}], 
     {LABColor[0.34454905880859693`, 0.5223177609303418, -0.4846623879805527],
       ArrowBox[{{1.5490370744940498`, 0.8303836860929354}, {
       1.8259629255059502`, 1.1181734724220516`}}]}}, 
    {Arrowheads[{{0.030451139054922305`, 1.}}], 
     {LABColor[0.2828985795232711, 0.5224278433437892, -0.6320036723746879], 
      ArrowBox[{{1.919659308154436, 0.8603561316723036}, {2.205340691845564, 
       1.0882010268426834`}}]}}, 
    {Arrowheads[{{0.028367203129640254`, 1.}}], 
     {LABColor[0.24619726068955256`, 0.5224933768124784, -0.7197178234827699],
       ArrowBox[{{2.2948990365373714`, 0.8813587164623524}, {
       2.5801009634626286`, 1.0671984420526346`}}]}}, 
    {Arrowheads[{{0.026809627384801225`, 1.}}], 
     {LABColor[0.2235708607107115, 0.5225337782618454, -0.7737936858725598], 
      ArrowBox[{{2.67171957944154, 0.896457672517653}, {2.95328042055846, 
       1.052099485997334}}]}}, 
    {Arrowheads[{{0.026850507569419136`, 1.}}], 
     {LABColor[0.22411218904904032`, 0.5225328116719561, -0.7724999406564169],
       ArrowBox[{{-2.7480001430290355`, 
       1.4030821158709623`}, {-2.5019998569709645`, 
       1.1949940954823537`}}]}}, 
    {Arrowheads[{{0.02828171592279591, 1.}}], 
     {LABColor[0.24484880781281154`, 0.52249578459501, -0.7229405523424185], 
      ArrowBox[{{-2.367659050289708, 
       1.4213129775199036`}, {-2.132340949710292, 1.1767632338334124`}}]}}, 
    {Arrowheads[{{0.03008105930891509, 1.}}], 
     {LABColor[0.2758435971464585, 0.5224404406422347, -0.6488646956275107], 
      ArrowBox[{{-1.981541326467938, 
       1.4447236245305408`}, {-1.768458673532062, 1.1533525868227752`}}]}}, 
    {Arrowheads[{{0.03228708754440001, 1.}}], 
     {LABColor[0.32132905889006713`, 0.5223592223051909, -0.5401569218639614],
       ArrowBox[{{-1.5839893664899418`, 
       1.4736067257439807`}, {-1.4160106335100582`, 
       1.1244694856093354`}}]}}, 
    {Arrowheads[{{0.03479066947316373, 1.}}], 
     {LABColor[0.3829382063657235, 0.5222492136933654, -0.39291441824158374`],
       ArrowBox[{{-1.1644489111591876`, 
       1.5040206609696094`}, {-1.0855510888408124`, 
       1.0940555503837066`}}]}}, 
    {Arrowheads[{{0.037110404208666445`, 1.}}], 
     {LABColor[0.4557863577416988, 0.5256979625328675, -0.10841768774869784`],
       ArrowBox[{{-0.707920756890336, 
       1.5176882667066003`}, {-0.792079243109664, 1.0803879446467157`}}]}}, 
    {Arrowheads[{{0.03837860828705306, 1.}}], 
     {LABColor[0.5013931864840477, 0.5286697834243934, 0.0947618714438691], 
      ArrowBox[{{-0.21533533839240349`, 
       1.4649664893232475`}, {-0.5346646616075965, 1.1331097220300685`}}]}}, 
    {Arrowheads[{{0.03853652819987618, 1.}}], 
     {LABColor[0.5072884666776927, 0.5290539302138983, 0.12102549169750049`], 
      ArrowBox[{{0.23121916919925706`, 
       1.299038105676658}, {-0.23121916919925706`, 1.299038105676658}}]}}, 
    {Arrowheads[{{0.03837860828705306, 1.}}], 
     {LABColor[0.5013931864840477, 0.5286697834243934, 0.0947618714438691], 
      ArrowBox[{{0.5346646616075965, 1.1331097220300685`}, {
       0.21533533839240349`, 1.4649664893232475`}}]}}, 
    {Arrowheads[{{0.037110404208666445`, 1.}}], 
     {LABColor[0.4557863577416988, 0.5256979625328675, -0.10841768774869784`],
       ArrowBox[{{0.792079243109664, 1.0803879446467157`}, {0.707920756890336,
        1.5176882667066003`}}]}}, 
    {Arrowheads[{{0.03479066947316373, 1.}}], 
     {LABColor[0.3829382063657235, 0.5222492136933654, -0.39291441824158374`],
       ArrowBox[{{1.0855510888408124`, 1.0940555503837066`}, {
       1.1644489111591876`, 1.5040206609696094`}}]}}, 
    {Arrowheads[{{0.03228708754440001, 1.}}], 
     {LABColor[0.32132905889006713`, 0.5223592223051909, -0.5401569218639614],
       ArrowBox[{{1.4160106335100582`, 1.1244694856093354`}, {
       1.5839893664899418`, 1.4736067257439807`}}]}}, 
    {Arrowheads[{{0.030081059308915078`, 1.}}], 
     {LABColor[0.2758435971464585, 0.5224404406422347, -0.6488646956275107], 
      ArrowBox[{{1.768458673532062, 1.1533525868227752`}, {1.981541326467938, 
       1.4447236245305408`}}]}}, 
    {Arrowheads[{{0.02828171592279591, 1.}}], 
     {LABColor[0.24484880781281154`, 0.52249578459501, -0.7229405523424185], 
      ArrowBox[{{2.132340949710292, 1.1767632338334124`}, {2.367659050289708, 
       1.4213129775199036`}}]}}, 
    {Arrowheads[{{0.026850507569419136`, 1.}}], 
     {LABColor[0.22411218904904032`, 0.5225328116719561, -0.7724999406564169],
       ArrowBox[{{2.5019998569709645`, 1.1949940954823537`}, {
       2.7480001430290355`, 1.4030821158709623`}}]}}, 
    {Arrowheads[{{0.02564556258633195, 1.}}], 
     {LABColor[0.20934474005279885`, 0.5225591802654336, -0.8077933386567955],
       ArrowBox[{{-2.9191919894920852`, 
       1.7346752000323606`}, {-2.7058080105079148`, 
       1.5129200641592844`}}]}}, 
    {Arrowheads[{{0.026652399012847175`, 1.}}], 
     {LABColor[0.22151525667467525`, 0.5225374487256601, -0.7787064674500331],
       ArrowBox[{{-2.5357490644612675`, 
       1.7499710633938828`}, {-2.3392509355387325`, 
       1.4976242007977623`}}]}}, 
    {Arrowheads[{{0.027846338179285696`, 1.}}], 
     {LABColor[0.2381733809463524, 0.5225077041633374, -0.7388944586183316], 
      ArrowBox[{{-2.146795011651649, 
       1.7680523332686908`}, {-1.978204988348351, 1.4795429309229542`}}]}}, 
    {Arrowheads[{{0.029213867724144613`, 1.}}], 
     {LABColor[0.26022090486804267`, 0.5224683363486509, -0.6862020784456201],
       ArrowBox[{{-1.7486238659346849`, 
       1.788078110058775}, {-1.6263761340653151`, 1.45951715413287}}]}}, 
    {Arrowheads[{{0.03066314968831119, 1.}}], 
     {LABColor[0.2870447701216108, 0.5224204399517479, -0.6220945028891611], 
      ArrowBox[{{-1.335583431050897, 
       1.8063226719341925`}, {-1.289416568949103, 1.4412725922574525`}}]}}, 
    {Arrowheads[{{0.031962857677327976`, 1.}}], 
     {LABColor[0.31412698794222316`, 0.522372082243361, -0.5573694787824862], 
      ArrowBox[{{-0.9012575260263594, 
       1.8121190510388372`}, {-0.9737424739736406, 1.4354762131528078`}}]}}, 
    {Arrowheads[{{0.03277096204113039, 1.}}], 
     {LABColor[0.3324085415233697, 0.5223394389036317, -0.5136775624082455], 
      ArrowBox[{{-0.446431555413751, 1.78251061355283}, {-0.678568444586249, 
       1.465084650638815}}]}}, 
    {Arrowheads[{{0.032979743251898716`, 1.}}], 
     {LABColor[0.33731160232222035`, 0.5223306840525377, -0.5019595144070006],
       ArrowBox[{{-0.0010763361577331432`, 
       1.6901459726796473`}, {-0.37392366384226683`, 1.5574492915119977`}}]}}, 
    {Arrowheads[{{0.032979743251898716`, 1.}}], 
     {LABColor[0.33731160232222035`, 0.5223306840525377, -0.5019595144070006],
       ArrowBox[{{0.37392366384226683`, 1.5574492915119977`}, {
       0.0010763361577331432`, 1.6901459726796473`}}]}}, 
    {Arrowheads[{{0.03277096204113039, 1.}}], 
     {LABColor[0.3324085415233697, 0.5223394389036317, -0.5136775624082455], 
      ArrowBox[{{0.678568444586249, 1.465084650638815}, {0.446431555413751, 
       1.78251061355283}}]}}, 
    {Arrowheads[{{0.031962857677327976`, 1.}}], 
     {LABColor[0.31412698794222316`, 0.522372082243361, -0.5573694787824862], 
      ArrowBox[{{0.9737424739736407, 1.4354762131528078`}, {
       0.9012575260263593, 1.8121190510388372`}}]}}, 
    {Arrowheads[{{0.03066314968831119, 1.}}], 
     {LABColor[0.2870447701216108, 0.5224204399517479, -0.6220945028891611], 
      ArrowBox[{{1.289416568949103, 1.4412725922574525`}, {1.335583431050897, 
       1.8063226719341925`}}]}}, 
    {Arrowheads[{{0.029213867724144613`, 1.}}], 
     {LABColor[0.26022090486804267`, 0.5224683363486509, -0.6862020784456201],
       ArrowBox[{{1.6263761340653151`, 1.45951715413287}, {
       1.7486238659346849`, 1.788078110058775}}]}}, 
    {Arrowheads[{{0.027846338179285685`, 1.}}], 
     {LABColor[0.2381733809463524, 0.5225077041633374, -0.7388944586183316], 
      ArrowBox[{{1.978204988348351, 1.4795429309229542`}, {2.146795011651649, 
       1.7680523332686908`}}]}}, 
    {Arrowheads[{{0.026652399012847175`, 1.}}], 
     {LABColor[0.22151525667467525`, 0.5225374487256601, -0.7787064674500331],
       ArrowBox[{{2.3392509355387325`, 1.4976242007977623`}, {
       2.5357490644612675`, 1.7499710633938828`}}]}}, 
    {Arrowheads[{{0.02564556258633195, 1.}}], 
     {LABColor[0.20934474005279885`, 0.5225591802654336, -0.8077933386567955],
       ArrowBox[{{2.7058080105079148`, 1.5129200641592844`}, {
       2.9191919894920852`, 1.7346752000323606`}}]}}, 
    {Arrowheads[{{0.02541436353426367, 1.}}], 
     {LABColor[0.2067925124035188, 0.5225637374948753, -0.8138930235946975], 
      ArrowBox[{{-2.70816289693526, 2.076369395925952}, {-2.54183710306474, 
       1.8207449211040219`}}]}}, 
    {Arrowheads[{{0.02623915379222988, 1.}}], 
     {LABColor[0.21631219675978824`, 0.5225467392518552, -0.791141496983073], 
      ArrowBox[{{-2.318256695535357, 
       2.0904260360637856`}, {-2.181743304464643, 1.8066882809661884`}}]}}, 
    {Arrowheads[{{0.027140120874227448`, 1.}}], 
     {LABColor[0.22802828241991355`, 0.5225258191389774, -0.7631406909999563],
       ArrowBox[{{-1.9210879436958799`, 
       2.1047397543581914`}, {-1.8289120563041201`, 
       1.7923745626717826`}}]}}, 
    {Arrowheads[{{0.02805518194307648, 1.}}], 
     {LABColor[0.2413353985481123, 0.5225020580997057, -0.7313374089388969], 
      ArrowBox[{{-1.5134548673449586`, 
       2.116349658239075}, {-1.4865451326550414`, 1.7807646587908992`}}]}}, 
    {Arrowheads[{{0.028864634835633396`, 1.}}], 
     {LABColor[0.254289256561796, 0.5224789278342133, -0.7003783945123908], 
      ArrowBox[{{-1.0922705805172381`, 
       2.118624210854122}, {-1.1577294194827619`, 1.7784901061758522`}}]}}, 
    {Arrowheads[{{0.029411668930401046`, 1.}}], 
     {LABColor[0.26367218109559915`, 0.5224621737880186, -0.6779537164205068],
       ArrowBox[{{-0.6581647430711206, 
       2.099248735182634}, {-0.8418352569288794, 1.79786558184734}}]}}, 
    {Arrowheads[{{0.029621489104600735`, 1.}}], 
     {LABColor[0.2674056200608809, 0.5224555074007249, -0.6690310008353473], 
      ArrowBox[{{-0.22418717204639924`, 
       2.042594731476548}, {-0.5258128279536007, 1.854519585553426}}]}}, 
    {Arrowheads[{{0.029640918410834577`, 1.}}], 
     {LABColor[0.2677551090490836, 0.5224548833570558, -0.668195741207193], 
      ArrowBox[{{0.17784551046500746`, 
       1.948557158514987}, {-0.17784551046500746`, 1.948557158514987}}]}}, 
    {Arrowheads[{{0.029621489104600707`, 1.}}], 
     {LABColor[0.2674056200608809, 0.5224555074007249, -0.6690310008353473], 
      ArrowBox[{{0.5258128279536007, 1.8545195855534264`}, {
       0.22418717204639926`, 2.0425947314765476`}}]}}, 
    {Arrowheads[{{0.029411668930401046`, 1.}}], 
     {LABColor[0.26367218109559915`, 0.5224621737880186, -0.6779537164205068],
       ArrowBox[{{0.8418352569288794, 1.79786558184734}, {0.6581647430711206, 
       2.099248735182634}}]}}, 
    {Arrowheads[{{0.028864634835633396`, 1.}}], 
     {LABColor[0.254289256561796, 0.5224789278342133, -0.7003783945123908], 
      ArrowBox[{{1.1577294194827619`, 1.7784901061758522`}, {
       1.0922705805172381`, 2.118624210854122}}]}}, 
    {Arrowheads[{{0.028055181943076463`, 1.}}], 
     {LABColor[0.2413353985481123, 0.5225020580997057, -0.7313374089388969], 
      ArrowBox[{{1.4865451326550414`, 1.7807646587908992`}, {
       1.5134548673449586`, 2.116349658239075}}]}}, 
    {Arrowheads[{{0.027140120874227486`, 1.}}], 
     {LABColor[0.22802828241991355`, 0.5225258191389774, -0.7631406909999563],
       ArrowBox[{{1.8289120563041201`, 1.7923745626717822`}, {
       1.9210879436958799`, 2.104739754358192}}]}}, 
    {Arrowheads[{{0.02623915379222988, 1.}}], 
     {LABColor[0.21631219675978824`, 0.5225467392518552, -0.791141496983073], 
      ArrowBox[{{2.181743304464643, 1.8066882809661884`}, {2.318256695535357, 
       2.0904260360637856`}}]}}, 
    {Arrowheads[{{0.025414363534263625`, 1.}}], 
     {LABColor[0.2067925124035188, 0.5225637374948753, -0.8138930235946975], 
      ArrowBox[{{2.54183710306474, 1.8207449211040223`}, {2.70816289693526, 
       2.0763693959259517`}}]}}, 
    {Arrowheads[{{0.02445822386812607, 1.}}], 
     {LABColor[0.19719932143650037`, 0.522580866990486, -0.8368202269985346], 
      ArrowBox[{{-2.883748214277058, 
       2.4016095596175564`}, {-2.741251785722942, 2.1450238102507466`}}]}}, 
    {Arrowheads[{{0.025048644541601873`, 1.}}], 
     {LABColor[0.20294024050510417`, 0.5225706160689392, -0.8230997434114394],
       ArrowBox[{{-2.4937892404626476`, 
       2.412669355412736}, {-2.3812107595373524`, 2.133964014455567}}]}}, 
    {Arrowheads[{{0.0256722240347895, 1.}}], 
     {LABColor[0.2096448822563781, 0.5225586443348369, -0.8070760151535736], 
      ArrowBox[{{-2.0980841235214847`, 
       2.4231834300156905`}, {-2.0269158764785153`, 
       2.1234499398526125`}}]}}, 
    {Arrowheads[{{0.026288511115827414`, 1.}}], 
     {LABColor[0.2169184265598746, 0.5225456567746342, -0.7896926408116663], 
      ArrowBox[{{-1.6947198906898773`, 
       2.430882425433657}, {-1.6802801093101227`, 2.115750944434646}}]}}, 
    {Arrowheads[{{0.02683116125936845, 1.}}], 
     {LABColor[0.22385565563704413`, 0.5225332697351771, -0.7731130415252454],
       ArrowBox[{{-1.2820763228231316`, 
       2.4314027488043806`}, {-1.3429236771768684`, 
       2.1152306210639225`}}]}}, 
    {Arrowheads[{{0.027219900529694776`, 1.}}], 
     {LABColor[0.22913201220125887`, 0.5225238483312962, -0.7605028369963429],
       ArrowBox[{{-0.8606406303430965, 
       2.417420344673995}, {-1.0143593696569035`, 2.129213025194308}}]}}, 
    {Arrowheads[{{0.027407983481300677`, 1.}}], 
     {LABColor[0.2317767676836434, 0.5225191258851798, -0.7541820155818091], 
      ArrowBox[{{-0.4369461020104899, 
       2.3795208788534348`}, {-0.6880538979895101, 2.1671124910148682`}}]}}, 
    {Arrowheads[{{0.027446616570634852`, 1.}}], 
     {LABColor[0.23232743228707758`, 0.5225181426245588, -0.7528659572010643],
       ArrowBox[{{-0.02776917435101467, 
       2.313384960911657}, {-0.34723082564898533`, 2.233248408956646}}]}}, 
    {Arrowheads[{{0.027446616570634852`, 1.}}], 
     {LABColor[0.23232743228707758`, 0.5225181426245588, -0.7528659572010643],
       ArrowBox[{{0.34723082564898533`, 2.233248408956646}, {
       0.02776917435101467, 2.313384960911657}}]}}, 
    {Arrowheads[{{0.027407983481300677`, 1.}}], 
     {LABColor[0.2317767676836434, 0.5225191258851798, -0.7541820155818091], 
      ArrowBox[{{0.6880538979895101, 2.1671124910148682`}, {
       0.4369461020104899, 2.3795208788534348`}}]}}, 
    {Arrowheads[{{0.02721990052969478, 1.}}], 
     {LABColor[0.22913201220125887`, 0.5225238483312962, -0.7605028369963429],
       ArrowBox[{{1.0143593696569035`, 2.129213025194308}, {
       0.8606406303430965, 2.417420344673995}}]}}, 
    {Arrowheads[{{0.02683116125936845, 1.}}], 
     {LABColor[0.22385565563704413`, 0.5225332697351771, -0.7731130415252454],
       ArrowBox[{{1.3429236771768684`, 2.1152306210639225`}, {
       1.2820763228231316`, 2.4314027488043806`}}]}}, 
    {Arrowheads[{{0.026288511115827414`, 1.}}], 
     {LABColor[0.2169184265598746, 0.5225456567746342, -0.7896926408116663], 
      ArrowBox[{{1.6802801093101227`, 2.115750944434646}, {
       1.6947198906898773`, 2.430882425433657}}]}}, 
    {Arrowheads[{{0.0256722240347895, 1.}}], 
     {LABColor[0.2096448822563781, 0.5225586443348369, -0.8070760151535736], 
      ArrowBox[{{2.0269158764785153`, 2.1234499398526125`}, {
       2.0980841235214847`, 2.4231834300156905`}}]}}, 
    {Arrowheads[{{0.025048644541601873`, 1.}}], 
     {LABColor[0.20294024050510417`, 0.5225706160689392, -0.8230997434114394],
       ArrowBox[{{2.3812107595373524`, 2.133964014455567}, {
       2.4937892404626476`, 2.412669355412736}}]}}, 
    {Arrowheads[{{0.02445822386812607, 1.}}], 
     {LABColor[0.19719932143650037`, 0.522580866990486, -0.8368202269985346], 
      ArrowBox[{{2.741251785722942, 2.1450238102507466`}, {2.883748214277058, 
       2.4016095596175564`}}]}}, 
    {Arrowheads[{{0.024142910573129308`, 1.}}], 
     {LABColor[0.19437532605167943`, 0.5225859094853883, -0.8435694220079831],
       ArrowBox[{{-2.6720793111925936`, 
       2.735069726424458}, {-2.5779206888074064`, 2.461082696282174}}]}}, 
    {Arrowheads[{{0.02459217880482063, 1.}}], 
     {LABColor[0.1984500250704274, 0.5225786337479204, -0.8338311135000597], 
      ArrowBox[{{-2.277884909706338, 
       2.7429704524808605`}, {-2.222115090293662, 2.4531819702257716`}}]}}, 
    {Arrowheads[{{0.025028319559488397`, 1.}}], 
     {LABColor[0.2027327958517151, 0.5225709864798161, -0.8235955248234473], 
      ArrowBox[{{-1.8778894863664752`, 
       2.748218327188698}, {-1.8721105136335248`, 2.447934095517934}}]}}, 
    {Arrowheads[{{0.0254123288858346, 1.}}], 
     {LABColor[0.20677045373994238`, 0.5225637768825808, -0.8139457425980378],
       ArrowBox[{{-1.4711851275141852`, 
       2.747802680830466}, {-1.5288148724858148`, 2.448349741876166}}]}}, 
    {Arrowheads[{{0.02569952802611859, 1.}}], 
     {LABColor[0.20995350614278063`, 0.5225580932594412, -0.8063384208908138],
       ArrowBox[{{-1.0581470491094642`, 
       2.737027460447294}, {-1.1918529508905358`, 2.459124962259338}}]}}, 
    {Arrowheads[{{0.02586070673771242, 1.}}], 
     {LABColor[0.21180108522326876`, 0.5225547942426847, -0.8019228076158712],
       ArrowBox[{{-0.6424129567355086, 
       2.709883946455442}, {-0.8575870432644914, 2.48626847625119}}]}}, 
    {Arrowheads[{{0.025912340446827845`, 1.}}], 
     {LABColor[0.21240226702826387`, 0.5225537207791077, -0.8004860158775229],
       ArrowBox[{{-0.23331756531354086`, 
       2.6620939092881875`}, {-0.5166824346864591, 2.5340585134184446`}}]}}, 
    {Arrowheads[{{0.025916539858333237`, 1.}}], 
     {LABColor[0.21245136025801684`, 0.52255363311878, -0.8003686857349075], 
      ArrowBox[{{0.1554992391499994, 2.598076211353316}, {-0.1554992391499994,
        2.598076211353316}}]}}, 
    {Arrowheads[{{0.025912340446827845`, 1.}}], 
     {LABColor[0.21240226702826387`, 0.5225537207791077, -0.8004860158775229],
       ArrowBox[{{0.5166824346864591, 2.5340585134184446`}, {
       0.23331756531354086`, 2.6620939092881875`}}]}}, 
    {Arrowheads[{{0.02586070673771242, 1.}}], 
     {LABColor[0.21180108522326876`, 0.5225547942426847, -0.8019228076158712],
       ArrowBox[{{0.8575870432644914, 2.48626847625119}, {0.6424129567355086, 
       2.709883946455442}}]}}, 
    {Arrowheads[{{0.02569952802611859, 1.}}], 
     {LABColor[0.20995350614278063`, 0.5225580932594412, -0.8063384208908138],
       ArrowBox[{{1.1918529508905358`, 2.459124962259338}, {
       1.0581470491094642`, 2.737027460447294}}]}}, 
    {Arrowheads[{{0.0254123288858346, 1.}}], 
     {LABColor[0.20677045373994238`, 0.5225637768825808, -0.8139457425980378],
       ArrowBox[{{1.5288148724858148`, 2.448349741876166}, {
       1.4711851275141852`, 2.747802680830466}}]}}, 
    {Arrowheads[{{0.025028319559488397`, 1.}}], 
     {LABColor[0.2027327958517151, 0.5225709864798161, -0.8235955248234473], 
      ArrowBox[{{1.8721105136335248`, 2.447934095517934}, {
       1.8778894863664752`, 2.748218327188698}}]}}, 
    {Arrowheads[{{0.02459217880482063, 1.}}], 
     {LABColor[0.1984500250704274, 0.5225786337479204, -0.8338311135000597], 
      ArrowBox[{{2.222115090293662, 2.4531819702257716`}, {2.277884909706338, 
       2.7429704524808605`}}]}}, 
    {Arrowheads[{{0.024142910573129308`, 1.}}], 
     {LABColor[0.19437532605167943`, 0.5225859094853883, -0.8435694220079831],
       ArrowBox[{{2.5779206888074064`, 2.461082696282174}, {
       2.6720793111925936`, 2.735069726424458}}]}}, 
    {Arrowheads[{{0.023437499999999983`, 1.}}], 
     {LABColor[0.1886675222501131, 0.5225961012766809, -0.8572107619122568], 
      ArrowBox[{{-2.852300345229779, 3.05771095100527}, {-2.772699654770221, 
       2.7879605245396912`}}]}}, 
    {Arrowheads[{{0.023772049520917705`, 1.}}], 
     {LABColor[0.19126941188753788`, 0.5225914553713428, -0.8509923875301908],
       ArrowBox[{{-2.4595209027139866`, 
       3.063757886588626}, {-2.4154790972860134`, 2.781913588956335}}]}}, 
    {Arrowheads[{{0.024092985612148617`, 1.}}], 
     {LABColor[0.1939436373986191, 0.5225866803038692, -0.8446011343537365], 
      ArrowBox[{{-2.0622189885768405`, 
       3.067393378310915}, {-2.0627810114231595`, 2.778278097234046}}]}}, 
    {Arrowheads[{{0.024376206502166726`, 1.}}], 
     {LABColor[0.1964485516254857, 0.5225822075567508, -0.8386145259159411], 
      ArrowBox[{{-1.6598599798663334`, 
       3.0664574953536925`}, {-1.7151400201336666`, 
       2.7792139801912685`}}]}}, 
    {Arrowheads[{{0.024595162453253397`, 1.}}], 
     {LABColor[0.1984782287678722, 0.5225785833877103, -0.8337637082007927], 
      ArrowBox[{{-1.2527352286601092`, 
       3.057762994790327}, {-1.3722647713398908`, 2.787908480754634}}]}}, 
    {Arrowheads[{{0.02473114633658845, 1.}}], 
     {LABColor[0.19977965974530087`, 0.5225762595669616, -0.8306533591169325],
       ArrowBox[{{-0.8430420861852641, 
       3.037275102005908}, {-1.031957913814736, 2.808396373539053}}]}}, 
    {Arrowheads[{{0.024788185784081627`, 1.}}], 
     {LABColor[0.20033488155114046`, 0.5225752681690505, -0.8293264092708912],
       ArrowBox[{{-0.4362951226984074, 
       3.001529311246248}, {-0.6887048773015926, 2.844142164298713}}]}}, 
    {Arrowheads[{{0.02479861681343028, 1.}}], 
     {LABColor[0.20043701336272815`, 0.5225750858036181, -0.8290823198092799],
       ArrowBox[{{-0.04143291540264227, 
       2.951179644492706}, {-0.33356708459735773`, 2.894491831052255}}]}}, 
    {Arrowheads[{{0.02479861681343028, 1.}}], 
     {LABColor[0.20043701336272815`, 0.5225750858036181, -0.8290823198092799],
       ArrowBox[{{0.33356708459735773`, 2.894491831052255}, {
       0.04143291540264227, 2.951179644492706}}]}}, 
    {Arrowheads[{{0.024788185784081627`, 1.}}], 
     {LABColor[0.20033488155114046`, 0.5225752681690505, -0.8293264092708912],
       ArrowBox[{{0.6887048773015926, 2.844142164298713}, {0.4362951226984074,
        3.001529311246248}}]}}, 
    {Arrowheads[{{0.02473114633658845, 1.}}], 
     {LABColor[0.19977965974530087`, 0.5225762595669616, -0.8306533591169325],
       ArrowBox[{{1.031957913814736, 2.808396373539053}, {0.8430420861852641, 
       3.037275102005908}}]}}, 
    {Arrowheads[{{0.024595162453253397`, 1.}}], 
     {LABColor[0.1984782287678722, 0.5225785833877103, -0.8337637082007927], 
      ArrowBox[{{1.3722647713398908`, 2.787908480754634}, {
       1.2527352286601092`, 3.057762994790327}}]}}, 
    {Arrowheads[{{0.024376206502166726`, 1.}}], 
     {LABColor[0.1964485516254857, 0.5225822075567508, -0.8386145259159411], 
      ArrowBox[{{1.7151400201336666`, 2.7792139801912685`}, {
       1.6598599798663334`, 3.0664574953536925`}}]}}, 
    {Arrowheads[{{0.024092985612148617`, 1.}}], 
     {LABColor[0.1939436373986191, 0.5225866803038692, -0.8446011343537365], 
      ArrowBox[{{2.0627810114231595`, 2.778278097234046}, {
       2.0622189885768405`, 3.067393378310915}}]}}, 
    {Arrowheads[{{0.023772049520917705`, 1.}}], 
     {LABColor[0.19126941188753788`, 0.5225914553713428, -0.8509923875301908],
       ArrowBox[{{2.4154790972860134`, 2.781913588956335}, {
       2.4595209027139866`, 3.063757886588626}}]}}, 
    {Arrowheads[{{0.023437499999999983`, 1.}}], 
     {LABColor[0.1886675222501131, 0.5225961012766809, -0.8572107619122568], 
      ArrowBox[{{2.772699654770221, 2.7879605245396912`}, {2.852300345229779, 
       3.05771095100527}}]}}}},
  AspectRatio->1,
  DisplayFunction->Identity,
  Frame->True,
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  LabelStyle->Opacity[0],
  Method->{
   "VectorLengthFunction" -> (Sqrt[#]& ), "DefaultBoundaryStyle" -> Automatic,
     "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
    "TransparentPolygonMesh" -> True},
  PlotRange->{{-3, 3}, {-3, 3}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.02]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.920384314637293*^9},
 CellLabel->
  "Out[1737]=",ExpressionUUID->"e7ec7655-4992-46d9-8487-5ef1085f3d7a"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"VectorPlot", "[", 
  RowBox[{
   RowBox[{"Qfield", "[", 
    RowBox[{"x", ",", "y"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", 
     RowBox[{"-", "3"}], ",", "3"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"y", ",", 
     RowBox[{"-", "3"}], ",", "3"}], "}"}], ",", 
   RowBox[{"VectorScaling", "->", "Automatic"}], ",", 
   RowBox[{"VectorSizes", "->", "1.5"}], ",", 
   RowBox[{"LabelStyle", "->", 
    RowBox[{"Opacity", "[", "0", "]"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.920385682342298*^9, 3.920385682743993*^9}},
 CellLabel->
  "In[1744]:=",ExpressionUUID->"7323721d-3890-483b-824b-9a9dfc3a443a"],

Cell[BoxData[
 GraphicsBox[{{}, 
   {RGBColor[0.2947336, 0.4054232, 0.5678384000000001], 
    {Arrowheads[{{0.023437500000000003`, 1.}}], 
     {LABColor[0.1886675222501131, 0.5225961012766809, -0.8572107619122568], 
      ArrowBox[{{-2.8656934966369074`, -2.7926595397156184`}, \
{-2.7593065033630926`, -3.0530119358293426`}}]}}, 
    {Arrowheads[{{0.02363733168124345, 1.}}], 
     {LABColor[0.1895593134817414, 0.5225945089041283, -0.8550794294878742], 
      ArrowBox[{{-2.5228160404135545`, -2.809543119246467}, \
{-2.3521839595864455`, -3.036128356298494}}]}}, 
    {Arrowheads[{{0.02385728237095984, 1.}}], 
     {LABColor[0.19063182402047543`, 0.5225925938411812, -0.8525161877720724],
       ArrowBox[{{-2.1796967347479157`, -2.8406466718267946`}, \
{-1.9453032652520843`, -3.0050248037181664`}}]}}, 
    {Arrowheads[{{0.024112930140648695`, 1.}}], 
     {LABColor[0.19199814401027335`, 0.5225901541553302, -0.8492507574863079],
       ArrowBox[{{-1.8279421943461223`, -2.8880853068962025`}, \
{-1.5470578056538777`, -2.9575861686487586`}}]}}, 
    {Arrowheads[{{0.024417167235943213`, 1.}}], 
     {LABColor[0.19379191129291803`, 0.5225869512243242, -0.8449637514744672],
       ArrowBox[{{-1.4570282492168432`, -2.9468089559152895`}, \
{-1.1679717507831568`, -2.8988625196296716`}}]}}, 
    {Arrowheads[{{0.02475264135153756, 1.}}], 
     {LABColor[0.1959812089848867, 0.5225830420385972, -0.8397314493481064], 
      ArrowBox[{{-1.061646557286596, -3.004350088984328}, \
{-0.8133534427134039, -2.841321386560633}}]}}, 
    {Arrowheads[{{0.02505516218170267, 1.}}], 
     {LABColor[0.19814553972841512`, 0.522579177433577, -0.8345588168673546], 
      ArrowBox[{{-0.6453980962184761, -3.048244298539294}, \
{-0.4796019037815239, -2.797427177005667}}]}}, 
    {Arrowheads[{{0.025237386224910285`, 1.}}], 
     {LABColor[0.19953622404152604`, 0.5225766942430599, -0.8312351571771807],
       ArrowBox[{{-0.21650107786918865`, -3.071456938706855}, \
{-0.15849892213081135`, -2.774214536838106}}]}}, 
    {Arrowheads[{{0.025237386224910285`, 1.}}], 
     {LABColor[0.19953622404152604`, 0.5225766942430599, -0.8312351571771807],
       ArrowBox[{{0.21650107786918865`, -3.071456938706855}, {
       0.15849892213081135`, -2.774214536838106}}]}}, 
    {Arrowheads[{{0.02505516218170267, 1.}}], 
     {LABColor[0.19814553972841512`, 0.522579177433577, -0.8345588168673546], 
      ArrowBox[{{0.6453980962184761, -3.048244298539294}, {
       0.4796019037815239, -2.797427177005667}}]}}, 
    {Arrowheads[{{0.02475264135153756, 1.}}], 
     {LABColor[0.1959812089848867, 0.5225830420385972, -0.8397314493481064], 
      ArrowBox[{{1.061646557286596, -3.004350088984328}, {
       0.8133534427134039, -2.841321386560633}}]}}, 
    {Arrowheads[{{0.024417167235943213`, 1.}}], 
     {LABColor[0.19379191129291803`, 0.5225869512243242, -0.8449637514744672],
       ArrowBox[{{1.4570282492168432`, -2.9468089559152895`}, {
       1.1679717507831568`, -2.8988625196296716`}}]}}, 
    {Arrowheads[{{0.024112930140648695`, 1.}}], 
     {LABColor[0.19199814401027335`, 0.5225901541553302, -0.8492507574863079],
       ArrowBox[{{1.8279421943461223`, -2.8880853068962025`}, {
       1.5470578056538777`, -2.9575861686487586`}}]}}, 
    {Arrowheads[{{0.02385728237095984, 1.}}], 
     {LABColor[0.19063182402047543`, 0.5225925938411812, -0.8525161877720724],
       ArrowBox[{{2.1796967347479157`, -2.8406466718267946`}, {
       1.9453032652520843`, -3.0050248037181664`}}]}}, 
    {Arrowheads[{{0.02363733168124345, 1.}}], 
     {LABColor[0.1895593134817414, 0.5225945089041283, -0.8550794294878742], 
      ArrowBox[{{2.5228160404135545`, -2.809543119246467}, {
       2.3521839595864455`, -3.036128356298494}}]}}, 
    {Arrowheads[{{0.023437500000000003`, 1.}}], 
     {LABColor[0.1886675222501131, 0.5225961012766809, -0.8572107619122568], 
      ArrowBox[{{2.8656934966369074`, -2.7926595397156184`}, {
       2.7593065033630926`, -3.0530119358293426`}}]}}, 
    {Arrowheads[{{0.023922264956198775`, 1.}}], 
     {LABColor[0.1909669237196185, 0.5225919954908673, -0.8517153177602869], 
      ArrowBox[{{-2.668003533118169, -2.4611361240077936`}, \
{-2.581996466881831, -2.7350162986988384`}}]}}, 
    {Arrowheads[{{0.02420062198794734, 1.}}], 
     {LABColor[0.19249646907801146`, 0.5225892643516048, -0.8480597877423985],
       ArrowBox[{{-2.329093166768005, -2.4763043150211357`}, \
{-2.170906833231995, -2.7198481076854963`}}]}}, 
    {Arrowheads[{{0.024507269750248636`, 1.}}], 
     {LABColor[0.1943581446058129, 0.5225859401643879, -0.8436104847268957], 
      ArrowBox[{{-1.9917027553781268`, -2.508620676984752}, \
{-1.7582972446218732`, -2.68753174572188}}]}}, 
    {Arrowheads[{{0.02486761360884596, 1.}}], 
     {LABColor[0.19678252074931804`, 0.5225816112251798, -0.8378163579175106],
       ArrowBox[{{-1.6448377365590403`, -2.5622381658428113`}, \
{-1.3551622634409597`, -2.6339142568638207`}}]}}, 
    {Arrowheads[{{0.025304684347523466`, 1.}}], 
     {LABColor[0.20006636321834306`, 0.5225757476324135, -0.8299681534470336],
       ArrowBox[{{-1.273283854368729, -2.6306902011576057`}, \
{-0.976716145631271, -2.5654622215490264`}}]}}, 
    {Arrowheads[{{0.025781134731821417`, 1.}}], 
     {LABColor[0.20407473661144665`, 0.5225685903252486, -0.8203883595684199],
       ArrowBox[{{-0.8699028930678004, -2.6958069891264587`}, \
{-0.6300971069321996, -2.5003454335801734`}}]}}, 
    {Arrowheads[{{0.026170007001621115`, 1.}}], 
     {LABColor[0.20767772299599463`, 0.5225621568726392, -0.8117774185391222],
       ArrowBox[{{-0.4413021316358872, -2.7404114527142447`}, \
{-0.3086978683641128, -2.4557409699923873`}}]}}, 
    {Arrowheads[{{0.0263216810597335, 1.}}], 
     {LABColor[0.20916376218912525`, 0.5225595034175038, -0.8082258658843157],
       ArrowBox[{{0., -2.756006297711717}, {0., -2.4401461249949152`}}]}}, 
    {Arrowheads[{{0.026170007001621115`, 1.}}], 
     {LABColor[0.20767772299599463`, 0.5225621568726392, -0.8117774185391222],
       ArrowBox[{{0.4413021316358872, -2.7404114527142447`}, {
       0.3086978683641128, -2.4557409699923873`}}]}}, 
    {Arrowheads[{{0.025781134731821417`, 1.}}], 
     {LABColor[0.20407473661144665`, 0.5225685903252486, -0.8203883595684199],
       ArrowBox[{{0.8699028930678004, -2.6958069891264587`}, {
       0.6300971069321996, -2.5003454335801734`}}]}}, 
    {Arrowheads[{{0.025304684347523466`, 1.}}], 
     {LABColor[0.20006636321834306`, 0.5225757476324135, -0.8299681534470336],
       ArrowBox[{{1.273283854368729, -2.6306902011576057`}, {
       0.976716145631271, -2.5654622215490264`}}]}}, 
    {Arrowheads[{{0.02486761360884596, 1.}}], 
     {LABColor[0.19678252074931804`, 0.5225816112251798, -0.8378163579175106],
       ArrowBox[{{1.6448377365590403`, -2.5622381658428113`}, {
       1.3551622634409597`, -2.6339142568638207`}}]}}, 
    {Arrowheads[{{0.024507269750248636`, 1.}}], 
     {LABColor[0.1943581446058129, 0.5225859401643879, -0.8436104847268957], 
      ArrowBox[{{1.9917027553781268`, -2.508620676984752}, {
       1.7582972446218732`, -2.68753174572188}}]}}, 
    {Arrowheads[{{0.02420062198794734, 1.}}], 
     {LABColor[0.19249646907801146`, 0.5225892643516048, -0.8480597877423985],
       ArrowBox[{{2.329093166768005, -2.4763043150211357`}, {
       2.170906833231995, -2.7198481076854963`}}]}}, 
    {Arrowheads[{{0.023922264956198775`, 1.}}], 
     {LABColor[0.1909669237196185, 0.5225919954908673, -0.8517153177602869], 
      ArrowBox[{{2.668003533118169, -2.4611361240077936`}, {
       2.581996466881831, -2.7350162986988384`}}]}}, 
    {Arrowheads[{{0.02421202706066869, 1.}}], 
     {LABColor[0.1925623936052687, 0.5225891466374987, -0.8479022317163667], 
      ArrowBox[{{-2.8103520950903818`, -2.1280604022389955`}, \
{-2.8146479049096182`, -2.4185729676293075`}}]}}, 
    {Arrowheads[{{0.024585534114012448`, 1.}}], 
     {LABColor[0.19486296084384336`, 0.5225850387701008, -0.8424040014398774],
       ArrowBox[{{-2.4676462514388513`, -2.128916722744574}, \
{-2.4073537485611487`, -2.417716647123729}}]}}, 
    {Arrowheads[{{0.024990458195751575`, 1.}}], 
     {LABColor[0.19766747192333103`, 0.5225800310661582, -0.8357013728579183],
       ArrowBox[{{-2.133309212828408, -2.141146781368207}, \
{-1.9916907871715919`, -2.405486588500096}}]}}, 
    {Arrowheads[{{0.025437201135099525`, 1.}}], 
     {LABColor[0.2011363387671152, 0.5225738370959164, -0.8274109702190366], 
      ArrowBox[{{-1.8035233173603324`, -2.1741580590569547`}, \
{-1.5714766826396676`, -2.3724753108113483`}}]}}, 
    {Arrowheads[{{0.02596838241299922, 1.}}], 
     {LABColor[0.20577244488595797`, 0.5225655589161443, -0.8163309293490154],
       ArrowBox[{{-1.4637490016114958`, -2.235892262736269}, \
{-1.1612509983885042`, -2.310741107132034}}]}}, 
    {Arrowheads[{{0.026627727134188827`, 1.}}], 
     {LABColor[0.21230023730434472`, 0.5225539029622535, -0.800729861355172], 
      ArrowBox[{{-1.09088337445676, -2.31802497414587}, {-0.7841166255432399, \
-2.228608395722433}}]}}, 
    {Arrowheads[{{0.027327584821428885`, 1.}}], 
     {LABColor[0.22016597619390982`, 0.5225398579859524, -0.7819311742381803],
       ArrowBox[{{-0.6749871218787811, -2.3926118463181503`}, \
{-0.45001287812121893`, -2.1540215235501528`}}]}}, 
    {Arrowheads[{{0.02780113836454513, 1.}}], 
     {LABColor[0.22603553323293704`, 0.5225293773698694, -0.7679032529149351],
       ArrowBox[{{-0.22844397142048134`, -2.4350204566942555`}, \
{-0.14655602857951866`, -2.1116129131740475`}}]}}, 
    {Arrowheads[{{0.02780113836454513, 1.}}], 
     {LABColor[0.22603553323293704`, 0.5225293773698694, -0.7679032529149351],
       ArrowBox[{{0.22844397142048134`, -2.4350204566942555`}, {
       0.14655602857951866`, -2.1116129131740475`}}]}}, 
    {Arrowheads[{{0.027327584821428885`, 1.}}], 
     {LABColor[0.22016597619390982`, 0.5225398579859524, -0.7819311742381803],
       ArrowBox[{{0.6749871218787811, -2.3926118463181503`}, {
       0.45001287812121893`, -2.1540215235501528`}}]}}, 
    {Arrowheads[{{0.026627727134188827`, 1.}}], 
     {LABColor[0.21230023730434472`, 0.5225539029622535, -0.800729861355172], 
      ArrowBox[{{1.09088337445676, -2.31802497414587}, {
       0.7841166255432399, -2.228608395722433}}]}}, 
    {Arrowheads[{{0.02596838241299922, 1.}}], 
     {LABColor[0.20577244488595797`, 0.5225655589161443, -0.8163309293490154],
       ArrowBox[{{1.4637490016114958`, -2.235892262736269}, {
       1.1612509983885042`, -2.310741107132034}}]}}, 
    {Arrowheads[{{0.025437201135099525`, 1.}}], 
     {LABColor[0.2011363387671152, 0.5225738370959164, -0.8274109702190366], 
      ArrowBox[{{1.8035233173603324`, -2.1741580590569547`}, {
       1.5714766826396676`, -2.3724753108113483`}}]}}, 
    {Arrowheads[{{0.024990458195751575`, 1.}}], 
     {LABColor[0.19766747192333103`, 0.5225800310661582, -0.8357013728579183],
       ArrowBox[{{2.133309212828408, -2.141146781368207}, {
       1.9916907871715919`, -2.405486588500096}}]}}, 
    {Arrowheads[{{0.024585534114012448`, 1.}}], 
     {LABColor[0.19486296084384336`, 0.5225850387701008, -0.8424040014398774],
       ArrowBox[{{2.4676462514388513`, -2.128916722744574}, {
       2.4073537485611487`, -2.417716647123729}}]}}, 
    {Arrowheads[{{0.02421202706066869, 1.}}], 
     {LABColor[0.1925623936052687, 0.5225891466374987, -0.8479022317163667], 
      ArrowBox[{{2.8103520950903818`, -2.1280604022389955`}, {
       2.8146479049096182`, -2.4185729676293075`}}]}}, 
    {Arrowheads[{{0.024960366493313412`, 1.}}], 
     {LABColor[0.19744794765096335`, 0.5225804230462693, -0.8362260239007211],
       ArrowBox[{{-2.604889208717795, -1.8001513893841934`}, \
{-2.645110791282205, -2.0969629276457806`}}]}}, 
    {Arrowheads[{{0.02552252518869608, 1.}}], 
     {LABColor[0.20184357345992066`, 0.5225725742654768, -0.8257207178606766],
       ArrowBox[{{-2.2635486004974146`, -1.796022539700647}, \
{-2.2364513995025854`, -2.101091777329327}}]}}, 
    {Arrowheads[{{0.026144663939235067`, 1.}}], 
     {LABColor[0.20743384049254693`, 0.522562592346538, -0.8123602844262297], 
      ArrowBox[{{-1.934337646648524, -1.8033448726020715`}, \
{-1.815662353351476, -2.0937694444279025`}}]}}, 
    {Arrowheads[{{0.026834241149129325`, 1.}}], 
     {LABColor[0.2145209192600189, 0.5225499377371325, -0.795422552549581], 
      ArrowBox[{{-1.6149400691824392`, -1.8358117176930957`}, \
{-1.3850599308175608`, -2.0613025993368783`}}]}}, 
    {Arrowheads[{{0.027664381755694665`, 1.}}], 
     {LABColor[0.22429511315335815`, 0.5225324850447001, -0.7720627620198632],
       ArrowBox[{{-1.2861270988775015`, -1.9086885411247003`}, \
{-0.9638729011224985, -1.9884257759052737`}}]}}, 
    {Arrowheads[{{0.02872424889247303, 1.}}], 
     {LABColor[0.238746978890759, 0.5225066799531966, -0.7375235908029565], 
      ArrowBox[{{-0.9104853326526714, -2.0113857116026077`}, \
{-0.5895146673473286, -1.8857286054273663`}}]}}, 
    {Arrowheads[{{0.029784403848066052`, 1.}}], 
     {LABColor[0.2554163039764509, 0.5224769153908242, -0.6976848126364124], 
      ArrowBox[{{-0.4735453759229724, -2.0976369845722003`}, \
{-0.2764546240770276, -1.7994773324577737`}}]}}, 
    {Arrowheads[{{0.030249390557272493`, 1.}}], 
     {LABColor[0.2634259502964525, 0.5224626134550082, -0.6785421946063089], 
      ArrowBox[{{0., -2.130053501858622}, {0., -1.767060815171352}}]}}, 
    {Arrowheads[{{0.029784403848066052`, 1.}}], 
     {LABColor[0.2554163039764509, 0.5224769153908242, -0.6976848126364124], 
      ArrowBox[{{0.4735453759229724, -2.0976369845722003`}, {
       0.2764546240770276, -1.7994773324577737`}}]}}, 
    {Arrowheads[{{0.02872424889247303, 1.}}], 
     {LABColor[0.238746978890759, 0.5225066799531966, -0.7375235908029565], 
      ArrowBox[{{0.9104853326526714, -2.0113857116026077`}, {
       0.5895146673473286, -1.8857286054273663`}}]}}, 
    {Arrowheads[{{0.027664381755694665`, 1.}}], 
     {LABColor[0.22429511315335815`, 0.5225324850447001, -0.7720627620198632],
       ArrowBox[{{1.2861270988775015`, -1.9086885411247003`}, {
       0.9638729011224985, -1.9884257759052737`}}]}}, 
    {Arrowheads[{{0.026834241149129325`, 1.}}], 
     {LABColor[0.2145209192600189, 0.5225499377371325, -0.795422552549581], 
      ArrowBox[{{1.6149400691824392`, -1.8358117176930957`}, {
       1.3850599308175608`, -2.0613025993368783`}}]}}, 
    {Arrowheads[{{0.026144663939235067`, 1.}}], 
     {LABColor[0.20743384049254693`, 0.522562592346538, -0.8123602844262297], 
      ArrowBox[{{1.934337646648524, -1.8033448726020715`}, {
       1.815662353351476, -2.0937694444279025`}}]}}, 
    {Arrowheads[{{0.02552252518869608, 1.}}], 
     {LABColor[0.20184357345992066`, 0.5225725742654768, -0.8257207178606766],
       ArrowBox[{{2.2635486004974146`, -1.796022539700647}, {
       2.2364513995025854`, -2.101091777329327}}]}}, 
    {Arrowheads[{{0.024960366493313412`, 1.}}], 
     {LABColor[0.19744794765096335`, 0.5225804230462693, -0.8362260239007211],
       ArrowBox[{{2.604889208717795, -1.8001513893841934`}, {
       2.645110791282205, -2.0969629276457806`}}]}}, 
    {Arrowheads[{{0.02525728191823047, 1.}}], 
     {LABColor[0.199692023008096, 0.5225764160501496, -0.8308628061410199], 
      ArrowBox[{{-2.747772492074109, -1.4867726703042035`}, \
{-2.877227507925891, -1.7608225938874416`}}]}}, 
    {Arrowheads[{{0.026005210609879013`, 1.}}], 
     {LABColor[0.20611448048761538`, 0.5225649481811597, -0.8155134829083562],
       ArrowBox[{{-2.3951176467202315`, -1.473632751482615}, \
{-2.4798823532797685`, -1.77396251270903}}]}}, 
    {Arrowheads[{{0.026896038085676838`, 1.}}], 
     {LABColor[0.2152017625578487, 0.5225487220308757, -0.7937953741863909], 
      ArrowBox[{{-2.0539920911702807`, -1.4626458321779574`}, \
{-2.0710079088297193`, -1.7849494320136876`}}]}}, 
    {Arrowheads[{{0.02792052290861224, 1.}}], 
     {LABColor[0.22758498584015385`, 0.5225266106844437, -0.7642001456576731],
       ArrowBox[{{-1.7301001707355588`, -1.4617815000751082`}, \
{-1.6448998292644412`, -1.7858137641165368`}}]}}, 
    {Arrowheads[{{0.029072231754029437`, 1.}}], 
     {LABColor[0.24397440758125888`, 0.5224973459143855, -0.7250303212247533],
       ArrowBox[{{-1.425345656498204, -1.4907831007872123`}, \
{-1.199654343501796, -1.7568121634044327`}}]}}, 
    {Arrowheads[{{0.030477131434811056`, 1.}}], 
     {LABColor[0.26750428410463944`, 0.5224553312273004, -0.6687951991497899],
       ArrowBox[{{-1.1150095432663538`, -1.579875410986441}, \
{-0.7599904567336462, -1.667719853205204}}]}}, 
    {Arrowheads[{{0.03233232895408379, 1.}}], 
     {LABColor[0.30453253115720536`, 0.5223892139992021, -0.5802997074223313],
       ArrowBox[{{-0.7329190781705752, -1.7164852776421111`}, \
{-0.3920809218294248, -1.531109986549534}}]}}, 
    {Arrowheads[{{0.03394748427985846, 1.}}], 
     {LABColor[
      0.34229005320611805`, 0.5223217945857422, -0.49006128821265527`], 
      ArrowBox[{{-0.25694504902564397`, -1.8152785083402936`}, \
{-0.11805495097435603`, -1.4323167558513514`}}]}}, 
    {Arrowheads[{{0.03394748427985846, 1.}}], 
     {LABColor[
      0.34229005320611805`, 0.5223217945857422, -0.49006128821265527`], 
      ArrowBox[{{0.25694504902564397`, -1.8152785083402936`}, {
       0.11805495097435603`, -1.4323167558513514`}}]}}, 
    {Arrowheads[{{0.03233232895408379, 1.}}], 
     {LABColor[0.30453253115720536`, 0.5223892139992021, -0.5802997074223313],
       ArrowBox[{{0.7329190781705752, -1.7164852776421111`}, {
       0.3920809218294248, -1.531109986549534}}]}}, 
    {Arrowheads[{{0.030477131434811056`, 1.}}], 
     {LABColor[0.26750428410463944`, 0.5224553312273004, -0.6687951991497899],
       ArrowBox[{{1.1150095432663538`, -1.579875410986441}, {
       0.7599904567336462, -1.667719853205204}}]}}, 
    {Arrowheads[{{0.029072231754029437`, 1.}}], 
     {LABColor[0.24397440758125888`, 0.5224973459143855, -0.7250303212247533],
       ArrowBox[{{1.425345656498204, -1.4907831007872123`}, {
       1.199654343501796, -1.7568121634044327`}}]}}, 
    {Arrowheads[{{0.02792052290861224, 1.}}], 
     {LABColor[0.22758498584015385`, 0.5225266106844437, -0.7642001456576731],
       ArrowBox[{{1.7301001707355588`, -1.4617815000751082`}, {
       1.6448998292644412`, -1.7858137641165368`}}]}}, 
    {Arrowheads[{{0.026896038085676838`, 1.}}], 
     {LABColor[0.2152017625578487, 0.5225487220308757, -0.7937953741863909], 
      ArrowBox[{{2.0539920911702807`, -1.4626458321779574`}, {
       2.0710079088297193`, -1.7849494320136876`}}]}}, 
    {Arrowheads[{{0.026005210609879013`, 1.}}], 
     {LABColor[0.20611448048761538`, 0.5225649481811597, -0.8155134829083562],
       ArrowBox[{{2.3951176467202315`, -1.473632751482615}, {
       2.4798823532797685`, -1.77396251270903}}]}}, 
    {Arrowheads[{{0.02525728191823047, 1.}}], 
     {LABColor[0.199692023008096, 0.5225764160501496, -0.8308628061410199], 
      ArrowBox[{{2.747772492074109, -1.4867726703042035`}, {
       2.877227507925891, -1.7608225938874416`}}]}}, 
    {Arrowheads[{{0.0263272115599333, 1.}}], 
     {LABColor[0.20921880398558637`, 0.5225594051354813, -0.8080943189915752],
       ArrowBox[{{-2.5360956183919785`, -1.1684685632953324`}, \
{-2.7139043816080215`, -1.4296076480579836`}}]}}, 
    {Arrowheads[{{0.027499133019890914`, 1.}}], 
     {LABColor[0.22224124137249202`, 0.5225361524154191, -0.7769714036019202],
       ArrowBox[{{-2.179527240648354, -1.1498507282085606`}, \
{-2.320472759351646, -1.4482254831447554`}}]}}, 
    {Arrowheads[{{0.0289948009902383, 1.}}], 
     {LABColor[0.242790603952653, 0.522499459701042, -0.7278595473578053], 
      ArrowBox[{{-1.8360652101255361`, -1.12948213386169}, \
{-1.9139347898744639`, -1.468594077491626}}]}}, 
    {Arrowheads[{{0.03083597061380126, 1.}}], 
     {LABColor[0.2741375997421977, 0.5224434868523173, -0.6529419364151048], 
      ArrowBox[{{-1.5163692363395709`, -1.1147478370386017`}, \
{-1.4836307636604291`, -1.4833283743147143`}}]}}, 
    {Arrowheads[{{0.032987181405953574`, 1.}}], 
     {LABColor[0.3192216926993193, 0.5223629851949363, -0.545193412169195], 
      ArrowBox[{{-1.2328096522249268`, -1.1330542877211875`}, \
{-1.0171903477750732`, -1.4650219236321285`}}]}}, 
    {Arrowheads[{{0.035655147889548086`, 1.}}], 
     {LABColor[0.3877985194402249, 0.5222405351721349, -0.38129853497098776`],
       ArrowBox[{{-0.9576681340731048, -1.2476535686298518`}, \
{-0.5423318659268952, -1.3504226427234642`}}]}}, 
    {Arrowheads[{{0.039309232381449837`, 1.}}], 
     {LABColor[0.5180825622740234, 0.5297572924007219, 0.1691134567155203], 
      ArrowBox[{{-0.5578193652389057, -1.4480510135360822`}, \
{-0.19218063476109426`, -1.1500251978172338`}}]}}, 
    {Arrowheads[{{0.04147141769309818, 1.}}], 
     {LABColor[0.6103550011341863, 0.5357699262338226, 0.5801894725276509], 
      ArrowBox[{{0., -1.547866611835247}, {0., -1.050209599518069}}]}}, 
    {Arrowheads[{{0.039309232381449837`, 1.}}], 
     {LABColor[0.5180825622740234, 0.5297572924007219, 0.1691134567155203], 
      ArrowBox[{{0.5578193652389057, -1.4480510135360822`}, {
       0.19218063476109426`, -1.1500251978172338`}}]}}, 
    {Arrowheads[{{0.035655147889548086`, 1.}}], 
     {LABColor[0.3877985194402249, 0.5222405351721349, -0.38129853497098776`],
       ArrowBox[{{0.9576681340731048, -1.2476535686298518`}, {
       0.5423318659268952, -1.3504226427234642`}}]}}, 
    {Arrowheads[{{0.032987181405953574`, 1.}}], 
     {LABColor[0.3192216926993193, 0.5223629851949363, -0.545193412169195], 
      ArrowBox[{{1.2328096522249268`, -1.1330542877211875`}, {
       1.0171903477750732`, -1.4650219236321285`}}]}}, 
    {Arrowheads[{{0.03083597061380126, 1.}}], 
     {LABColor[0.2741375997421977, 0.5224434868523173, -0.6529419364151048], 
      ArrowBox[{{1.5163692363395709`, -1.1147478370386017`}, {
       1.4836307636604291`, -1.4833283743147143`}}]}}, 
    {Arrowheads[{{0.0289948009902383, 1.}}], 
     {LABColor[0.242790603952653, 0.522499459701042, -0.7278595473578053], 
      ArrowBox[{{1.8360652101255361`, -1.12948213386169}, {
       1.9139347898744639`, -1.468594077491626}}]}}, 
    {Arrowheads[{{0.027499133019890914`, 1.}}], 
     {LABColor[0.22224124137249202`, 0.5225361524154191, -0.7769714036019202],
       ArrowBox[{{2.179527240648354, -1.1498507282085606`}, {
       2.320472759351646, -1.4482254831447554`}}]}}, 
    {Arrowheads[{{0.0263272115599333, 1.}}], 
     {LABColor[0.20921880398558637`, 0.5225594051354813, -0.8080943189915752],
       ArrowBox[{{2.5360956183919785`, -1.1684685632953324`}, {
       2.7139043816080215`, -1.4296076480579836`}}]}}, 
    {Arrowheads[{{0.026417897815989883`, 1.}}], 
     {LABColor[0.210129944113769, 0.5225577782137532, -0.8059167437593026], 
      ArrowBox[{{-2.6899046434338305`, -0.8738048501090598}, \
{-2.9350953565661695`, -1.0747523084059272`}}]}}, 
    {Arrowheads[{{0.027778306029721447`, 1.}}], 
     {LABColor[0.22574239788989078`, 0.5225299007890934, -0.7686038304034873],
       ArrowBox[{{-2.320197432845007, -0.8558769659637582}, \
{-2.554802567154993, -1.0926801925512288`}}]}}, 
    {Arrowheads[{{0.029674942533515335`, 1.}}], 
     {LABColor[0.2535927020586946, 0.5224801715942244, -0.702043121799627], 
      ArrowBox[{{-1.956054543650166, -0.8315514110669093}, \
{-2.1689454563498343`, -1.1170057474480777`}}]}}, 
    {Arrowheads[{{0.03234263848644123, 1.}}], 
     {LABColor[0.3047572425303029, 0.5223888127570615, -0.5797626594915777], 
      ArrowBox[{{-1.6046146604075269`, -0.7988143777970045}, \
{-1.7703853395924731`, -1.1497427807179825`}}]}}, 
    {Arrowheads[{{0.03602615942741791, 1.}}], 
     {LABColor[0.39844534986654984`, 0.5222215243095677, -0.3558531907023559],
       ArrowBox[{{-1.2834734000444932`, -0.7600794047346833}, \
{-1.3415265999555068`, -1.1884777537803037`}}]}}, 
    {Arrowheads[{{0.04076334921110454, 1.}}], 
     {LABColor[0.5789886636018041, 0.5337260407074688, 0.44045165674312764`], 
      ArrowBox[{{-1.0300160567112524`, -0.7478714189218876}, \
{-0.8449839432887476, -1.2006857395930994`}}]}}, 
    {Arrowheads[{{0.04684222047694286, 1.}}], 
     {LABColor[0.8154643573741762, 0.14803980728376048`, 0.8275098258787097], 
      ArrowBox[{{-0.8353255833469493, -0.9067717546915601}, \
{-0.28967441665305066`, -1.0417854038234269`}}]}}, 
    {Arrowheads[{{0.047730405085367446`, 1.}}], 
     {LABColor[0.8167969189733053, 0.14500114740169545`, 0.8282532063436999], 
      ArrowBox[{{-0.34542193579186586`, -1.2131834948658324`}, \
{-0.029578064208134136`, -0.7353736636491546}}]}}, 
    {Arrowheads[{{0.047730405085367446`, 1.}}], 
     {LABColor[0.8167969189733053, 0.14500114740169545`, 0.8282532063436999], 
      ArrowBox[{{0.34542193579186586`, -1.2131834948658324`}, {
       0.029578064208134136`, -0.7353736636491546}}]}}, 
    {Arrowheads[{{0.04684222047694286, 1.}}], 
     {LABColor[0.8154643573741762, 0.14803980728376048`, 0.8275098258787097], 
      ArrowBox[{{0.8353255833469493, -0.9067717546915601}, {
       0.28967441665305066`, -1.0417854038234269`}}]}}, 
    {Arrowheads[{{0.04076334921110454, 1.}}], 
     {LABColor[0.5789886636018041, 0.5337260407074688, 0.44045165674312764`], 
      ArrowBox[{{1.0300160567112524`, -0.7478714189218876}, {
       0.8449839432887476, -1.2006857395930994`}}]}}, 
    {Arrowheads[{{0.03602615942741791, 1.}}], 
     {LABColor[0.39844534986654984`, 0.5222215243095677, -0.3558531907023559],
       ArrowBox[{{1.2834734000444932`, -0.7600794047346833}, {
       1.3415265999555068`, -1.1884777537803037`}}]}}, 
    {Arrowheads[{{0.03234263848644123, 1.}}], 
     {LABColor[0.3047572425303029, 0.5223888127570615, -0.5797626594915777], 
      ArrowBox[{{1.6046146604075269`, -0.7988143777970045}, {
       1.7703853395924731`, -1.1497427807179825`}}]}}, 
    {Arrowheads[{{0.029674942533515335`, 1.}}], 
     {LABColor[0.2535927020586946, 0.5224801715942244, -0.702043121799627], 
      ArrowBox[{{1.956054543650166, -0.8315514110669093}, {
       2.1689454563498343`, -1.1170057474480777`}}]}}, 
    {Arrowheads[{{0.027778306029721447`, 1.}}], 
     {LABColor[0.22574239788989078`, 0.5225299007890934, -0.7686038304034873],
       ArrowBox[{{2.320197432845007, -0.8558769659637582}, {
       2.554802567154993, -1.0926801925512288`}}]}}, 
    {Arrowheads[{{0.026417897815989883`, 1.}}], 
     {LABColor[0.210129944113769, 0.5225577782137532, -0.8059167437593026], 
      ArrowBox[{{2.6899046434338305`, -0.8738048501090598}, {
       2.9350953565661695`, -1.0747523084059272`}}]}}, 
    {Arrowheads[{{0.027672576636458942`, 1.}}], 
     {LABColor[0.224398366927846, 0.5225323006759032, -0.7718159911280884], 
      ArrowBox[{{-2.47869547686834, -0.5710158017690737}, {-2.77130452313166, \
-0.7280223039075843}}]}}, 
    {Arrowheads[{{0.029720329686950677`, 1.}}], 
     {LABColor[0.2543459781281422, 0.5224788265528123, -0.7002428330612037], 
      ArrowBox[{{-2.1002195234100514`, -0.5527485164456576}, \
{-2.3997804765899486`, -0.7462895892310004}}]}}, 
    {Arrowheads[{{0.03285055902521234, 1.}}], 
     {LABColor[0.3160873511773049, 0.5223685818404662, -0.5526843175268992], 
      ArrowBox[{{-1.722553123827427, -0.5245803392107798}, \
{-2.027446876172573, -0.7744577664658782}}]}}, 
    {Arrowheads[{{0.037864571375786006`, 1.}}], 
     {LABColor[0.4622463720529094, 0.5261189083872279, -0.07963816292041997], 
      ArrowBox[{{-1.350808128632247, -0.4781833791600796}, \
{-1.649191871367753, -0.8208547265165784}}]}}, 
    {Arrowheads[{{0.04618122553372784, 1.}}], 
     {LABColor[0.7889577170281777, 0.20848329048210346`, 0.8127228782144401], 
      ArrowBox[{{-1.0066501454337344`, -0.39897821139957856`}, \
{-1.2433498545662656`, -0.9000598942770794}}]}}, 
    {Arrowheads[{{0.04773040508536744, 1.}}], 
     {LABColor[0.8167969189733053, 0.14500114740169545`, 0.8282532063436999], 
      ArrowBox[{{-0.7753376256973128, -0.3642596950074235}, \
{-0.7246623743026872, -0.9347784106692345}}]}}, 
    {Arrowheads[{{0.04773040508536746, 1.}}], 
     {LABColor[0.8167969189733053, 0.14500114740169545`, 0.8282532063436999], 
      ArrowBox[{{-0.6529986832010115, -0.5807322180181296}, \
{-0.09700131679898849, -0.7183058876585284}}]}}, 
    {Arrowheads[{{0.047730405085367446`, 1.}}], 
     {LABColor[0.8167969189733053, 0.14500114740169545`, 0.8282532063436999], 
      ArrowBox[{{0., -0.9359014833505337}, {0., -0.3631366223261243}}]}}, 
    {Arrowheads[{{0.04773040508536746, 1.}}], 
     {LABColor[0.8167969189733053, 0.14500114740169545`, 0.8282532063436999], 
      ArrowBox[{{0.6529986832010115, -0.5807322180181296}, {
       0.09700131679898849, -0.7183058876585284}}]}}, 
    {Arrowheads[{{0.04773040508536744, 1.}}], 
     {LABColor[0.8167969189733053, 0.14500114740169545`, 0.8282532063436999], 
      ArrowBox[{{0.7753376256973128, -0.3642596950074235}, {
       0.7246623743026872, -0.9347784106692345}}]}}, 
    {Arrowheads[{{0.04618122553372784, 1.}}], 
     {LABColor[0.7889577170281777, 0.20848329048210346`, 0.8127228782144401], 
      ArrowBox[{{1.0066501454337344`, -0.39897821139957856`}, {
       1.2433498545662656`, -0.9000598942770794}}]}}, 
    {Arrowheads[{{0.037864571375786006`, 1.}}], 
     {LABColor[0.4622463720529094, 0.5261189083872279, -0.07963816292041997], 
      ArrowBox[{{1.350808128632247, -0.4781833791600796}, {
       1.649191871367753, -0.8208547265165784}}]}}, 
    {Arrowheads[{{0.03285055902521234, 1.}}], 
     {LABColor[0.3160873511773049, 0.5223685818404662, -0.5526843175268992], 
      ArrowBox[{{1.722553123827427, -0.5245803392107798}, {
       2.027446876172573, -0.7744577664658782}}]}}, 
    {Arrowheads[{{0.029720329686950677`, 1.}}], 
     {LABColor[0.2543459781281422, 0.5224788265528123, -0.7002428330612037], 
      ArrowBox[{{2.1002195234100514`, -0.5527485164456576}, {
       2.3997804765899486`, -0.7462895892310004}}]}}, 
    {Arrowheads[{{0.027672576636458942`, 1.}}], 
     {LABColor[0.224398366927846, 0.5225323006759032, -0.7718159911280884], 
      ArrowBox[{{2.47869547686834, -0.5710158017690737}, {
       2.77130452313166, -0.7280223039075843}}]}}, 
    {Arrowheads[{{0.027246162967876006`, 1.}}], 
     {LABColor[0.21920127944984155`, 0.5225415805377811, -0.784236746862588], 
      ArrowBox[{{-2.65335358469314, -0.2873811801747075}, {-2.97164641530686, \
-0.3621378726636215}}]}}, 
    {Arrowheads[{{0.029174173960340843`, 1.}}], 
     {LABColor[0.24555096439297247`, 0.5224945308319922, -0.7212624363964273],
       ArrowBox[{{-2.2686150151459628`, -0.27873095663356423`}, \
{-2.6063849848540372`, -0.37078809620476477`}}]}}, 
    {Arrowheads[{{0.0321956482356678, 1.}}], 
     {LABColor[0.3015731611601139, 0.5223944982175138, -0.5873724403746721], 
      ArrowBox[{{-1.8787880303135758`, -0.26504299817723437`}, \
{-2.2462119696864242`, -0.38447605466109464`}}]}}, 
    {Arrowheads[{{0.03730277801924593, 1.}}], 
     {LABColor[
      0.44179109809578626`, 0.5247860068862029, -0.17076691842435776`], 
      ArrowBox[{{-1.4799621782536603`, -0.2409624293865258}, \
{-1.8950378217463397`, -0.4085566234518032}}]}}, 
    {Arrowheads[{{0.046875, 1.}}], 
     {LABColor[0.8167969189733053, 0.14500114740169545`, 0.8282532063436999], 
      ArrowBox[{{-1.0646725348567276`, -0.1917816710421878}, \
{-1.5603274651432724`, -0.4577373817961412}}]}}, 
    {Arrowheads[{{0.04773040508536743, 1.}}], 
     {LABColor[0.8167969189733053, 0.14500114740169545`, 0.8282532063436999], 
      ArrowBox[{{-0.7160014511280841, -0.14322911752381406`}, \
{-1.158998548871916, -0.5062899353145149}}]}}, 
    {Arrowheads[{{0.04773040508536744, 1.}}], 
     {LABColor[0.8167969189733053, 0.14500114740169545`, 0.8282532063436999], 
      ArrowBox[{{-0.44018002180633786`, -0.06581412784877139}, \
{-0.6848199781936621, -0.5837049249895576}}]}}, 
    {Arrowheads[{{0.04773040508536744, 1.}}], 
     {LABColor[0.8167969189733053, 0.14500114740169545`, 0.8282532063436999], 
      ArrowBox[{{-0.46549868320101145`, -0.255972691598965}, {
       0.09049868320101145, -0.393546361239364}}]}}, 
    {Arrowheads[{{0.04773040508536744, 1.}}], 
     {LABColor[0.8167969189733053, 0.14500114740169545`, 0.8282532063436999], 
      ArrowBox[{{
       0.46549868320101145`, -0.255972691598965}, {-0.09049868320101145, \
-0.393546361239364}}]}}, 
    {Arrowheads[{{0.04773040508536744, 1.}}], 
     {LABColor[0.8167969189733053, 0.14500114740169545`, 0.8282532063436999], 
      ArrowBox[{{0.44018002180633786`, -0.06581412784877139}, {
       0.6848199781936621, -0.5837049249895576}}]}}, 
    {Arrowheads[{{0.04773040508536743, 1.}}], 
     {LABColor[0.8167969189733053, 0.14500114740169545`, 0.8282532063436999], 
      ArrowBox[{{0.7160014511280841, -0.14322911752381406`}, {
       1.158998548871916, -0.5062899353145149}}]}}, 
    {Arrowheads[{{0.046875, 1.}}], 
     {LABColor[0.8167969189733053, 0.14500114740169545`, 0.8282532063436999], 
      ArrowBox[{{1.0646725348567276`, -0.1917816710421878}, {
       1.5603274651432724`, -0.4577373817961412}}]}}, 
    {Arrowheads[{{0.03730277801924593, 1.}}], 
     {LABColor[
      0.44179109809578626`, 0.5247860068862029, -0.17076691842435776`], 
      ArrowBox[{{1.4799621782536603`, -0.2409624293865258}, {
       1.8950378217463397`, -0.4085566234518032}}]}}, 
    {Arrowheads[{{0.0321956482356678, 1.}}], 
     {LABColor[0.3015731611601139, 0.5223944982175138, -0.5873724403746721], 
      ArrowBox[{{1.8787880303135758`, -0.26504299817723437`}, {
       2.2462119696864242`, -0.38447605466109464`}}]}}, 
    {Arrowheads[{{0.029174173960340843`, 1.}}], 
     {LABColor[0.24555096439297247`, 0.5224945308319922, -0.7212624363964273],
       ArrowBox[{{2.2686150151459628`, -0.27873095663356423`}, {
       2.6063849848540372`, -0.37078809620476477`}}]}}, 
    {Arrowheads[{{0.027246162967876006`, 1.}}], 
     {LABColor[0.21920127944984155`, 0.5225415805377811, -0.784236746862588], 
      ArrowBox[{{2.65335358469314, -0.2873811801747075}, {
       2.97164641530686, -0.3621378726636215}}]}}, 
    {Arrowheads[{{0.028267675138664128`, 1.}}], 
     {LABColor[0.2322500680887684, 0.522518280765215, -0.7530508534172354], 
      ArrowBox[{{-2.4553939491680152`, 0.}, {-2.7946060508319848`, 0.}}]}}, 
    {Arrowheads[{{0.03079397463229409, 1.}}], 
     {LABColor[0.27334817897893515`, 0.5224448964332947, -0.6548286090011877],
       ArrowBox[{{-2.0652361522062357`, 0.}, {-2.4347638477937643`, 0.}}]}}, 
    {Arrowheads[{{0.03498374517711428, 1.}}], 
     {LABColor[0.36922072140055595`, 0.5222737074826903, -0.4256984594502642],
       ArrowBox[{{-1.6650975289373142`, 0.}, {-2.084902471062686, 0.}}]}}, 
    {Arrowheads[{{0.042696731861896785`, 1.}}], 
     {LABColor[0.6607006219402569, 0.500949837385899, 0.7411736012076074], 
      ArrowBox[{{-1.2438196088286193`, 0.}, {-1.7561803911713807`, 0.}}]}}, 
    {Arrowheads[{{0.047730405085367446`, 1.}}], 
     {LABColor[0.8167969189733053, 0.14500114740169545`, 0.8282532063436999], 
      ArrowBox[{{-0.8386175694877953, 0.}, {-1.4113824305122047`, 0.}}]}}, 
    {Arrowheads[{{0.047730405085367446`, 1.}}], 
     {LABColor[0.8167969189733053, 0.14500114740169545`, 0.8282532063436999], 
      ArrowBox[{{-0.4636175694877953, 0.}, {-1.0363824305122047`, 0.}}]}}, 
    {Arrowheads[{{0.047730405085367446`, 1.}}], 
     {LABColor[0.8167969189733053, 0.14500114740169545`, 0.8282532063436999], 
      ArrowBox[{{-0.08861756948779531, 0.}, {-0.6613824305122047, 0.}}]}}, 
    {Arrowheads[{{0.04773040508536744, 1.}}], 
     {LABColor[0.8167969189733053, 0.14500114740169545`, 0.8282532063436999], 
      ArrowBox[{{0.2863824305122046, 0.}, {-0.2863824305122046, 0.}}]}}, 
    {Arrowheads[{{0.047730405085367446`, 1.}}], 
     {LABColor[0.8167969189733053, 0.14500114740169545`, 0.8282532063436999], 
      ArrowBox[{{0.08861756948779531, 0.}, {0.6613824305122047, 0.}}]}}, 
    {Arrowheads[{{0.047730405085367446`, 1.}}], 
     {LABColor[0.8167969189733053, 0.14500114740169545`, 0.8282532063436999], 
      ArrowBox[{{0.4636175694877953, 0.}, {1.0363824305122047`, 0.}}]}}, 
    {Arrowheads[{{0.047730405085367446`, 1.}}], 
     {LABColor[0.8167969189733053, 0.14500114740169545`, 0.8282532063436999], 
      ArrowBox[{{0.8386175694877953, 0.}, {1.4113824305122047`, 0.}}]}}, 
    {Arrowheads[{{0.042696731861896785`, 1.}}], 
     {LABColor[0.6607006219402569, 0.500949837385899, 0.7411736012076074], 
      ArrowBox[{{1.2438196088286193`, 0.}, {1.7561803911713807`, 0.}}]}}, 
    {Arrowheads[{{0.03498374517711428, 1.}}], 
     {LABColor[0.36922072140055595`, 0.5222737074826903, -0.4256984594502642],
       ArrowBox[{{1.6650975289373142`, 0.}, {2.084902471062686, 0.}}]}}, 
    {Arrowheads[{{0.03079397463229409, 1.}}], 
     {LABColor[0.27334817897893515`, 0.5224448964332947, -0.6548286090011877],
       ArrowBox[{{2.0652361522062357`, 0.}, {2.4347638477937643`, 0.}}]}}, 
    {Arrowheads[{{0.028267675138664128`, 1.}}], 
     {LABColor[0.2322500680887684, 0.522518280765215, -0.7530508534172354], 
      ArrowBox[{{2.4553939491680152`, 0.}, {2.7946060508319848`, 0.}}]}}, 
    {Arrowheads[{{0.027246162967876006`, 1.}}], 
     {LABColor[0.21920127944984155`, 0.5225415805377811, -0.784236746862588], 
      ArrowBox[{{-2.65335358469314, 0.2873811801747075}, {-2.97164641530686, 
       0.3621378726636215}}]}}, 
    {Arrowheads[{{0.029174173960340843`, 1.}}], 
     {LABColor[0.24555096439297247`, 0.5224945308319922, -0.7212624363964273],
       ArrowBox[{{-2.2686150151459628`, 
       0.27873095663356423`}, {-2.6063849848540372`, 
       0.37078809620476477`}}]}}, 
    {Arrowheads[{{0.0321956482356678, 1.}}], 
     {LABColor[0.3015731611601139, 0.5223944982175138, -0.5873724403746721], 
      ArrowBox[{{-1.8787880303135758`, 
       0.26504299817723437`}, {-2.2462119696864242`, 
       0.38447605466109464`}}]}}, 
    {Arrowheads[{{0.03730277801924593, 1.}}], 
     {LABColor[
      0.44179109809578626`, 0.5247860068862029, -0.17076691842435776`], 
      ArrowBox[{{-1.4799621782536603`, 
       0.2409624293865258}, {-1.8950378217463397`, 0.4085566234518032}}]}}, 
    {Arrowheads[{{0.046875, 1.}}], 
     {LABColor[0.8167969189733053, 0.14500114740169545`, 0.8282532063436999], 
      ArrowBox[{{-1.0646725348567276`, 
       0.1917816710421878}, {-1.5603274651432724`, 0.4577373817961412}}]}}, 
    {Arrowheads[{{0.04773040508536743, 1.}}], 
     {LABColor[0.8167969189733053, 0.14500114740169545`, 0.8282532063436999], 
      ArrowBox[{{-0.7160014511280841, 
       0.14322911752381406`}, {-1.158998548871916, 0.5062899353145149}}]}}, 
    {Arrowheads[{{0.04773040508536744, 1.}}], 
     {LABColor[0.8167969189733053, 0.14500114740169545`, 0.8282532063436999], 
      ArrowBox[{{-0.44018002180633786`, 
       0.06581412784877139}, {-0.6848199781936621, 0.5837049249895576}}]}}, 
    {Arrowheads[{{0.04773040508536744, 1.}}], 
     {LABColor[0.8167969189733053, 0.14500114740169545`, 0.8282532063436999], 
      ArrowBox[{{-0.46549868320101145`, 0.255972691598965}, {
       0.09049868320101145, 0.393546361239364}}]}}, 
    {Arrowheads[{{0.04773040508536744, 1.}}], 
     {LABColor[0.8167969189733053, 0.14500114740169545`, 0.8282532063436999], 
      ArrowBox[{{0.46549868320101145`, 
       0.255972691598965}, {-0.09049868320101145, 0.393546361239364}}]}}, 
    {Arrowheads[{{0.04773040508536744, 1.}}], 
     {LABColor[0.8167969189733053, 0.14500114740169545`, 0.8282532063436999], 
      ArrowBox[{{0.44018002180633786`, 0.06581412784877139}, {
       0.6848199781936621, 0.5837049249895576}}]}}, 
    {Arrowheads[{{0.04773040508536743, 1.}}], 
     {LABColor[0.8167969189733053, 0.14500114740169545`, 0.8282532063436999], 
      ArrowBox[{{0.7160014511280841, 0.14322911752381406`}, {
       1.158998548871916, 0.5062899353145149}}]}}, 
    {Arrowheads[{{0.046875, 1.}}], 
     {LABColor[0.8167969189733053, 0.14500114740169545`, 0.8282532063436999], 
      ArrowBox[{{1.0646725348567276`, 0.1917816710421878}, {
       1.5603274651432724`, 0.4577373817961412}}]}}, 
    {Arrowheads[{{0.03730277801924593, 1.}}], 
     {LABColor[
      0.44179109809578626`, 0.5247860068862029, -0.17076691842435776`], 
      ArrowBox[{{1.4799621782536603`, 0.2409624293865258}, {
       1.8950378217463397`, 0.4085566234518032}}]}}, 
    {Arrowheads[{{0.0321956482356678, 1.}}], 
     {LABColor[0.3015731611601139, 0.5223944982175138, -0.5873724403746721], 
      ArrowBox[{{1.8787880303135758`, 0.26504299817723437`}, {
       2.2462119696864242`, 0.38447605466109464`}}]}}, 
    {Arrowheads[{{0.029174173960340843`, 1.}}], 
     {LABColor[0.24555096439297247`, 0.5224945308319922, -0.7212624363964273],
       ArrowBox[{{2.2686150151459628`, 0.27873095663356423`}, {
       2.6063849848540372`, 0.37078809620476477`}}]}}, 
    {Arrowheads[{{0.027246162967876006`, 1.}}], 
     {LABColor[0.21920127944984155`, 0.5225415805377811, -0.784236746862588], 
      ArrowBox[{{2.65335358469314, 0.2873811801747075}, {2.97164641530686, 
       0.3621378726636215}}]}}, 
    {Arrowheads[{{0.027672576636458942`, 1.}}], 
     {LABColor[0.224398366927846, 0.5225323006759032, -0.7718159911280884], 
      ArrowBox[{{-2.47869547686834, 0.5710158017690737}, {-2.77130452313166, 
       0.7280223039075843}}]}}, 
    {Arrowheads[{{0.029720329686950677`, 1.}}], 
     {LABColor[0.2543459781281422, 0.5224788265528123, -0.7002428330612037], 
      ArrowBox[{{-2.1002195234100514`, 
       0.5527485164456576}, {-2.3997804765899486`, 0.7462895892310004}}]}}, 
    {Arrowheads[{{0.03285055902521234, 1.}}], 
     {LABColor[0.3160873511773049, 0.5223685818404662, -0.5526843175268992], 
      ArrowBox[{{-1.722553123827427, 0.5245803392107798}, {-2.027446876172573,
        0.7744577664658782}}]}}, 
    {Arrowheads[{{0.037864571375786006`, 1.}}], 
     {LABColor[0.4622463720529094, 0.5261189083872279, -0.07963816292041997], 
      ArrowBox[{{-1.350808128632247, 0.4781833791600796}, {-1.649191871367753,
        0.8208547265165784}}]}}, 
    {Arrowheads[{{0.04618122553372784, 1.}}], 
     {LABColor[0.7889577170281777, 0.20848329048210346`, 0.8127228782144401], 
      ArrowBox[{{-1.0066501454337344`, 
       0.39897821139957856`}, {-1.2433498545662656`, 
       0.9000598942770794}}]}}, 
    {Arrowheads[{{0.04773040508536744, 1.}}], 
     {LABColor[0.8167969189733053, 0.14500114740169545`, 0.8282532063436999], 
      ArrowBox[{{-0.7753376256973128, 
       0.3642596950074235}, {-0.7246623743026872, 0.9347784106692345}}]}}, 
    {Arrowheads[{{0.04773040508536746, 1.}}], 
     {LABColor[0.8167969189733053, 0.14500114740169545`, 0.8282532063436999], 
      ArrowBox[{{-0.6529986832010115, 
       0.5807322180181296}, {-0.09700131679898849, 0.7183058876585284}}]}}, 
    {Arrowheads[{{0.047730405085367446`, 1.}}], 
     {LABColor[0.8167969189733053, 0.14500114740169545`, 0.8282532063436999], 
      ArrowBox[{{0., 0.9359014833505337}, {0., 0.3631366223261243}}]}}, 
    {Arrowheads[{{0.04773040508536746, 1.}}], 
     {LABColor[0.8167969189733053, 0.14500114740169545`, 0.8282532063436999], 
      ArrowBox[{{0.6529986832010115, 0.5807322180181296}, {
       0.09700131679898849, 0.7183058876585284}}]}}, 
    {Arrowheads[{{0.04773040508536744, 1.}}], 
     {LABColor[0.8167969189733053, 0.14500114740169545`, 0.8282532063436999], 
      ArrowBox[{{0.7753376256973128, 0.3642596950074235}, {0.7246623743026872,
        0.9347784106692345}}]}}, 
    {Arrowheads[{{0.04618122553372784, 1.}}], 
     {LABColor[0.7889577170281777, 0.20848329048210346`, 0.8127228782144401], 
      ArrowBox[{{1.0066501454337344`, 0.39897821139957856`}, {
       1.2433498545662656`, 0.9000598942770794}}]}}, 
    {Arrowheads[{{0.037864571375786006`, 1.}}], 
     {LABColor[0.4622463720529094, 0.5261189083872279, -0.07963816292041997], 
      ArrowBox[{{1.350808128632247, 0.4781833791600796}, {1.649191871367753, 
       0.8208547265165784}}]}}, 
    {Arrowheads[{{0.03285055902521234, 1.}}], 
     {LABColor[0.3160873511773049, 0.5223685818404662, -0.5526843175268992], 
      ArrowBox[{{1.722553123827427, 0.5245803392107798}, {2.027446876172573, 
       0.7744577664658782}}]}}, 
    {Arrowheads[{{0.029720329686950677`, 1.}}], 
     {LABColor[0.2543459781281422, 0.5224788265528123, -0.7002428330612037], 
      ArrowBox[{{2.1002195234100514`, 0.5527485164456576}, {
       2.3997804765899486`, 0.7462895892310004}}]}}, 
    {Arrowheads[{{0.027672576636458942`, 1.}}], 
     {LABColor[0.224398366927846, 0.5225323006759032, -0.7718159911280884], 
      ArrowBox[{{2.47869547686834, 0.5710158017690737}, {2.77130452313166, 
       0.7280223039075843}}]}}, 
    {Arrowheads[{{0.026417897815989883`, 1.}}], 
     {LABColor[0.210129944113769, 0.5225577782137532, -0.8059167437593026], 
      ArrowBox[{{-2.6899046434338305`, 
       0.8738048501090598}, {-2.9350953565661695`, 1.0747523084059272`}}]}}, 
    {Arrowheads[{{0.027778306029721447`, 1.}}], 
     {LABColor[0.22574239788989078`, 0.5225299007890934, -0.7686038304034873],
       ArrowBox[{{-2.320197432845007, 
       0.8558769659637582}, {-2.554802567154993, 1.0926801925512288`}}]}}, 
    {Arrowheads[{{0.029674942533515335`, 1.}}], 
     {LABColor[0.2535927020586946, 0.5224801715942244, -0.702043121799627], 
      ArrowBox[{{-1.956054543650166, 
       0.8315514110669093}, {-2.1689454563498343`, 1.1170057474480777`}}]}}, 
    {Arrowheads[{{0.03234263848644123, 1.}}], 
     {LABColor[0.3047572425303029, 0.5223888127570615, -0.5797626594915777], 
      ArrowBox[{{-1.6046146604075269`, 
       0.7988143777970045}, {-1.7703853395924731`, 1.1497427807179825`}}]}}, 
    {Arrowheads[{{0.03602615942741791, 1.}}], 
     {LABColor[0.39844534986654984`, 0.5222215243095677, -0.3558531907023559],
       ArrowBox[{{-1.2834734000444932`, 
       0.7600794047346833}, {-1.3415265999555068`, 1.1884777537803037`}}]}}, 
    {Arrowheads[{{0.04076334921110454, 1.}}], 
     {LABColor[0.5789886636018041, 0.5337260407074688, 0.44045165674312764`], 
      ArrowBox[{{-1.0300160567112524`, 
       0.7478714189218876}, {-0.8449839432887476, 1.2006857395930994`}}]}}, 
    {Arrowheads[{{0.04684222047694286, 1.}}], 
     {LABColor[0.8154643573741762, 0.14803980728376048`, 0.8275098258787097], 
      ArrowBox[{{-0.8353255833469493, 
       0.9067717546915601}, {-0.28967441665305066`, 
       1.0417854038234269`}}]}}, 
    {Arrowheads[{{0.047730405085367446`, 1.}}], 
     {LABColor[0.8167969189733053, 0.14500114740169545`, 0.8282532063436999], 
      ArrowBox[{{-0.34542193579186586`, 
       1.2131834948658324`}, {-0.029578064208134136`, 0.7353736636491546}}]}}, 
    {Arrowheads[{{0.047730405085367446`, 1.}}], 
     {LABColor[0.8167969189733053, 0.14500114740169545`, 0.8282532063436999], 
      ArrowBox[{{0.34542193579186586`, 1.2131834948658324`}, {
       0.029578064208134136`, 0.7353736636491546}}]}}, 
    {Arrowheads[{{0.04684222047694286, 1.}}], 
     {LABColor[0.8154643573741762, 0.14803980728376048`, 0.8275098258787097], 
      ArrowBox[{{0.8353255833469493, 0.9067717546915601}, {
       0.28967441665305066`, 1.0417854038234269`}}]}}, 
    {Arrowheads[{{0.04076334921110454, 1.}}], 
     {LABColor[0.5789886636018041, 0.5337260407074688, 0.44045165674312764`], 
      ArrowBox[{{1.0300160567112524`, 0.7478714189218876}, {
       0.8449839432887476, 1.2006857395930994`}}]}}, 
    {Arrowheads[{{0.03602615942741791, 1.}}], 
     {LABColor[0.39844534986654984`, 0.5222215243095677, -0.3558531907023559],
       ArrowBox[{{1.2834734000444932`, 0.7600794047346833}, {
       1.3415265999555068`, 1.1884777537803037`}}]}}, 
    {Arrowheads[{{0.03234263848644123, 1.}}], 
     {LABColor[0.3047572425303029, 0.5223888127570615, -0.5797626594915777], 
      ArrowBox[{{1.6046146604075269`, 0.7988143777970045}, {
       1.7703853395924731`, 1.1497427807179825`}}]}}, 
    {Arrowheads[{{0.029674942533515335`, 1.}}], 
     {LABColor[0.2535927020586946, 0.5224801715942244, -0.702043121799627], 
      ArrowBox[{{1.956054543650166, 0.8315514110669093}, {2.1689454563498343`,
        1.1170057474480777`}}]}}, 
    {Arrowheads[{{0.027778306029721447`, 1.}}], 
     {LABColor[0.22574239788989078`, 0.5225299007890934, -0.7686038304034873],
       ArrowBox[{{2.320197432845007, 0.8558769659637582}, {2.554802567154993, 
       1.0926801925512288`}}]}}, 
    {Arrowheads[{{0.026417897815989883`, 1.}}], 
     {LABColor[0.210129944113769, 0.5225577782137532, -0.8059167437593026], 
      ArrowBox[{{2.6899046434338305`, 0.8738048501090598}, {
       2.9350953565661695`, 1.0747523084059272`}}]}}, 
    {Arrowheads[{{0.0263272115599333, 1.}}], 
     {LABColor[0.20921880398558637`, 0.5225594051354813, -0.8080943189915752],
       ArrowBox[{{-2.5360956183919785`, 
       1.1684685632953324`}, {-2.7139043816080215`, 
       1.4296076480579836`}}]}}, 
    {Arrowheads[{{0.027499133019890914`, 1.}}], 
     {LABColor[0.22224124137249202`, 0.5225361524154191, -0.7769714036019202],
       ArrowBox[{{-2.179527240648354, 
       1.1498507282085606`}, {-2.320472759351646, 1.4482254831447554`}}]}}, 
    {Arrowheads[{{0.0289948009902383, 1.}}], 
     {LABColor[0.242790603952653, 0.522499459701042, -0.7278595473578053], 
      ArrowBox[{{-1.8360652101255361`, 
       1.12948213386169}, {-1.9139347898744639`, 1.468594077491626}}]}}, 
    {Arrowheads[{{0.03083597061380126, 1.}}], 
     {LABColor[0.2741375997421977, 0.5224434868523173, -0.6529419364151048], 
      ArrowBox[{{-1.5163692363395709`, 
       1.1147478370386017`}, {-1.4836307636604291`, 
       1.4833283743147143`}}]}}, 
    {Arrowheads[{{0.032987181405953574`, 1.}}], 
     {LABColor[0.3192216926993193, 0.5223629851949363, -0.545193412169195], 
      ArrowBox[{{-1.2328096522249268`, 
       1.1330542877211875`}, {-1.0171903477750732`, 
       1.4650219236321285`}}]}}, 
    {Arrowheads[{{0.035655147889548086`, 1.}}], 
     {LABColor[0.3877985194402249, 0.5222405351721349, -0.38129853497098776`],
       ArrowBox[{{-0.9576681340731048, 
       1.2476535686298518`}, {-0.5423318659268952, 1.3504226427234642`}}]}}, 
    {Arrowheads[{{0.039309232381449837`, 1.}}], 
     {LABColor[0.5180825622740234, 0.5297572924007219, 0.1691134567155203], 
      ArrowBox[{{-0.5578193652389057, 
       1.4480510135360822`}, {-0.19218063476109426`, 1.1500251978172338`}}]}}, 
    {Arrowheads[{{0.04147141769309818, 1.}}], 
     {LABColor[0.6103550011341863, 0.5357699262338226, 0.5801894725276509], 
      ArrowBox[{{0., 1.547866611835247}, {0., 1.050209599518069}}]}}, 
    {Arrowheads[{{0.039309232381449837`, 1.}}], 
     {LABColor[0.5180825622740234, 0.5297572924007219, 0.1691134567155203], 
      ArrowBox[{{0.5578193652389057, 1.4480510135360822`}, {
       0.19218063476109426`, 1.1500251978172338`}}]}}, 
    {Arrowheads[{{0.035655147889548086`, 1.}}], 
     {LABColor[0.3877985194402249, 0.5222405351721349, -0.38129853497098776`],
       ArrowBox[{{0.9576681340731048, 1.2476535686298518`}, {
       0.5423318659268952, 1.3504226427234642`}}]}}, 
    {Arrowheads[{{0.032987181405953574`, 1.}}], 
     {LABColor[0.3192216926993193, 0.5223629851949363, -0.545193412169195], 
      ArrowBox[{{1.2328096522249268`, 1.1330542877211875`}, {
       1.0171903477750732`, 1.4650219236321285`}}]}}, 
    {Arrowheads[{{0.03083597061380126, 1.}}], 
     {LABColor[0.2741375997421977, 0.5224434868523173, -0.6529419364151048], 
      ArrowBox[{{1.5163692363395709`, 1.1147478370386017`}, {
       1.4836307636604291`, 1.4833283743147143`}}]}}, 
    {Arrowheads[{{0.0289948009902383, 1.}}], 
     {LABColor[0.242790603952653, 0.522499459701042, -0.7278595473578053], 
      ArrowBox[{{1.8360652101255361`, 1.12948213386169}, {1.9139347898744639`,
        1.468594077491626}}]}}, 
    {Arrowheads[{{0.027499133019890914`, 1.}}], 
     {LABColor[0.22224124137249202`, 0.5225361524154191, -0.7769714036019202],
       ArrowBox[{{2.179527240648354, 1.1498507282085606`}, {2.320472759351646,
        1.4482254831447554`}}]}}, 
    {Arrowheads[{{0.0263272115599333, 1.}}], 
     {LABColor[0.20921880398558637`, 0.5225594051354813, -0.8080943189915752],
       ArrowBox[{{2.5360956183919785`, 1.1684685632953324`}, {
       2.7139043816080215`, 1.4296076480579836`}}]}}, 
    {Arrowheads[{{0.02525728191823047, 1.}}], 
     {LABColor[0.199692023008096, 0.5225764160501496, -0.8308628061410199], 
      ArrowBox[{{-2.747772492074109, 
       1.4867726703042035`}, {-2.877227507925891, 1.7608225938874416`}}]}}, 
    {Arrowheads[{{0.026005210609879013`, 1.}}], 
     {LABColor[0.20611448048761538`, 0.5225649481811597, -0.8155134829083562],
       ArrowBox[{{-2.3951176467202315`, 
       1.473632751482615}, {-2.4798823532797685`, 1.77396251270903}}]}}, 
    {Arrowheads[{{0.026896038085676838`, 1.}}], 
     {LABColor[0.2152017625578487, 0.5225487220308757, -0.7937953741863909], 
      ArrowBox[{{-2.0539920911702807`, 
       1.4626458321779574`}, {-2.0710079088297193`, 
       1.7849494320136876`}}]}}, 
    {Arrowheads[{{0.02792052290861224, 1.}}], 
     {LABColor[0.22758498584015385`, 0.5225266106844437, -0.7642001456576731],
       ArrowBox[{{-1.7301001707355588`, 
       1.4617815000751082`}, {-1.6448998292644412`, 
       1.7858137641165368`}}]}}, 
    {Arrowheads[{{0.029072231754029437`, 1.}}], 
     {LABColor[0.24397440758125888`, 0.5224973459143855, -0.7250303212247533],
       ArrowBox[{{-1.425345656498204, 
       1.4907831007872123`}, {-1.199654343501796, 1.7568121634044327`}}]}}, 
    {Arrowheads[{{0.030477131434811056`, 1.}}], 
     {LABColor[0.26750428410463944`, 0.5224553312273004, -0.6687951991497899],
       ArrowBox[{{-1.1150095432663538`, 
       1.579875410986441}, {-0.7599904567336462, 1.667719853205204}}]}}, 
    {Arrowheads[{{0.03233232895408379, 1.}}], 
     {LABColor[0.30453253115720536`, 0.5223892139992021, -0.5802997074223313],
       ArrowBox[{{-0.7329190781705752, 
       1.7164852776421111`}, {-0.3920809218294248, 1.531109986549534}}]}}, 
    {Arrowheads[{{0.03394748427985846, 1.}}], 
     {LABColor[
      0.34229005320611805`, 0.5223217945857422, -0.49006128821265527`], 
      ArrowBox[{{-0.25694504902564397`, 
       1.8152785083402936`}, {-0.11805495097435603`, 1.4323167558513514`}}]}}, 
    {Arrowheads[{{0.03394748427985846, 1.}}], 
     {LABColor[
      0.34229005320611805`, 0.5223217945857422, -0.49006128821265527`], 
      ArrowBox[{{0.25694504902564397`, 1.8152785083402936`}, {
       0.11805495097435603`, 1.4323167558513514`}}]}}, 
    {Arrowheads[{{0.03233232895408379, 1.}}], 
     {LABColor[0.30453253115720536`, 0.5223892139992021, -0.5802997074223313],
       ArrowBox[{{0.7329190781705752, 1.7164852776421111`}, {
       0.3920809218294248, 1.531109986549534}}]}}, 
    {Arrowheads[{{0.030477131434811056`, 1.}}], 
     {LABColor[0.26750428410463944`, 0.5224553312273004, -0.6687951991497899],
       ArrowBox[{{1.1150095432663538`, 1.579875410986441}, {
       0.7599904567336462, 1.667719853205204}}]}}, 
    {Arrowheads[{{0.029072231754029437`, 1.}}], 
     {LABColor[0.24397440758125888`, 0.5224973459143855, -0.7250303212247533],
       ArrowBox[{{1.425345656498204, 1.4907831007872123`}, {1.199654343501796,
        1.7568121634044327`}}]}}, 
    {Arrowheads[{{0.02792052290861224, 1.}}], 
     {LABColor[0.22758498584015385`, 0.5225266106844437, -0.7642001456576731],
       ArrowBox[{{1.7301001707355588`, 1.4617815000751082`}, {
       1.6448998292644412`, 1.7858137641165368`}}]}}, 
    {Arrowheads[{{0.026896038085676838`, 1.}}], 
     {LABColor[0.2152017625578487, 0.5225487220308757, -0.7937953741863909], 
      ArrowBox[{{2.0539920911702807`, 1.4626458321779574`}, {
       2.0710079088297193`, 1.7849494320136876`}}]}}, 
    {Arrowheads[{{0.026005210609879013`, 1.}}], 
     {LABColor[0.20611448048761538`, 0.5225649481811597, -0.8155134829083562],
       ArrowBox[{{2.3951176467202315`, 1.473632751482615}, {
       2.4798823532797685`, 1.77396251270903}}]}}, 
    {Arrowheads[{{0.02525728191823047, 1.}}], 
     {LABColor[0.199692023008096, 0.5225764160501496, -0.8308628061410199], 
      ArrowBox[{{2.747772492074109, 1.4867726703042035`}, {2.877227507925891, 
       1.7608225938874416`}}]}}, 
    {Arrowheads[{{0.024960366493313412`, 1.}}], 
     {LABColor[0.19744794765096335`, 0.5225804230462693, -0.8362260239007211],
       ArrowBox[{{-2.604889208717795, 
       1.8001513893841934`}, {-2.645110791282205, 2.0969629276457806`}}]}}, 
    {Arrowheads[{{0.02552252518869608, 1.}}], 
     {LABColor[0.20184357345992066`, 0.5225725742654768, -0.8257207178606766],
       ArrowBox[{{-2.2635486004974146`, 
       1.796022539700647}, {-2.2364513995025854`, 2.101091777329327}}]}}, 
    {Arrowheads[{{0.026144663939235067`, 1.}}], 
     {LABColor[0.20743384049254693`, 0.522562592346538, -0.8123602844262297], 
      ArrowBox[{{-1.934337646648524, 
       1.8033448726020715`}, {-1.815662353351476, 2.0937694444279025`}}]}}, 
    {Arrowheads[{{0.026834241149129325`, 1.}}], 
     {LABColor[0.2145209192600189, 0.5225499377371325, -0.795422552549581], 
      ArrowBox[{{-1.6149400691824392`, 
       1.8358117176930957`}, {-1.3850599308175608`, 
       2.0613025993368783`}}]}}, 
    {Arrowheads[{{0.027664381755694665`, 1.}}], 
     {LABColor[0.22429511315335815`, 0.5225324850447001, -0.7720627620198632],
       ArrowBox[{{-1.2861270988775015`, 
       1.9086885411247003`}, {-0.9638729011224985, 1.9884257759052737`}}]}}, 
    {Arrowheads[{{0.02872424889247303, 1.}}], 
     {LABColor[0.238746978890759, 0.5225066799531966, -0.7375235908029565], 
      ArrowBox[{{-0.9104853326526714, 
       2.0113857116026077`}, {-0.5895146673473286, 1.8857286054273663`}}]}}, 
    {Arrowheads[{{0.029784403848066052`, 1.}}], 
     {LABColor[0.2554163039764509, 0.5224769153908242, -0.6976848126364124], 
      ArrowBox[{{-0.4735453759229724, 
       2.0976369845722003`}, {-0.2764546240770276, 1.7994773324577737`}}]}}, 
    {Arrowheads[{{0.030249390557272493`, 1.}}], 
     {LABColor[0.2634259502964525, 0.5224626134550082, -0.6785421946063089], 
      ArrowBox[{{0., 2.130053501858622}, {0., 1.767060815171352}}]}}, 
    {Arrowheads[{{0.029784403848066052`, 1.}}], 
     {LABColor[0.2554163039764509, 0.5224769153908242, -0.6976848126364124], 
      ArrowBox[{{0.4735453759229724, 2.0976369845722003`}, {
       0.2764546240770276, 1.7994773324577737`}}]}}, 
    {Arrowheads[{{0.02872424889247303, 1.}}], 
     {LABColor[0.238746978890759, 0.5225066799531966, -0.7375235908029565], 
      ArrowBox[{{0.9104853326526714, 2.0113857116026077`}, {
       0.5895146673473286, 1.8857286054273663`}}]}}, 
    {Arrowheads[{{0.027664381755694665`, 1.}}], 
     {LABColor[0.22429511315335815`, 0.5225324850447001, -0.7720627620198632],
       ArrowBox[{{1.2861270988775015`, 1.9086885411247003`}, {
       0.9638729011224985, 1.9884257759052737`}}]}}, 
    {Arrowheads[{{0.026834241149129325`, 1.}}], 
     {LABColor[0.2145209192600189, 0.5225499377371325, -0.795422552549581], 
      ArrowBox[{{1.6149400691824392`, 1.8358117176930957`}, {
       1.3850599308175608`, 2.0613025993368783`}}]}}, 
    {Arrowheads[{{0.026144663939235067`, 1.}}], 
     {LABColor[0.20743384049254693`, 0.522562592346538, -0.8123602844262297], 
      ArrowBox[{{1.934337646648524, 1.8033448726020715`}, {1.815662353351476, 
       2.0937694444279025`}}]}}, 
    {Arrowheads[{{0.02552252518869608, 1.}}], 
     {LABColor[0.20184357345992066`, 0.5225725742654768, -0.8257207178606766],
       ArrowBox[{{2.2635486004974146`, 1.796022539700647}, {
       2.2364513995025854`, 2.101091777329327}}]}}, 
    {Arrowheads[{{0.024960366493313412`, 1.}}], 
     {LABColor[0.19744794765096335`, 0.5225804230462693, -0.8362260239007211],
       ArrowBox[{{2.604889208717795, 1.8001513893841934`}, {2.645110791282205,
        2.0969629276457806`}}]}}, 
    {Arrowheads[{{0.02421202706066869, 1.}}], 
     {LABColor[0.1925623936052687, 0.5225891466374987, -0.8479022317163667], 
      ArrowBox[{{-2.8103520950903818`, 
       2.1280604022389955`}, {-2.8146479049096182`, 
       2.4185729676293075`}}]}}, 
    {Arrowheads[{{0.024585534114012448`, 1.}}], 
     {LABColor[0.19486296084384336`, 0.5225850387701008, -0.8424040014398774],
       ArrowBox[{{-2.4676462514388513`, 
       2.128916722744574}, {-2.4073537485611487`, 2.417716647123729}}]}}, 
    {Arrowheads[{{0.024990458195751575`, 1.}}], 
     {LABColor[0.19766747192333103`, 0.5225800310661582, -0.8357013728579183],
       ArrowBox[{{-2.133309212828408, 
       2.141146781368207}, {-1.9916907871715919`, 2.405486588500096}}]}}, 
    {Arrowheads[{{0.025437201135099525`, 1.}}], 
     {LABColor[0.2011363387671152, 0.5225738370959164, -0.8274109702190366], 
      ArrowBox[{{-1.8035233173603324`, 
       2.1741580590569547`}, {-1.5714766826396676`, 
       2.3724753108113483`}}]}}, 
    {Arrowheads[{{0.02596838241299922, 1.}}], 
     {LABColor[0.20577244488595797`, 0.5225655589161443, -0.8163309293490154],
       ArrowBox[{{-1.4637490016114958`, 
       2.235892262736269}, {-1.1612509983885042`, 2.310741107132034}}]}}, 
    {Arrowheads[{{0.026627727134188827`, 1.}}], 
     {LABColor[0.21230023730434472`, 0.5225539029622535, -0.800729861355172], 
      ArrowBox[{{-1.09088337445676, 2.31802497414587}, {-0.7841166255432399, 
       2.228608395722433}}]}}, 
    {Arrowheads[{{0.027327584821428885`, 1.}}], 
     {LABColor[0.22016597619390982`, 0.5225398579859524, -0.7819311742381803],
       ArrowBox[{{-0.6749871218787811, 
       2.3926118463181503`}, {-0.45001287812121893`, 2.1540215235501528`}}]}}, 
    {Arrowheads[{{0.02780113836454513, 1.}}], 
     {LABColor[0.22603553323293704`, 0.5225293773698694, -0.7679032529149351],
       ArrowBox[{{-0.22844397142048134`, 
       2.4350204566942555`}, {-0.14655602857951866`, 2.1116129131740475`}}]}}, 
    {Arrowheads[{{0.02780113836454513, 1.}}], 
     {LABColor[0.22603553323293704`, 0.5225293773698694, -0.7679032529149351],
       ArrowBox[{{0.22844397142048134`, 2.4350204566942555`}, {
       0.14655602857951866`, 2.1116129131740475`}}]}}, 
    {Arrowheads[{{0.027327584821428885`, 1.}}], 
     {LABColor[0.22016597619390982`, 0.5225398579859524, -0.7819311742381803],
       ArrowBox[{{0.6749871218787811, 2.3926118463181503`}, {
       0.45001287812121893`, 2.1540215235501528`}}]}}, 
    {Arrowheads[{{0.026627727134188827`, 1.}}], 
     {LABColor[0.21230023730434472`, 0.5225539029622535, -0.800729861355172], 
      ArrowBox[{{1.09088337445676, 2.31802497414587}, {0.7841166255432399, 
       2.228608395722433}}]}}, 
    {Arrowheads[{{0.02596838241299922, 1.}}], 
     {LABColor[0.20577244488595797`, 0.5225655589161443, -0.8163309293490154],
       ArrowBox[{{1.4637490016114958`, 2.235892262736269}, {
       1.1612509983885042`, 2.310741107132034}}]}}, 
    {Arrowheads[{{0.025437201135099525`, 1.}}], 
     {LABColor[0.2011363387671152, 0.5225738370959164, -0.8274109702190366], 
      ArrowBox[{{1.8035233173603324`, 2.1741580590569547`}, {
       1.5714766826396676`, 2.3724753108113483`}}]}}, 
    {Arrowheads[{{0.024990458195751575`, 1.}}], 
     {LABColor[0.19766747192333103`, 0.5225800310661582, -0.8357013728579183],
       ArrowBox[{{2.133309212828408, 2.141146781368207}, {1.9916907871715919`,
        2.405486588500096}}]}}, 
    {Arrowheads[{{0.024585534114012448`, 1.}}], 
     {LABColor[0.19486296084384336`, 0.5225850387701008, -0.8424040014398774],
       ArrowBox[{{2.4676462514388513`, 2.128916722744574}, {
       2.4073537485611487`, 2.417716647123729}}]}}, 
    {Arrowheads[{{0.02421202706066869, 1.}}], 
     {LABColor[0.1925623936052687, 0.5225891466374987, -0.8479022317163667], 
      ArrowBox[{{2.8103520950903818`, 2.1280604022389955`}, {
       2.8146479049096182`, 2.4185729676293075`}}]}}, 
    {Arrowheads[{{0.023922264956198775`, 1.}}], 
     {LABColor[0.1909669237196185, 0.5225919954908673, -0.8517153177602869], 
      ArrowBox[{{-2.668003533118169, 
       2.4611361240077936`}, {-2.581996466881831, 2.7350162986988384`}}]}}, 
    {Arrowheads[{{0.02420062198794734, 1.}}], 
     {LABColor[0.19249646907801146`, 0.5225892643516048, -0.8480597877423985],
       ArrowBox[{{-2.329093166768005, 
       2.4763043150211357`}, {-2.170906833231995, 2.7198481076854963`}}]}}, 
    {Arrowheads[{{0.024507269750248636`, 1.}}], 
     {LABColor[0.1943581446058129, 0.5225859401643879, -0.8436104847268957], 
      ArrowBox[{{-1.9917027553781268`, 
       2.508620676984752}, {-1.7582972446218732`, 2.68753174572188}}]}}, 
    {Arrowheads[{{0.02486761360884596, 1.}}], 
     {LABColor[0.19678252074931804`, 0.5225816112251798, -0.8378163579175106],
       ArrowBox[{{-1.6448377365590403`, 
       2.5622381658428113`}, {-1.3551622634409597`, 
       2.6339142568638207`}}]}}, 
    {Arrowheads[{{0.025304684347523466`, 1.}}], 
     {LABColor[0.20006636321834306`, 0.5225757476324135, -0.8299681534470336],
       ArrowBox[{{-1.273283854368729, 
       2.6306902011576057`}, {-0.976716145631271, 2.5654622215490264`}}]}}, 
    {Arrowheads[{{0.025781134731821417`, 1.}}], 
     {LABColor[0.20407473661144665`, 0.5225685903252486, -0.8203883595684199],
       ArrowBox[{{-0.8699028930678004, 
       2.6958069891264587`}, {-0.6300971069321996, 2.5003454335801734`}}]}}, 
    {Arrowheads[{{0.026170007001621115`, 1.}}], 
     {LABColor[0.20767772299599463`, 0.5225621568726392, -0.8117774185391222],
       ArrowBox[{{-0.4413021316358872, 
       2.7404114527142447`}, {-0.3086978683641128, 2.4557409699923873`}}]}}, 
    {Arrowheads[{{0.0263216810597335, 1.}}], 
     {LABColor[0.20916376218912525`, 0.5225595034175038, -0.8082258658843157],
       ArrowBox[{{0., 2.756006297711717}, {0., 2.4401461249949152`}}]}}, 
    {Arrowheads[{{0.026170007001621115`, 1.}}], 
     {LABColor[0.20767772299599463`, 0.5225621568726392, -0.8117774185391222],
       ArrowBox[{{0.4413021316358872, 2.7404114527142447`}, {
       0.3086978683641128, 2.4557409699923873`}}]}}, 
    {Arrowheads[{{0.025781134731821417`, 1.}}], 
     {LABColor[0.20407473661144665`, 0.5225685903252486, -0.8203883595684199],
       ArrowBox[{{0.8699028930678004, 2.6958069891264587`}, {
       0.6300971069321996, 2.5003454335801734`}}]}}, 
    {Arrowheads[{{0.025304684347523466`, 1.}}], 
     {LABColor[0.20006636321834306`, 0.5225757476324135, -0.8299681534470336],
       ArrowBox[{{1.273283854368729, 2.6306902011576057`}, {0.976716145631271,
        2.5654622215490264`}}]}}, 
    {Arrowheads[{{0.02486761360884596, 1.}}], 
     {LABColor[0.19678252074931804`, 0.5225816112251798, -0.8378163579175106],
       ArrowBox[{{1.6448377365590403`, 2.5622381658428113`}, {
       1.3551622634409597`, 2.6339142568638207`}}]}}, 
    {Arrowheads[{{0.024507269750248636`, 1.}}], 
     {LABColor[0.1943581446058129, 0.5225859401643879, -0.8436104847268957], 
      ArrowBox[{{1.9917027553781268`, 2.508620676984752}, {
       1.7582972446218732`, 2.68753174572188}}]}}, 
    {Arrowheads[{{0.02420062198794734, 1.}}], 
     {LABColor[0.19249646907801146`, 0.5225892643516048, -0.8480597877423985],
       ArrowBox[{{2.329093166768005, 2.4763043150211357`}, {2.170906833231995,
        2.7198481076854963`}}]}}, 
    {Arrowheads[{{0.023922264956198775`, 1.}}], 
     {LABColor[0.1909669237196185, 0.5225919954908673, -0.8517153177602869], 
      ArrowBox[{{2.668003533118169, 2.4611361240077936`}, {2.581996466881831, 
       2.7350162986988384`}}]}}, 
    {Arrowheads[{{0.023437500000000003`, 1.}}], 
     {LABColor[0.1886675222501131, 0.5225961012766809, -0.8572107619122568], 
      ArrowBox[{{-2.8656934966369074`, 
       2.7926595397156184`}, {-2.7593065033630926`, 
       3.0530119358293426`}}]}}, 
    {Arrowheads[{{0.02363733168124345, 1.}}], 
     {LABColor[0.1895593134817414, 0.5225945089041283, -0.8550794294878742], 
      ArrowBox[{{-2.5228160404135545`, 
       2.809543119246467}, {-2.3521839595864455`, 3.036128356298494}}]}}, 
    {Arrowheads[{{0.02385728237095984, 1.}}], 
     {LABColor[0.19063182402047543`, 0.5225925938411812, -0.8525161877720724],
       ArrowBox[{{-2.1796967347479157`, 
       2.8406466718267946`}, {-1.9453032652520843`, 
       3.0050248037181664`}}]}}, 
    {Arrowheads[{{0.024112930140648695`, 1.}}], 
     {LABColor[0.19199814401027335`, 0.5225901541553302, -0.8492507574863079],
       ArrowBox[{{-1.8279421943461223`, 
       2.8880853068962025`}, {-1.5470578056538777`, 
       2.9575861686487586`}}]}}, 
    {Arrowheads[{{0.024417167235943213`, 1.}}], 
     {LABColor[0.19379191129291803`, 0.5225869512243242, -0.8449637514744672],
       ArrowBox[{{-1.4570282492168432`, 
       2.9468089559152895`}, {-1.1679717507831568`, 
       2.8988625196296716`}}]}}, 
    {Arrowheads[{{0.02475264135153756, 1.}}], 
     {LABColor[0.1959812089848867, 0.5225830420385972, -0.8397314493481064], 
      ArrowBox[{{-1.061646557286596, 3.004350088984328}, {-0.8133534427134039,
        2.841321386560633}}]}}, 
    {Arrowheads[{{0.02505516218170267, 1.}}], 
     {LABColor[0.19814553972841512`, 0.522579177433577, -0.8345588168673546], 
      ArrowBox[{{-0.6453980962184761, 
       3.048244298539294}, {-0.4796019037815239, 2.797427177005667}}]}}, 
    {Arrowheads[{{0.025237386224910285`, 1.}}], 
     {LABColor[0.19953622404152604`, 0.5225766942430599, -0.8312351571771807],
       ArrowBox[{{-0.21650107786918865`, 
       3.071456938706855}, {-0.15849892213081135`, 2.774214536838106}}]}}, 
    {Arrowheads[{{0.025237386224910285`, 1.}}], 
     {LABColor[0.19953622404152604`, 0.5225766942430599, -0.8312351571771807],
       ArrowBox[{{0.21650107786918865`, 3.071456938706855}, {
       0.15849892213081135`, 2.774214536838106}}]}}, 
    {Arrowheads[{{0.02505516218170267, 1.}}], 
     {LABColor[0.19814553972841512`, 0.522579177433577, -0.8345588168673546], 
      ArrowBox[{{0.6453980962184761, 3.048244298539294}, {0.4796019037815239, 
       2.797427177005667}}]}}, 
    {Arrowheads[{{0.02475264135153756, 1.}}], 
     {LABColor[0.1959812089848867, 0.5225830420385972, -0.8397314493481064], 
      ArrowBox[{{1.061646557286596, 3.004350088984328}, {0.8133534427134039, 
       2.841321386560633}}]}}, 
    {Arrowheads[{{0.024417167235943213`, 1.}}], 
     {LABColor[0.19379191129291803`, 0.5225869512243242, -0.8449637514744672],
       ArrowBox[{{1.4570282492168432`, 2.9468089559152895`}, {
       1.1679717507831568`, 2.8988625196296716`}}]}}, 
    {Arrowheads[{{0.024112930140648695`, 1.}}], 
     {LABColor[0.19199814401027335`, 0.5225901541553302, -0.8492507574863079],
       ArrowBox[{{1.8279421943461223`, 2.8880853068962025`}, {
       1.5470578056538777`, 2.9575861686487586`}}]}}, 
    {Arrowheads[{{0.02385728237095984, 1.}}], 
     {LABColor[0.19063182402047543`, 0.5225925938411812, -0.8525161877720724],
       ArrowBox[{{2.1796967347479157`, 2.8406466718267946`}, {
       1.9453032652520843`, 3.0050248037181664`}}]}}, 
    {Arrowheads[{{0.02363733168124345, 1.}}], 
     {LABColor[0.1895593134817414, 0.5225945089041283, -0.8550794294878742], 
      ArrowBox[{{2.5228160404135545`, 2.809543119246467}, {
       2.3521839595864455`, 3.036128356298494}}]}}, 
    {Arrowheads[{{0.023437500000000003`, 1.}}], 
     {LABColor[0.1886675222501131, 0.5225961012766809, -0.8572107619122568], 
      ArrowBox[{{2.8656934966369074`, 2.7926595397156184`}, {
       2.7593065033630926`, 3.0530119358293426`}}]}}}},
  AspectRatio->1,
  DisplayFunction->Identity,
  Frame->True,
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  LabelStyle->Opacity[0],
  Method->{
   "VectorLengthFunction" -> (Sqrt[#]& ), "DefaultBoundaryStyle" -> Automatic,
     "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
    "TransparentPolygonMesh" -> True},
  PlotRange->{{-3, 3}, {-3, 3}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.02]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.920385685344058*^9},
 CellLabel->
  "Out[1744]=",ExpressionUUID->"8f35ac6f-d608-4cfb-8b21-0f66f889552e"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"VectorPlot", "[", 
  RowBox[{
   RowBox[{"\[Mu]field", "[", 
    RowBox[{"x", ",", "y"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", 
     RowBox[{"-", "1"}], ",", "3"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"y", ",", 
     RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
   RowBox[{"VectorScaling", "->", "Automatic"}], ",", 
   RowBox[{"VectorSizes", "->", "1.5"}], ",", 
   RowBox[{"LabelStyle", "->", 
    RowBox[{"Opacity", "[", "0", "]"}]}], ",", 
   RowBox[{"AspectRatio", "->", "Automatic"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.920384310230754*^9, 3.9203843111092243`*^9}, {
  3.920977395689445*^9, 3.920977420643511*^9}},
 CellLabel->
  "In[2862]:=",ExpressionUUID->"83c2551b-4004-4bbf-9c81-b8ced3e211a3"],

Cell[BoxData[
 GraphicsBox[{{}, 
   {RGBColor[0.2947336, 0.4054232, 0.5678384000000001], 
    {Arrowheads[{{0.028471008767304146`, 1.}}], 
     {LABColor[0.23623729124563866`, 0.5225111612236778, -0.7435216074501383],
       ArrowBox[{{-0.8878757662665945, -1.0308554917012955`}, \
{-0.8621242337334055, -0.9177016668136913}}]}}, 
    {Arrowheads[{{0.029492486073970137`, 1.}}], 
     {LABColor[0.2519058841416596, 0.5224831835576269, -0.7060745246583903], 
      ArrowBox[{{-0.6195821502222633, -1.033201313963545}, \
{-0.6304178497777367, -0.9153558445514415}}]}}, 
    {Arrowheads[{{0.030188116080467068`, 1.}}], 
     {LABColor[0.2637378913573001, 0.5224620564565026, -0.6777966724774729], 
      ArrowBox[{{-0.33980295219551226`, -1.0320330714326753`}, \
{-0.41019704780448774`, -0.9165240870823113}}]}}, 
    {Arrowheads[{{0.03038502341035105, 1.}}], 
     {LABColor[0.2672580142034043, 0.5224557709641102, -0.6693837707874518], 
      ArrowBox[{{-0.029908162788516296`, -1.0121254313660437`}, \
{-0.2200918372114837, -0.9364317271489427}}]}}, 
    {Arrowheads[{{0.030385023410351042`, 1.}}], 
     {LABColor[0.2672580142034043, 0.5224557709641102, -0.6693837707874518], 
      ArrowBox[{{0.22009183721148373`, -0.936431727148943}, {
       0.029908162788516282`, -1.012125431366044}}]}}, 
    {Arrowheads[{{0.030188116080467054`, 1.}}], 
     {LABColor[0.2637378913573001, 0.5224620564565026, -0.6777966724774729], 
      ArrowBox[{{0.41019704780448774`, -0.9165240870823113}, {
       0.33980295219551226`, -1.0320330714326755`}}]}}, 
    {Arrowheads[{{0.02949248607397011, 1.}}], 
     {LABColor[0.2519058841416596, 0.5224831835576269, -0.7060745246583903], 
      ArrowBox[{{0.6304178497777367, -0.9153558445514416}, {
       0.6195821502222633, -1.033201313963545}}]}}, 
    {Arrowheads[{{0.028471008767304132`, 1.}}], 
     {LABColor[0.23623729124563866`, 0.5225111612236778, -0.7435216074501383],
       ArrowBox[{{0.8621242337334055, -0.9177016668136915}, {
       0.8878757662665945, -1.0308554917012955`}}]}}, 
    {Arrowheads[{{0.02741363974947891, 1.}}], 
     {LABColor[0.2221558305480806, 0.5225363049240418, -0.7771755308157848], 
      ArrowBox[{{1.0993528804076902`, -0.9209720422154826}, {
       1.1506471195923098`, -1.0275851162995042`}}]}}, 
    {Arrowheads[{{0.026470654909681424`, 1.}}], 
     {LABColor[0.21143212345419102`, 0.5225554530567358, -0.802804606128688], 
      ArrowBox[{{1.3398135983537744`, -0.9243460090233528}, {
       1.4101864016462256`, -1.0242111494916342`}}]}}, 
    {Arrowheads[{{0.025681022513842515`, 1.}}], 
     {LABColor[0.20378287396935982`, 0.5225691114719518, -0.8210858953710649],
       ArrowBox[{{1.5823766634739778`, -0.9275466579908332}, {
       1.6676233365260222`, -1.0210105005241532`}}]}}, 
    {Arrowheads[{{0.025035340920658056`, 1.}}], 
     {LABColor[0.19842936937781072`, 0.5225786706304965, -0.8338804794792941],
       ArrowBox[{{1.826411075203373, -0.930496707702805}, {
       1.923588924796627, -1.0180604508121818`}}]}}, 
    {Arrowheads[{{0.02451020171979988, 1.}}], 
     {LABColor[0.19467325285314788`, 0.5225853775105892, -0.8428573931950255],
       ArrowBox[{{2.071533109068529, -0.9331893732915507}, {
       2.178466890931471, -1.0153677852234364`}}]}}, 
    {Arrowheads[{{0.02408169950178602, 1.}}], 
     {LABColor[0.19200574688929162`, 0.5225901405797135, -0.8492325870199524],
       ArrowBox[{{2.31749133841711, -0.9356404961746925}, {
       2.43250866158289, -1.0129166623402943`}}]}}, 
    {Arrowheads[{{0.02372951834364798, 1.}}], 
     {LABColor[0.19008073738123937`, 0.5225935778553846, -0.8538332547953748],
       ArrowBox[{{2.5641100510508337`, -0.9378716610615231}, {
       2.6858899489491663`, -1.0106854974534638`}}]}}, 
    {Arrowheads[{{0.023437500000000007`, 1.}}], 
     {LABColor[0.1886675222501131, 0.5225961012766809, -0.8572107619122568], 
      ArrowBox[{{2.8112600593881685`, -0.9399045975605754}, {
       2.9387399406118315`, -1.008652560954411}}]}}, 
    {Arrowheads[{{0.03128745648886094, 1.}}], 
     {LABColor[0.28435566681042584`, 0.5224252415848567, -0.6285213131967464],
       ArrowBox[{{-0.769955641918441, -0.8195465176482527}, \
{-0.730044358081559, -0.6959979389745147}}]}}, 
    {Arrowheads[{{0.03324086746044061, 1.}}], 
     {LABColor[0.3267906049939834, 0.5223494702289176, -0.5271041244314466], 
      ArrowBox[{{-0.49566134909904813`, -0.824218560830043}, \
{-0.5043386509009519, -0.6913258957927244}}]}}, 
    {Arrowheads[{{0.03446916014297558, 1.}}], 
     {LABColor[0.3572740589977984, 0.5222950393108478, -0.454250331277551], 
      ArrowBox[{{-0.1993238233006426, -0.821885201122136}, \
{-0.3006761766993574, -0.6936592555006313}}]}}, 
    {Arrowheads[{{0.03464362907486701, 1.}}], 
     {LABColor[
      0.36184199470831047`, 0.5222868828554023, -0.44333321396688513`], 
      ArrowBox[{{
       0.13857451629946804`, -0.7577722283113837}, {-0.13857451629946804`, \
-0.7577722283113837}}]}}, 
    {Arrowheads[{{0.03446916014297558, 1.}}], 
     {LABColor[0.3572740589977984, 0.5222950393108478, -0.454250331277551], 
      ArrowBox[{{0.3006761766993574, -0.6936592555006313}, {
       0.1993238233006426, -0.821885201122136}}]}}, 
    {Arrowheads[{{0.03324086746044061, 1.}}], 
     {LABColor[0.3267906049939834, 0.5223494702289176, -0.5271041244314466], 
      ArrowBox[{{0.5043386509009519, -0.6913258957927244}, {
       0.49566134909904813`, -0.824218560830043}}]}}, 
    {Arrowheads[{{0.03128745648886094, 1.}}], 
     {LABColor[0.28435566681042584`, 0.5224252415848567, -0.6285213131967464],
       ArrowBox[{{0.730044358081559, -0.6959979389745147}, {
       0.769955641918441, -0.8195465176482527}}]}}, 
    {Arrowheads[{{0.029397809357839158`, 1.}}], 
     {LABColor[0.2503682896204064, 0.5224859290693855, -0.7097492917366853], 
      ArrowBox[{{0.9648140147857637, -0.7016704334088557}, {
       1.0351859852142364`, -0.8138740232139117}}]}}, 
    {Arrowheads[{{0.027855537524458376`, 1.}}], 
     {LABColor[0.22777628414880197`, 0.5225262691043011, -0.7637429531293201],
       ArrowBox[{{1.204375965172802, -0.7069457023172958}, {
       1.295624034827198, -0.8085987543054716}}]}}, 
    {Arrowheads[{{0.026661702136813195`, 1.}}], 
     {LABColor[0.2134650230122303, 0.5225518231337856, -0.797946087015811], 
      ArrowBox[{{1.4467957540560454`, -0.711558458753898}, {
       1.5532042459439546`, -0.8039859978688694}}]}}, 
    {Arrowheads[{{0.025745763004683845`, 1.}}], 
     {LABColor[0.2043643819711369, 0.5225680731377002, -0.8196961229498195], 
      ArrowBox[{{1.6910774268472837`, -0.7155417908990256}, {
       1.8089225731527163`, -0.8000026657237418}}]}}, 
    {Arrowheads[{{0.025037518803782445`, 1.}}], 
     {LABColor[0.1984460637928908, 0.5225786408211337, -0.8338405807374089], 
      ArrowBox[{{1.9366535935377363`, -0.7189866950743833}, {
       2.0633464064622635`, -0.7965577615483841}}]}}, 
    {Arrowheads[{{0.024482310181615268`, 1.}}], 
     {LABColor[0.19448875636465274`, 0.522585706945477, -0.8432983297440387], 
      ArrowBox[{{2.1831704301782064`, -0.7219813608075945}, {
       2.3168295698217936`, -0.7935630958151729}}]}}, 
    {Arrowheads[{{0.02404039784768951, 1.}}], 
     {LABColor[0.19176750667406986`, 0.5225905659788049, -0.8498019681458097],
       ArrowBox[{{2.4303910991803375`, -0.724599752576667}, {
       2.5696089008196625`, -0.7909447040461004}}]}}, 
    {Arrowheads[{{0.02368337736094963, 1.}}], 
     {LABColor[0.18984640616094178`, 0.5225939962746179, -0.8543932936364761],
       ArrowBox[{{2.6781490001251864`, -0.726902050029878}, {
       2.8218509998748136`, -0.7886424065928894}}]}}, 
    {Arrowheads[{{0.03252153538597836, 1.}}], 
     {LABColor[0.31030088034171227`, 0.5223789140987439, -0.5665136673536791],
       ArrowBox[{{-0.9269669515442142, -0.6008935558564421}, \
{-0.8230330484557858, -0.48163819887410614`}}]}}, 
    {Arrowheads[{{0.03635369427269643, 1.}}], 
     {LABColor[0.4107374447646835, 0.5227624964104157, -0.3091117182958183], 
      ArrowBox[{{-0.6590110818247633, -0.6119565834543211}, \
{-0.5909889181752367, -0.47057517127622706`}}]}}, 
    {Arrowheads[{{0.040917920065338224`, 1.}}], 
     {LABColor[0.5871984280971501, 0.5342610033504451, 0.4770263622694137], 
      ArrowBox[{{-0.37342514143080446`, -0.6230979290627319}, \
{-0.37657485856919554`, -0.4594338256678164}}]}}, 
    {Arrowheads[{{0.043457065289434056`, 1.}}], 
     {LABColor[0.6877234522938438, 0.43932927849468995`, 0.7562485097197021], 
      ArrowBox[{{-0.030809815364828047`, -0.6143146170797866}, \
{-0.21919018463517195`, -0.4682171376507616}}]}}, 
    {Arrowheads[{{0.04345706528943406, 1.}}], 
     {LABColor[0.6877234522938438, 0.43932927849468995`, 0.7562485097197021], 
      ArrowBox[{{0.21919018463517193`, -0.4682171376507616}, {
       0.03080981536482809, -0.6143146170797866}}]}}, 
    {Arrowheads[{{0.040917920065338224`, 1.}}], 
     {LABColor[0.5871984280971501, 0.5342610033504451, 0.4770263622694137], 
      ArrowBox[{{0.37657485856919554`, -0.4594338256678164}, {
       0.37342514143080446`, -0.6230979290627319}}]}}, 
    {Arrowheads[{{0.03635369427269643, 1.}}], 
     {LABColor[0.4107374447646835, 0.5227624964104157, -0.3091117182958183], 
      ArrowBox[{{0.5909889181752367, -0.47057517127622706`}, {
       0.6590110818247633, -0.6119565834543211}}]}}, 
    {Arrowheads[{{0.03252153538597836, 1.}}], 
     {LABColor[0.31030088034171227`, 0.5223789140987439, -0.5665136673536791],
       ArrowBox[{{0.8230330484557858, -0.48163819887410614`}, {
       0.9269669515442142, -0.6008935558564421}}]}}, 
    {Arrowheads[{{0.029818211828170713`, 1.}}], 
     {LABColor[0.25732899547678667`, 0.5224735001100514, -0.6931135842278717],
       ArrowBox[{{1.0626925308105541`, -0.4904136616090241}, {
       1.1873074691894459`, -0.5921180931215241}}]}}, 
    {Arrowheads[{{0.027947297617298646`, 1.}}], 
     {LABColor[0.22899099391644395`, 0.5225241001319848, -0.7608398630089311],
       ArrowBox[{{1.306181895668333, -0.4972179159426564}, {
       1.443818104331667, -0.5853138387878918}}]}}, 
    {Arrowheads[{{0.026625098221371536`, 1.}}], 
     {LABColor[0.21307002944003758`, 0.5225525284299362, -0.7988901001188553],
       ArrowBox[{{1.551842357589735, -0.5025673856577969}, {
       1.698157642410265, -0.5799643690727513}}]}}, 
    {Arrowheads[{{0.025662899284803798`, 1.}}], 
     {LABColor[0.2036215491050696, 0.522569399531844, -0.8214714530015128], 
      ArrowBox[{{1.7988391376063888`, -0.5068534034833619}, {
       1.9511608623936112`, -0.5756783512471862}}]}}, 
    {Arrowheads[{{0.02494230602890077, 1.}}], 
     {LABColor[0.19772483133364605`, 0.5225799286458301, -0.8355642869944202],
       ArrowBox[{{2.046703737295761, -0.5103482718338855}, {
       2.203296262704239, -0.5721834828966627}}]}}, 
    {Arrowheads[{{0.02438859531278831, 1.}}], 
     {LABColor[0.1938799358273544, 0.5225867940486898, -0.8447533776361387], 
      ArrowBox[{{2.295152920050668, -0.5132422216220438}, {
       2.454847079949332, -0.5692895331085044}}]}}, 
    {Arrowheads[{{0.02395347127967888, 1.}}], 
     {LABColor[0.1912769284137334, 0.5225914419499167, -0.850974423442374], 
      ArrowBox[{{2.5440067563420072`, -0.5156709801038107}, {
       2.7059932436579928`, -0.5668607746267375}}]}}, 
    {Arrowheads[{{0.023604835056887024`, 1.}}], 
     {LABColor[0.18945704555299883`, 0.52259469151261, -0.8553238442620646], 
      ArrowBox[{{2.793146896907592, -0.5177335521340678}, {
       2.956853103092408, -0.5647982025964804}}]}}, 
    {Arrowheads[{{0.037670414373795286`, 1.}}], 
     {LABColor[
      0.45693162072620513`, 0.5257725898761295, -0.10331551259711805`], 
      ArrowBox[{{-0.83621371004733, -0.3865498130857797}, {-0.66378628995267, \
-0.2629692397525491}}]}}, 
    {Arrowheads[{{0.04687499999999999, 1.}}], 
     {LABColor[0.8167969189733053, 0.14500114740169545`, 0.8282532063436999], 
      ArrowBox[{{-0.570376290391765, -0.4116551933863584}, \
{-0.42962370960823504`, -0.23786385945197036`}}]}}, 
    {Arrowheads[{{0.046875, 1.}}], 
     {LABColor[0.8167969189733053, 0.14500114740169545`, 0.8282532063436999], 
      ArrowBox[{{-0.2575115466102109, -0.4184342650997748}, \
{-0.24248845338978908`, -0.23108478773855395`}}]}}, 
    {Arrowheads[{{0.046875, 1.}}], 
     {LABColor[0.8167969189733053, 0.14500114740169545`, 0.8282532063436999], 
      ArrowBox[{{
       0.1875, -0.3247595264191644}, {-0.1875, -0.3247595264191644}}]}}, 
    {Arrowheads[{{0.046875, 1.}}], 
     {LABColor[0.8167969189733053, 0.14500114740169545`, 0.8282532063436999], 
      ArrowBox[{{0.2424884533897891, -0.23108478773855395`}, {
       0.2575115466102109, -0.4184342650997748}}]}}, 
    {Arrowheads[{{0.04687499999999999, 1.}}], 
     {LABColor[0.8167969189733053, 0.14500114740169545`, 0.8282532063436999], 
      ArrowBox[{{0.42962370960823504`, -0.23786385945197036`}, {
       0.570376290391765, -0.4116551933863584}}]}}, 
    {Arrowheads[{{0.03767041437379529, 1.}}], 
     {LABColor[
      0.45693162072620513`, 0.5257725898761295, -0.10331551259711805`], 
      ArrowBox[{{0.66378628995267, -0.26296923975254916`}, {
       0.83621371004733, -0.38654981308577974`}}]}}, 
    {Arrowheads[{{0.03260299626367815, 1.}}], 
     {LABColor[0.3121177287941655, 0.5223756699542567, -0.5621714986043492], 
      ArrowBox[{{0.9090901394265809, -0.2780083684216557}, {
       1.090909860573419, -0.37151068441667306`}}]}}, 
    {Arrowheads[{{0.029602646439168812`, 1.}}], 
     {LABColor[0.2537168850316329, 0.5224799498544824, -0.7017463312645862], 
      ArrowBox[{{1.157836465397371, -0.287587797548997}, {
       1.342163534602629, -0.3619312552893318}}]}}, 
    {Arrowheads[{{0.02768619557116994, 1.}}], 
     {LABColor[0.22557755447742614`, 0.5225301951316662, -0.7689977971722458],
       ArrowBox[{{1.4077884686554778`, -0.29409423541133545`}, {
       1.5922115313445222`, -0.35542481742699333`}}]}}, 
    {Arrowheads[{{0.026384394004583017`, 1.}}], 
     {LABColor[0.21053749976142647`, 0.5225570504868996, -0.8049427079807644],
       ArrowBox[{{1.6581728185499511`, -0.2987501593624432}, {
       1.8418271814500489`, -0.3507688934758856}}]}}, 
    {Arrowheads[{{0.02545623103093349, 1.}}], 
     {LABColor[0.20182706104021422`, 0.5225726037498707, -0.8257601816435409],
       ArrowBox[{{1.9086941871882712`, -0.30222309081149945`}, {
       2.091305812811729, -0.34729596202682933`}}]}}, 
    {Arrowheads[{{0.024768548984765736`, 1.}}], 
     {LABColor[0.19645408020966787`, 0.522582197684972, -0.8386013129011562], 
      ArrowBox[{{2.159234806304829, -0.3049014303721496}, {
       2.340765193695171, -0.34461762246617916`}}]}}, 
    {Arrowheads[{{0.02424301850040713, 1.}}], 
     {LABColor[0.1929680708049225, 0.5225884222647811, -0.8469326853261469], 
      ArrowBox[{{2.409748334022966, -0.3070238284871175}, {
       2.590251665977034, -0.34249522435121127`}}]}}, 
    {Arrowheads[{{0.023831083892062305`, 1.}}], 
     {LABColor[0.19061113683575678`, 0.5225926307799892, -0.8525656290157136],
       ArrowBox[{{2.6602185062800245`, -0.30874381275306306`}, {
       2.8397814937199755`, -0.3407752400852657}}]}}, 
    {Arrowheads[{{0.03631878523728257, 1.}}], 
     {LABColor[
      0.40956473982668506`, 0.5226860809013693, -0.31433614803443377`], 
      ArrowBox[{{-1.0110693169231164`, -0.1336992339589294}, \
{-0.7389306830768837, -0.0828071169871802}}]}}, 
    {Arrowheads[{{0.04597595007158646, 1.}}], 
     {LABColor[0.7810691441077297, 0.22647171974179214`, 0.8083221728290045], 
      ArrowBox[{{-0.787658474000076, -0.15115663860753492`}, \
{-0.46234152599992395`, -0.06534971233857467}}]}}, 
    {Arrowheads[{{0.04687499999999999, 1.}}], 
     {LABColor[0.8167969189733053, 0.14500114740169545`, 0.8282532063436999], 
      ArrowBox[{{-0.5141129032258065, -0.1711098580057963}, \
{-0.23588709677419353`, -0.04539649294031328}}]}}, 
    {Arrowheads[{{0.04687499999999999, 1.}}], 
     {LABColor[0.8167969189733053, 0.14500114740169545`, 0.8282532063436999], 
      ArrowBox[{{-0.16885440028671767`, -0.19940283479152446`}, \
{-0.08114559971328235, -0.017103516154585136`}}]}}, 
    {Arrowheads[{{0.04687499999999999, 1.}}], 
     {LABColor[0.8167969189733053, 0.14500114740169545`, 0.8282532063436999], 
      ArrowBox[{{0.08114559971328235, -0.017103516154585136`}, {
       0.16885440028671767`, -0.19940283479152446`}}]}}, 
    {Arrowheads[{{0.04687499999999999, 1.}}], 
     {LABColor[0.8167969189733053, 0.14500114740169545`, 0.8282532063436999], 
      ArrowBox[{{0.23588709677419353`, -0.04539649294031328}, {
       0.5141129032258065, -0.1711098580057963}}]}}, 
    {Arrowheads[{{0.04597595007158646, 1.}}], 
     {LABColor[0.7810691441077297, 0.22647171974179214`, 0.8083221728290045], 
      ArrowBox[{{0.46234152599992395`, -0.06534971233857467}, {
       0.787658474000076, -0.15115663860753492`}}]}}, 
    {Arrowheads[{{0.03631878523728257, 1.}}], 
     {LABColor[
      0.40956473982668506`, 0.5226860809013693, -0.31433614803443377`], 
      ArrowBox[{{0.7389306830768837, -0.0828071169871802}, {
       1.0110693169231164`, -0.1336992339589294}}]}}, 
    {Arrowheads[{{0.03159625851290779, 1.}}], 
     {LABColor[0.2905700326800066, 0.5224141452819423, -0.6136693175669728], 
      ArrowBox[{{1.003616708893665, -0.09065151736631188}, {
       1.246383291106335, -0.1258548335797977}}]}}, 
    {Arrowheads[{{0.02888895062239137, 1.}}], 
     {LABColor[0.2424028553165985, 0.5225001520607148, -0.728786245458463], 
      ArrowBox[{{1.2625569670263237`, -0.09493300444667316}, {
       1.4874430329736763`, -0.12157334649943644`}}]}}, 
    {Arrowheads[{{0.02717145530703802, 1.}}], 
     {LABColor[0.2192366304479387, 0.5225415174154301, -0.7841522599044227], 
      ArrowBox[{{1.5184308640039352`, -0.0975804650735112}, {
       1.7315691359960648`, -0.11892588587259839`}}]}}, 
    {Arrowheads[{{0.02600275264130957, 1.}}], 
     {LABColor[0.20675310662210408`, 0.5225638078574025, -0.8139872012639306],
       ArrowBox[{{1.7725198931443387`, -0.09936332145774131}, {
       1.9774801068556613`, -0.11714302948836829`}}]}}, 
    {Arrowheads[{{0.02516554500166559, 1.}}], 
     {LABColor[0.19944365119090443`, 0.5225768595401173, -0.8314564012432242],
       ArrowBox[{{2.025496125912355, -0.10063980688149432`}, {
       2.224503874087645, -0.11586654406461527`}}]}}, 
    {Arrowheads[{{0.02454177510522458, 1.}}], 
     {LABColor[0.1948839298594748, 0.5225850013280585, -0.8423538866357195], 
      ArrowBox[{{2.277739851061402, -0.10159654281290786`}, {
       2.472260148938598, -0.11490980813320173`}}]}}, 
    {Arrowheads[{{0.024062393385013568`, 1.}}], 
     {LABColor[0.19189397049558957`, 0.5225903401664049, -0.849499726507008], 
      ArrowBox[{{2.5294799069050873`, -0.10233937335889981`}, {
       2.7205200930949127`, -0.11416697758720978`}}]}}, 
    {Arrowheads[{{0.023684615316858205`, 1.}}], 
     {LABColor[0.18985263917394934`, 0.5225939851450189, -0.8543783970752031],
       ArrowBox[{{2.78086108470028, -0.10293244550638223`}, {
       2.96913891529972, -0.11357390543972737`}}]}}, 
    {Arrowheads[{{0.04018175945813207, 1.}}], 
     {LABColor[0.5556314405940163, 0.5322040431203372, 0.33639464586225226`], 
      ArrowBox[{{-0.8972474298947971, 
       0.14046875819243057`}, {-0.6027525701052029, 
       0.07603759275367902}}]}}, 
    {Arrowheads[{{0.04687500000000001, 1.}}], 
     {LABColor[0.8167969189733053, 0.14500114740169545`, 0.8282532063436999], 
      ArrowBox[{{-0.65612168601003, 
       0.1601720284009307}, {-0.34387831398997004`, 
       0.056334322545178894`}}]}}, 
    {Arrowheads[{{0.04687500000000001, 1.}}], 
     {LABColor[0.8167969189733053, 0.14500114740169545`, 0.8282532063436999], 
      ArrowBox[{{-0.35727961785522133`, 
       0.18514162322828925`}, {-0.14272038214477867`, 
       0.031364727717820326`}}]}}, 
    {Arrowheads[{{0.046875, 1.}}], 
     {LABColor[0.8167969189733053, 0.14500114740169545`, 0.8282532063436999], 
      ArrowBox[{{0.1875, 0.1082531754730548}, {-0.1875, 
       0.1082531754730548}}]}}, 
    {Arrowheads[{{0.04687500000000001, 1.}}], 
     {LABColor[0.8167969189733053, 0.14500114740169545`, 0.8282532063436999], 
      ArrowBox[{{0.14272038214477867`, 0.031364727717820326`}, {
       0.35727961785522133`, 0.18514162322828925`}}]}}, 
    {Arrowheads[{{0.04687500000000001, 1.}}], 
     {LABColor[0.8167969189733053, 0.14500114740169545`, 0.8282532063436999], 
      ArrowBox[{{0.34387831398997004`, 0.056334322545178894`}, {
       0.65612168601003, 0.1601720284009307}}]}}, 
    {Arrowheads[{{0.04018175945813207, 1.}}], 
     {LABColor[0.5556314405940163, 0.5322040431203372, 0.33639464586225226`], 
      ArrowBox[{{0.6027525701052029, 0.07603759275367902}, {
       0.8972474298947971, 0.14046875819243057`}}]}}, 
    {Arrowheads[{{0.03359693392875383, 1.}}], 
     {LABColor[0.33532533888584404`, 0.5223342307025451, -0.5067065757316391],
       ArrowBox[{{0.8722556770354247, 0.0873878246436828}, {
       1.1277443229645754`, 0.1291185263024268}}]}}, 
    {Arrowheads[{{0.03007585643142343, 1.}}], 
     {LABColor[0.26176477248236896`, 0.5224655796357266, -0.6825123190168805],
       ArrowBox[{{1.133589939386761, 0.0930741436416142}, {1.366410060613239, 
       0.12343220730449539`}}]}}, 
    {Arrowheads[{{0.02794165370061672, 1.}}], 
     {LABColor[0.22891580771225567`, 0.5225242343836388, -0.7610195539378947],
       ArrowBox[{{1.390777063234039, 0.09639857437662491}, {1.609222936765961,
        0.12010777656948468`}}]}}, 
    {Arrowheads[{{0.02653531722325416, 1.}}], 
     {LABColor[0.21211223595118617`, 0.5225542386553887, -0.8011791743396505],
       ArrowBox[{{1.6456471923462586`, 0.098551880495052}, {
       1.8543528076537414`, 0.1179544704510576}}]}}, 
    {Arrowheads[{{0.02555163142978831, 1.}}], 
     {LABColor[0.20264509380145038`, 0.5225711430796264, -0.8238051279421871],
       ArrowBox[{{1.8991186541634073`, 0.10005061547970961`}, {
       2.100881345836593, 0.11645573546639998`}}]}}, 
    {Arrowheads[{{0.024832098752284225`, 1.}}], 
     {LABColor[0.19691203263446844`, 0.522581379970191, -0.8375068315728078], 
      ArrowBox[{{2.15169271077462, 0.10115023699224582`}, {2.34830728922538, 
       0.11535611395386378`}}]}}, 
    {Arrowheads[{{0.024287158133226686`, 1.}}], 
     {LABColor[0.19324019862195646`, 0.5225879363563629, -0.8462823146794632],
       ArrowBox[{{2.4036623294964707`, 0.10198998848544356`}, {
       2.5963376705035293`, 0.11451636246066603`}}]}}, 
    {Arrowheads[{{0.02386280433231215, 1.}}], 
     {LABColor[0.1907809001837143, 0.5225923276524341, -0.8521599038693553], 
      ArrowBox[{{2.655208506776637, 0.1026516644688572}, {2.844791493223363, 
       0.11385468647725239`}}]}}, 
    {Arrowheads[{{0.034782797875021775`, 1.}}], 
     {LABColor[0.3655281530288564, 0.5222803008919045, -0.4345234965449698], 
      ArrowBox[{{-0.9642526664994946, 
       0.3781248943345175}, {-0.7857473335005054, 0.2713941585038117}}]}}, 
    {Arrowheads[{{0.041568051022177685`, 1.}}], 
     {LABColor[0.6160696834836189, 0.5361423049512822, 0.6056485248823502], 
      ArrowBox[{{-0.7056758298782477, 
       0.3974538458773828}, {-0.5443241701217523, 0.2520652069609464}}]}}, 
    {Arrowheads[{{0.04687500000000001, 1.}}], 
     {LABColor[0.8167969189733053, 0.14500114740169545`, 0.8282532063436999], 
      ArrowBox[{{-0.4188544002867176, 
       0.4159091857376343}, {-0.3311455997132824, 0.23360986710069492`}}]}}, 
    {Arrowheads[{{0.04687499999999999, 1.}}], 
     {LABColor[0.8167969189733053, 0.14500114740169545`, 0.8282532063436999], 
      ArrowBox[{{-0.07034731443864792, 
       0.41443858467823086`}, {-0.17965268556135208`, 
       0.23508046816009837`}}]}}, 
    {Arrowheads[{{0.04687500000000001, 1.}}], 
     {LABColor[0.8167969189733053, 0.14500114740169545`, 0.8282532063436999], 
      ArrowBox[{{0.1796526855613521, 0.2350804681600984}, {0.0703473144386479,
        0.4144385846782309}}]}}, 
    {Arrowheads[{{0.046875, 1.}}], 
     {LABColor[0.8167969189733053, 0.14500114740169545`, 0.8282532063436999], 
      ArrowBox[{{0.3311455997132824, 0.2336098671006949}, {0.4188544002867176,
        0.41590918573763425`}}]}}, 
    {Arrowheads[{{0.04156805102217767, 1.}}], 
     {LABColor[0.6160696834836189, 0.5361423049512822, 0.6056485248823502], 
      ArrowBox[{{0.5443241701217524, 0.25206520696094636`}, {
       0.7056758298782476, 0.39745384587738275`}}]}}, 
    {Arrowheads[{{0.034782797875021775`, 1.}}], 
     {LABColor[0.3655281530288564, 0.5222803008919045, -0.4345234965449698], 
      ArrowBox[{{0.7857473335005054, 0.2713941585038117}, {0.9642526664994946,
        0.3781248943345175}}]}}, 
    {Arrowheads[{{0.030923125940238893`, 1.}}], 
     {LABColor[0.27726233971160225`, 0.5224379073512134, -0.6454739782446751],
       ArrowBox[{{1.033228142370904, 0.28329339073605886`}, {
       1.216771857629096, 0.36622566210227037`}}]}}, 
    {Arrowheads[{{0.02854578940826265, 1.}}], 
     {LABColor[0.23731551425912176`, 0.522509235960599, -0.7409447132311224], 
      ArrowBox[{{1.2827273066082698`, 0.29113087962327844`}, {
       1.4672726933917302`, 0.3583881732150508}}]}}, 
    {Arrowheads[{{0.026976986148136824`, 1.}}], 
     {LABColor[0.21697515369412254`, 0.5225455554832911, -0.7895570660534977],
       ArrowBox[{{1.5329512476311817`, 0.29660303652104236`}, {
       1.7170487523688183`, 0.35291601631728686`}}]}}, 
    {Arrowheads[{{0.025883641488236988`, 1.}}], 
     {LABColor[0.20562999429171055`, 0.5225658132743487, -0.8166713785030598],
       ArrowBox[{{1.7834261745654796`, 0.30060564038423576`}, {
       1.9665738254345204`, 0.34891341245409346`}}]}}, 
    {Arrowheads[{{0.02508813259287412, 1.}}], 
     {LABColor[0.19883663888563116`, 0.5225779434145711, -0.8329071275593665],
       ArrowBox[{{2.033966002741828, 0.30364411915834394`}, {
       2.216033997258172, 0.3458749336799853}}]}}, 
    {Arrowheads[{{0.024489059902801317`, 1.}}], 
     {LABColor[0.19453326553101735`, 0.5225856274704022, -0.8431919552630047],
       ArrowBox[{{2.284496407842844, 0.3060210320464904}, {2.465503592157156, 
       0.34349802079183883`}}]}}, 
    {Arrowheads[{{0.02402511924933905, 1.}}], 
     {LABColor[0.19168021588043693`, 0.5225907218442799, -0.8500105883836204],
       ArrowBox[{{2.5349892371428178`, 0.3079267886071845}, {
       2.7150107628571822`, 0.34159226423114475`}}]}}, 
    {Arrowheads[{{0.02365743007559124, 1.}}], 
     {LABColor[0.18971644956201905`, 0.5225942283236825, -0.8547038828228496],
       ArrowBox[{{2.785436009280485, 0.3094863838897238}, {2.964563990719515, 
       0.3400326689486054}}]}}, 
    {Arrowheads[{{0.03428773406558147, 1.}}], 
     {LABColor[0.3525867653054896, 0.5223034088905845, -0.4654527076574812], 
      ArrowBox[{{-0.7943352308835968, 
       0.6061595723982486}, {-0.7056647691164032, 0.4763721823322998}}]}}, 
    {Arrowheads[{{0.03864684732650981, 1.}}], 
     {LABColor[0.4936552519035058, 0.5281655660455964, 0.06028917995248406], 
      ArrowBox[{{-0.5195513408684564, 
       0.6179388941356843}, {-0.4804486591315435, 0.4645928605948641}}]}}, 
    {Arrowheads[{{0.0426769768933354, 1.}}], 
     {LABColor[0.6608333983190402, 0.5006470654496835, 0.7412476716042512], 
      ArrowBox[{{-0.21541565800302687`, 
       0.6248498366468028}, {-0.28458434199697313`, 0.4576819180837456}}]}}, 
    {Arrowheads[{{0.04353809153278123, 1.}}], 
     {LABColor[0.6905712012434444, 0.43283551453435964`, 0.7578371499294403], 
      ArrowBox[{{0.17415236613112492`, 
       0.5412658773652742}, {-0.17415236613112492`, 0.5412658773652742}}]}}, 
    {Arrowheads[{{0.0426769768933354, 1.}}], 
     {LABColor[0.6608333983190402, 0.5006470654496835, 0.7412476716042512], 
      ArrowBox[{{0.28458434199697313`, 0.4576819180837456}, {
       0.21541565800302687`, 0.6248498366468028}}]}}, 
    {Arrowheads[{{0.03864684732650981, 1.}}], 
     {LABColor[0.4936552519035058, 0.5281655660455964, 0.06028917995248406], 
      ArrowBox[{{0.4804486591315435, 0.4645928605948641}, {0.5195513408684564,
        0.6179388941356843}}]}}, 
    {Arrowheads[{{0.03428773406558147, 1.}}], 
     {LABColor[0.3525867653054896, 0.5223034088905845, -0.4654527076574812], 
      ArrowBox[{{0.7056647691164032, 0.4763721823322998}, {0.7943352308835968,
        0.6061595723982486}}]}}, 
    {Arrowheads[{{0.031044679625692368`, 1.}}], 
     {LABColor[0.27960022785123073`, 0.5224337328440277, -0.6398865530493503],
       ArrowBox[{{0.9422233024393692, 0.4863063300873502}, {
       1.0577766975606309`, 0.5962254246431982}}]}}, 
    {Arrowheads[{{0.028798755573030407`, 1.}}], 
     {LABColor[0.24104353093935835`, 0.5225025792552774, -0.7320349566116056],
       ArrowBox[{{1.1840902508249467`, 0.49402765628169637`}, {
       1.3159097491750533`, 0.5885040984488523}}]}}, 
    {Arrowheads[{{0.027231424290730125`, 1.}}], 
     {LABColor[0.21994884712327367`, 0.5225402456892176, -0.7824501008794279],
       ArrowBox[{{1.4288047831195017`, 0.5000468023035778}, {
       1.5711952168804983`, 0.5824849524269706}}]}}, 
    {Arrowheads[{{0.026107686840607092`, 1.}}], 
     {LABColor[0.20776540659251186`, 0.5225620003057797, -0.8115678595238329],
       ArrowBox[{{1.6752087352090463`, 0.5048239794123519}, {
       1.8247912647909537`, 0.5777077753181965}}]}}, 
    {Arrowheads[{{0.02527785115629143, 1.}}], 
     {LABColor[0.2003449959303427, 0.5225752501089269, -0.8293022364560196], 
      ArrowBox[{{1.922683765360296, 0.508686297846762}, {2.077316234639704, 
       0.5738454568837862}}]}}, 
    {Arrowheads[{{0.024648082080883534`, 1.}}], 
     {LABColor[0.19560752994656108`, 0.522583709275752, -0.8406245218772467], 
      ArrowBox[{{2.170868310361298, 0.5118608484621269}, {2.329131689638702, 
       0.5706709062684215}}]}}, 
    {Arrowheads[{{0.024158509995335337`, 1.}}], 
     {LABColor[0.19245763549448758`, 0.5225893336924218, -0.8481525978898681],
       ArrowBox[{{2.419537764011479, 0.5145078586473131}, {2.580462235988521, 
       0.5680238960832356}}]}}, 
    {Arrowheads[{{0.023769900088844668`, 1.}}], 
     {LABColor[0.19028921767316212`, 0.5225932055952829, -0.853334998263733], 
      ArrowBox[{{2.6685467418407334`, 0.5167429435125599}, {
       2.8314532581592666`, 0.5657888112179885}}]}}, 
    {Arrowheads[{{0.030306540566280887`, 1.}}], 
     {LABColor[0.2658459334256763, 0.5224582923599177, -0.6727585668615552], 
      ArrowBox[{{-0.9033536034410523, 
       0.8167040863964586}, {-0.8466463965589477, 0.698840370226309}}]}}, 
    {Arrowheads[{{0.032294167345340775`, 1.}}], 
     {LABColor[0.30529810447406014`, 0.5223878469999612, -0.5784700289330335],
       ArrowBox[{{-0.6343864303668053, 
       0.822189824582572}, {-0.6156135696331947, 0.6933546320401959}}]}}, 
    {Arrowheads[{{0.03400440132190351, 1.}}], 
     {LABColor[0.34539468948144453`, 0.522316250981572, -0.482641376775047], 
      ArrowBox[{{-0.351965614880374, 0.8247987268965291}, {-0.398034385119626,
        0.6907457297262387}}]}}, 
    {Arrowheads[{{0.03462984604412919, 1.}}], 
     {LABColor[0.36147897432247267`, 0.5222875310605851, -0.4442008128976743],
       ArrowBox[{{-0.029312143289000073`, 
       0.8078508012510567}, {-0.22068785671099994`, 0.7076936553717107}}]}}, 
    {Arrowheads[{{0.03462984604412919, 1.}}], 
     {LABColor[0.36147897432247267`, 0.5222875310605851, -0.4442008128976743],
       ArrowBox[{{0.22068785671099994`, 0.7076936553717109}, {
       0.029312143289000073`, 0.8078508012510569}}]}}, 
    {Arrowheads[{{0.03400440132190351, 1.}}], 
     {LABColor[0.34539468948144453`, 0.522316250981572, -0.482641376775047], 
      ArrowBox[{{0.398034385119626, 0.6907457297262385}, {0.351965614880374, 
       0.8247987268965289}}]}}, 
    {Arrowheads[{{0.032294167345340775`, 1.}}], 
     {LABColor[0.30529810447406014`, 0.5223878469999612, -0.5784700289330335],
       ArrowBox[{{0.6156135696331947, 0.6933546320401957}, {
       0.6343864303668053, 0.8221898245825717}}]}}, 
    {Arrowheads[{{0.030306540566280887`, 1.}}], 
     {LABColor[0.2658459334256763, 0.5224582923599177, -0.6727585668615552], 
      ArrowBox[{{0.8466463965589477, 0.698840370226309}, {0.9033536034410523, 
       0.8167040863964586}}]}}, 
    {Arrowheads[{{0.028579946326773596`, 1.}}], 
     {LABColor[0.2378116237110855, 0.5225083501130526, -0.7397590386881217], 
      ArrowBox[{{1.0841482599190944`, 0.7043864890053146}, {
       1.1658517400809056`, 0.811157967617453}}]}}, 
    {Arrowheads[{{0.02721907879357225, 1.}}], 
     {LABColor[0.21980165507431487`, 0.5225405085137111, -0.7828018818517349],
       ArrowBox[{{1.3253047749983933`, 0.7093355773692234}, {
       1.4246952250016067`, 0.8062088792535442}}]}}, 
    {Arrowheads[{{0.026173701771621836`, 1.}}], 
     {LABColor[0.20841322743346108`, 0.5225608435640564, -0.8100196030322493],
       ArrowBox[{{1.5687460056544782`, 0.7136233587022682}, {
       1.6812539943455218`, 0.8019210979204996}}]}}, 
    {Arrowheads[{{0.025369481770817357`, 1.}}], 
     {LABColor[0.20109857642729395`, 0.5225739045239325, -0.8275012201524594],
       ArrowBox[{{1.8137293387973954`, 0.7173257335284208}, {
       1.9362706612026046`, 0.7982187230943466}}]}}, 
    {Arrowheads[{{0.02474357813045685, 1.}}], 
     {LABColor[0.19627628487340967`, 0.5225825151543566, -0.8390262340616607],
       ArrowBox[{{2.0598112744564907`, 0.7205353359827356}, {
       2.1901887255435093`, 0.795009120640032}}]}}, 
    {Arrowheads[{{0.02424919041027686, 1.}}], 
     {LABColor[0.19300589371394788`, 0.5225883547286133, -0.8468422906356282],
       ArrowBox[{{2.306704485160484, 0.7233335348777352}, {2.443295514839516, 
       0.7922109217450322}}]}}, 
    {Arrowheads[{{0.0238527042302468, 1.}}], 
     {LABColor[0.19072663348925326`, 0.5225924245504431, -0.8522895983105729],
       ArrowBox[{{2.5542113293812028`, 0.725787122021293}, {
       2.6957886706187972`, 0.7897573346014743}}]}}, 
    {Arrowheads[{{0.02353009901263174, 1.}}], 
     {LABColor[0.18909769435635826`, 0.5225953331661293, -0.8561826740307116],
       ArrowBox[{{2.802190218612919, 0.7279503207304061}, {2.947809781387081, 
       0.7875941358923615}}]}}, 
    {Arrowheads[{{0.02900182038896881, 1.}}], 
     {LABColor[0.24412619884519768`, 0.5224970748775846, -0.7246675483793867],
       ArrowBox[{{-0.7546474352134976, 
       1.0322356554430647`}, {-0.7453525647865024, 0.9163215030719221}}]}}, 
    {Arrowheads[{{0.029900956536374406`, 1.}}], 
     {LABColor[0.2587395079759065, 0.522470981514545, -0.6897425362541416], 
      ArrowBox[{{-0.4818310911625096, 
       1.0333864594011288`}, {-0.5181689088374904, 0.9151706991138583}}]}}, 
    {Arrowheads[{{0.03033929373146123, 1.}}], 
     {LABColor[0.2664337790382176, 0.5224572427092984, -0.6713536478961011], 
      ArrowBox[{{-0.1903840217407831, 
       1.0271309657745151`}, {-0.30961597825921694`, 
       0.9214261927404714}}]}}, 
    {Arrowheads[{{0.030388602832981282`, 1.}}], 
     {LABColor[0.26732270163167937`, 0.5224556554589543, -0.6692291713605424],
       ArrowBox[{{0.12155441133192513`, 
       0.9742785792574934}, {-0.12155441133192513`, 0.9742785792574934}}]}}, 
    {Arrowheads[{{0.03033929373146122, 1.}}], 
     {LABColor[0.2664337790382176, 0.5224572427092984, -0.6713536478961011], 
      ArrowBox[{{0.30961597825921694`, 0.9214261927404717}, {
       0.19038402174078306`, 1.0271309657745153`}}]}}, 
    {Arrowheads[{{0.02990095653637442, 1.}}], 
     {LABColor[0.2587395079759065, 0.522470981514545, -0.6897425362541416], 
      ArrowBox[{{0.5181689088374904, 0.9151706991138582}, {
       0.48183109116250955`, 1.0333864594011286`}}]}}, 
    {Arrowheads[{{0.02900182038896881, 1.}}], 
     {LABColor[0.24412619884519768`, 0.5224970748775846, -0.7246675483793867],
       ArrowBox[{{0.7453525647865024, 0.9163215030719221}, {
       0.7546474352134976, 1.0322356554430647`}}]}}, 
    {Arrowheads[{{0.027933937926789807`, 1.}}], 
     {LABColor[0.2288131212277557, 0.5225244177394889, -0.7612649690375262], 
      ArrowBox[{{0.9802319103090822, 0.9192919880748791}, {
       1.0197680896909178`, 1.0292651704401075`}}]}}, 
    {Arrowheads[{{0.026923670561679176`, 1.}}], 
     {LABColor[0.21636799575326338`, 0.5225466396177901, -0.7910081404307505],
       ArrowBox[{{1.2192660505569055`, 0.9226705156049724}, {
       1.2807339494430945`, 1.0258866429100142`}}]}}, 
    {Arrowheads[{{0.026056663727631824`, 1.}}], 
     {LABColor[0.20727051165041774`, 0.5225628839847107, -0.8127506314544586],
       ArrowBox[{{1.4608795448930905`, 0.9259754075550408}, {
       1.5391204551069095`, 1.0225817509599457`}}]}}, 
    {Arrowheads[{{0.025341548423314764`, 1.}}], 
     {LABColor[0.20086711906589355`, 0.5225743178116351, -0.8280543906274752],
       ArrowBox[{{1.7042379842032287`, 0.9290542961396945}, {
       1.7957620157967713`, 1.0195028623752926`}}]}}, 
    {Arrowheads[{{0.024759260325653315`, 1.}}], 
     {LABColor[0.1963878022332011, 0.5225823160301932, -0.8387597136515295], 
      ArrowBox[{{1.9488541076124641`, 0.9318744720217015}, {2.051145892387536,
        1.016682686493285}}]}}, 
    {Arrowheads[{{0.024285240397942418`, 1.}}], 
     {LABColor[0.1932282967361368, 0.5225879576082385, -0.8463107595376981], 
      ArrowBox[{{2.1944200253991797`, 0.9344438179228693}, {
       2.3055799746008203`, 1.0141133405921174`}}]}}, 
    {Arrowheads[{{0.023897172177873145`, 1.}}], 
     {LABColor[0.19096704094603406`, 0.5225919952815492, -0.8517150375955447],
       ArrowBox[{{2.4407270693079397`, 0.9367821891087177}, {
       2.5592729306920603`, 1.0117749694062692`}}]}}, 
    {Arrowheads[{{0.023576848242457614`, 1.}}], 
     {LABColor[0.18932120495448782`, 0.5225949340680791, -0.8556484958866668],
       ArrowBox[{{2.687625389725684, 0.9389116018566285}, {2.812374610274316, 
       1.0096455566583584`}}]}}}},
  AspectRatio->NCache[
    Rational[1, 2], 0.5],
  DisplayFunction->Identity,
  Frame->True,
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  LabelStyle->Opacity[0],
  Method->{
   "VectorLengthFunction" -> (Sqrt[#]& ), "DefaultBoundaryStyle" -> Automatic,
     "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
    "TransparentPolygonMesh" -> True},
  PlotRange->{{-1, 3}, {-1, 1}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.02]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.920384314637293*^9, {3.92097739903194*^9, 3.920977421440941*^9}},
 CellLabel->
  "Out[2862]=",ExpressionUUID->"741f5f1d-f984-446c-b567-54abb6c16af7"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Decay rates", "Section",
 CellChangeTimes->{{3.9206553028068523`*^9, 
  3.920655304772027*^9}},ExpressionUUID->"eb6c22b7-c52f-4723-861a-\
054f1ab8f688"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{"nlist", ",", 
   RowBox[{"{", 
    RowBox[{"r", ",", "1", ",", "6"}], "}"}], ",", 
   RowBox[{"Evaluated", "->", "True"}], ",", 
   RowBox[{"PlotRange", "->", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "0.5"}], ",", "0"}], "}"}]}], ",", 
   RowBox[{"BaseStyle", "->", "14"}], ",", 
   RowBox[{"AxesLabel", "->", 
    RowBox[{"{", 
     RowBox[{
     "\"\<r\>\"", ",", "\"\<\!\(\*SuperscriptBox[\(r\), \(-n\)]\)\>\""}], 
     "}"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.9203778114519043`*^9, 3.9203778713907013`*^9}, {
   3.920377919234953*^9, 3.920378151550002*^9}, {3.920378279406671*^9, 
   3.9203783220244617`*^9}, 3.920655310728393*^9},
 CellLabel->
  "In[2269]:=",ExpressionUUID->"cc585ba0-51d4-4c47-8b2b-6f6c71caf870"],

Cell[BoxData[
 GraphicsBox[
  InterpretationBox[{
    TagBox[{{{}, {}, 
       TagBox[
        {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[2], 
         Opacity[1.], LineBox[CompressedData["
1:eJwdxQ841HccwPE7/+IIh7tvRh7/Ri46a1uNeTyfeHryr0gP090zzyRR/mSH
bZ3SsZ1/JbIN8aQJ2xOLUyf5+/Hv57/jzp+E6sZi5lGLGGbsz/t5Xs/b4sxF
/zAVGo3m+q//Hs/axX9KpwHt/5Qob/4woWA/DYJ9eLYN915gm+/2PuEaDX7L
fJCmwX2OovOx5sHNdHD/uMS9eHoaDZ3fd+F8rwLMbXp2XNYULm96V4qDVYHG
lQ2rX5zEckGta+9HarD1lYjx6ORTtBX0sPT01KGe8cEk228CV0Peg1/H1eEH
DeXzO58/wXzNxRsl1RqgVHVzKL85juI7m46vLu0CEDRzOUNjeGyJ96dlgCYI
DscOSxhjONF+ls6z14LIuq/JQOAo1qZ3BpuvakHaQva4sH4Ez6knKGUyBiyG
dkr8jEcwVJBYq1OoDTPJHktV1xXIDd8v8wnRgdjQ83FxDAUOGdhrJzjthsHT
Mz6qYjk2VqUU2avqgnpF5IabnhwT6Ry/gWe64GR3Wj8mbxgZ00KPGKkeOMy7
LVraDGPciH6fr6s+XPJXXnEVD6H3dzop0xX6cH30qu5anQw9jz+cddRnwmv6
ulUmXYYH+g6Ep8Yx4Y8F24MtgYN45a5iy/cFE1IKDpoOlg/gssDC5Rd3A7CY
PBfD1BxAeXFB1pzEAI5WVr3OOduP4+0N6Q/ZhjBheqhEqOjDjoqa8mShIYiV
X8q1PfvwnVfDox1zhlAWNpCr19CL+XZF9we9jYA3lvV4y6kXk1qzCrzrjWB0
0koilfagj0lAeZ81C9bMPgkzPtyDENPNZ2awQEU07hnU1Y3FpmesB1ZZMKiq
FV3i141WHT/lneCzYX7v9h5qrguzHdo5ihY2FFl1NeWmdGHYipq8l0PgnshN
s9K4C0Nqls0zsgmEMPdEcBopvJByasvrJoHM5aTCa/UUxp+SPtH5loBnfRNj
qY7C1NWEGzl5BI5Ui8skUgp/dtr4K/82AUe7/kbnKgrX23bGf6wk0P6uRTSv
hMIchU5WZzcBIpcmdqdRWFgaHZHaS8CGn3TCMZXC0niZu0c/geNHoz699Q2F
j9g5m/0yAn+/vcqNSqZwmmcYMTJGoKbRoNQokULbWWP3mVkCUen+TbExFDpK
hWZlLwm0mNh7P4ui0Fk8tRE2T0DaGsjyiqTQx/a2ZOF3AgUrF/jWERQKIs3N
3rwhENNqcX8qhMLLLskbD1YImGSwWV6fUSjePTMav0rAgvu27nEwhQXVpdfW
1wnkHjlUlcen8K5ILbxhk0ClTETX4FFYeTLM7fIWgS+EouyEIAqlll17XbcJ
tAXvC3oZSGHLis3Gzg4B81uR/IAACv8BdWnnFg==
          "]]},
        Annotation[#, "Charting`Private`Tag#1"]& ], 
       TagBox[
        {RGBColor[0.880722, 0.611041, 0.142051], AbsoluteThickness[2], 
         Opacity[1.], LineBox[CompressedData["
1:eJwdxQk4lAkYwHGEJeeY+LYtkTxEk3QtSb63smuKoqg27VoptFIW0a4rJneh
VkX5Rs4KuXLUKN5ylNwTg2UmSpF0uIYZI+3xf57f81/p5rPfXUZKSuqnf/33
B15VrhkZM6TU/w0ieBtFNmTOkIdUVOKq5wfQ4NfYdkHPDKm5Oos14T6A49Y/
eqhaz5IRMQe1rlq/xCj12mSf5SKyL4k70G3Cx+PpjQTqicjxFgXRMl0+WjPa
01SNRCTBvXrdm8ZHGSY/u3CziNSxZzNNp/sx7NxM2dheESm4QSpCVT8GfjLu
8owQkTWcV4JAZj96tCQvcR0WkRv651ZOefchM9b9qkOJmISH5W6Czl58mZbo
bHhfTM7ol4blP+1F/+L7OgvVYtJlzG4Fi9OL6d2K+QXNYvJLDfehw81eFOoX
1ciPiMnZ0/u2ep3sxawnMyOPtOfIzeG+vEi5XvwyF2NhdGGOPNR4JFVtew/e
O5U/IO0hITt0z2e5dPIwunW88oG3hJzfe3BpSSMPndeaJfr4S0g3d467Yg0P
ZT7WWQrCJaS3WZpr5x0eOnoLrj9Ik5DDvY2L68N4OO2l7uTDlZCO8ZeLaAwe
fn8isJFvOU/S5daNr7nYhRy3HaX36V9IhnPypreunehsHm10MWeBBKFl1qAf
F7nVmwNS10iBZwxn+Gendnxiv7A6aEYKVCrTD/v+0YLhv/2u61ItDUqt8WI5
hSakW2y0NL4qA3c+OPygz3mGk3O2BVEui8C59E72e14D5vpVWD03l4WRMEWt
UIV6NPRr1FRTk4NVHpmc93/UovDoenjTLQepLdesRxlPMEVhLDGzWB50VKZk
y3mIUTfnTD/9+Q3ItjrSdlVVo81H51m9AwpA02i1Ie4+xN7a49LODEUArwkt
Xh8HK2LrXXSFijDKHh4ddXiAHnIBg21ti8Gp9nKpTUslHvMLrlC+oQQNalf+
comowHWea9rsjipDva9VSvyhcmzXYCgFbFEBk0GySWRShg+LWGmMRapAbykZ
DDG9h8HSxg4tAlWgSQ77u20oxcX8IObpcjWIjCh+lGFXgv6d6k32VuqwVqZz
yFG5GG2vKLP4+eoQf/7vd6qhhbhrT9mQqToNIq97ag3p3UWTJhPPaH8aBLpl
CFYN52No1ot5+wEaKMoXSbNy83DSb6Xlq50aMF48HaebeAe56akJwyUa0Gf+
KmPc7zZ211bFlmnRgdWwr9Qn+BbW5ZfmRgTRwUCwf/JwSi5+96mjq26YDuuC
fY0ni3IwxSitsNV2CcQIg6YXDWVj2OOEVFvOEhBTn0OU6Nlot+xAbpO+JkSu
PzYr65iFcPrZEVqcJlgU5tl/yMvE9OVu+i1CTVgdoGxWNp+Bq+puX9t7RAt6
8tzM249lYNLaWuMXNVoQsfHl8m0FN9F9Spb73JiATZNOkRidjkdLJ3Xjkgg4
1DD+mH+ejV4sx/ndlwmIlM8xCDzHxjOO5T3KyQQkcC1j1YPZGC0MSLx0jQCl
7sltTD823t0ilqSwCZCc2H6yzpWNoidfu28VENBht/viu21svPRCOaH+GQEa
uzhvxkQU3sg+dSL6OQEb7B6b5UxTmH2mbSezmQCL6nOhv4xTWKl1aa65jYCN
ToqDL0Yo5DvTT3TyCHi9+Ky4sZtCw6GlO18PEbDM6xL5upxC0/KgFTlvCdiz
G6m8EgotovrF7iME5Bmav/O9S6GdIbtk9D0BW5o/M+VyKPQ7qbtiYoIAxsdO
I7NkCkMsI8T3pggI31I8IZdEYZTK664zQgLoUrdzefEUphZnXxCJCDDW6ek4
y6IwK1zWs2qOgEpmlM3uMAoL9rnvCJkn4Gzi1jztIArL9Z5qWy0QoP1thXAi
gMKaKQPx168EXDYoZDzzpfAf+eDWvw==
          "]]},
        Annotation[#, "Charting`Private`Tag#2"]& ], 
       TagBox[
        {RGBColor[0.560181, 0.691569, 0.194885], AbsoluteThickness[2], 
         Opacity[1.], LineBox[CompressedData["
1:eJwdj3k41PsfxWcmiZI1vuWmi/xsWYqIUp9P0koorZRCUgrdGaPLTeHGRXER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          "]]},
        Annotation[#, "Charting`Private`Tag#3"]& ], 
       TagBox[
        {RGBColor[0.922526, 0.385626, 0.209179], AbsoluteThickness[2], 
         Opacity[1.], LineBox[CompressedData["
1:eJwdlXk4FPr/xQdjl0IaiaxZJlSWiuTzuZQMFdKqUmQrQrJkSXKz3bITEtkL
ZS+7tzVrWRKR7WrhqlTGjBmG+fb7nec5z3lef5zz75Gzcz/hwEkgEIb++P+y
eUz3agAfFRH+X9NA07mR9uYwFcWcHdjR4DgJFwzTLVWPUlF+JbMODCah7XgX
b+gJKvp+zmGNizQJiU5yXvqXqIj9WjfIvHMCNFMHjhbdoqL+mKvpn9UnwI21
Zz2iiIoor5XlHxPHYa5l8fIhkSV0rCbptvTEKFj0bSdlkpZQoHkJ1b1+FKo+
mr5ZlV5CsXQPGi1tFMKWsnUryEuILczYknZ+FBSVrETlDy2hksdfL6KJD2Ab
WdHK9llC84F9axn/jcCYuZdS3fgSqtPVd7BWHIbgZw0L9JkldDu/xWWZfxiU
OHirNP9bQpEK9Mq6n+/Bszz1SCFtCWW5fF6urnsPAuLgnCpMQ+k+c7VBp96D
3hh/kS+mIVa7yigrZgge2T/ZpZ1LQ7IhpRWCMu8AN8wtuxfS0L2PbVVi/O/g
q7hmU1EpDdnzZ6MD1EHQ7GizUGigofa5y5xzHYPQrTp/Q3SYhrw75e6Wew7C
yoJ25S9eOqpI9FCcfDMA5/26979woaNLw2Jn9VL7ofrMXkMPTzo65DFjYhTa
D5v3Zptp+dGRz00TnWs3+uHtop9NTRgd7c1wURUx7QfsqnqvPYuOnnhJOgUw
+0DpUkTfxAgd8YQ3l3a+fQu/Dhk7Ch9aRl/b94WRs3rhqEK5+4DpMuqqIu9d
udMLBRzb/RItl1Ht3g8/mTa9YNdIuy95aRlZ8D7XipDuhff78sqU/JdRc20j
38jjHqglE9cMSpdRrIXuOUZON4Ruaklwl2KgbxvEk/UHO8E+o5ME8gxkMU8i
W1Z3wiG1vjRhVQYq+p4aGZ7RCZwm4zkvdBhouXjHx7MunRB0h17x7TgDNa6F
SUTwdILPAnnI6S4DpXwTKvlu2AGOvQmbL39loOJjibxBg+1w2PpRSsl3Bvqd
bfXCtb4dFOcypdiLDJR5UX2Pb347zHAVK2awGWh7ZA15yr8dbA50ao9LMJG7
tYw1XbEdzhSyTp41Y6I9wT0Htwe1gUmEQ5JFKRON2Md2GRu1wmRatLVyFRMV
fvOWGdBohZslVTLrDUxU38+Z4iPZChnD/IVFPUyk39J/SHSxBWiKxY08s0zk
GdwxF57dAtnN9Nl66RWErYe0TPhaYG0lXE/1/goKC3IsF/jaBPHCZWx23Arq
zz8QUDTUBCryY23DKSsoZXpjnF1rE5ykqJnfy19BXbrPJcWymqAwuf/KVPMf
5uij+l1sgrPaW6OSGCvoU93rT39XApRfL5zicFxFj7Vf1ze1N0DYm1+vql1X
URY5OjDnWQNYq++Ldr+5irC8fnfB/Qbg/NGqPxG8io5VuCLZEw1g5TqRWp22
ipakztOKp+th6dqmk+4Dq2j5ZVyPMrEe9jr7dI7rs1Cq6+io7pVaEOisf5Jg
xEKEZ0Fju0xrYVKZy9fUlIV2XpION9pTC2GzMTuqz7CQl9PCgVZ2DYw4FoQk
eLIQ/WJqhExGDdxyGNc3fcZCUZXMPSrT1VBjZ1hWJbaG+C1UVFxuVcEmTwWu
1a1raFIv4fxB+ypwvEs8ZSC7hlIVuPV2WFTB5szXjDa1NVS+NS5CR6UK3CZM
8eDhNbQVnK+eGn0F8met+r77rqHkw7nP/NEr+OeY/Q+58TVUYsOXlC/5EqYv
HEYOM2vIVrZJbpXvJexzVYp7NreGRkVaVOyWK+HzP3Pau2hrKGWHJMVpqBIM
Ol0D9YXX0XBw8QmzmEpYNPQWPIPXkduc3KIjXyVY7w9TfZC7jmY1tymd5q0A
pzeR9aeL1hH9LytmML0cvOyizOXK15GmjalD45dyiH6Q6P0K1pERRSzPo60c
Wqezm6fH1lGtcPa20pByUIuEczoibBT3/p5kGGc5rI8yIidvs9Fwd7PlT+Ey
EHRnSRXcY6MamjPGhDKQIBJKb95nI5n3bozM36WgqcE7zJfKRgpXzG/GDZWC
U4i4vFYlG8neEbdTSyuFfrJmbfg8GxXaDizu31kKAw063ik7CTjSr9/pxPNi
kJgmslo1CNi691K5RWIxXOYcCvm5h4Dzpce8HAOL4ZexZ6zxfgJudyqijhwt
ho39xUVLhwhYqrJ4qm/hBRybUZ6xsCFgwa1fZVl7X0AXj6Q5fxwBr0W/5EwY
KYJm83UVfzoBf3AML71/sgBUJMark5gE/MVRaBfRsACip2tMylgE/FfuZFrU
rgK4cMPbeY6TA+vsPk4fFCgARvz3p6c3cmD/u9XPd7Q8g93DY0paKhz4l3u6
zUetZ5B5oUrx+zkO7PKxxk5Y4SkEX/WQtWngwBoed6oF1fOgxWvKoqGJAyeW
jXUzpfKAGHz8rlQbB/ZV7JVYFsqDyIdqM2PdHFh03lhe5kcuxLfO5Zz5wIG5
kZuQQnEu5EnbKltSOXBZYVjUN81c6B6w1Dikyol51SR2Cx/JATE9LX1yEid2
m9Mwt3qYBVvSfxaYp3BiEVm1fe7/ZIEk4TnJO40Tm9FVyUlBWSD7WpEKWZzY
/PbffGzHLNA4saXwVDEnDhDoe0DZnwWm15ikux2cOHubjWDZeCaEPALqCJMT
a2bpLYapZcLiillRqA0Xjt1ruVjRmw4Dmak1C7ZcONTny6WmqnQoNZ7tOOPA
hS+fI2hPZafD9fiQz6quXNjv34stVn7pMKdaI/3WjwsX7/hls0U5HabOKsVu
SeLCjHPB0r9DH0PvK4L30x4ufKpx/+3bFmmQ5/nSoGs/EWuXsPcdFE+F3EaR
0/L6RJyzOyj+KTEVsgXcrgcgIiYllDyRWUqBjGylx+rGRCwsSkvb/y4FHg4m
M+OsiJjvwUqOUHwKhGn6V1q7EXFFQv2VPaIp4LhoQP6eQ8QzyEd/s1QyKHt2
im/cyI2/SLB/Zlkl/flbz2saotxYwqwrk3AkCfJrtsExcW7MK1df4KyXBIoc
7s4PtnHjEjYz+6RcEsjGitfxq3Djg/mdR9N+JoJksd1l4l/cmJtj0nk8KhGE
51mFTE9u3PMkr4venwA02z348zA3pkVztvxwj4dYE1edI2PcuO/gWGKIfTyQ
dz0lF05w4/ZOq4Oy5+LhMktK3OMzN75wxmXB2zAeuh/yza/+5sZ4YPBHpHg8
ZPRMJYht4MFapANXjjXEgbFO9KyhEQ9OqJb4LSgWB8l836KzSnhw3b0Ni0+K
YmDR+GZzdzkPvrXhuxs7NQaOh65SqS95MPlChLpLRAzwcAqdM67/s2cod8TJ
IQa8VtUUvnXyYBmVjf2/ZGLgxIJblfYMDw75VuOPk6NBeGhxqmMzL/7bT00n
OjoKQp+s7F7w48WTKrf+nU6/D0d+WC/Ln+LDI2NBrcSFcPjQYs9hrcaPuzvr
Pdo/3YOXEW02sjR+3G+61Xenfwg4cntPv30rgD03/Ju/cjAYrngGvBR6JIjd
9X8eKZ4NhF1OO98etRXCAtbMGzXjftAnqiborbsBe+xkt0sQfKGuOCRNjUsY
rz7MnC964QUBHGSL3glhrP3rzWRJgCcIjPubuFVuxI1Hi31KH3nAzXebus0N
NuG8jF2UWRk3MEsUChkv3IQlTz5oSVBzAcqxik+7N4ngOrdNHloNzqDRreEU
dlMEn6ycdLnx2BFuZw+yzKdEcPlVW1VqlD0sesrp/2skihv9Pmx8NmIHAxkp
UV9LRXGXT1/TsIYtDLfURlRsEcM244vuO5MvQWthWd5dfzHcyjPQ90n+Ikgu
9A+1fhXDoVIRZsP11pCsmvbijdlmfFF+0r6x6iwENUWlmNVsxrc3CCxZNpyG
o9tO5XUrimP1S8q//FgnAbt1nBeJFMdymWuv5YOtIEPKTrGXJo53We39e43v
BCi0Pn14/PwWbD/+aOOGbguIUW8hDzZuwXVN4Q3WZ8zBgUoc6CKTsGNrVPDk
9mNgW7YoGxlDwr4rogEyumZwLcSKZRpHwvMGsaMce8zAy6pyRCiBhMe2ChvM
qphBGM07Ovbhn356rlidhBk812WuJqeT8ImAhJ4whikwmtnD+UUkvC3A1+hF
tSnEDgpFtXWQcKyDs4z6AVN4lHPdOayLhF95q7+4rmUKOV5vjUx6SPgJWZBU
ttMUXm2JXel5S8K5gQR/LGUK49Zizu/ek7CSXPi5u2sUUP601WjmEwmXeHU4
/tNEgd2V/ttzv5DwOCtKhlFNAb3Qj0yHWRJ+SbqV6VxGgaPK6aX/zZMwQ6qf
ZplNAU8X2e2/f5PwdkO73sP3KBCof5dZTiXh82/EcrsCKRC6YWbIi0bCkld3
6ll4UyClJOc+g0HCK3M1jx0cKZAdTHSqXSHhw587HZdsKFBk6WAYyCLhAmm3
+dAzFKiUfy1tsE7C3WRfJUkLCjRSlZhsNgkbG5RvLTOhwP8An1K2Xg==
          "]]},
        Annotation[#, "Charting`Private`Tag#4"]& ], 
       TagBox[
        {RGBColor[0.528488, 0.470624, 0.701351], AbsoluteThickness[2], 
         Opacity[1.], LineBox[CompressedData["
1:eJwdlmcgFWr8gM859ghlHKQushMlpLje9yJ1ZWamsh0qq4NuREbZhYzMzChU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          "]]},
        Annotation[#, "Charting`Private`Tag#5"]& ], 
       TagBox[
        {RGBColor[0.772079, 0.431554, 0.102387], AbsoluteThickness[2], 
         Opacity[1.], LineBox[CompressedData["
1:eJwdVnk0FPz3njHDWMZSaEqlzUskZA/5fEJ4kaYsIdnKkn0vLe9riUiylbUk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          "]]},
        Annotation[#, "Charting`Private`Tag#6"]& ], 
       TagBox[
        {RGBColor[0.363898, 0.618501, 0.782349], AbsoluteThickness[2], 
         Opacity[1.], LineBox[CompressedData["
1:eJwdlnc41v/3x2/c3Fbc5l3ZQhlZWUXeL0JCVpFRVkbJyAxRUQiFjISMjHxQ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          "]]},
        Annotation[#, "Charting`Private`Tag#7"]& ]}, {}},
     {"WolframDynamicHighlight", <|
      "Label" -> {"XYLabel"}, "Ball" -> {"InterpolatedBall"}|>}], 
    StyleBox[
     DynamicBox[(Charting`HighlightActionBox["DynamicHighlight", {}, 
       Slot["HighlightElements"], 
       Slot["LayoutOptions"], 
       Slot["Meta"], 
       Charting`HighlightActionFunction["DynamicHighlight", {{{{}, {}, 
           Annotation[{
             Directive[
              Opacity[1.], 
              RGBColor[0.368417, 0.506779, 0.709798], 
              AbsoluteThickness[2]], 
             Line[CompressedData["
1:eJwdxQ841HccwPE7/+IIh7tvRh7/Ri46a1uNeTyfeHryr0gP090zzyRR/mSH
bZ3SsZ1/JbIN8aQJ2xOLUyf5+/Hv57/jzp+E6sZi5lGLGGbsz/t5Xs/b4sxF
/zAVGo3m+q//Hs/axX9KpwHt/5Qob/4woWA/DYJ9eLYN915gm+/2PuEaDX7L
fJCmwX2OovOx5sHNdHD/uMS9eHoaDZ3fd+F8rwLMbXp2XNYULm96V4qDVYHG
lQ2rX5zEckGta+9HarD1lYjx6ORTtBX0sPT01KGe8cEk228CV0Peg1/H1eEH
DeXzO58/wXzNxRsl1RqgVHVzKL85juI7m46vLu0CEDRzOUNjeGyJ96dlgCYI
DscOSxhjONF+ls6z14LIuq/JQOAo1qZ3BpuvakHaQva4sH4Ez6knKGUyBiyG
dkr8jEcwVJBYq1OoDTPJHktV1xXIDd8v8wnRgdjQ83FxDAUOGdhrJzjthsHT
Mz6qYjk2VqUU2avqgnpF5IabnhwT6Ry/gWe64GR3Wj8mbxgZ00KPGKkeOMy7
LVraDGPciH6fr6s+XPJXXnEVD6H3dzop0xX6cH30qu5anQw9jz+cddRnwmv6
ulUmXYYH+g6Ep8Yx4Y8F24MtgYN45a5iy/cFE1IKDpoOlg/gssDC5Rd3A7CY
PBfD1BxAeXFB1pzEAI5WVr3OOduP4+0N6Q/ZhjBheqhEqOjDjoqa8mShIYiV
X8q1PfvwnVfDox1zhlAWNpCr19CL+XZF9we9jYA3lvV4y6kXk1qzCrzrjWB0
0koilfagj0lAeZ81C9bMPgkzPtyDENPNZ2awQEU07hnU1Y3FpmesB1ZZMKiq
FV3i141WHT/lneCzYX7v9h5qrguzHdo5ihY2FFl1NeWmdGHYipq8l0PgnshN
s9K4C0Nqls0zsgmEMPdEcBopvJByasvrJoHM5aTCa/UUxp+SPtH5loBnfRNj
qY7C1NWEGzl5BI5Ui8skUgp/dtr4K/82AUe7/kbnKgrX23bGf6wk0P6uRTSv
hMIchU5WZzcBIpcmdqdRWFgaHZHaS8CGn3TCMZXC0niZu0c/geNHoz699Q2F
j9g5m/0yAn+/vcqNSqZwmmcYMTJGoKbRoNQokULbWWP3mVkCUen+TbExFDpK
hWZlLwm0mNh7P4ui0Fk8tRE2T0DaGsjyiqTQx/a2ZOF3AgUrF/jWERQKIs3N
3rwhENNqcX8qhMLLLskbD1YImGSwWV6fUSjePTMav0rAgvu27nEwhQXVpdfW
1wnkHjlUlcen8K5ILbxhk0ClTETX4FFYeTLM7fIWgS+EouyEIAqlll17XbcJ
tAXvC3oZSGHLis3Gzg4B81uR/IAACv8BdWnnFg==
              "]]}, "Charting`Private`Tag#1"], 
           Annotation[{
             Directive[
              Opacity[1.], 
              RGBColor[0.880722, 0.611041, 0.142051], 
              AbsoluteThickness[2]], 
             Line[CompressedData["
1:eJwdxQk4lAkYwHGEJeeY+LYtkTxEk3QtSb63smuKoqg27VoptFIW0a4rJneh
VkX5Rs4KuXLUKN5ylNwTg2UmSpF0uIYZI+3xf57f81/p5rPfXUZKSuqnf/33
B15VrhkZM6TU/w0ieBtFNmTOkIdUVOKq5wfQ4NfYdkHPDKm5Oos14T6A49Y/
eqhaz5IRMQe1rlq/xCj12mSf5SKyL4k70G3Cx+PpjQTqicjxFgXRMl0+WjPa
01SNRCTBvXrdm8ZHGSY/u3CziNSxZzNNp/sx7NxM2dheESm4QSpCVT8GfjLu
8owQkTWcV4JAZj96tCQvcR0WkRv651ZOefchM9b9qkOJmISH5W6Czl58mZbo
bHhfTM7ol4blP+1F/+L7OgvVYtJlzG4Fi9OL6d2K+QXNYvJLDfehw81eFOoX
1ciPiMnZ0/u2ep3sxawnMyOPtOfIzeG+vEi5XvwyF2NhdGGOPNR4JFVtew/e
O5U/IO0hITt0z2e5dPIwunW88oG3hJzfe3BpSSMPndeaJfr4S0g3d467Yg0P
ZT7WWQrCJaS3WZpr5x0eOnoLrj9Ik5DDvY2L68N4OO2l7uTDlZCO8ZeLaAwe
fn8isJFvOU/S5daNr7nYhRy3HaX36V9IhnPypreunehsHm10MWeBBKFl1qAf
F7nVmwNS10iBZwxn+Gendnxiv7A6aEYKVCrTD/v+0YLhv/2u61ItDUqt8WI5
hSakW2y0NL4qA3c+OPygz3mGk3O2BVEui8C59E72e14D5vpVWD03l4WRMEWt
UIV6NPRr1FRTk4NVHpmc93/UovDoenjTLQepLdesRxlPMEVhLDGzWB50VKZk
y3mIUTfnTD/9+Q3ItjrSdlVVo81H51m9AwpA02i1Ie4+xN7a49LODEUArwkt
Xh8HK2LrXXSFijDKHh4ddXiAHnIBg21ti8Gp9nKpTUslHvMLrlC+oQQNalf+
comowHWea9rsjipDva9VSvyhcmzXYCgFbFEBk0GySWRShg+LWGmMRapAbykZ
DDG9h8HSxg4tAlWgSQ77u20oxcX8IObpcjWIjCh+lGFXgv6d6k32VuqwVqZz
yFG5GG2vKLP4+eoQf/7vd6qhhbhrT9mQqToNIq97ag3p3UWTJhPPaH8aBLpl
CFYN52No1ot5+wEaKMoXSbNy83DSb6Xlq50aMF48HaebeAe56akJwyUa0Gf+
KmPc7zZ211bFlmnRgdWwr9Qn+BbW5ZfmRgTRwUCwf/JwSi5+96mjq26YDuuC
fY0ni3IwxSitsNV2CcQIg6YXDWVj2OOEVFvOEhBTn0OU6Nlot+xAbpO+JkSu
PzYr65iFcPrZEVqcJlgU5tl/yMvE9OVu+i1CTVgdoGxWNp+Bq+puX9t7RAt6
8tzM249lYNLaWuMXNVoQsfHl8m0FN9F9Spb73JiATZNOkRidjkdLJ3Xjkgg4
1DD+mH+ejV4sx/ndlwmIlM8xCDzHxjOO5T3KyQQkcC1j1YPZGC0MSLx0jQCl
7sltTD823t0ilqSwCZCc2H6yzpWNoidfu28VENBht/viu21svPRCOaH+GQEa
uzhvxkQU3sg+dSL6OQEb7B6b5UxTmH2mbSezmQCL6nOhv4xTWKl1aa65jYCN
ToqDL0Yo5DvTT3TyCHi9+Ky4sZtCw6GlO18PEbDM6xL5upxC0/KgFTlvCdiz
G6m8EgotovrF7iME5Bmav/O9S6GdIbtk9D0BW5o/M+VyKPQ7qbtiYoIAxsdO
I7NkCkMsI8T3pggI31I8IZdEYZTK664zQgLoUrdzefEUphZnXxCJCDDW6ek4
y6IwK1zWs2qOgEpmlM3uMAoL9rnvCJkn4Gzi1jztIArL9Z5qWy0QoP1thXAi
gMKaKQPx168EXDYoZDzzpfAf+eDWvw==
              "]]}, "Charting`Private`Tag#2"], 
           Annotation[{
             Directive[
              Opacity[1.], 
              RGBColor[0.560181, 0.691569, 0.194885], 
              AbsoluteThickness[2]], 
             Line[CompressedData["
1:eJwdj3k41PsfxWcmiZI1vuWmi/xsWYqIUp9P0koorZRCUgrdGaPLTeHGRXER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              "]]}, "Charting`Private`Tag#3"], 
           Annotation[{
             Directive[
              Opacity[1.], 
              RGBColor[0.922526, 0.385626, 0.209179], 
              AbsoluteThickness[2]], 
             Line[CompressedData["
1:eJwdlXk4FPr/xQdjl0IaiaxZJlSWiuTzuZQMFdKqUmQrQrJkSXKz3bITEtkL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              "]]}, "Charting`Private`Tag#4"], 
           Annotation[{
             Directive[
              Opacity[1.], 
              RGBColor[0.528488, 0.470624, 0.701351], 
              AbsoluteThickness[2]], 
             Line[CompressedData["
1:eJwdlmcgFWr8gM859ghlHKQushMlpLje9yJ1ZWamsh0qq4NuREbZhYzMzChU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              "]]}, "Charting`Private`Tag#5"], 
           Annotation[{
             Directive[
              Opacity[1.], 
              RGBColor[0.772079, 0.431554, 0.102387], 
              AbsoluteThickness[2]], 
             Line[CompressedData["
1:eJwdVnk0FPz3njHDWMZSaEqlzUskZA/5fEJ4kaYsIdnKkn0vLe9riUiylbUk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              "]]}, "Charting`Private`Tag#6"], 
           Annotation[{
             Directive[
              Opacity[1.], 
              RGBColor[0.363898, 0.618501, 0.782349], 
              AbsoluteThickness[2]], 
             Line[CompressedData["
1:eJwdlnc41v/3x2/c3Fbc5l3ZQhlZWUXeL0JCVpFRVkbJyAxRUQiFjISMjHxQ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              "]]}, "Charting`Private`Tag#7"]}}, {}}, <|
        "HighlightElements" -> <|
          "Label" -> {"XYLabel"}, "Ball" -> {"InterpolatedBall"}|>, 
         "LayoutOptions" -> <|
          "PanelPlotLayout" -> <||>, 
           "PlotRange" -> {{1.0000001020408162`, 5.999999897959183}, {-0.5, 
            0.}}, "Frame" -> {{False, False}, {False, False}}, 
           "AxesOrigin" -> {1.0000001020408185`, 0}, 
           "ImageSize" -> {360, 360/GoldenRatio}, "Axes" -> {True, True}, 
           "LabelStyle" -> {}, "AspectRatio" -> GoldenRatio^(-1), 
           "DefaultStyle" -> {
             Directive[
              Opacity[1.], 
              RGBColor[0.363898, 0.618501, 0.782349], 
              AbsoluteThickness[2]], 
             Directive[
              Opacity[1.], 
              RGBColor[0.772079, 0.431554, 0.102387], 
              AbsoluteThickness[2]], 
             Directive[
              Opacity[1.], 
              RGBColor[0.528488, 0.470624, 0.701351], 
              AbsoluteThickness[2]], 
             Directive[
              Opacity[1.], 
              RGBColor[0.922526, 0.385626, 0.209179], 
              AbsoluteThickness[2]], 
             Directive[
              Opacity[1.], 
              RGBColor[0.560181, 0.691569, 0.194885], 
              AbsoluteThickness[2]], 
             Directive[
              Opacity[1.], 
              RGBColor[0.880722, 0.611041, 0.142051], 
              AbsoluteThickness[2]], 
             Directive[
              Opacity[1.], 
              RGBColor[0.368417, 0.506779, 0.709798], 
              AbsoluteThickness[2]]}, 
           "HighlightLabelingFunctions" -> <|"CoordinatesToolOptions" -> ({
               Identity[
                Part[#, 1]], 
               Identity[
                Part[#, 2]]}& ), 
             "ScalingFunctions" -> {{Identity, Identity}, {
               Identity, Identity}}|>, "Primitives" -> {}, "GCFlag" -> 
           False|>, 
         "Meta" -> <|
          "DefaultHighlight" -> {"Dynamic", None}, "Index" -> {}, "Function" -> 
           Plot, "GroupHighlight" -> False|>|>]]& )[<|
       "HighlightElements" -> <|
         "Label" -> {"XYLabel"}, "Ball" -> {"InterpolatedBall"}|>, 
        "LayoutOptions" -> <|
         "PanelPlotLayout" -> <||>, 
          "PlotRange" -> {{1.0000001020408162`, 5.999999897959183}, {-0.5, 
           0.}}, "Frame" -> {{False, False}, {False, False}}, 
          "AxesOrigin" -> {1.0000001020408185`, 0}, 
          "ImageSize" -> {360, 360/GoldenRatio}, "Axes" -> {True, True}, 
          "LabelStyle" -> {}, "AspectRatio" -> GoldenRatio^(-1), 
          "DefaultStyle" -> {
            Directive[
             Opacity[1.], 
             RGBColor[0.363898, 0.618501, 0.782349], 
             AbsoluteThickness[2]], 
            Directive[
             Opacity[1.], 
             RGBColor[0.772079, 0.431554, 0.102387], 
             AbsoluteThickness[2]], 
            Directive[
             Opacity[1.], 
             RGBColor[0.528488, 0.470624, 0.701351], 
             AbsoluteThickness[2]], 
            Directive[
             Opacity[1.], 
             RGBColor[0.922526, 0.385626, 0.209179], 
             AbsoluteThickness[2]], 
            Directive[
             Opacity[1.], 
             RGBColor[0.560181, 0.691569, 0.194885], 
             AbsoluteThickness[2]], 
            Directive[
             Opacity[1.], 
             RGBColor[0.880722, 0.611041, 0.142051], 
             AbsoluteThickness[2]], 
            Directive[
             Opacity[1.], 
             RGBColor[0.368417, 0.506779, 0.709798], 
             AbsoluteThickness[2]]}, 
          "HighlightLabelingFunctions" -> <|"CoordinatesToolOptions" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& ), 
            "ScalingFunctions" -> {{Identity, Identity}, {
              Identity, Identity}}|>, "Primitives" -> {}, "GCFlag" -> False|>,
         "Meta" -> <|
         "DefaultHighlight" -> {"Dynamic", None}, "Index" -> {}, "Function" -> 
          Plot, "GroupHighlight" -> False|>|>],
      ImageSizeCache->{{4.503599627370496*^15, -4.503599627370496*^15}, {
       4.503599627370496*^15, -4.503599627370496*^15}}],
     Selectable->False]},
   Annotation[{{{{}, {}, 
       Annotation[{
         Directive[
          Opacity[1.], 
          RGBColor[0.368417, 0.506779, 0.709798], 
          AbsoluteThickness[2]], 
         Line[CompressedData["
1:eJwdxQ841HccwPE7/+IIh7tvRh7/Ri46a1uNeTyfeHryr0gP090zzyRR/mSH
bZ3SsZ1/JbIN8aQJ2xOLUyf5+/Hv57/jzp+E6sZi5lGLGGbsz/t5Xs/b4sxF
/zAVGo3m+q//Hs/axX9KpwHt/5Qob/4woWA/DYJ9eLYN915gm+/2PuEaDX7L
fJCmwX2OovOx5sHNdHD/uMS9eHoaDZ3fd+F8rwLMbXp2XNYULm96V4qDVYHG
lQ2rX5zEckGta+9HarD1lYjx6ORTtBX0sPT01KGe8cEk228CV0Peg1/H1eEH
DeXzO58/wXzNxRsl1RqgVHVzKL85juI7m46vLu0CEDRzOUNjeGyJ96dlgCYI
DscOSxhjONF+ls6z14LIuq/JQOAo1qZ3BpuvakHaQva4sH4Ez6knKGUyBiyG
dkr8jEcwVJBYq1OoDTPJHktV1xXIDd8v8wnRgdjQ83FxDAUOGdhrJzjthsHT
Mz6qYjk2VqUU2avqgnpF5IabnhwT6Ry/gWe64GR3Wj8mbxgZ00KPGKkeOMy7
LVraDGPciH6fr6s+XPJXXnEVD6H3dzop0xX6cH30qu5anQw9jz+cddRnwmv6
ulUmXYYH+g6Ep8Yx4Y8F24MtgYN45a5iy/cFE1IKDpoOlg/gssDC5Rd3A7CY
PBfD1BxAeXFB1pzEAI5WVr3OOduP4+0N6Q/ZhjBheqhEqOjDjoqa8mShIYiV
X8q1PfvwnVfDox1zhlAWNpCr19CL+XZF9we9jYA3lvV4y6kXk1qzCrzrjWB0
0koilfagj0lAeZ81C9bMPgkzPtyDENPNZ2awQEU07hnU1Y3FpmesB1ZZMKiq
FV3i141WHT/lneCzYX7v9h5qrguzHdo5ihY2FFl1NeWmdGHYipq8l0PgnshN
s9K4C0Nqls0zsgmEMPdEcBopvJByasvrJoHM5aTCa/UUxp+SPtH5loBnfRNj
qY7C1NWEGzl5BI5Ui8skUgp/dtr4K/82AUe7/kbnKgrX23bGf6wk0P6uRTSv
hMIchU5WZzcBIpcmdqdRWFgaHZHaS8CGn3TCMZXC0niZu0c/geNHoz699Q2F
j9g5m/0yAn+/vcqNSqZwmmcYMTJGoKbRoNQokULbWWP3mVkCUen+TbExFDpK
hWZlLwm0mNh7P4ui0Fk8tRE2T0DaGsjyiqTQx/a2ZOF3AgUrF/jWERQKIs3N
3rwhENNqcX8qhMLLLskbD1YImGSwWV6fUSjePTMav0rAgvu27nEwhQXVpdfW
1wnkHjlUlcen8K5ILbxhk0ClTETX4FFYeTLM7fIWgS+EouyEIAqlll17XbcJ
tAXvC3oZSGHLis3Gzg4B81uR/IAACv8BdWnnFg==
          "]]}, "Charting`Private`Tag#1"], 
       Annotation[{
         Directive[
          Opacity[1.], 
          RGBColor[0.880722, 0.611041, 0.142051], 
          AbsoluteThickness[2]], 
         Line[CompressedData["
1:eJwdxQk4lAkYwHGEJeeY+LYtkTxEk3QtSb63smuKoqg27VoptFIW0a4rJneh
VkX5Rs4KuXLUKN5ylNwTg2UmSpF0uIYZI+3xf57f81/p5rPfXUZKSuqnf/33
B15VrhkZM6TU/w0ieBtFNmTOkIdUVOKq5wfQ4NfYdkHPDKm5Oos14T6A49Y/
eqhaz5IRMQe1rlq/xCj12mSf5SKyL4k70G3Cx+PpjQTqicjxFgXRMl0+WjPa
01SNRCTBvXrdm8ZHGSY/u3CziNSxZzNNp/sx7NxM2dheESm4QSpCVT8GfjLu
8owQkTWcV4JAZj96tCQvcR0WkRv651ZOefchM9b9qkOJmISH5W6Czl58mZbo
bHhfTM7ol4blP+1F/+L7OgvVYtJlzG4Fi9OL6d2K+QXNYvJLDfehw81eFOoX
1ciPiMnZ0/u2ep3sxawnMyOPtOfIzeG+vEi5XvwyF2NhdGGOPNR4JFVtew/e
O5U/IO0hITt0z2e5dPIwunW88oG3hJzfe3BpSSMPndeaJfr4S0g3d467Yg0P
ZT7WWQrCJaS3WZpr5x0eOnoLrj9Ik5DDvY2L68N4OO2l7uTDlZCO8ZeLaAwe
fn8isJFvOU/S5daNr7nYhRy3HaX36V9IhnPypreunehsHm10MWeBBKFl1qAf
F7nVmwNS10iBZwxn+Gendnxiv7A6aEYKVCrTD/v+0YLhv/2u61ItDUqt8WI5
hSakW2y0NL4qA3c+OPygz3mGk3O2BVEui8C59E72e14D5vpVWD03l4WRMEWt
UIV6NPRr1FRTk4NVHpmc93/UovDoenjTLQepLdesRxlPMEVhLDGzWB50VKZk
y3mIUTfnTD/9+Q3ItjrSdlVVo81H51m9AwpA02i1Ie4+xN7a49LODEUArwkt
Xh8HK2LrXXSFijDKHh4ddXiAHnIBg21ti8Gp9nKpTUslHvMLrlC+oQQNalf+
comowHWea9rsjipDva9VSvyhcmzXYCgFbFEBk0GySWRShg+LWGmMRapAbykZ
DDG9h8HSxg4tAlWgSQ77u20oxcX8IObpcjWIjCh+lGFXgv6d6k32VuqwVqZz
yFG5GG2vKLP4+eoQf/7vd6qhhbhrT9mQqToNIq97ag3p3UWTJhPPaH8aBLpl
CFYN52No1ot5+wEaKMoXSbNy83DSb6Xlq50aMF48HaebeAe56akJwyUa0Gf+
KmPc7zZ211bFlmnRgdWwr9Qn+BbW5ZfmRgTRwUCwf/JwSi5+96mjq26YDuuC
fY0ni3IwxSitsNV2CcQIg6YXDWVj2OOEVFvOEhBTn0OU6Nlot+xAbpO+JkSu
PzYr65iFcPrZEVqcJlgU5tl/yMvE9OVu+i1CTVgdoGxWNp+Bq+puX9t7RAt6
8tzM249lYNLaWuMXNVoQsfHl8m0FN9F9Spb73JiATZNOkRidjkdLJ3Xjkgg4
1DD+mH+ejV4sx/ndlwmIlM8xCDzHxjOO5T3KyQQkcC1j1YPZGC0MSLx0jQCl
7sltTD823t0ilqSwCZCc2H6yzpWNoidfu28VENBht/viu21svPRCOaH+GQEa
uzhvxkQU3sg+dSL6OQEb7B6b5UxTmH2mbSezmQCL6nOhv4xTWKl1aa65jYCN
ToqDL0Yo5DvTT3TyCHi9+Ky4sZtCw6GlO18PEbDM6xL5upxC0/KgFTlvCdiz
G6m8EgotovrF7iME5Bmav/O9S6GdIbtk9D0BW5o/M+VyKPQ7qbtiYoIAxsdO
I7NkCkMsI8T3pggI31I8IZdEYZTK664zQgLoUrdzefEUphZnXxCJCDDW6ek4
y6IwK1zWs2qOgEpmlM3uMAoL9rnvCJkn4Gzi1jztIArL9Z5qWy0QoP1thXAi
gMKaKQPx168EXDYoZDzzpfAf+eDWvw==
          "]]}, "Charting`Private`Tag#2"], 
       Annotation[{
         Directive[
          Opacity[1.], 
          RGBColor[0.560181, 0.691569, 0.194885], 
          AbsoluteThickness[2]], 
         Line[CompressedData["
1:eJwdj3k41PsfxWcmiZI1vuWmi/xsWYqIUp9P0koorZRCUgrdGaPLTeHGRXER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          "]]}, "Charting`Private`Tag#3"], 
       Annotation[{
         Directive[
          Opacity[1.], 
          RGBColor[0.922526, 0.385626, 0.209179], 
          AbsoluteThickness[2]], 
         Line[CompressedData["
1:eJwdlXk4FPr/xQdjl0IaiaxZJlSWiuTzuZQMFdKqUmQrQrJkSXKz3bITEtkL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          "]]}, "Charting`Private`Tag#4"], 
       Annotation[{
         Directive[
          Opacity[1.], 
          RGBColor[0.528488, 0.470624, 0.701351], 
          AbsoluteThickness[2]], 
         Line[CompressedData["
1:eJwdlmcgFWr8gM859ghlHKQushMlpLje9yJ1ZWamsh0qq4NuREbZhYzMzChU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          "]]}, "Charting`Private`Tag#5"], 
       Annotation[{
         Directive[
          Opacity[1.], 
          RGBColor[0.772079, 0.431554, 0.102387], 
          AbsoluteThickness[2]], 
         Line[CompressedData["
1:eJwdVnk0FPz3njHDWMZSaEqlzUskZA/5fEJ4kaYsIdnKkn0vLe9riUiylbUk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          "]]}, "Charting`Private`Tag#6"], 
       Annotation[{
         Directive[
          Opacity[1.], 
          RGBColor[0.363898, 0.618501, 0.782349], 
          AbsoluteThickness[2]], 
         Line[CompressedData["
1:eJwdlnc41v/3x2/c3Fbc5l3ZQhlZWUXeL0JCVpFRVkbJyAxRUQiFjISMjHxQ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          "]]}, "Charting`Private`Tag#7"]}}, {}}, <|
    "HighlightElements" -> <|
      "Label" -> {"XYLabel"}, "Ball" -> {"InterpolatedBall"}|>, 
     "LayoutOptions" -> <|
      "PanelPlotLayout" -> <||>, 
       "PlotRange" -> {{1.0000001020408162`, 5.999999897959183}, {-0.5, 0.}}, 
       "Frame" -> {{False, False}, {False, False}}, 
       "AxesOrigin" -> {1.0000001020408185`, 0}, 
       "ImageSize" -> {360, 360/GoldenRatio}, "Axes" -> {True, True}, 
       "LabelStyle" -> {}, "AspectRatio" -> GoldenRatio^(-1), "DefaultStyle" -> {
         Directive[
          Opacity[1.], 
          RGBColor[0.363898, 0.618501, 0.782349], 
          AbsoluteThickness[2]], 
         Directive[
          Opacity[1.], 
          RGBColor[0.772079, 0.431554, 0.102387], 
          AbsoluteThickness[2]], 
         Directive[
          Opacity[1.], 
          RGBColor[0.528488, 0.470624, 0.701351], 
          AbsoluteThickness[2]], 
         Directive[
          Opacity[1.], 
          RGBColor[0.922526, 0.385626, 0.209179], 
          AbsoluteThickness[2]], 
         Directive[
          Opacity[1.], 
          RGBColor[0.560181, 0.691569, 0.194885], 
          AbsoluteThickness[2]], 
         Directive[
          Opacity[1.], 
          RGBColor[0.880722, 0.611041, 0.142051], 
          AbsoluteThickness[2]], 
         Directive[
          Opacity[1.], 
          RGBColor[0.368417, 0.506779, 0.709798], 
          AbsoluteThickness[2]]}, 
       "HighlightLabelingFunctions" -> <|"CoordinatesToolOptions" -> ({
           Identity[
            Part[#, 1]], 
           Identity[
            Part[#, 2]]}& ), 
         "ScalingFunctions" -> {{Identity, Identity}, {Identity, Identity}}|>,
        "Primitives" -> {}, "GCFlag" -> False|>, 
     "Meta" -> <|
      "DefaultHighlight" -> {"Dynamic", None}, "Index" -> {}, "Function" -> 
       Plot, "GroupHighlight" -> False|>|>, "DynamicHighlight"]],
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{
    FormBox[
     TagBox["\"r\"", HoldForm], TraditionalForm], 
    FormBox[
     TagBox["\"\\!\\(\\*SuperscriptBox[\\(r\\), \\(-n\\)]\\)\"", HoldForm], 
     TraditionalForm]},
  AxesOrigin->{1.0000001020408185`, 0},
  BaseStyle->14,
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{1.0000001020408162`, 5.999999897959183}, {-0.5, 0.}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {0, 0}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{{3.920377844644293*^9, 3.920377871986855*^9}, {
   3.9203779200905337`*^9, 3.92037793400117*^9}, {3.9203779811337347`*^9, 
   3.920377989917657*^9}, {3.920378035617886*^9, 3.920378056580029*^9}, {
   3.9203781056908073`*^9, 3.920378153768824*^9}, 3.920378322960798*^9, 
   3.920655314056068*^9},
 CellLabel->
  "Out[2269]=",ExpressionUUID->"361b54b8-18b0-46fa-b89d-9a40eb4cfa5e"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Derivative matrix form", "Section",
 CellChangeTimes->{{3.9208980081920233`*^9, 
  3.920898015569983*^9}},ExpressionUUID->"bd672f69-9d0f-43e5-b3a4-\
e6e924216450"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"Clear", "[", "mu", "]"}], "\[IndentingNewLine]", 
 RowBox[{"muvec", "=", 
  RowBox[{"Transpose", "[", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"mu", "[", "1", "]"}], ",", 
      RowBox[{"mu", "[", "2", "]"}], ",", 
      RowBox[{"mu", "[", "3", "]"}]}], "}"}], "}"}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Tmat", "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"D", "[", 
         RowBox[{
          FractionBox["1", 
           RowBox[{"Sqrt", "[", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                RowBox[{"xA", "[", "1", "]"}], "-", 
                RowBox[{"xB", "[", "1", "]"}]}], ")"}], "2"], "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                RowBox[{"xA", "[", "2", "]"}], "-", 
                RowBox[{"xB", "[", "2", "]"}]}], ")"}], "2"], "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                RowBox[{"xA", "[", "3", "]"}], "-", 
                RowBox[{"xB", "[", "3", "]"}]}], ")"}], "2"]}], "]"}]], ",", 
          RowBox[{"xA", "[", "i", "]"}], ",", 
          RowBox[{"xB", "[", "j", "]"}]}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "3"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"j", ",", "3"}], "}"}]}], "]"}], "/.", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"xA", "[", "1", "]"}], "-", 
             RowBox[{"xB", "[", "1", "]"}]}], ")"}], "2"], "+", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"xA", "[", "2", "]"}], "-", 
             RowBox[{"xB", "[", "2", "]"}]}], ")"}], "2"], "+", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"xA", "[", "3", "]"}], "-", 
             RowBox[{"xB", "[", "3", "]"}]}], ")"}], "2"]}], "->", 
         SuperscriptBox["r", "2"]}], ",", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"xA", "[", "i_", "]"}], "-", 
           RowBox[{"xB", "[", "i_", "]"}]}], ")"}], ":>", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"x", ",", "y", ",", "z"}], "}"}], "[", 
          RowBox[{"[", "i", "]"}], "]"}]}]}], "}"}]}], ",", 
     RowBox[{"Assumptions", "->", 
      RowBox[{"r", ">", "0"}]}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Tmat", "//", "MatrixForm"}], "\[IndentingNewLine]", 
 RowBox[{"Emu", "=", 
  RowBox[{
   RowBox[{"Tmat", ".", "muvec"}], "//", "Simplify"}]}]}], "Input",
 CellChangeTimes->{{3.920895750027347*^9, 3.920895908680448*^9}, {
  3.920895974067596*^9, 3.920896041170952*^9}, {3.920897344718766*^9, 
  3.9208973499287243`*^9}, {3.920898053020582*^9, 3.9208981827219954`*^9}, {
  3.920898220069048*^9, 3.920898401444973*^9}},
 CellLabel->
  "In[2668]:=",ExpressionUUID->"1adc474a-5ddb-4c81-99d9-742ec6e3e8ab"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"mu", "[", "1", "]"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"mu", "[", "2", "]"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"mu", "[", "3", "]"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.9208958227161427`*^9, 3.9208958437348433`*^9}, {
   3.920895894880958*^9, 3.920895909082008*^9}, 3.920895987090885*^9, {
   3.9208960234982367`*^9, 3.920896041603451*^9}, 3.92089735226898*^9, {
   3.9208981253441*^9, 3.920898183523733*^9}, {3.920898263738268*^9, 
   3.920898332676312*^9}, 3.9208983635982428`*^9, {3.920898395117281*^9, 
   3.920898402036179*^9}},
 CellLabel->
  "Out[2669]=",ExpressionUUID->"d2197921-464c-4c52-920b-d3c7d12f449f"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      FractionBox[
       RowBox[{
        SuperscriptBox["r", "2"], "-", 
        RowBox[{"3", " ", 
         SuperscriptBox["x", "2"]}]}], 
       SuperscriptBox["r", "5"]], 
      RowBox[{"-", 
       FractionBox[
        RowBox[{"3", " ", "x", " ", "y"}], 
        SuperscriptBox["r", "5"]]}], 
      RowBox[{"-", 
       FractionBox[
        RowBox[{"3", " ", "x", " ", "z"}], 
        SuperscriptBox["r", "5"]]}]},
     {
      RowBox[{"-", 
       FractionBox[
        RowBox[{"3", " ", "x", " ", "y"}], 
        SuperscriptBox["r", "5"]]}], 
      FractionBox[
       RowBox[{
        SuperscriptBox["r", "2"], "-", 
        RowBox[{"3", " ", 
         SuperscriptBox["y", "2"]}]}], 
       SuperscriptBox["r", "5"]], 
      RowBox[{"-", 
       FractionBox[
        RowBox[{"3", " ", "y", " ", "z"}], 
        SuperscriptBox["r", "5"]]}]},
     {
      RowBox[{"-", 
       FractionBox[
        RowBox[{"3", " ", "x", " ", "z"}], 
        SuperscriptBox["r", "5"]]}], 
      RowBox[{"-", 
       FractionBox[
        RowBox[{"3", " ", "y", " ", "z"}], 
        SuperscriptBox["r", "5"]]}], 
      FractionBox[
       RowBox[{
        SuperscriptBox["r", "2"], "-", 
        RowBox[{"3", " ", 
         SuperscriptBox["z", "2"]}]}], 
       SuperscriptBox["r", "5"]]}
    },
    GridBoxAlignment->{"Columns" -> {{Center}}, "Rows" -> {{Baseline}}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{{3.9208958227161427`*^9, 3.9208958437348433`*^9}, {
   3.920895894880958*^9, 3.920895909082008*^9}, 3.920895987090885*^9, {
   3.9208960234982367`*^9, 3.920896041603451*^9}, 3.92089735226898*^9, {
   3.9208981253441*^9, 3.920898183523733*^9}, {3.920898263738268*^9, 
   3.920898332676312*^9}, 3.9208983635982428`*^9, {3.920898395117281*^9, 
   3.920898402102748*^9}},
 CellLabel->
  "Out[2671]//MatrixForm=",ExpressionUUID->"101ef5b0-d735-471c-8e40-\
3822486cb8b1"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    FractionBox[
     RowBox[{
      RowBox[{
       SuperscriptBox["r", "2"], " ", 
       RowBox[{"mu", "[", "1", "]"}]}], "-", 
      RowBox[{"3", " ", "x", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"x", " ", 
          RowBox[{"mu", "[", "1", "]"}]}], "+", 
         RowBox[{"y", " ", 
          RowBox[{"mu", "[", "2", "]"}]}], "+", 
         RowBox[{"z", " ", 
          RowBox[{"mu", "[", "3", "]"}]}]}], ")"}]}]}], 
     SuperscriptBox["r", "5"]], "}"}], ",", 
   RowBox[{"{", 
    FractionBox[
     RowBox[{
      RowBox[{
       RowBox[{"-", "3"}], " ", "x", " ", "y", " ", 
       RowBox[{"mu", "[", "1", "]"}]}], "+", 
      RowBox[{
       SuperscriptBox["r", "2"], " ", 
       RowBox[{"mu", "[", "2", "]"}]}], "-", 
      RowBox[{"3", " ", "y", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"y", " ", 
          RowBox[{"mu", "[", "2", "]"}]}], "+", 
         RowBox[{"z", " ", 
          RowBox[{"mu", "[", "3", "]"}]}]}], ")"}]}]}], 
     SuperscriptBox["r", "5"]], "}"}], ",", 
   RowBox[{"{", 
    FractionBox[
     RowBox[{
      RowBox[{
       RowBox[{"-", "3"}], " ", "x", " ", "z", " ", 
       RowBox[{"mu", "[", "1", "]"}]}], "-", 
      RowBox[{"3", " ", "y", " ", "z", " ", 
       RowBox[{"mu", "[", "2", "]"}]}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["r", "2"], "-", 
         RowBox[{"3", " ", 
          SuperscriptBox["z", "2"]}]}], ")"}], " ", 
       RowBox[{"mu", "[", "3", "]"}]}]}], 
     SuperscriptBox["r", "5"]], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.9208958227161427`*^9, 3.9208958437348433`*^9}, {
   3.920895894880958*^9, 3.920895909082008*^9}, 3.920895987090885*^9, {
   3.9208960234982367`*^9, 3.920896041603451*^9}, 3.92089735226898*^9, {
   3.9208981253441*^9, 3.920898183523733*^9}, {3.920898263738268*^9, 
   3.920898332676312*^9}, 3.9208983635982428`*^9, {3.920898395117281*^9, 
   3.920898402157772*^9}},
 CellLabel->
  "Out[2672]=",ExpressionUUID->"2b436adb-1acd-4388-90d0-f48e5c0021ff"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Tmat", "//", "TeXForm"}]], "Input",
 CellChangeTimes->{{3.920898669599967*^9, 3.920898678280302*^9}},
 CellLabel->
  "In[2673]:=",ExpressionUUID->"a902b970-3078-407a-ad5f-93e62d1e6011"],

Cell["\<\
\\left(
\\begin{array}{ccc}
 \\frac{r^2-3 x^2}{r^5} & -\\frac{3 x y}{r^5} & -\\frac{3 x z}{r^5} \\\\
 -\\frac{3 x y}{r^5} & \\frac{r^2-3 y^2}{r^5} & -\\frac{3 y z}{r^5} \\\\
 -\\frac{3 x z}{r^5} & -\\frac{3 y z}{r^5} & \\frac{r^2-3 z^2}{r^5} \\\\
\\end{array}
\\right)\
\>", "Output",
 CellChangeTimes->{3.920898679290553*^9},
 CellLabel->
  "Out[2673]//TeXForm=",ExpressionUUID->"4d717be9-7621-4c05-8bc8-\
04137962a2f2"]
}, Open  ]],

Cell["Show consistency with r dot mu formula", "Text",
 CellChangeTimes->{{3.9210093151042147`*^9, 
  3.921009324719617*^9}},ExpressionUUID->"2420005a-9fbf-4f9a-bdad-\
92ca571037b3"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"3", " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"Transpose", "[", "muvec", "]"}], ".", "rvec"}], ")"}], "[", 
       
       RowBox[{"[", "1", "]"}], "]"}], 
      RowBox[{"Transpose", "[", "rvec", "]"}]}], " ", "-", " ", 
     RowBox[{
      SuperscriptBox["r", "2"], 
      RowBox[{"Transpose", "[", "muvec", "]"}]}]}], "//", "Simplify"}], "//", 
   "Transpose"}], "//", "MatrixForm"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"%", "-", 
   RowBox[{"form1", " ", 
    SuperscriptBox["r", "5"]}]}], "//", "Simplify"}]}], "Input",
 CellChangeTimes->{{3.9208971987654467`*^9, 3.9208973217633057`*^9}, {
  3.920897361325004*^9, 3.920897394342456*^9}},
 CellLabel->
  "In[2603]:=",ExpressionUUID->"abdb4ee5-9e3e-4a83-b5f7-5512fa95b227"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["r", "2"]}], " ", 
        RowBox[{"mu", "[", "1", "]"}]}], "+", 
       RowBox[{"3", " ", 
        RowBox[{"x", "[", "1", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"mu", "[", "1", "]"}], " ", 
           RowBox[{"x", "[", "1", "]"}]}], "+", 
          RowBox[{
           RowBox[{"mu", "[", "2", "]"}], " ", 
           RowBox[{"x", "[", "2", "]"}]}], "+", 
          RowBox[{
           RowBox[{"mu", "[", "3", "]"}], " ", 
           RowBox[{"x", "[", "3", "]"}]}]}], ")"}]}]}]},
     {
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["r", "2"]}], " ", 
        RowBox[{"mu", "[", "2", "]"}]}], "+", 
       RowBox[{"3", " ", 
        RowBox[{"x", "[", "2", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"mu", "[", "1", "]"}], " ", 
           RowBox[{"x", "[", "1", "]"}]}], "+", 
          RowBox[{
           RowBox[{"mu", "[", "2", "]"}], " ", 
           RowBox[{"x", "[", "2", "]"}]}], "+", 
          RowBox[{
           RowBox[{"mu", "[", "3", "]"}], " ", 
           RowBox[{"x", "[", "3", "]"}]}]}], ")"}]}]}]},
     {
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["r", "2"]}], " ", 
        RowBox[{"mu", "[", "3", "]"}]}], "+", 
       RowBox[{"3", " ", 
        RowBox[{"x", "[", "3", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"mu", "[", "1", "]"}], " ", 
           RowBox[{"x", "[", "1", "]"}]}], "+", 
          RowBox[{
           RowBox[{"mu", "[", "2", "]"}], " ", 
           RowBox[{"x", "[", "2", "]"}]}], "+", 
          RowBox[{
           RowBox[{"mu", "[", "3", "]"}], " ", 
           RowBox[{"x", "[", "3", "]"}]}]}], ")"}]}]}]}
    },
    GridBoxAlignment->{"Columns" -> {{Center}}, "Rows" -> {{Baseline}}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{{3.920897238978018*^9, 3.920897326750142*^9}, {
  3.920897366157784*^9, 3.920897394948949*^9}},
 CellLabel->
  "Out[2603]//MatrixForm=",ExpressionUUID->"f38fbee4-6137-40aa-85d4-\
9fd2e2a31629"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", "0", "}"}], ",", 
   RowBox[{"{", "0", "}"}], ",", 
   RowBox[{"{", "0", "}"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.920897238978018*^9, 3.920897326750142*^9}, {
  3.920897366157784*^9, 3.920897394952075*^9}},
 CellLabel->
  "Out[2604]=",ExpressionUUID->"11522e6d-eb84-4f09-862e-50c31086047e"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"vars", "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"xA", "[", "1", "]"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"xA", "[", "2", "]"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"xA", "[", "3", "]"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"xA", "[", "1", "]"}], ",", 
      RowBox[{"xA", "[", "1", "]"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"xA", "[", "1", "]"}], ",", 
      RowBox[{"xA", "[", "2", "]"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"xA", "[", "1", "]"}], ",", 
      RowBox[{"xA", "[", "3", "]"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"xA", "[", "1", "]"}], ",", 
      RowBox[{"xA", "[", "2", "]"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"xA", "[", "2", "]"}], ",", 
      RowBox[{"xA", "[", "2", "]"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"xA", "[", "2", "]"}], ",", 
      RowBox[{"xA", "[", "3", "]"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"xA", "[", "1", "]"}], ",", 
      RowBox[{"xA", "[", "3", "]"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"xA", "[", "2", "]"}], ",", 
      RowBox[{"xA", "[", "3", "]"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"xA", "[", "3", "]"}], ",", 
      RowBox[{"xA", "[", "3", "]"}]}], "}"}]}], 
   "}"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"T1mat", "=", 
   RowBox[{
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"D", "[", 
       RowBox[{
        FractionBox["1", 
         RowBox[{"Sqrt", "[", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"xA", "[", "1", "]"}], "-", 
              RowBox[{"xB", "[", "1", "]"}]}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"xA", "[", "2", "]"}], "-", 
              RowBox[{"xB", "[", "2", "]"}]}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"xA", "[", "3", "]"}], "-", 
              RowBox[{"xB", "[", "3", "]"}]}], ")"}], "2"]}], "]"}]], ",", 
        RowBox[{"Sequence", "@@", "X"}]}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"X", ",", "vars"}], "}"}]}], "]"}], "//", "Simplify"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"T1mat", "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{
     RowBox[{"T1mat", "/.", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"xA", "[", "1", "]"}], "-", 
             RowBox[{"xB", "[", "1", "]"}]}], ")"}], "2"], "+", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"xA", "[", "2", "]"}], "-", 
             RowBox[{"xB", "[", "2", "]"}]}], ")"}], "2"], "+", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"xA", "[", "3", "]"}], "-", 
             RowBox[{"xB", "[", "3", "]"}]}], ")"}], "2"]}], "->", 
         SuperscriptBox["r", "2"]}], ",", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"xA", "[", "i_", "]"}], "-", 
           RowBox[{"xB", "[", "i_", "]"}]}], ")"}], ":>", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"x", ",", "y", ",", "z"}], "}"}], "[", 
          RowBox[{"[", "i", "]"}], "]"}]}], ",", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            RowBox[{"xA", "[", "i_", "]"}]}], "+", 
           RowBox[{"xB", "[", "i_", "]"}]}], ")"}], ":>", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "x"}], ",", 
            RowBox[{"-", "y"}], ",", 
            RowBox[{"-", "z"}]}], "}"}], "[", 
          RowBox[{"[", "i", "]"}], "]"}]}]}], "}"}]}], ",", 
     RowBox[{"Assumptions", "->", 
      RowBox[{"r", ">", "0"}]}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"T1mat", "//", "MatrixForm"}], "\[IndentingNewLine]", 
 RowBox[{"T1mat", "//", "TeXForm"}]}], "Input",
 CellChangeTimes->{{3.920904964520401*^9, 3.920905024378893*^9}, 
   3.920908191438095*^9, {3.920908377817162*^9, 3.920908385156653*^9}, {
   3.92090842823836*^9, 3.920908428788381*^9}, {3.920908505735702*^9, 
   3.920908559480626*^9}, {3.92090859108829*^9, 3.9209086636925898`*^9}, {
   3.920908812423571*^9, 3.920908820424102*^9}, {3.920908907050592*^9, 
   3.920908917977489*^9}, {3.9209090283980913`*^9, 3.920909061541255*^9}, {
   3.920909555097918*^9, 3.920909562904957*^9}, {3.920909656585804*^9, 
   3.920909667649062*^9}},
 CellLabel->
  "In[2741]:=",ExpressionUUID->"3c847abd-06b8-436a-b2e2-407eb21107c5"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"xA", "[", "1", "]"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"xA", "[", "2", "]"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"xA", "[", "3", "]"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"xA", "[", "1", "]"}], ",", 
     RowBox[{"xA", "[", "1", "]"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"xA", "[", "1", "]"}], ",", 
     RowBox[{"xA", "[", "2", "]"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"xA", "[", "1", "]"}], ",", 
     RowBox[{"xA", "[", "3", "]"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"xA", "[", "1", "]"}], ",", 
     RowBox[{"xA", "[", "2", "]"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"xA", "[", "2", "]"}], ",", 
     RowBox[{"xA", "[", "2", "]"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"xA", "[", "2", "]"}], ",", 
     RowBox[{"xA", "[", "3", "]"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"xA", "[", "1", "]"}], ",", 
     RowBox[{"xA", "[", "3", "]"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"xA", "[", "2", "]"}], ",", 
     RowBox[{"xA", "[", "3", "]"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"xA", "[", "3", "]"}], ",", 
     RowBox[{"xA", "[", "3", "]"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.920904997334161*^9, 3.920905024945621*^9}, 
   3.920908386599069*^9, 3.92090842958162*^9, 3.920908630414617*^9, 
   3.9209086652080307`*^9, 3.920908821998398*^9, {3.9209089103966846`*^9, 
   3.9209089183619013`*^9}, {3.920909019355465*^9, 3.920909063218821*^9}, 
   3.920909563455673*^9, 3.920909668509289*^9},
 CellLabel->
  "Out[2741]=",ExpressionUUID->"8033292e-0471-44ba-bac7-260a88c6c1fd"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", 
   TagBox[GridBox[{
      {
       FractionBox["1", "r"]},
      {
       RowBox[{"-", 
        FractionBox["x", 
         SuperscriptBox["r", "3"]]}]},
      {
       RowBox[{"-", 
        FractionBox["y", 
         SuperscriptBox["r", "3"]]}]},
      {
       RowBox[{"-", 
        FractionBox["z", 
         SuperscriptBox["r", "3"]]}]},
      {
       RowBox[{"-", 
        FractionBox[
         RowBox[{
          RowBox[{
           RowBox[{"-", "2"}], " ", 
           SuperscriptBox["x", "2"]}], "+", 
          SuperscriptBox["y", "2"], "+", 
          SuperscriptBox["z", "2"]}], 
         SuperscriptBox["r", "5"]]}]},
      {
       FractionBox[
        RowBox[{"3", " ", "x", " ", "y"}], 
        SuperscriptBox["r", "5"]]},
      {
       FractionBox[
        RowBox[{"3", " ", "x", " ", "z"}], 
        SuperscriptBox["r", "5"]]},
      {
       FractionBox[
        RowBox[{"3", " ", "x", " ", "y"}], 
        SuperscriptBox["r", "5"]]},
      {
       RowBox[{"-", 
        FractionBox[
         RowBox[{
          SuperscriptBox["x", "2"], "-", 
          RowBox[{"2", " ", 
           SuperscriptBox["y", "2"]}], "+", 
          SuperscriptBox["z", "2"]}], 
         SuperscriptBox["r", "5"]]}]},
      {
       FractionBox[
        RowBox[{"3", " ", "y", " ", "z"}], 
        SuperscriptBox["r", "5"]]},
      {
       FractionBox[
        RowBox[{"3", " ", "x", " ", "z"}], 
        SuperscriptBox["r", "5"]]},
      {
       FractionBox[
        RowBox[{"3", " ", "y", " ", "z"}], 
        SuperscriptBox["r", "5"]]},
      {
       RowBox[{"-", 
        FractionBox[
         RowBox[{
          SuperscriptBox["x", "2"], "+", 
          SuperscriptBox["y", "2"], "-", 
          RowBox[{"2", " ", 
           SuperscriptBox["z", "2"]}]}], 
         SuperscriptBox["r", "5"]]}]}
     },
     GridBoxAlignment->{"Columns" -> {{Center}}, "Rows" -> {{Baseline}}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[0.5599999999999999]}, 
         Offset[0.27999999999999997`]}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}}],
    Column], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{{3.920904997334161*^9, 3.920905024945621*^9}, 
   3.920908386599069*^9, 3.92090842958162*^9, 3.920908630414617*^9, 
   3.9209086652080307`*^9, 3.920908821998398*^9, {3.9209089103966846`*^9, 
   3.9209089183619013`*^9}, {3.920909019355465*^9, 3.920909063218821*^9}, 
   3.920909563455673*^9, 3.920909668568305*^9},
 CellLabel->
  "Out[2744]//MatrixForm=",ExpressionUUID->"3300bc67-28c1-4ac9-bab8-\
d6fb612490cf"],

Cell["\<\
\\left\\{\\frac{1}{r},-\\frac{x}{r^3},-\\frac{y}{r^3},-\\frac{z}{r^3},-\\frac{\
-2
   x^2+y^2+z^2}{r^5},\\frac{3 x y}{r^5},\\frac{3 x z}{r^5},\\frac{3 x \
y}{r^5},-\\frac{x^2-2
   y^2+z^2}{r^5},\\frac{3 y z}{r^5},\\frac{3 x z}{r^5},\\frac{3 y \
z}{r^5},-\\frac{x^2+y^2-2
   z^2}{r^5}\\right\\}\
\>", "Output",
 CellChangeTimes->{{3.920904997334161*^9, 3.920905024945621*^9}, 
   3.920908386599069*^9, 3.92090842958162*^9, 3.920908630414617*^9, 
   3.9209086652080307`*^9, 3.920908821998398*^9, {3.9209089103966846`*^9, 
   3.9209089183619013`*^9}, {3.920909019355465*^9, 3.920909063218821*^9}, 
   3.920909563455673*^9, 3.920909668625412*^9},
 CellLabel->
  "Out[2745]//TeXForm=",ExpressionUUID->"94442473-e654-446d-a2b4-\
a4510a8bb271"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"vars", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"xA", "[", "1", "]"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"xA", "[", "2", "]"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"xA", "[", "3", "]"}], "}"}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"T1mat", "=", 
   RowBox[{
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"D", "[", 
       RowBox[{
        FractionBox["1", 
         RowBox[{"Sqrt", "[", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"xA", "[", "1", "]"}], "-", 
              RowBox[{"xB", "[", "1", "]"}]}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"xA", "[", "2", "]"}], "-", 
              RowBox[{"xB", "[", "2", "]"}]}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"xA", "[", "3", "]"}], "-", 
              RowBox[{"xB", "[", "3", "]"}]}], ")"}], "2"]}], "]"}]], ",", 
        RowBox[{"Sequence", "@@", "X"}]}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"X", ",", "vars"}], "}"}]}], "]"}], "//", "Simplify"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Exmat", "=", 
   RowBox[{"D", "[", 
    RowBox[{"T1mat", ",", 
     RowBox[{"xB", "[", "2", "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Exmat", "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{"Exmat", "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"xA", "[", "1", "]"}], "-", 
            RowBox[{"xB", "[", "1", "]"}]}], ")"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"xA", "[", "2", "]"}], "-", 
            RowBox[{"xB", "[", "2", "]"}]}], ")"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"xA", "[", "3", "]"}], "-", 
            RowBox[{"xB", "[", "3", "]"}]}], ")"}], "2"]}], "->", 
        SuperscriptBox["r", "2"]}], ",", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"xA", "[", "i_", "]"}], "-", 
          RowBox[{"xB", "[", "i_", "]"}]}], ")"}], ":>", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"x", ",", "y", ",", "z"}], "}"}], "[", 
         RowBox[{"[", "i", "]"}], "]"}]}], ",", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"xA", "[", "i_", "]"}]}], "+", 
          RowBox[{"xB", "[", "i_", "]"}]}], ")"}], ":>", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "x"}], ",", 
           RowBox[{"-", "y"}], ",", 
           RowBox[{"-", "z"}]}], "}"}], "[", 
         RowBox[{"[", "i", "]"}], "]"}]}]}], "}"}]}], ",", 
    RowBox[{"Assumptions", "->", 
     RowBox[{"r", ">", "0"}]}]}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"Exmat", "//", "TeXForm"}], "\[IndentingNewLine]"}], "Input",
 CellChangeTimes->{{3.920918532064981*^9, 3.9209186525353403`*^9}, {
  3.920918873469584*^9, 3.920918873653632*^9}},
 CellLabel->
  "In[2771]:=",ExpressionUUID->"5e4fe1a2-51ba-4de4-9a09-0002cdee6765"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   FractionBox["y", 
    SuperscriptBox["r", "3"]], ",", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{"3", " ", "x", " ", "y"}], 
     SuperscriptBox["r", "5"]]}], ",", 
   FractionBox[
    RowBox[{
     SuperscriptBox["r", "2"], "-", 
     RowBox[{"3", " ", 
      SuperscriptBox["y", "2"]}]}], 
    SuperscriptBox["r", "5"]], ",", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{"3", " ", "y", " ", "z"}], 
     SuperscriptBox["r", "5"]]}]}], "}"}]], "Output",
 CellChangeTimes->{{3.920918548358088*^9, 3.920918553424082*^9}, {
   3.920918604782982*^9, 3.920918653214697*^9}, 3.9209188741759*^9},
 CellLabel->
  "Out[2774]=",ExpressionUUID->"7dd8d256-5b94-4c60-b6a7-3741e530a983"],

Cell["\<\
\\left\\{\\frac{y}{r^3},-\\frac{3 x y}{r^5},\\frac{r^2-3 y^2}{r^5},-\\frac{3 \
y
   z}{r^5}\\right\\}\
\>", "Output",
 CellChangeTimes->{{3.920918548358088*^9, 3.920918553424082*^9}, {
   3.920918604782982*^9, 3.920918653214697*^9}, 3.920918874236744*^9},
 CellLabel->
  "Out[2775]//TeXForm=",ExpressionUUID->"583a5608-0024-4b3b-ba4b-\
0cbba748a4ea"]
}, Open  ]]
}, Closed]]
}, Closed]]
},
WindowSize->{1406, 923},
WindowMargins->{{60, Automatic}, {0, Automatic}},
FrontEndVersion->"14.0 for Mac OS X x86 (64-bit) (December 12, 2023)",
StyleDefinitions->"Default.nb",
ExpressionUUID->"ccc720a4-4c60-422b-af89-55fc7010e2c8"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[580, 22, 162, 3, 69, "Chapter",ExpressionUUID->"0f5958a7-fc2d-421d-b6e9-4f7fb65b1ae8"],
Cell[CellGroupData[{
Cell[767, 29, 227, 4, 67, "Section",ExpressionUUID->"10e6cfc1-eb30-44e5-9003-313493f96754"],
Cell[997, 35, 164, 3, 35, "Text",ExpressionUUID->"7fd73f06-c299-411e-8ae9-a8e15f288fd1"],
Cell[1164, 40, 1023, 28, 91, "Input",ExpressionUUID->"a1e08532-6166-4bf6-9a0e-8cb7528a07d9"],
Cell[2190, 70, 442, 8, 58, "Text",ExpressionUUID->"3202917e-ea26-48c6-9349-b99149d0f2fe"],
Cell[2635, 80, 711, 19, 30, "Input",ExpressionUUID->"3d240324-f64a-4630-8ff5-b60b6a769a2c"],
Cell[3349, 101, 388, 11, 30, "Input",ExpressionUUID->"20bf5969-7ee5-405e-8d1d-ee394b11e73d"],
Cell[3740, 114, 162, 3, 35, "Text",ExpressionUUID->"5da7ad11-60be-4c88-9274-f41c0a3f168d"],
Cell[CellGroupData[{
Cell[3927, 121, 872, 23, 52, "Input",ExpressionUUID->"f86575bd-dcf8-450c-9868-888bcca57b74"],
Cell[4802, 146, 298, 5, 34, "Output",ExpressionUUID->"9e645bf0-9c2a-4616-802a-95af5838dbfb"]
}, Open  ]],
Cell[5115, 154, 170, 3, 35, "Text",ExpressionUUID->"d8925abf-bec7-49c6-86a4-d3d783ef5323"],
Cell[CellGroupData[{
Cell[5310, 161, 1870, 45, 119, "Input",ExpressionUUID->"071cf76b-b020-4cb7-a040-d0be07e6df10"],
Cell[7183, 208, 1245, 33, 56, "Output",ExpressionUUID->"c62aa57f-885c-482b-be2f-c6b5a8eb23f2"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[8477, 247, 171, 3, 53, "Section",ExpressionUUID->"aa8d7999-7444-4782-ac2f-eee1a0b736e8"],
Cell[8651, 252, 3800, 120, 212, "Input",ExpressionUUID->"07a2df1f-6ee9-43ad-a9b0-99e569867408"],
Cell[CellGroupData[{
Cell[12476, 376, 4170, 106, 178, "Input",ExpressionUUID->"4f25bcd4-25ed-49b8-963b-31bb69967540"],
Cell[16649, 484, 284673, 5282, 304, "Output",ExpressionUUID->"628a3968-dd03-457b-bf15-a6cdba65cc1f"]
}, Open  ]],
Cell[CellGroupData[{
Cell[301359, 5771, 653, 17, 30, "Input",ExpressionUUID->"0afecf0e-3ec1-42c8-9085-70cbd4660459"],
Cell[302015, 5790, 71350, 1214, 378, "Output",ExpressionUUID->"e7ec7655-4992-46d9-8487-5ef1085f3d7a"]
}, Open  ]],
Cell[CellGroupData[{
Cell[373402, 7009, 647, 17, 30, "Input",ExpressionUUID->"7323721d-3890-483b-824b-9a9dfc3a443a"],
Cell[374052, 7028, 71721, 1213, 378, "Output",ExpressionUUID->"8f35ac6f-d608-4cfb-8b21-0f66f889552e"]
}, Open  ]],
Cell[CellGroupData[{
Cell[445810, 8246, 755, 19, 30, "Input",ExpressionUUID->"83c2551b-4004-4bbf-9c81-b8ced3e211a3"],
Cell[446568, 8267, 38705, 663, 219, "Output",ExpressionUUID->"741f5f1d-f984-446c-b567-54abb6c16af7"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[485322, 8936, 158, 3, 53, "Section",ExpressionUUID->"eb6c22b7-c52f-4723-861a-054f1ab8f688"],
Cell[CellGroupData[{
Cell[485505, 8943, 787, 20, 33, "Input",ExpressionUUID->"cc585ba0-51d4-4c47-8b2b-6f6c71caf870"],
Cell[486295, 8965, 113274, 1989, 262, "Output",ExpressionUUID->"361b54b8-18b0-46fa-b89d-9a40eb4cfa5e"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[599618, 10960, 169, 3, 53, "Section",ExpressionUUID->"bd672f69-9d0f-43e5-b3a4-e6e924216450"],
Cell[CellGroupData[{
Cell[599812, 10967, 3109, 84, 170, "Input",ExpressionUUID->"1adc474a-5ddb-4c81-99d9-742ec6e3e8ab"],
Cell[602924, 11053, 719, 16, 48, "Output",ExpressionUUID->"d2197921-464c-4c52-920b-d3c7d12f449f"],
Cell[603646, 11071, 2217, 67, 119, "Output",ExpressionUUID->"101ef5b0-d735-471c-8e40-3822486cb8b1"],
Cell[605866, 11140, 2087, 59, 69, "Output",ExpressionUUID->"2b436adb-1acd-4388-90d0-f48e5c0021ff"]
}, Open  ]],
Cell[CellGroupData[{
Cell[607990, 11204, 209, 4, 30, "Input",ExpressionUUID->"a902b970-3078-407a-ad5f-93e62d1e6011"],
Cell[608202, 11210, 431, 12, 156, "Output",ExpressionUUID->"4d717be9-7621-4c05-8bc8-04137962a2f2"]
}, Open  ]],
Cell[608648, 11225, 182, 3, 35, "Text",ExpressionUUID->"2420005a-9fbf-4f9a-bdad-92ca571037b3"],
Cell[CellGroupData[{
Cell[608855, 11232, 844, 24, 52, "Input",ExpressionUUID->"abdb4ee5-9e3e-4a83-b5f7-5512fa95b227"],
Cell[609702, 11258, 2509, 75, 89, "Output",ExpressionUUID->"f38fbee4-6137-40aa-85d4-9fd2e2a31629"],
Cell[612214, 11335, 354, 9, 34, "Output",ExpressionUUID->"11522e6d-eb84-4f09-862e-50c31086047e"]
}, Open  ]],
Cell[CellGroupData[{
Cell[612605, 11349, 4827, 137, 188, "Input",ExpressionUUID->"3c847abd-06b8-436a-b2e2-407eb21107c5"],
Cell[617435, 11488, 1801, 52, 70, "Output",ExpressionUUID->"8033292e-0471-44ba-bac7-260a88c6c1fd"],
Cell[619239, 11542, 2709, 89, 381, "Output",ExpressionUUID->"3300bc67-28c1-4ac9-bab8-d6fb612490cf"],
Cell[621951, 11633, 747, 16, 102, "Output",ExpressionUUID->"94442473-e654-446d-a2b4-a4510a8bb271"]
}, Open  ]],
Cell[CellGroupData[{
Cell[622735, 11654, 3351, 99, 188, "Input",ExpressionUUID->"5e4fe1a2-51ba-4de4-9a09-0002cdee6765"],
Cell[626089, 11755, 725, 22, 68, "Output",ExpressionUUID->"7dd8d256-5b94-4c60-b6a7-3741e530a983"],
Cell[626817, 11779, 360, 9, 66, "Output",ExpressionUUID->"583a5608-0024-4b3b-ba4b-0cbba748a4ea"]
}, Open  ]]
}, Closed]]
}, Closed]]
}
]
*)

